# 1 "<built-in>"
# 1 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
//===- SourceManager.cpp - Track and cache source files -------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
//  This file implements the SourceManager interface.
//
//===----------------------------------------------------------------------===//

#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/SourceManager.h"
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h" 1
//===- SourceManager.h - Track and cache source files -----------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
/// \file
/// Defines the SourceManager interface.
///
/// There are three different types of locations in a %file: a spelling
/// location, an expansion location, and a presumed location.
///
/// Given an example of:
/// \code
/// #define min(x, y) x < y ? x : y
/// \endcode
///
/// and then later on a use of min:
/// \code
/// #line 17
/// return min(a, b);
/// \endcode
///
/// The expansion location is the line in the source code where the macro
/// was expanded (the return statement), the spelling location is the
/// location in the source where the macro was originally defined,
/// and the presumed location is where the line directive states that
/// the line is 17, or any other line.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_SOURCEMANAGER_H
#define LLVM_CLANG_BASIC_SOURCEMANAGER_H

#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/Diagnostic.h"
#endif /* expanded by -frewrite-includes */
# 37 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 1
//===- Diagnostic.h - C Language Family Diagnostic Handling -----*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
/// \file
/// Defines the Diagnostic-related interfaces.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_DIAGNOSTIC_H
#define LLVM_CLANG_BASIC_DIAGNOSTIC_H

#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/DiagnosticIDs.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h" 1
//===--- DiagnosticIDs.h - Diagnostic IDs Handling --------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
///
/// \file
/// Defines the Diagnostic IDs-related interfaces.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_DIAGNOSTICIDS_H
#define LLVM_CLANG_BASIC_DIAGNOSTICIDS_H

#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/LLVM.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/LLVM.h" 1
//===--- LLVM.h - Import various common LLVM datatypes ----------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
/// \file
/// Forward-declares and imports various common LLVM datatypes that
/// clang wants to use unqualified.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_LLVM_H
#define LLVM_CLANG_BASIC_LLVM_H

// Do not proliferate #includes here, require clients to #include their
// dependencies.
// Casting.h has complex templates that cannot be easily forward declared.
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Casting.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/LLVM.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h" 1
//===- llvm/Support/Casting.h - Allow flexible, checked, casts --*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the isa<X>(), cast<X>(), dyn_cast<X>(), cast_or_null<X>(),
// and dyn_cast_or_null<X>() templates.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_CASTING_H
#define LLVM_SUPPORT_CASTING_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h" 1
//===-- llvm/Support/Compiler.h - Compiler abstraction support --*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines several macros, based on the current compiler.  This allows
// use of compiler-specific features in a way that remains portable. This header
// can be included from either C or C++.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_COMPILER_H
#define LLVM_SUPPORT_COMPILER_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Config/llvm-config.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# 1 "include/llvm/Config/llvm-config.h" 1
/*===------- llvm/Config/llvm-config.h - llvm configuration -------*- C -*-===*/
/*                                                                            */
/* Part of the LLVM Project, under the Apache License v2.0 with LLVM          */
/* Exceptions.                                                                */
/* See https://llvm.org/LICENSE.txt for license information.                  */
/* SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception                    */
/*                                                                            */
/*===----------------------------------------------------------------------===*/

/* This file enumerates variables from the LLVM configuration so that they
   can be in exported headers and won't override package specific directives.
   This is a C header that can be included in the llvm-c headers. */

#ifndef LLVM_CONFIG_H
#define LLVM_CONFIG_H

/* Define if LLVM_ENABLE_DUMP is enabled */
/* #undef LLVM_ENABLE_DUMP */

/* Target triple LLVM will generate code for by default */
#define LLVM_DEFAULT_TARGET_TRIPLE "x86_64-apple-darwin18.6.0"

/* Define if threads enabled */
#define LLVM_ENABLE_THREADS 1

/* Has gcc/MSVC atomic intrinsics */
#define LLVM_HAS_ATOMICS 1

/* Host triple LLVM will be executed on */
#define LLVM_HOST_TRIPLE "x86_64-apple-darwin18.6.0"

/* LLVM architecture name for the native architecture, if available */
#define LLVM_NATIVE_ARCH X86

/* LLVM name for the native AsmParser init function, if available */
#define LLVM_NATIVE_ASMPARSER LLVMInitializeX86AsmParser

/* LLVM name for the native AsmPrinter init function, if available */
#define LLVM_NATIVE_ASMPRINTER LLVMInitializeX86AsmPrinter

/* LLVM name for the native Disassembler init function, if available */
#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeX86Disassembler

/* LLVM name for the native Target init function, if available */
#define LLVM_NATIVE_TARGET LLVMInitializeX86Target

/* LLVM name for the native TargetInfo init function, if available */
#define LLVM_NATIVE_TARGETINFO LLVMInitializeX86TargetInfo

/* LLVM name for the native target MC init function, if available */
#define LLVM_NATIVE_TARGETMC LLVMInitializeX86TargetMC

/* Define if this is Unixish platform */
#define LLVM_ON_UNIX 1

/* Define if we have the Intel JIT API runtime support library */
#define LLVM_USE_INTEL_JITEVENTS 0

/* Define if we have the oprofile JIT-support library */
#define LLVM_USE_OPROFILE 0

/* Define if we have the perf JIT-support library */
#define LLVM_USE_PERF 0

/* Major version of the LLVM API */
#define LLVM_VERSION_MAJOR 11

/* Minor version of the LLVM API */
#define LLVM_VERSION_MINOR 0

/* Patch version of the LLVM API */
#define LLVM_VERSION_PATCH 0

/* LLVM version string */
#define LLVM_VERSION_STRING "11.0.0git"

/* Whether LLVM records statistics for use with GetStatistics(),
 * PrintStatistics() or PrintStatisticsJSON()
 */
#define LLVM_FORCE_ENABLE_STATS 0

#endif
# 83 "include/llvm/Config/llvm-config.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h" 2

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 1 3
// -*- C++ -*-
//===----------------------------- new ------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_NEW
#define _LIBCPP_NEW

/*
    new synopsis

namespace std
{

class bad_alloc
    : public exception
{
public:
    bad_alloc() noexcept;
    bad_alloc(const bad_alloc&) noexcept;
    bad_alloc& operator=(const bad_alloc&) noexcept;
    virtual const char* what() const noexcept;
};

class bad_array_new_length : public bad_alloc // C++14
{
public:
    bad_array_new_length() noexcept;
};

enum class align_val_t : size_t {}; // C++17

struct destroying_delete_t { // C++20
  explicit destroying_delete_t() = default;
};
inline constexpr destroying_delete_t destroying_delete{}; // C++20

struct nothrow_t { explicit nothrow_t() = default; };
extern const nothrow_t nothrow;
typedef void (*new_handler)();
new_handler set_new_handler(new_handler new_p) noexcept;
new_handler get_new_handler() noexcept;

// 21.6.4, pointer optimization barrier
template <class T> constexpr T* launder(T* p) noexcept; // C++17
}  // std

void* operator new(std::size_t size);                                   // replaceable, nodiscard in C++2a
void* operator new(std::size_t size, std::align_val_t alignment);       // replaceable, C++17, nodiscard in C++2a
void* operator new(std::size_t size, const std::nothrow_t&) noexcept;   // replaceable, nodiscard in C++2a
void* operator new(std::size_t size, std::align_val_t alignment,
                   const std::nothrow_t&) noexcept;                     // replaceable, C++17, nodiscard in C++2a
void  operator delete(void* ptr) noexcept;                              // replaceable
void  operator delete(void* ptr, std::size_t size) noexcept;            // replaceable, C++14
void  operator delete(void* ptr, std::align_val_t alignment) noexcept;  // replaceable, C++17
void  operator delete(void* ptr, std::size_t size,
                      std::align_val_t alignment) noexcept;             // replaceable, C++17
void  operator delete(void* ptr, const std::nothrow_t&) noexcept;       // replaceable
void  operator delete(void* ptr, std:align_val_t alignment,
                      const std::nothrow_t&) noexcept;                  // replaceable, C++17

void* operator new[](std::size_t size);                                 // replaceable, nodiscard in C++2a
void* operator new[](std::size_t size,
                     std::align_val_t alignment) noexcept;              // replaceable, C++17, nodiscard in C++2a
void* operator new[](std::size_t size, const std::nothrow_t&) noexcept; // replaceable, nodiscard in C++2a
void* operator new[](std::size_t size, std::align_val_t alignment,
                     const std::nothrow_t&) noexcept;                   // replaceable, C++17, nodiscard in C++2a
void  operator delete[](void* ptr) noexcept;                            // replaceable
void  operator delete[](void* ptr, std::size_t size) noexcept;          // replaceable, C++14
void  operator delete[](void* ptr,
                        std::align_val_t alignment) noexcept;           // replaceable, C++17
void  operator delete[](void* ptr, std::size_t size,
                        std::align_val_t alignment) noexcept;           // replaceable, C++17
void  operator delete[](void* ptr, const std::nothrow_t&) noexcept;     // replaceable
void  operator delete[](void* ptr, std::align_val_t alignment,
                        const std::nothrow_t&) noexcept;                // replaceable, C++17

void* operator new  (std::size_t size, void* ptr) noexcept;             // nodiscard in C++2a
void* operator new[](std::size_t size, void* ptr) noexcept;             // nodiscard in C++2a
void  operator delete  (void* ptr, void*) noexcept;
void  operator delete[](void* ptr, void*) noexcept;

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 89 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 1 3
// -*- C++ -*-
//===--------------------------- __config ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CONFIG
#define _LIBCPP_CONFIG

#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER) && !defined(__clang__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER
#  endif
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __cplusplus

#ifdef __GNUC__
#  define _GNUC_VER (__GNUC__ * 100 + __GNUC_MINOR__)
// The _GNUC_VER_NEW macro better represents the new GCC versioning scheme
// introduced in GCC 5.0.
#  define _GNUC_VER_NEW (_GNUC_VER * 10 + __GNUC_PATCHLEVEL__)
#else
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _GNUC_VER 0
#  define _GNUC_VER_NEW 0
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_VERSION 11000

#ifndef _LIBCPP_ABI_VERSION
#  define _LIBCPP_ABI_VERSION 1
#endif
# 40 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef __STDC_HOSTED__
#  define _LIBCPP_FREESTANDING
#endif
# 44 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_STD_VER
#if 0 /* disabled by -frewrite-includes */
#  if  __cplusplus <= 201103L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 47 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_STD_VER 11
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif __cplusplus <= 201402L
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 49 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_STD_VER 14
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif __cplusplus <= 201703L
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 51 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_STD_VER 17
#  else
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_STD_VER 18  // current year, or date of c++2a ratification
#  endif
# 55 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif  // _LIBCPP_STD_VER
# 56 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__ELF__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_OBJECT_FORMAT_ELF   1
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__MACH__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_OBJECT_FORMAT_MACHO 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_OBJECT_FORMAT_COFF  1
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__wasm__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 64 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_OBJECT_FORMAT_WASM  1
#else
# 66 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  error Unknown object file format
#endif
# 68 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_UNSTABLE) || _LIBCPP_ABI_VERSION >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 70 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// Change short string representation so that string data starts at offset 0,
// improving its alignment in some cases.
#  define _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT
// Fix deque iterator type in order to support incomplete types.
#  define _LIBCPP_ABI_INCOMPLETE_TYPES_IN_DEQUE
// Fix undefined behavior in how std::list stores its linked nodes.
#  define _LIBCPP_ABI_LIST_REMOVE_NODE_POINTER_UB
// Fix undefined behavior in  how __tree stores its end and parent nodes.
#  define _LIBCPP_ABI_TREE_REMOVE_NODE_POINTER_UB
// Fix undefined behavior in how __hash_table stores its pointer types.
#  define _LIBCPP_ABI_FIX_UNORDERED_NODE_POINTER_UB
#  define _LIBCPP_ABI_FORWARD_LIST_REMOVE_NODE_POINTER_UB
#  define _LIBCPP_ABI_FIX_UNORDERED_CONTAINER_SIZE_TYPE
// Don't use a nullptr_t simulation type in C++03 instead using C++11 nullptr
// provided under the alternate keyword __nullptr, which changes the mangling
// of nullptr_t. This option is ABI incompatible with GCC in C++03 mode.
#  define _LIBCPP_ABI_ALWAYS_USE_CXX11_NULLPTR
// Define the `pointer_safety` enum as a C++11 strongly typed enumeration
// instead of as a class simulating an enum. If this option is enabled
// `pointer_safety` and `get_pointer_safety()` will no longer be available
// in C++03.
#  define _LIBCPP_ABI_POINTER_SAFETY_ENUM_TYPE
// Define a key function for `bad_function_call` in the library, to centralize
// its vtable and typeinfo to libc++ rather than having all other libraries
// using that class define their own copies.
#  define _LIBCPP_ABI_BAD_FUNCTION_CALL_KEY_FUNCTION
// Enable optimized version of __do_get_(un)signed which avoids redundant copies.
#  define _LIBCPP_ABI_OPTIMIZED_LOCALE_NUM_GET
// Use the smallest possible integer type to represent the index of the variant.
// Previously libc++ used "unsigned int" exclusively.
#  define _LIBCPP_ABI_VARIANT_INDEX_TYPE_OPTIMIZATION
// Unstable attempt to provide a more optimized std::function
#  define _LIBCPP_ABI_OPTIMIZED_FUNCTION
// All the regex constants must be distinct and nonzero.
#  define _LIBCPP_ABI_REGEX_CONSTANTS_NONZERO
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _LIBCPP_ABI_VERSION == 1
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_OBJECT_FORMAT_COFF)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// Enable compiling copies of now inline methods into the dylib to support
// applications compiled against older libraries. This is unnecessary with
// COFF dllexport semantics, since dllexport forces a non-inline definition
// of inline functions to be emitted anyway. Our own non-inline copy would
// conflict with the dllexport-emitted copy, so we disable it.
#    define _LIBCPP_DEPRECATED_ABI_LEGACY_LIBRARY_DEFINITIONS_FOR_INLINE_FUNCTIONS
#  endif
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// Feature macros for disabling pre ABI v1 features. All of these options
// are deprecated.
#if 0 /* disabled by -frewrite-includes */
#  if defined(__FreeBSD__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 117 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_DEPRECATED_ABI_DISABLE_PAIR_TRIVIAL_COPY_CTOR
#  endif
# 119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_TRIVIAL_PAIR_COPY_CTOR
#error "_LIBCPP_TRIVIAL_PAIR_COPY_CTOR" is no longer supported. \
       use _LIBCPP_DEPRECATED_ABI_DISABLE_PAIR_TRIVIAL_COPY_CTOR instead
#endif
# 125 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_CONCAT1(_LIBCPP_X,_LIBCPP_Y) _LIBCPP_X##_LIBCPP_Y
#define _LIBCPP_CONCAT(_LIBCPP_X,_LIBCPP_Y) _LIBCPP_CONCAT1(_LIBCPP_X,_LIBCPP_Y)

#ifndef _LIBCPP_ABI_NAMESPACE
# define _LIBCPP_ABI_NAMESPACE _LIBCPP_CONCAT(__,_LIBCPP_ABI_VERSION)
#endif
# 132 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __cplusplus < 201103L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 134 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_CXX03_LANG
#endif
# 136 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef __has_attribute
#define __has_attribute(__x) 0
#endif
# 140 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef __has_builtin
#define __has_builtin(__x) 0
#endif
# 144 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef __has_extension
#define __has_extension(__x) 0
#endif
# 148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef __has_feature
#define __has_feature(__x) 0
#endif
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef __has_cpp_attribute
#define __has_cpp_attribute(__x) 0
#endif
# 156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// '__is_identifier' returns '0' if '__x' is a reserved identifier provided by
// the compiler and '1' otherwise.
#ifndef __is_identifier
#define __is_identifier(__x) 1
#endif
# 162 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef __has_declspec_attribute
#define __has_declspec_attribute(__x) 0
#endif
# 166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define __has_keyword(__x) !(__is_identifier(__x))

#ifndef __has_include
#define __has_include(...) 0
#endif
# 172 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__clang__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 174 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_COMPILER_CLANG
#  ifndef __apple_build_version__
#    define _LIBCPP_CLANG_VER (__clang_major__ * 100 + __clang_minor__)
#  endif
# 178 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 179 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_COMPILER_GCC
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_COMPILER_MSVC
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__IBMCPP__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 183 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_COMPILER_IBM
#endif
# 185 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_COMPILER_GCC) && __cplusplus < 201103L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 187 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#error "libc++ does not support using GCC with C++03. Please enable C++11"
#endif
# 189 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// FIXME: ABI detection should be done via compiler builtin macros. This
// is just a placeholder until Clang implements such macros. For now assume
// that Windows compilers pretending to be MSVC++ target the Microsoft ABI,
// and allow the user to explicitly specify the ABI to handle cases where this
// heuristic falls short.
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_FORCE_ITANIUM) && defined(_LIBCPP_ABI_FORCE_MICROSOFT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 196 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  error "Only one of _LIBCPP_ABI_FORCE_ITANIUM and _LIBCPP_ABI_FORCE_MICROSOFT can be defined"
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_ABI_FORCE_ITANIUM)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 198 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_ABI_ITANIUM
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_ABI_FORCE_MICROSOFT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 200 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_ABI_MICROSOFT
#else
# 202 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(_WIN32) && defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 203 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_ABI_MICROSOFT
#  else
# 205 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_ABI_ITANIUM
#  endif
# 207 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 208 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_MICROSOFT) && !defined(_LIBCPP_NO_VCRUNTIME)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 210 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# define _LIBCPP_ABI_VCRUNTIME
#endif
# 212 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Need to detect which libc we're using if we're on Linux.
#if 0 /* disabled by -frewrite-includes */
#if defined(__linux__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 215 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* expanded by -frewrite-includes */
#  include <features.h>
#endif /* expanded by -frewrite-includes */
# 215 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# 216 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(__GLIBC_PREREQ)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 217 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_GLIBC_PREREQ(a, b) __GLIBC_PREREQ(a, b)
#  else
# 219 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_GLIBC_PREREQ(a, b) 0
#  endif // defined(__GLIBC_PREREQ)
# 221 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // defined(__linux__)
# 222 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __LITTLE_ENDIAN__
#if 0 /* disabled by -frewrite-includes */
#  if __LITTLE_ENDIAN__
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 225 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_LITTLE_ENDIAN
#  endif  // __LITTLE_ENDIAN__
# 227 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif  // __LITTLE_ENDIAN__
# 228 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __BIG_ENDIAN__
#if 0 /* disabled by -frewrite-includes */
#  if __BIG_ENDIAN__
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 231 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_BIG_ENDIAN
#  endif  // __BIG_ENDIAN__
# 233 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif  // __BIG_ENDIAN__
# 234 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __BYTE_ORDER__
#if 0 /* disabled by -frewrite-includes */
#  if __BYTE_ORDER__ == __ORDER_LITTLE_ENDIAN__
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 237 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_LITTLE_ENDIAN
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif __BYTE_ORDER__ == __ORDER_BIG_ENDIAN__
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 239 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_BIG_ENDIAN
#  endif // __BYTE_ORDER__ == __ORDER_BIG_ENDIAN__
# 241 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // __BYTE_ORDER__
# 242 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __FreeBSD__
#if 0 /* expanded by -frewrite-includes */
#  include <sys/endian.h>
#endif /* expanded by -frewrite-includes */
# 244 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# 245 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* expanded by -frewrite-includes */
#  include <osreldate.h>
#endif /* expanded by -frewrite-includes */
# 245 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# 246 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if _BYTE_ORDER == _LITTLE_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 247 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_LITTLE_ENDIAN
#  else  // _BYTE_ORDER == _LITTLE_ENDIAN
# 249 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_BIG_ENDIAN
#  endif  // _BYTE_ORDER == _LITTLE_ENDIAN
# 251 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  ifndef __LONG_LONG_SUPPORTED
#    define _LIBCPP_HAS_NO_LONG_LONG
#  endif  // __LONG_LONG_SUPPORTED
# 254 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif  // __FreeBSD__
# 255 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __NetBSD__
#if 0 /* expanded by -frewrite-includes */
#  include <sys/endian.h>
#endif /* expanded by -frewrite-includes */
# 257 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# 258 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if _BYTE_ORDER == _LITTLE_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 259 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_LITTLE_ENDIAN
#  else  // _BYTE_ORDER == _LITTLE_ENDIAN
# 261 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_BIG_ENDIAN
#  endif  // _BYTE_ORDER == _LITTLE_ENDIAN
# 263 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif  // __NetBSD__
# 264 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 266 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_WIN32API
#  define _LIBCPP_LITTLE_ENDIAN
#  define _LIBCPP_SHORT_WCHAR   1
// Both MinGW and native MSVC provide a "MSVC"-like environment
#  define _LIBCPP_MSVCRT_LIKE
// If mingw not explicitly detected, assume using MS C runtime only if
// a MS compatibility version is specified.
#if 0 /* disabled by -frewrite-includes */
#  if defined(_MSC_VER) && !defined(__MINGW32__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 274 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_MSVCRT // Using Microsoft's C Runtime library
#  endif
# 276 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if (defined(_M_AMD64) || defined(__x86_64__)) || (defined(_M_ARM) || defined(__arm__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 277 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_BITSCAN64
#  endif
# 279 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_HAS_OPEN_WITH_WCHAR
#if 0 /* disabled by -frewrite-includes */
#  if defined(_LIBCPP_MSVCRT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 281 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_QUICK_EXIT
#  endif
# 283 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Some CRT APIs are unavailable to store apps
#if 0 /* disabled by -frewrite-includes */
#  if defined(WINAPI_FAMILY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 286 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* expanded by -frewrite-includes */
#    include <winapifamily.h>
#endif /* expanded by -frewrite-includes */
# 286 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# 287 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#    if !WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP) &&                  \
        (!defined(WINAPI_PARTITION_SYSTEM) ||                                  \
         !WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_SYSTEM))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 290 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_WINDOWS_STORE_APP
#    endif
# 292 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  endif
# 293 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // defined(_WIN32)
# 294 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __sun__
#if 0 /* expanded by -frewrite-includes */
#  include <sys/isa_defs.h>
#endif /* expanded by -frewrite-includes */
# 296 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# 297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  ifdef _LITTLE_ENDIAN
#    define _LIBCPP_LITTLE_ENDIAN
#  else
# 300 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_BIG_ENDIAN
#  endif
# 302 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // __sun__
# 303 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__CloudABI__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
   // Certain architectures provide arc4random(). Prefer using
   // arc4random() over /dev/{u,}random to make it possible to obtain
   // random data even when using sandboxing mechanisms such as chroots,
   // Capsicum, etc.
#  define _LIBCPP_USING_ARC4_RANDOM
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__Fuchsia__) || defined(__wasi__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 311 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_USING_GETENTROPY
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__native_client__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 313 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
   // NaCl's sandbox (which PNaCl also runs in) doesn't allow filesystem access,
   // including accesses to the special files under /dev. C++11's
   // std::random_device is instead exposed through a NaCl syscall.
#  define _LIBCPP_USING_NACL_RANDOM
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_WIN32API)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 318 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_USING_WIN32_RANDOM
#else
# 320 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_USING_DEV_RANDOM
#endif
# 322 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_LITTLE_ENDIAN) && !defined(_LIBCPP_BIG_ENDIAN)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 324 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* expanded by -frewrite-includes */
#  include <endian.h>
#endif /* expanded by -frewrite-includes */
# 324 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# 325 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if __BYTE_ORDER == __LITTLE_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 326 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_LITTLE_ENDIAN
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif __BYTE_ORDER == __BIG_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 328 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_BIG_ENDIAN
#  else  // __BYTE_ORDER == __BIG_ENDIAN
# 330 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    error unable to determine endian
#  endif
# 332 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif  // !defined(_LIBCPP_LITTLE_ENDIAN) && !defined(_LIBCPP_BIG_ENDIAN)
# 333 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(__no_sanitize__) && !defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 335 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NO_CFI __attribute__((__no_sanitize__("cfi")))
#else
# 337 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NO_CFI
#endif
# 339 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __ISO_C_VISIBLE >= 2011 || __cplusplus >= 201103L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 341 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(__FreeBSD__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 342 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_ALIGNED_ALLOC
#    define _LIBCPP_HAS_QUICK_EXIT
#    define _LIBCPP_HAS_C11_FEATURES
#if 0 /* disabled by -frewrite-includes */
#    if __FreeBSD_version >= 1300064 || \
       (__FreeBSD_version >= 1201504 && __FreeBSD_version < 1300000)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 347 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_HAS_TIMESPEC_GET
#    endif
# 349 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(__BIONIC__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 350 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_C11_FEATURES
#if 0 /* disabled by -frewrite-includes */
#    if __ANDROID_API__ >= 21
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 352 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_HAS_QUICK_EXIT
#    endif
# 354 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#    if __ANDROID_API__ >= 28
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 355 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_HAS_ALIGNED_ALLOC
#    endif
# 357 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#    if __ANDROID_API__ >= 29
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 358 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_HAS_TIMESPEC_GET
#    endif
# 360 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(__Fuchsia__) || defined(__wasi__) || defined(__NetBSD__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 361 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_ALIGNED_ALLOC
#    define _LIBCPP_HAS_QUICK_EXIT
#    define _LIBCPP_HAS_TIMESPEC_GET
#    define _LIBCPP_HAS_C11_FEATURES
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(__linux__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 366 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#    if !defined(_LIBCPP_HAS_MUSL_LIBC)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 367 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#      if _LIBCPP_GLIBC_PREREQ(2, 15) || defined(__BIONIC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 368 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#        define _LIBCPP_HAS_QUICK_EXIT
#      endif
# 370 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#      if _LIBCPP_GLIBC_PREREQ(2, 17)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 371 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#        define _LIBCPP_HAS_ALIGNED_ALLOC
#        define _LIBCPP_HAS_C11_FEATURES
#        define _LIBCPP_HAS_TIMESPEC_GET
#      endif
# 375 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    else // defined(_LIBCPP_HAS_MUSL_LIBC)
# 376 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_HAS_ALIGNED_ALLOC
#      define _LIBCPP_HAS_QUICK_EXIT
#      define _LIBCPP_HAS_TIMESPEC_GET
#      define _LIBCPP_HAS_C11_FEATURES
#    endif
# 381 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  endif // __linux__
# 382 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 383 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_CXX03_LANG
# define _LIBCPP_ALIGNOF(_Tp) alignof(_Tp)
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_COMPILER_CLANG)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 387 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# define _LIBCPP_ALIGNOF(_Tp) _Alignof(_Tp)
#else
# 389 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// This definition is potentially buggy, but it's only taken with GCC in C++03,
// which we barely support anyway. See llvm.org/PR39713
# define _LIBCPP_ALIGNOF(_Tp) __alignof(_Tp)
#endif
# 393 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_PREFERRED_ALIGNOF(_Tp) __alignof(_Tp)

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_COMPILER_CLANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 397 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// _LIBCPP_ALTERNATE_STRING_LAYOUT is an old name for
// _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT left here for backward compatibility.
#if 0 /* disabled by -frewrite-includes */
#if (defined(__APPLE__) && !defined(__i386__) && !defined(__x86_64__) &&       \
     (!defined(__arm__) || __ARM_ARCH_7K__ >= 2)) ||                           \
    defined(_LIBCPP_ALTERNATE_STRING_LAYOUT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 403 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT
#endif
# 405 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_alignas)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 407 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _ALIGNAS_TYPE(x) alignas(x)
#  define _ALIGNAS(x) alignas(x)
#else
# 410 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _ALIGNAS_TYPE(x) __attribute__((__aligned__(_LIBCPP_ALIGNOF(x))))
#  define _ALIGNAS(x) __attribute__((__aligned__(x)))
#endif
# 413 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __cplusplus < 201103L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 415 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
typedef __char16_t char16_t;
typedef __char32_t char32_t;
#endif
# 418 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_exceptions)) && !defined(_LIBCPP_NO_EXCEPTIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 420 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_NO_EXCEPTIONS
#endif
# 422 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_rtti)) && !defined(_LIBCPP_NO_RTTI)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 424 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_NO_RTTI
#endif
# 426 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_strong_enums))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 428 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_STRONG_ENUMS
#endif
# 430 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_attributes)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 432 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NORETURN [[noreturn]]
#else
# 434 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NORETURN __attribute__ ((noreturn))
#endif
# 436 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_lambdas))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 438 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_LAMBDAS
#endif
# 440 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_nullptr))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 442 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if (__has_extension(cxx_nullptr) || __has_keyword(__nullptr)) && defined(_LIBCPP_ABI_ALWAYS_USE_CXX11_NULLPTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 443 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define nullptr __nullptr
#  else
# 445 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_NO_NULLPTR
#  endif
# 447 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 448 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_rvalue_references))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 450 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_RVALUE_REFERENCES
#endif
# 452 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_auto_type))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 454 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_AUTO_TYPE
#endif
# 456 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_variadic_templates))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 458 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_VARIADICS
#endif
# 460 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Objective-C++ features (opt-in)
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(objc_arc)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 463 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_OBJC_ARC
#endif
# 465 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(objc_arc_weak)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 467 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_OBJC_ARC_WEAK
#endif
# 469 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_extension(blocks)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 471 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_HAS_EXTENSION_BLOCKS
#endif
# 473 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_relaxed_constexpr))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 475 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_CXX14_CONSTEXPR
#endif
# 477 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_variable_templates))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 479 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_VARIABLE_TEMPLATES
#endif
# 481 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !(__has_feature(cxx_noexcept))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 483 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_NOEXCEPT
#endif
# 485 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_ASAN) && !__has_feature(address_sanitizer)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 487 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_ASAN
#endif
# 489 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Allow for build-time disabling of unsigned integer sanitization
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK) && __has_attribute(no_sanitize)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 492 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK __attribute__((__no_sanitize__("unsigned-integer-overflow")))
#endif
# 494 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_launder)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 496 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_COMPILER_HAS_BUILTIN_LAUNDER
#endif
# 498 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !__is_identifier(__has_unique_object_representations)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 500 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_UNIQUE_OBJECT_REPRESENTATIONS
#endif
# 502 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_ALWAYS_INLINE __attribute__ ((__always_inline__))

// Literal operators ""d and ""y are supported starting with LLVM Clang 8 and AppleClang 10.0.1
#if 0 /* disabled by -frewrite-includes */
#if (defined(_LIBCPP_CLANG_VER) && _LIBCPP_CLANG_VER < 800) || \
    (defined(__apple_build_version__) && __apple_build_version__ < 10010000)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 508 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_CXX20_CHRONO_LITERALS
#endif
# 510 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_DISABLE_EXTENSION_WARNING __extension__

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 514 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _ALIGNAS(x) __attribute__((__aligned__(x)))
#define _ALIGNAS_TYPE(x) __attribute__((__aligned__(_LIBCPP_ALIGNOF(x))))

#define _LIBCPP_NORETURN __attribute__((noreturn))

#if 0 /* disabled by -frewrite-includes */
#if !__EXCEPTIONS && !defined(_LIBCPP_NO_EXCEPTIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 521 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_NO_EXCEPTIONS
#endif
# 523 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Determine if GCC supports relaxed constexpr
#if 0 /* disabled by -frewrite-includes */
#if !defined(__cpp_constexpr) || __cpp_constexpr < 201304L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 526 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_CXX14_CONSTEXPR
#endif
# 528 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// GCC 5 supports variable templates
#if 0 /* disabled by -frewrite-includes */
#if !defined(__cpp_variable_templates) || __cpp_variable_templates < 201304L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 531 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_VARIABLE_TEMPLATES
#endif
# 533 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_ASAN) && !defined(__SANITIZE_ADDRESS__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 535 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_ASAN
#endif
# 537 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _GNUC_VER >= 700
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 539 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_COMPILER_HAS_BUILTIN_LAUNDER
#endif
# 541 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _GNUC_VER >= 700
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 543 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_UNIQUE_OBJECT_REPRESENTATIONS
#endif
# 545 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_ALWAYS_INLINE __attribute__ ((__always_inline__))

#define _LIBCPP_DISABLE_EXTENSION_WARNING __extension__

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_COMPILER_MSVC)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 551 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_TOSTRING2(x) #x
#define _LIBCPP_TOSTRING(x) _LIBCPP_TOSTRING2(x)
#define _LIBCPP_WARNING(x) __pragma(message(__FILE__ "(" _LIBCPP_TOSTRING(__LINE__) ") : warning note: " x))

#if 0 /* disabled by -frewrite-includes */
#if _MSC_VER < 1900
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 557 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#error "MSVC versions prior to Visual Studio 2015 are not supported"
#endif
# 559 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_HAS_NO_CXX14_CONSTEXPR
#define _LIBCPP_HAS_NO_VARIABLE_TEMPLATES
#define __alignof__ __alignof
#define _LIBCPP_NORETURN __declspec(noreturn)
#define _ALIGNAS(x) __declspec(align(x))
#define _ALIGNAS_TYPE(x) alignas(x)

#define _LIBCPP_WEAK

#define _LIBCPP_HAS_NO_ASAN

#define _LIBCPP_ALWAYS_INLINE __forceinline

#define _LIBCPP_HAS_NO_VECTOR_EXTENSION

#define _LIBCPP_DISABLE_EXTENSION_WARNING

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_COMPILER_IBM)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 578 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _ALIGNAS(x) __attribute__((__aligned__(x)))
#define _ALIGNAS_TYPE(x) __attribute__((__aligned__(_LIBCPP_ALIGNOF(x))))
#define _ATTRIBUTE(x) __attribute__((x))
#define _LIBCPP_NORETURN __attribute__((noreturn))

#define _LIBCPP_HAS_NO_UNICODE_CHARS
#define _LIBCPP_HAS_NO_VARIABLE_TEMPLATES

#if 0 /* disabled by -frewrite-includes */
#if defined(_AIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 588 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define __MULTILOCALE_API
#endif
# 590 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_HAS_NO_ASAN

#define _LIBCPP_ALWAYS_INLINE __attribute__ ((__always_inline__))

#define _LIBCPP_HAS_NO_VECTOR_EXTENSION

#define _LIBCPP_DISABLE_EXTENSION_WARNING

#endif // _LIBCPP_COMPILER_[CLANG|GCC|MSVC|IBM]
# 600 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_OBJECT_FORMAT_COFF)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 602 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _DLL
#  define _LIBCPP_CRT_FUNC __declspec(dllimport)
#else
# 606 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CRT_FUNC
#endif
# 608 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 610 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DLL_VIS
#  define _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS
#  define _LIBCPP_CLASS_TEMPLATE_INSTANTIATION_VIS
#  define _LIBCPP_OVERRIDABLE_FUNC_VIS
#  define _LIBCPP_EXPORTED_FROM_ABI
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 616 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DLL_VIS __declspec(dllexport)
#if 0 /* disabled by -frewrite-includes */
#  if defined(__MINGW32__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 618 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS _LIBCPP_DLL_VIS
#    define _LIBCPP_CLASS_TEMPLATE_INSTANTIATION_VIS
#  else
# 621 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS
#    define _LIBCPP_CLASS_TEMPLATE_INSTANTIATION_VIS _LIBCPP_DLL_VIS
#  endif
# 624 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_OVERRIDABLE_FUNC_VIS _LIBCPP_DLL_VIS
#  define _LIBCPP_EXPORTED_FROM_ABI __declspec(dllexport)
#else
# 627 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DLL_VIS __declspec(dllimport)
#  define _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS _LIBCPP_DLL_VIS
#  define _LIBCPP_CLASS_TEMPLATE_INSTANTIATION_VIS
#  define _LIBCPP_OVERRIDABLE_FUNC_VIS
#  define _LIBCPP_EXPORTED_FROM_ABI __declspec(dllimport)
#endif
# 633 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_TYPE_VIS            _LIBCPP_DLL_VIS
#define _LIBCPP_FUNC_VIS            _LIBCPP_DLL_VIS
#define _LIBCPP_EXCEPTION_ABI       _LIBCPP_DLL_VIS
#define _LIBCPP_HIDDEN
#define _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
#define _LIBCPP_TEMPLATE_VIS
#define _LIBCPP_ENUM_VIS

#endif // defined(_LIBCPP_OBJECT_FORMAT_COFF)
# 643 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_HIDDEN
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 646 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HIDDEN __attribute__ ((__visibility__("hidden")))
#  else
# 648 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HIDDEN
#  endif
# 650 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 651 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 654 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// The inline should be removed once PR32114 is resolved
#    define _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS inline _LIBCPP_HIDDEN
#  else
# 657 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
#  endif
# 659 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 660 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_FUNC_VIS
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 663 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_FUNC_VIS __attribute__ ((__visibility__("default")))
#  else
# 665 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_FUNC_VIS
#  endif
# 667 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 668 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_TYPE_VIS
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 671 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_TYPE_VIS __attribute__ ((__visibility__("default")))
#  else
# 673 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_TYPE_VIS
#  endif
# 675 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 676 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_TEMPLATE_VIS
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 679 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#    if __has_attribute(__type_visibility__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 680 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_TEMPLATE_VIS __attribute__ ((__type_visibility__("default")))
#    else
# 682 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_TEMPLATE_VIS __attribute__ ((__visibility__("default")))
#    endif
# 684 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  else
# 685 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_TEMPLATE_VIS
#  endif
# 687 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 688 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_EXPORTED_FROM_ABI
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 691 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXPORTED_FROM_ABI __attribute__((__visibility__("default")))
#  else
# 693 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXPORTED_FROM_ABI
#  endif
# 695 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 696 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_OVERRIDABLE_FUNC_VIS
#define _LIBCPP_OVERRIDABLE_FUNC_VIS _LIBCPP_FUNC_VIS
#endif
# 700 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_EXCEPTION_ABI
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 703 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXCEPTION_ABI __attribute__ ((__visibility__("default")))
#  else
# 705 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXCEPTION_ABI
#  endif
# 707 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 708 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_ENUM_VIS
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS) && __has_attribute(__type_visibility__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 711 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_ENUM_VIS __attribute__ ((__type_visibility__("default")))
#  else
# 713 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_ENUM_VIS
#  endif
# 715 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 716 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_DISABLE_VISIBILITY_ANNOTATIONS) && __has_attribute(__type_visibility__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 719 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS __attribute__ ((__visibility__("default")))
#  else
# 721 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS
#  endif
# 723 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 724 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_CLASS_TEMPLATE_INSTANTIATION_VIS
#define _LIBCPP_CLASS_TEMPLATE_INSTANTIATION_VIS
#endif
# 728 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(internal_linkage)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 730 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_INTERNAL_LINKAGE __attribute__ ((internal_linkage))
#else
# 732 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_INTERNAL_LINKAGE _LIBCPP_ALWAYS_INLINE
#endif
# 734 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(exclude_from_explicit_instantiation)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 736 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_EXCLUDE_FROM_EXPLICIT_INSTANTIATION __attribute__ ((__exclude_from_explicit_instantiation__))
#else
# 738 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
   // Try to approximate the effect of exclude_from_explicit_instantiation
   // (which is that entities are not assumed to be provided by explicit
   // template instantiations in the dylib) by always inlining those entities.
#  define _LIBCPP_EXCLUDE_FROM_EXPLICIT_INSTANTIATION _LIBCPP_ALWAYS_INLINE
#endif
# 743 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_HIDE_FROM_ABI_PER_TU
#  ifndef _LIBCPP_HIDE_FROM_ABI_PER_TU_BY_DEFAULT
#    define _LIBCPP_HIDE_FROM_ABI_PER_TU 0
#  else
# 748 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HIDE_FROM_ABI_PER_TU 1
#  endif
# 750 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 751 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_HAS_MERGED_TYPEINFO_NAMES_DEFAULT
# ifdef _LIBCPP_OBJECT_FORMAT_COFF // Windows binaries can't merge typeinfos.
# define _LIBCPP_HAS_MERGED_TYPEINFO_NAMES_DEFAULT 0
#else
# 756 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// TODO: This isn't strictly correct on ELF platforms due to llvm.org/PR37398
// And we should consider defaulting to OFF.
# define _LIBCPP_HAS_MERGED_TYPEINFO_NAMES_DEFAULT 1
#endif
# 760 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 761 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_HIDE_FROM_ABI
#if 0 /* disabled by -frewrite-includes */
#  if _LIBCPP_HIDE_FROM_ABI_PER_TU
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 764 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HIDE_FROM_ABI _LIBCPP_HIDDEN _LIBCPP_INTERNAL_LINKAGE
#  else
# 766 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HIDE_FROM_ABI _LIBCPP_HIDDEN _LIBCPP_EXCLUDE_FROM_EXPLICIT_INSTANTIATION
#  endif
# 768 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 769 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_BUILDING_LIBRARY
#if 0 /* disabled by -frewrite-includes */
#  if _LIBCPP_ABI_VERSION > 1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 772 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HIDE_FROM_ABI_AFTER_V1 _LIBCPP_HIDE_FROM_ABI
#  else
# 774 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HIDE_FROM_ABI_AFTER_V1
#  endif
# 776 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#else
# 777 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_HIDE_FROM_ABI_AFTER_V1 _LIBCPP_HIDE_FROM_ABI
#endif
# 779 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Just so we can migrate to the new macros gradually.
#define _LIBCPP_INLINE_VISIBILITY _LIBCPP_HIDE_FROM_ABI

// Inline namespaces are available in Clang/GCC/MSVC regardless of C++ dialect.
#define _LIBCPP_BEGIN_NAMESPACE_STD namespace std { inline namespace _LIBCPP_ABI_NAMESPACE {
#define _LIBCPP_END_NAMESPACE_STD  } }
#define _VSTD std::_LIBCPP_ABI_NAMESPACE
_LIBCPP_BEGIN_NAMESPACE_STD _LIBCPP_END_NAMESPACE_STD

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 790 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_BEGIN_NAMESPACE_FILESYSTEM \
  _LIBCPP_BEGIN_NAMESPACE_STD inline namespace __fs { namespace filesystem {
#else
# 793 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_BEGIN_NAMESPACE_FILESYSTEM \
  _LIBCPP_BEGIN_NAMESPACE_STD namespace __fs { namespace filesystem {
#endif
# 796 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_END_NAMESPACE_FILESYSTEM \
  _LIBCPP_END_NAMESPACE_STD } }

#define _VSTD_FS _VSTD::__fs::filesystem

#ifndef _LIBCPP_PREFERRED_OVERLOAD
#if 0 /* disabled by -frewrite-includes */
#  if __has_attribute(__enable_if__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 804 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_PREFERRED_OVERLOAD __attribute__ ((__enable_if__(true, "")))
#  endif
# 806 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 807 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_HAS_NO_NOEXCEPT
#  define _NOEXCEPT noexcept
#  define _NOEXCEPT_(x) noexcept(x)
#else
# 812 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _NOEXCEPT throw()
#  define _NOEXCEPT_(x)
#endif
# 815 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_UNICODE_CHARS
typedef unsigned short char16_t;
typedef unsigned int   char32_t;
#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 820 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef __SIZEOF_INT128__
#define _LIBCPP_HAS_NO_INT128
#endif
# 824 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_CXX03_LANG
# define static_assert(...) _Static_assert(__VA_ARGS__)
# define decltype(...) __decltype(__VA_ARGS__)
#endif  // _LIBCPP_CXX03_LANG
# 829 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_CXX03_LANG
#  define _LIBCPP_CONSTEXPR
#else
# 833 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR constexpr
#endif
# 835 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_CXX03_LANG
#  define _LIBCPP_DEFAULT {}
#else
# 839 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DEFAULT = default;
#endif
# 841 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_CXX03_LANG
#  define _LIBCPP_EQUAL_DELETE
#else
# 845 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_EQUAL_DELETE = delete
#endif
# 847 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __GNUC__
#  define _LIBCPP_NOALIAS __attribute__((__malloc__))
#else
# 851 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NOALIAS
#endif
# 853 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_explicit_conversions) || defined(__IBMCPP__) || \
    (!defined(_LIBCPP_CXX03_LANG) && defined(__GNUC__)) // All supported GCC versions
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 856 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_EXPLICIT explicit
#else
# 858 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_EXPLICIT
#endif
# 860 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !__has_builtin(__builtin_operator_new) || !__has_builtin(__builtin_operator_delete)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 862 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_BUILTIN_OPERATOR_NEW_DELETE
#endif
# 864 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_STRONG_ENUMS
#  define _LIBCPP_DECLARE_STRONG_ENUM(x) struct _LIBCPP_TYPE_VIS x { enum __lx
#  define _LIBCPP_DECLARE_STRONG_ENUM_EPILOG(x) \
     __lx __v_; \
     _LIBCPP_INLINE_VISIBILITY x(__lx __v) : __v_(__v) {} \
     _LIBCPP_INLINE_VISIBILITY explicit x(int __v) : __v_(static_cast<__lx>(__v)) {} \
     _LIBCPP_INLINE_VISIBILITY operator int() const {return __v_;} \
     };
#else  // _LIBCPP_HAS_NO_STRONG_ENUMS
# 874 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DECLARE_STRONG_ENUM(x) enum class _LIBCPP_ENUM_VIS x
#  define _LIBCPP_DECLARE_STRONG_ENUM_EPILOG(x)
#endif  // _LIBCPP_HAS_NO_STRONG_ENUMS
# 877 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_DEBUG
#if 0 /* disabled by -frewrite-includes */
#  if _LIBCPP_DEBUG == 0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 880 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_DEBUG_LEVEL 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif _LIBCPP_DEBUG == 1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 882 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_DEBUG_LEVEL 2
#  else
# 884 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    error Supported values for _LIBCPP_DEBUG are 0 and 1
#  endif
# 886 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if !defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 887 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_EXTERN_TEMPLATE(...)
#  endif
# 889 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 890 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_DEBUG_LEVEL
# define _LIBCPP_DEBUG_LEVEL 0
#endif
# 894 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_DISABLE_EXTERN_TEMPLATE
#define _LIBCPP_EXTERN_TEMPLATE(...)
#define _LIBCPP_EXTERN_TEMPLATE2(...)
#endif
# 899 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_EXTERN_TEMPLATE
#define _LIBCPP_EXTERN_TEMPLATE(...) extern template __VA_ARGS__;
#endif
# 903 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_EXTERN_TEMPLATE2
#define _LIBCPP_EXTERN_TEMPLATE2(...) extern template __VA_ARGS__;
#endif
# 907 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_EXTERN_TEMPLATE_DEFINE
#define _LIBCPP_EXTERN_TEMPLATE_DEFINE(...) template __VA_ARGS__;
#endif
# 911 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__APPLE__) || defined(__FreeBSD__) || defined(_LIBCPP_MSVCRT_LIKE) || \
    defined(__sun__) || defined(__NetBSD__) || defined(__CloudABI__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 914 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_LOCALE__L_EXTENSIONS 1
#endif
# 916 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__unix__) || (defined(__APPLE__) && defined(__MACH__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 918 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// Most unix variants have catopen.  These are the specific ones that don't.
#if 0 /* disabled by -frewrite-includes */
#  if !defined(__BIONIC__) && !defined(_NEWLIB_VERSION)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 920 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_CATOPEN 1
#  endif
# 922 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 923 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef __FreeBSD__
#define _DECLARE_C99_LDBL_MATH 1
#endif
# 927 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// If we are getting operator new from the MSVC CRT, then allocation overloads
// for align_val_t were added in 19.12, aka VS 2017 version 15.3.
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_MSVCRT) && defined(_MSC_VER) && _MSC_VER < 1912
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 931 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_HAS_NO_LIBRARY_ALIGNED_ALLOCATION
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_ABI_VCRUNTIME) && !defined(__cpp_aligned_new)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 933 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
   // We're deferring to Microsoft's STL to provide aligned new et al. We don't
   // have it unless the language feature test macro is defined.
#  define _LIBCPP_HAS_NO_LIBRARY_ALIGNED_ALLOCATION
#endif
# 937 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__APPLE__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 939 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if !defined(__MAC_OS_X_VERSION_MIN_REQUIRED) && \
      defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 941 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define __MAC_OS_X_VERSION_MIN_REQUIRED __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__
#  endif
# 943 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // defined(__APPLE__)
# 944 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_ALIGNED_ALLOCATION) && \
    (defined(_LIBCPP_HAS_NO_LIBRARY_ALIGNED_ALLOCATION) || \
    (!defined(__cpp_aligned_new) || __cpp_aligned_new < 201606))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 948 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_HAS_NO_ALIGNED_ALLOCATION
#endif
# 950 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__APPLE__) || defined(__FreeBSD__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 952 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_DEFAULTRUNELOCALE
#endif
# 954 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 956 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_WCTYPE_IS_MASK
#endif
# 958 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 17 || !defined(__cpp_char8_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 960 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_NO_HAS_CHAR8_T
#endif
# 962 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Deprecation macros.
//
// Deprecations warnings are always enabled, except when users explicitly opt-out
// by defining _LIBCPP_DISABLE_DEPRECATION_WARNINGS.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_DEPRECATION_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 968 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if __has_attribute(deprecated)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 969 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_DEPRECATED __attribute__ ((deprecated))
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 971 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_DEPRECATED [[deprecated]]
#  else
# 973 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_DEPRECATED
#  endif
# 975 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#else
# 976 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DEPRECATED
#endif
# 978 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 980 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DEPRECATED_IN_CXX11 _LIBCPP_DEPRECATED
#else
# 982 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DEPRECATED_IN_CXX11
#endif
# 984 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 986 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DEPRECATED_IN_CXX14 _LIBCPP_DEPRECATED
#else
# 988 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DEPRECATED_IN_CXX14
#endif
# 990 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 992 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DEPRECATED_IN_CXX17 _LIBCPP_DEPRECATED
#else
# 994 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DEPRECATED_IN_CXX17
#endif
# 996 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Macros to enter and leave a state where deprecation warnings are suppressed.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_SUPPRESS_DEPRECATED_PUSH) && \
    (defined(_LIBCPP_COMPILER_CLANG) || defined(_LIBCPP_COMPILER_GCC))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1000 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_SUPPRESS_DEPRECATED_PUSH \
    _Pragma("GCC diagnostic push") \
    _Pragma("GCC diagnostic ignored \"-Wdeprecated\"")
#  define _LIBCPP_SUPPRESS_DEPRECATED_POP \
    _Pragma("GCC diagnostic pop")
#endif
# 1006 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_SUPPRESS_DEPRECATED_PUSH)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1007 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_SUPPRESS_DEPRECATED_PUSH
#  define _LIBCPP_SUPPRESS_DEPRECATED_POP
#endif
# 1010 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 11
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1012 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_EXPLICIT_AFTER_CXX11
#else
# 1014 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_EXPLICIT_AFTER_CXX11 explicit
#endif
# 1016 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11 && !defined(_LIBCPP_HAS_NO_CXX14_CONSTEXPR)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1018 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR_AFTER_CXX11 constexpr
#else
# 1020 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR_AFTER_CXX11
#endif
# 1022 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_CXX14_CONSTEXPR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1024 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR_AFTER_CXX14 constexpr
#else
# 1026 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR_AFTER_CXX14
#endif
# 1028 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17 && !defined(_LIBCPP_HAS_NO_CXX14_CONSTEXPR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1030 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR_AFTER_CXX17 constexpr
#else
# 1032 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR_AFTER_CXX17
#endif
# 1034 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17 && \
    !defined(_LIBCPP_HAS_NO_CXX14_CONSTEXPR) && \
    !defined(_LIBCPP_HAS_NO_BUILTIN_IS_CONSTANT_EVALUATED)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1038 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED constexpr
#else
# 1040 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
#endif
# 1042 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// The _LIBCPP_NODISCARD_ATTRIBUTE should only be used to define other
// NODISCARD macros to the correct attribute.
#if 0 /* disabled by -frewrite-includes */
#if __has_cpp_attribute(nodiscard) || defined(_LIBCPP_COMPILER_MSVC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1046 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NODISCARD_ATTRIBUTE [[nodiscard]]
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_COMPILER_CLANG) && !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 1048 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NODISCARD_ATTRIBUTE [[clang::warn_unused_result]]
#else
# 1050 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// We can't use GCC's [[gnu::warn_unused_result]] and
// __attribute__((warn_unused_result)), because GCC does not silence them via
// (void) cast.
#  define _LIBCPP_NODISCARD_ATTRIBUTE
#endif
# 1055 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// _LIBCPP_NODISCARD_EXT may be used to apply [[nodiscard]] to entities not
// specified as such as an extension.
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ENABLE_NODISCARD) && !defined(_LIBCPP_DISABLE_NODISCARD_EXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1059 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NODISCARD_EXT _LIBCPP_NODISCARD_ATTRIBUTE
#else
# 1061 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NODISCARD_EXT
#endif
# 1063 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_NODISCARD_AFTER_CXX17) && \
    (_LIBCPP_STD_VER > 17 || defined(_LIBCPP_ENABLE_NODISCARD))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1066 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_NODISCARD_ATTRIBUTE
#else
# 1068 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NODISCARD_AFTER_CXX17
#endif
# 1070 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && defined(__cpp_inline_variables) && (__cpp_inline_variables >= 201606L)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1072 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_INLINE_VAR inline
#else
# 1074 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_INLINE_VAR
#endif
# 1076 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_RVALUE_REFERENCES
#  define _LIBCPP_EXPLICIT_MOVE(x) _VSTD::move(x)
#else
# 1080 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_EXPLICIT_MOVE(x) (x)
#endif
# 1082 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_CONSTEXPR_IF_NODEBUG
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_DEBUG) || defined(_LIBCPP_HAS_NO_CXX14_CONSTEXPR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1085 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_CONSTEXPR_IF_NODEBUG
#else
# 1087 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_CONSTEXPR_IF_NODEBUG constexpr
#endif
# 1089 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1090 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(no_destroy)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1092 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NO_DESTROY __attribute__((__no_destroy__))
#else
# 1094 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_NO_DESTROY
#endif
# 1096 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_HAS_NO_ASAN
_LIBCPP_FUNC_VIS extern "C" void __sanitizer_annotate_contiguous_container(
  const void *, const void *, const void *, const void *);
#endif
# 1101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Try to find out if RTTI is disabled.
// g++ and cl.exe have RTTI on by default and define a macro when it is.
// g++ only defines the macro in 4.3.2 and onwards.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_NO_RTTI)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(__GNUC__) && \
      ((__GNUC__ >= 5) || \
       (__GNUC__ == 4 && (__GNUC_MINOR__ >= 3 || __GNUC_PATCHLEVEL__ >= 2))) && \
      !defined(__GXX_RTTI)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_NO_RTTI
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(_LIBCPP_COMPILER_MSVC) && !defined(_CPPRTTI)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 1112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_NO_RTTI
#  endif
# 1114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1115 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_WEAK
#define _LIBCPP_WEAK __attribute__((__weak__))
#endif
# 1119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Thread API
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_THREADS) && \
    !defined(_LIBCPP_HAS_THREAD_API_PTHREAD) && \
    !defined(_LIBCPP_HAS_THREAD_API_WIN32) && \
    !defined(_LIBCPP_HAS_THREAD_API_EXTERNAL)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1125 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(__FreeBSD__) || \
      defined(__wasi__) || \
      defined(__NetBSD__) || \
      defined(__linux__) || \
      defined(__GNU__) || \
      defined(__APPLE__) || \
      defined(__CloudABI__) || \
      defined(__sun__) || \
      (defined(__MINGW32__) && __has_include(<pthread.h>))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1134 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_THREAD_API_PTHREAD
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(__Fuchsia__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 1136 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
     // TODO(44575): Switch to C11 thread API when possible.
#    define _LIBCPP_HAS_THREAD_API_PTHREAD
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(_LIBCPP_WIN32API)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 1139 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_THREAD_API_WIN32
#  else
# 1141 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    error "No thread API"
#  endif // _LIBCPP_HAS_THREAD_API
# 1143 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // _LIBCPP_HAS_NO_THREADS
# 1144 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_THREAD_API_PTHREAD)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1146 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(__ANDROID__) && __ANDROID_API__ >= 30
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1147 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_COND_CLOCKWAIT
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_GLIBC_PREREQ)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 1149 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_GLIBC_PREREQ(2, 30)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1150 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_COND_CLOCKWAIT
#endif
# 1152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1153 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_THREADS) && defined(_LIBCPP_HAS_THREAD_API_PTHREAD)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#error _LIBCPP_HAS_THREAD_API_PTHREAD may only be defined when \
       _LIBCPP_HAS_NO_THREADS is not defined.
#endif
# 1159 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_THREADS) && defined(_LIBCPP_HAS_THREAD_API_EXTERNAL)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1161 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#error _LIBCPP_HAS_THREAD_API_EXTERNAL may not be defined when \
       _LIBCPP_HAS_NO_THREADS is defined.
#endif
# 1164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_MONOTONIC_CLOCK) && !defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#error _LIBCPP_HAS_NO_MONOTONIC_CLOCK may only be defined when \
       _LIBCPP_HAS_NO_THREADS is defined.
#endif
# 1169 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__STDCPP_THREADS__) && defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1171 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#error _LIBCPP_HAS_NO_THREADS cannot be set when __STDCPP_THREADS__ is set.
#endif
# 1173 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_THREADS) && !defined(__STDCPP_THREADS__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1175 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define __STDCPP_THREADS__ 1
#endif
# 1177 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// The glibc and Bionic implementation of pthreads implements
// pthread_mutex_destroy as nop for regular mutexes. Additionally, Win32
// mutexes have no destroy mechanism.
//
// This optimization can't be performed on Apple platforms, where
// pthread_mutex_destroy can allow the kernel to release resources.
// See https://llvm.org/D64298 for details.
//
// TODO(EricWF): Enable this optimization on Bionic after speaking to their
//               respective stakeholders.
#if 0 /* disabled by -frewrite-includes */
#if (defined(_LIBCPP_HAS_THREAD_API_PTHREAD) && defined(__GLIBC__)) \
  || (defined(_LIBCPP_HAS_THREAD_API_C11) && defined(__Fuchsia__)) \
  || defined(_LIBCPP_HAS_THREAD_API_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1191 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# define _LIBCPP_HAS_TRIVIAL_MUTEX_DESTRUCTION
#endif
# 1193 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Destroying a condvar is a nop on Windows.
//
// This optimization can't be performed on Apple platforms, where
// pthread_cond_destroy can allow the kernel to release resources.
// See https://llvm.org/D64298 for details.
//
// TODO(EricWF): This is potentially true for some pthread implementations
// as well.
#if 0 /* disabled by -frewrite-includes */
#if (defined(_LIBCPP_HAS_THREAD_API_C11) && defined(__Fuchsia__)) || \
     defined(_LIBCPP_HAS_THREAD_API_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1204 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# define _LIBCPP_HAS_TRIVIAL_CONDVAR_DESTRUCTION
#endif
# 1206 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Systems that use capability-based security (FreeBSD with Capsicum,
// Nuxi CloudABI) may only provide local filesystem access (using *at()).
// Functions like open(), rename(), unlink() and stat() should not be
// used, as they attempt to access the global filesystem namespace.
#ifdef __CloudABI__
#define _LIBCPP_HAS_NO_GLOBAL_FILESYSTEM_NAMESPACE
#endif
# 1214 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// CloudABI is intended for running networked services. Processes do not
// have standard input and output channels.
#ifdef __CloudABI__
#define _LIBCPP_HAS_NO_STDIN
#define _LIBCPP_HAS_NO_STDOUT
#endif
# 1221 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Some systems do not provide gets() in their C library, for security reasons.
#ifndef _LIBCPP_C_HAS_NO_GETS
#if 0 /* disabled by -frewrite-includes */
#  if defined(_LIBCPP_MSVCRT) || \
      (defined(__FreeBSD_version) && __FreeBSD_version >= 1300043)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1226 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_C_HAS_NO_GETS
#  endif
# 1228 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1229 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__BIONIC__) || defined(__CloudABI__) ||                            \
    defined(__Fuchsia__) || defined(__wasi__) || defined(_LIBCPP_HAS_MUSL_LIBC)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1232 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_PROVIDES_DEFAULT_RUNE_TABLE
#endif
# 1234 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Thread-unsafe functions such as strtok() and localtime()
// are not available.
#ifdef __CloudABI__
#define _LIBCPP_HAS_NO_THREAD_UNSAFE_C_FUNCTIONS
#endif
# 1240 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_atomic) || __has_extension(c_atomic) || __has_keyword(_Atomic)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1242 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_HAS_C_ATOMIC_IMP
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 1244 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_HAS_GCC_ATOMIC_IMP
#endif
# 1246 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if (!defined(_LIBCPP_HAS_C_ATOMIC_IMP) && \
     !defined(_LIBCPP_HAS_GCC_ATOMIC_IMP) && \
     !defined(_LIBCPP_HAS_EXTERNAL_ATOMIC_IMP)) \
     || defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1251 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_HAS_NO_ATOMIC_HEADER
#else
# 1253 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  ifndef _LIBCPP_ATOMIC_FLAG_TYPE
#    define _LIBCPP_ATOMIC_FLAG_TYPE bool
#  endif
# 1256 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  ifdef _LIBCPP_FREESTANDING
#    define _LIBCPP_ATOMIC_ONLY_USE_BUILTINS
#  endif
# 1259 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1260 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
#define _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
#endif
# 1264 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ENABLE_THREAD_SAFETY_ANNOTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1266 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(__clang__) && __has_attribute(acquire_capability)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1267 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
// Work around the attribute handling in clang.  When both __declspec and
// __attribute__ are present, the processing goes awry preventing the definition
// of the types.
#if 0 /* disabled by -frewrite-includes */
#    if !defined(_LIBCPP_OBJECT_FORMAT_COFF)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1271 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      define _LIBCPP_HAS_THREAD_SAFETY_ANNOTATIONS
#    endif
# 1273 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  endif
# 1274 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1275 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_THREAD_SAFETY_ANNOTATION
#  ifdef _LIBCPP_HAS_THREAD_SAFETY_ANNOTATIONS
#    define _LIBCPP_THREAD_SAFETY_ANNOTATION(x) __attribute__((x))
#  else
# 1280 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_THREAD_SAFETY_ANNOTATION(x)
#  endif
# 1282 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif  // _LIBCPP_THREAD_SAFETY_ANNOTATION
# 1283 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(require_constant_initialization)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1285 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_SAFE_STATIC __attribute__((__require_constant_initialization__))
#else
# 1287 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_SAFE_STATIC
#endif
# 1289 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !__has_builtin(__builtin_addressof) && _GNUC_VER < 700
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1291 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_BUILTIN_ADDRESSOF
#endif
# 1293 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !__has_builtin(__builtin_is_constant_evaluated) && _GNUC_VER < 900
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_BUILTIN_IS_CONSTANT_EVALUATED
#endif
# 1297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_OFF_T_FUNCTIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1299 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(_LIBCPP_MSVCRT) || defined(_NEWLIB_VERSION)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1300 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_HAS_NO_OFF_T_FUNCTIONS
#  endif
# 1302 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1303 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(diagnose_if) && !defined(_LIBCPP_DISABLE_ADDITIONAL_DIAGNOSTICS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DIAGNOSE_WARNING(...) \
     __attribute__((diagnose_if(__VA_ARGS__, "warning")))
#  define _LIBCPP_DIAGNOSE_ERROR(...) \
     __attribute__((diagnose_if(__VA_ARGS__, "error")))
#else
# 1310 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DIAGNOSE_WARNING(...)
#  define _LIBCPP_DIAGNOSE_ERROR(...)
#endif
# 1313 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Use a function like macro to imply that it must be followed by a semicolon
#if 0 /* disabled by -frewrite-includes */
#if __cplusplus > 201402L && __has_cpp_attribute(fallthrough)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1316 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_FALLTHROUGH() [[fallthrough]]
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __has_cpp_attribute(clang::fallthrough)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 1318 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_FALLTHROUGH() [[clang::fallthrough]]
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __has_attribute(fallthrough) || _GNUC_VER >= 700
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 1320 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_FALLTHROUGH() __attribute__((__fallthrough__))
#else
# 1322 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_FALLTHROUGH() ((void)0)
#endif
# 1324 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(__nodebug__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1326 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_NODEBUG __attribute__((__nodebug__))
#else
# 1328 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_NODEBUG
#endif
# 1330 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_NODEBUG_TYPE
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(__nodebug__) && \
    (defined(_LIBCPP_CLANG_VER) && _LIBCPP_CLANG_VER >= 900)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1334 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_NODEBUG_TYPE __attribute__((nodebug))
#else
# 1336 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_NODEBUG_TYPE
#endif
# 1338 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // !defined(_LIBCPP_NODEBUG_TYPE)
# 1339 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_MICROSOFT) && \
    (defined(_LIBCPP_COMPILER_MSVC) || __has_declspec_attribute(empty_bases))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1342 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DECLSPEC_EMPTY_BASES __declspec(empty_bases)
#else
# 1344 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DECLSPEC_EMPTY_BASES
#endif
# 1346 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ENABLE_CXX17_REMOVED_FEATURES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1348 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR
#define _LIBCPP_ENABLE_CXX17_REMOVED_UNEXPECTED_FUNCTIONS
#define _LIBCPP_ENABLE_CXX17_REMOVED_RANDOM_SHUFFLE
#define _LIBCPP_ENABLE_CXX17_REMOVED_BINDERS
#endif // _LIBCPP_ENABLE_CXX17_REMOVED_FEATURES
# 1353 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(__cpp_deduction_guides) || __cpp_deduction_guides < 201611
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1355 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_DEDUCTION_GUIDES
#endif
# 1357 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !__has_keyword(__is_aggregate) && (_GNUC_VER_NEW < 7001)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1359 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_IS_AGGREGATE
#endif
# 1361 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(__cpp_coroutines) || __cpp_coroutines < 201703L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1363 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_COROUTINES
#endif
# 1365 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(__cpp_impl_three_way_comparison) || __cpp_impl_three_way_comparison < 201907L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1367 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_SPACESHIP_OPERATOR
#endif
# 1369 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Decide whether to use availability macros.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_BUILDING_LIBRARY) &&                                      \
    !defined(_LIBCPP_DISABLE_AVAILABILITY) &&                                  \
    __has_feature(attribute_availability_with_strict) &&                       \
    __has_feature(attribute_availability_in_templates) &&                      \
    __has_extension(pragma_clang_attribute_external_declaration)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1376 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  ifdef __APPLE__
#    define _LIBCPP_USE_AVAILABILITY_APPLE
#  endif
# 1379 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif
# 1380 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Define availability macros.
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_USE_AVAILABILITY_APPLE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1383 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_AVAILABILITY_SHARED_MUTEX                                    \
     __attribute__((availability(macosx,strict,introduced=10.12)))             \
     __attribute__((availability(ios,strict,introduced=10.0)))                 \
     __attribute__((availability(tvos,strict,introduced=10.0)))                \
     __attribute__((availability(watchos,strict,introduced=3.0)))
#  define _LIBCPP_AVAILABILITY_BAD_OPTIONAL_ACCESS                             \
     __attribute__((availability(macosx,strict,introduced=10.14)))             \
     __attribute__((availability(ios,strict,introduced=12.0)))                 \
     __attribute__((availability(tvos,strict,introduced=12.0)))                \
     __attribute__((availability(watchos,strict,introduced=5.0)))
#  define _LIBCPP_AVAILABILITY_BAD_VARIANT_ACCESS                              \
     _LIBCPP_AVAILABILITY_BAD_OPTIONAL_ACCESS
#  define _LIBCPP_AVAILABILITY_BAD_ANY_CAST                                    \
     _LIBCPP_AVAILABILITY_BAD_OPTIONAL_ACCESS
#  define _LIBCPP_AVAILABILITY_UNCAUGHT_EXCEPTIONS                             \
     __attribute__((availability(macosx,strict,introduced=10.12)))             \
     __attribute__((availability(ios,strict,introduced=10.0)))                 \
     __attribute__((availability(tvos,strict,introduced=10.0)))                \
     __attribute__((availability(watchos,strict,introduced=3.0)))
#  define _LIBCPP_AVAILABILITY_SIZED_NEW_DELETE                                \
     __attribute__((availability(macosx,strict,introduced=10.12)))             \
     __attribute__((availability(ios,strict,introduced=10.0)))                 \
     __attribute__((availability(tvos,strict,introduced=10.0)))                \
     __attribute__((availability(watchos,strict,introduced=3.0)))
#  define _LIBCPP_AVAILABILITY_FUTURE_ERROR                                    \
     __attribute__((availability(ios,strict,introduced=6.0)))
#  define _LIBCPP_AVAILABILITY_TYPEINFO_VTABLE                                 \
     __attribute__((availability(macosx,strict,introduced=10.9)))              \
     __attribute__((availability(ios,strict,introduced=7.0)))
#  define _LIBCPP_AVAILABILITY_LOCALE_CATEGORY                                 \
     __attribute__((availability(macosx,strict,introduced=10.9)))              \
     __attribute__((availability(ios,strict,introduced=7.0)))
#  define _LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR                               \
     __attribute__((availability(macosx,strict,introduced=10.9)))              \
     __attribute__((availability(ios,strict,introduced=7.0)))
#  define _LIBCPP_AVAILABILITY_FILESYSTEM                                      \
     __attribute__((availability(macosx,strict,introduced=10.15)))             \
     __attribute__((availability(ios,strict,introduced=13.0)))                 \
     __attribute__((availability(tvos,strict,introduced=13.0)))                \
     __attribute__((availability(watchos,strict,introduced=6.0)))
#  define _LIBCPP_AVAILABILITY_FILESYSTEM_PUSH                                 \
     _Pragma("clang attribute push(__attribute__((availability(macosx,strict,introduced=10.15))), apply_to=any(function,record))") \
     _Pragma("clang attribute push(__attribute__((availability(ios,strict,introduced=13.0))), apply_to=any(function,record))")     \
     _Pragma("clang attribute push(__attribute__((availability(tvos,strict,introduced=13.0))), apply_to=any(function,record))")    \
     _Pragma("clang attribute push(__attribute__((availability(watchos,strict,introduced=6.0))), apply_to=any(function,record))")
#  define _LIBCPP_AVAILABILITY_FILESYSTEM_POP                                  \
     _Pragma("clang attribute pop")                                            \
     _Pragma("clang attribute pop")                                            \
     _Pragma("clang attribute pop")                                            \
     _Pragma("clang attribute pop")
#  define _LIBCPP_AVAILABILITY_TO_CHARS                                        \
     _LIBCPP_AVAILABILITY_FILESYSTEM
#else
# 1436 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_AVAILABILITY_SHARED_MUTEX
#  define _LIBCPP_AVAILABILITY_BAD_VARIANT_ACCESS
#  define _LIBCPP_AVAILABILITY_BAD_OPTIONAL_ACCESS
#  define _LIBCPP_AVAILABILITY_BAD_ANY_CAST
#  define _LIBCPP_AVAILABILITY_UNCAUGHT_EXCEPTIONS
#  define _LIBCPP_AVAILABILITY_SIZED_NEW_DELETE
#  define _LIBCPP_AVAILABILITY_FUTURE_ERROR
#  define _LIBCPP_AVAILABILITY_TYPEINFO_VTABLE
#  define _LIBCPP_AVAILABILITY_LOCALE_CATEGORY
#  define _LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
#  define _LIBCPP_AVAILABILITY_FILESYSTEM
#  define _LIBCPP_AVAILABILITY_FILESYSTEM_PUSH
#  define _LIBCPP_AVAILABILITY_FILESYSTEM_POP
#  define _LIBCPP_AVAILABILITY_TO_CHARS
#endif
# 1451 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// Define availability that depends on _LIBCPP_NO_EXCEPTIONS.
#ifdef _LIBCPP_NO_EXCEPTIONS
#  define _LIBCPP_AVAILABILITY_FUTURE
#  define _LIBCPP_AVAILABILITY_THROW_BAD_ANY_CAST
#  define _LIBCPP_AVAILABILITY_THROW_BAD_OPTIONAL_ACCESS
#  define _LIBCPP_AVAILABILITY_THROW_BAD_VARIANT_ACCESS
#else
# 1459 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_AVAILABILITY_FUTURE                    _LIBCPP_AVAILABILITY_FUTURE_ERROR
#  define _LIBCPP_AVAILABILITY_THROW_BAD_ANY_CAST        _LIBCPP_AVAILABILITY_BAD_ANY_CAST
#  define _LIBCPP_AVAILABILITY_THROW_BAD_OPTIONAL_ACCESS _LIBCPP_AVAILABILITY_BAD_OPTIONAL_ACCESS
#  define _LIBCPP_AVAILABILITY_THROW_BAD_VARIANT_ACCESS  _LIBCPP_AVAILABILITY_BAD_VARIANT_ACCESS
#endif
# 1464 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

// The stream API was dropped and re-added in the dylib shipped on macOS
// and iOS. We can only assume the dylib to provide these definitions for
// macosx >= 10.9 and ios >= 7.0. Otherwise, the definitions are available
// from the headers, but not from the dylib. Explicit instantiation
// declarations for streams exist conditionally to this; if we provide
// an explicit instantiation declaration and we try to deploy to a dylib
// that does not provide those symbols, we'll get a load-time error.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_BUILDING_LIBRARY) &&                                      \
    ((defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) &&                \
      __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ < 1090) ||                 \
     (defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) &&               \
      __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ < 70000))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1477 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_DO_NOT_ASSUME_STREAMS_EXPLICIT_INSTANTIATION_IN_DYLIB
#endif
# 1479 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_COMPILER_IBM)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1481 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#define _LIBCPP_HAS_NO_PRAGMA_PUSH_POP_MACRO
#endif
# 1483 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_PRAGMA_PUSH_POP_MACRO)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1485 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_PUSH_MACROS
#  define _LIBCPP_POP_MACROS
#else
# 1488 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
  // Don't warn about macro conflicts when we can restore them at the
  // end of the header.
#  ifndef _LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS
#    define _LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS
#  endif
# 1493 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(_LIBCPP_COMPILER_MSVC)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1494 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_PUSH_MACROS    \
       __pragma(push_macro("min")) \
       __pragma(push_macro("max"))
#    define _LIBCPP_POP_MACROS     \
       __pragma(pop_macro("min"))  \
       __pragma(pop_macro("max"))
#  else
# 1501 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#    define _LIBCPP_PUSH_MACROS        \
       _Pragma("push_macro(\"min\")")  \
       _Pragma("push_macro(\"max\")")
#    define _LIBCPP_POP_MACROS         \
       _Pragma("pop_macro(\"min\")")   \
       _Pragma("pop_macro(\"max\")")
#  endif
# 1508 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // defined(_LIBCPP_HAS_NO_PRAGMA_PUSH_POP_MACRO)
# 1509 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#ifndef _LIBCPP_NO_AUTO_LINK
#if 0 /* disabled by -frewrite-includes */
#  if defined(_LIBCPP_ABI_MICROSOFT) && !defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1512 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#if 0 /* disabled by -frewrite-includes */
#    if defined(_DLL)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1513 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      pragma comment(lib, "c++.lib")
#    else
# 1515 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#      pragma comment(lib, "libc++.lib")
#    endif
# 1517 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  endif // defined(_LIBCPP_ABI_MICROSOFT) && !defined(_LIBCPP_BUILDING_LIBRARY)
# 1518 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#endif // _LIBCPP_NO_AUTO_LINK
# 1519 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#define _LIBCPP_UNUSED_VAR(x) ((void)(x))

// Configures the fopen close-on-exec mode character, if any. This string will
// be appended to any mode string used by fstream for fopen/fdopen.
//
// Not all platforms support this, but it helps avoid fd-leaks on platforms that
// do.
#if 0 /* disabled by -frewrite-includes */
#if defined(__BIONIC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1528 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_FOPEN_CLOEXEC_MODE "e"
#else
# 1530 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
#  define _LIBCPP_FOPEN_CLOEXEC_MODE
#endif
# 1532 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#endif // __cplusplus
# 1534 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3

#endif // _LIBCPP_CONFIG
# 1536 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__config" 3
# 90 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 90 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 1 3
// -*- C++ -*-
//===-------------------------- exception ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_EXCEPTION
#define _LIBCPP_EXCEPTION

/*
    exception synopsis

namespace std
{

class exception
{
public:
    exception() noexcept;
    exception(const exception&) noexcept;
    exception& operator=(const exception&) noexcept;
    virtual ~exception() noexcept;
    virtual const char* what() const noexcept;
};

class bad_exception
    : public exception
{
public:
    bad_exception() noexcept;
    bad_exception(const bad_exception&) noexcept;
    bad_exception& operator=(const bad_exception&) noexcept;
    virtual ~bad_exception() noexcept;
    virtual const char* what() const noexcept;
};

typedef void (*unexpected_handler)();
unexpected_handler set_unexpected(unexpected_handler  f ) noexcept;
unexpected_handler get_unexpected() noexcept;
[[noreturn]] void unexpected();

typedef void (*terminate_handler)();
terminate_handler set_terminate(terminate_handler  f ) noexcept;
terminate_handler get_terminate() noexcept;
[[noreturn]] void terminate() noexcept;

bool uncaught_exception()  noexcept;
int  uncaught_exceptions() noexcept;  // C++17

typedef unspecified exception_ptr;

exception_ptr current_exception() noexcept;
void rethrow_exception [[noreturn]] (exception_ptr p);
template<class E> exception_ptr make_exception_ptr(E e) noexcept;

class nested_exception
{
public:
    nested_exception() noexcept;
    nested_exception(const nested_exception&) noexcept = default;
    nested_exception& operator=(const nested_exception&) noexcept = default;
    virtual ~nested_exception() = default;

    // access functions
    [[noreturn]] void rethrow_nested() const;
    exception_ptr nested_ptr() const noexcept;
};

template <class T> [[noreturn]] void throw_with_nested(T&& t);
template <class E> void rethrow_if_nested(const E& e);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 79 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
# 80 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 80 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 1 3
// -*- C++ -*-
//===--------------------------- cstddef ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDDEF
#define _LIBCPP_CSTDDEF

/*
    cstddef synopsis

Macros:

    offsetof(type,member-designator)
    NULL

namespace std
{

Types:

    ptrdiff_t
    size_t
    max_align_t
    nullptr_t
    byte // C++17

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 36 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
# 37 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 37 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 1 3
// -*- C++ -*-
//===--------------------------- version ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_VERSIONH
#define _LIBCPP_VERSIONH

/*
  version synopsis

Macro name                                              Value   Headers
__cpp_lib_addressof_constexpr                           201603L <memory>
__cpp_lib_allocator_traits_is_always_equal              201411L <memory> <scoped_allocator> <string>
                                                                <deque> <forward_list> <list>
                                                                <vector> <map> <set>
                                                                <unordered_map> <unordered_set>
__cpp_lib_any                                           201606L <any>
__cpp_lib_apply                                         201603L <tuple>
__cpp_lib_array_constexpr                               201603L <iterator> <array>
__cpp_lib_as_const                                      201510L <utility>
__cpp_lib_atomic_is_always_lock_free                    201603L <atomic>
__cpp_lib_atomic_ref                                    201806L <atomic>
__cpp_lib_bind_front                                    201811L <functional>
__cpp_lib_bit_cast                                      201806L <bit>
__cpp_lib_bool_constant                                 201505L <type_traits>
__cpp_lib_boyer_moore_searcher                          201603L <functional>
__cpp_lib_byte                                          201603L <cstddef>
__cpp_lib_char8_t                                       201811L <atomic> <filesystem> <istream>
                                                                <limits> <locale> <ostream>
                                                                <string> <string_view>
__cpp_lib_chrono                                        201611L <chrono>
__cpp_lib_chrono_udls                                   201304L <chrono>
__cpp_lib_clamp                                         201603L <algorithm>
__cpp_lib_complex_udls                                  201309L <complex>
__cpp_lib_concepts                                      201806L <concepts>
__cpp_lib_constexpr_misc                                201811L <array> <functional> <iterator>
                                                                <string_view> <tuple> <utility>
__cpp_lib_constexpr_swap_algorithms                     201806L <algorithm>
__cpp_lib_destroying_delete                             201806L <new>
__cpp_lib_enable_shared_from_this                       201603L <memory>
__cpp_lib_endian                                        201907L <bit>
__cpp_lib_erase_if                                      201811L <string> <deque> <forward_list>
                                                                <list> <vector> <map>
                                                                <set> <unordered_map> <unordered_set>
__cpp_lib_exchange_function                             201304L <utility>
__cpp_lib_execution                                     201603L <execution>
__cpp_lib_filesystem                                    201703L <filesystem>
__cpp_lib_gcd_lcm                                       201606L <numeric>
__cpp_lib_generic_associative_lookup                    201304L <map> <set>
__cpp_lib_generic_unordered_lookup                      201811L <unordered_map> <unordered_set>
__cpp_lib_hardware_interference_size                    201703L <new>
__cpp_lib_has_unique_object_representations             201606L <type_traits>
__cpp_lib_hypot                                         201603L <cmath>
__cpp_lib_incomplete_container_elements                 201505L <forward_list> <list> <vector>
__cpp_lib_integer_sequence                              201304L <utility>
__cpp_lib_integral_constant_callable                    201304L <type_traits>
__cpp_lib_interpolate                                   201902L <numeric>
__cpp_lib_invoke                                        201411L <functional>
__cpp_lib_is_aggregate                                  201703L <type_traits>
__cpp_lib_is_constant_evaluated                         201811L <type_traits>
__cpp_lib_is_final                                      201402L <type_traits>
__cpp_lib_is_invocable                                  201703L <type_traits>
__cpp_lib_is_null_pointer                               201309L <type_traits>
__cpp_lib_is_swappable                                  201603L <type_traits>
__cpp_lib_launder                                       201606L <new>
__cpp_lib_list_remove_return_type                       201806L <forward_list> <list>
__cpp_lib_logical_traits                                201510L <type_traits>
__cpp_lib_make_from_tuple                               201606L <tuple>
__cpp_lib_make_reverse_iterator                         201402L <iterator>
__cpp_lib_make_unique                                   201304L <memory>
__cpp_lib_map_try_emplace                               201411L <map>
__cpp_lib_math_special_functions                        201603L <cmath>
__cpp_lib_memory_resource                               201603L <memory_resource>
__cpp_lib_node_extract                                  201606L <map> <set> <unordered_map>
                                                                <unordered_set>
__cpp_lib_nonmember_container_access                    201411L <iterator> <array> <deque>
                                                                <forward_list> <list> <map>
                                                                <regex> <set> <string>
                                                                <unordered_map> <unordered_set> <vector>
__cpp_lib_not_fn                                        201603L <functional>
__cpp_lib_null_iterators                                201304L <iterator>
__cpp_lib_optional                                      201606L <optional>
__cpp_lib_parallel_algorithm                            201603L <algorithm> <numeric>
__cpp_lib_quoted_string_io                              201304L <iomanip>
__cpp_lib_ranges                                        201811L <algorithm> <functional> <iterator>
                                                                <memory> <ranges>
__cpp_lib_raw_memory_algorithms                         201606L <memory>
__cpp_lib_result_of_sfinae                              201210L <functional> <type_traits>
__cpp_lib_robust_nonmodifying_seq_ops                   201304L <algorithm>
__cpp_lib_sample                                        201603L <algorithm>
__cpp_lib_scoped_lock                                   201703L <mutex>
__cpp_lib_shared_mutex                                  201505L <shared_mutex>
__cpp_lib_shared_ptr_arrays                             201611L <memory>
__cpp_lib_shared_ptr_weak_type                          201606L <memory>
__cpp_lib_shared_timed_mutex                            201402L <shared_mutex>
__cpp_lib_string_udls                                   201304L <string>
__cpp_lib_string_view                                   201606L <string> <string_view>
__cpp_lib_three_way_comparison                          201711L <compare>
__cpp_lib_to_array                                      201907L <array>
__cpp_lib_to_chars                                      201611L <utility>
__cpp_lib_transformation_trait_aliases                  201304L <type_traits>
__cpp_lib_transparent_operators                         201510L <functional>
                                                        201210L // C++14
__cpp_lib_tuple_element_t                               201402L <tuple>
__cpp_lib_tuples_by_type                                201304L <utility> <tuple>
__cpp_lib_type_trait_variable_templates                 201510L <type_traits>
__cpp_lib_uncaught_exceptions                           201411L <exception>
__cpp_lib_unordered_map_try_emplace                     201411L <unordered_map>
__cpp_lib_variant                                       201606L <variant>
__cpp_lib_void_t                                        201411L <type_traits>

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#endif
# 124 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 126 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# define __cpp_lib_chrono_udls                          201304L
# define __cpp_lib_complex_udls                         201309L
# define __cpp_lib_exchange_function                    201304L
# define __cpp_lib_generic_associative_lookup           201304L
# define __cpp_lib_integer_sequence                     201304L
# define __cpp_lib_integral_constant_callable           201304L
# define __cpp_lib_is_final                             201402L
# define __cpp_lib_is_null_pointer                      201309L
# define __cpp_lib_make_reverse_iterator                201402L
# define __cpp_lib_make_unique                          201304L
# define __cpp_lib_null_iterators                       201304L
# define __cpp_lib_quoted_string_io                     201304L
# define __cpp_lib_result_of_sfinae                     201210L
# define __cpp_lib_robust_nonmodifying_seq_ops          201304L
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 141 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_shared_timed_mutex                 201402L
# endif
# 143 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# define __cpp_lib_string_udls                          201304L
# define __cpp_lib_transformation_trait_aliases         201304L
# define __cpp_lib_transparent_operators                201210L
# define __cpp_lib_tuple_element_t                      201402L
# define __cpp_lib_tuples_by_type                       201304L
#endif
# 149 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 151 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_HAS_NO_BUILTIN_ADDRESSOF)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_addressof_constexpr                201603L
# endif
# 154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# define __cpp_lib_allocator_traits_is_always_equal     201411L
# define __cpp_lib_any                                  201606L
# define __cpp_lib_apply                                201603L
# define __cpp_lib_array_constexpr                      201603L
# define __cpp_lib_as_const                             201510L
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 160 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_atomic_is_always_lock_free         201603L
# endif
# 162 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# define __cpp_lib_bool_constant                        201505L
// # define __cpp_lib_boyer_moore_searcher                 201603L
# define __cpp_lib_byte                                 201603L
# define __cpp_lib_chrono                               201611L
# define __cpp_lib_clamp                                201603L
# define __cpp_lib_enable_shared_from_this              201603L
// # define __cpp_lib_execution                            201603L
# define __cpp_lib_filesystem                           201703L
# define __cpp_lib_gcd_lcm                              201606L
# define __cpp_lib_hardware_interference_size           201703L
#if 0 /* disabled by -frewrite-includes */
# if defined(_LIBCPP_HAS_UNIQUE_OBJECT_REPRESENTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 173 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_has_unique_object_representations  201606L
# endif
# 175 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# define __cpp_lib_hypot                                201603L
# define __cpp_lib_incomplete_container_elements        201505L
# define __cpp_lib_invoke                               201411L
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_HAS_NO_IS_AGGREGATE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 179 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_is_aggregate                       201703L
# endif
# 181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# define __cpp_lib_is_invocable                         201703L
# define __cpp_lib_is_swappable                         201603L
# define __cpp_lib_launder                              201606L
# define __cpp_lib_logical_traits                       201510L
# define __cpp_lib_make_from_tuple                      201606L
# define __cpp_lib_map_try_emplace                      201411L
// # define __cpp_lib_math_special_functions               201603L
// # define __cpp_lib_memory_resource                      201603L
# define __cpp_lib_node_extract                         201606L
# define __cpp_lib_nonmember_container_access           201411L
# define __cpp_lib_not_fn                               201603L
# define __cpp_lib_optional                             201606L
// # define __cpp_lib_parallel_algorithm                   201603L
# define __cpp_lib_raw_memory_algorithms                201606L
# define __cpp_lib_sample                               201603L
# define __cpp_lib_scoped_lock                          201703L
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 198 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_shared_mutex                       201505L
# endif
# 200 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
// # define __cpp_lib_shared_ptr_arrays                    201611L
# define __cpp_lib_shared_ptr_weak_type                 201606L
# define __cpp_lib_string_view                          201606L
// # define __cpp_lib_to_chars                             201611L
# undef  __cpp_lib_transparent_operators
# define __cpp_lib_transparent_operators                201510L
# define __cpp_lib_type_trait_variable_templates        201510L
# define __cpp_lib_uncaught_exceptions                  201411L
# define __cpp_lib_unordered_map_try_emplace            201411L
# define __cpp_lib_variant                              201606L
# define __cpp_lib_void_t                               201411L
#endif
# 212 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 214 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 215 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
// #   define __cpp_lib_atomic_ref                         201806L
# endif
# 217 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
// # define __cpp_lib_bind_front                           201811L
// # define __cpp_lib_bit_cast                             201806L
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_NO_HAS_CHAR8_T)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 220 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_char8_t                            201811L
# endif
# 222 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
// # define __cpp_lib_concepts                             201806L
// # define __cpp_lib_constexpr_misc                       201811L
// # define __cpp_lib_constexpr_swap_algorithms            201806L
#if 0 /* disabled by -frewrite-includes */
# if _LIBCPP_STD_VER > 17 && defined(__cpp_impl_destroying_delete) && __cpp_impl_destroying_delete >= 201806L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 226 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_destroying_delete                  201806L
# endif
# 228 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# define __cpp_lib_endian                               201907L
# define __cpp_lib_erase_if                             201811L
// # define __cpp_lib_generic_unordered_lookup             201811L
# define __cpp_lib_interpolate                          201902L
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_HAS_NO_BUILTIN_IS_CONSTANT_EVALUATED)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 233 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
#   define __cpp_lib_is_constant_evaluated              201811L
# endif
# 235 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
// # define __cpp_lib_list_remove_return_type              201806L
// # define __cpp_lib_ranges                               201811L
# define __cpp_lib_to_array                                201907L
// # define __cpp_lib_three_way_comparison                 201711L
#endif
# 240 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3

#endif // _LIBCPP_VERSIONH
# 242 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/version" 3
# 38 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 41 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
#endif
# 42 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3

// Don't include our own <stddef.h>; we don't want to declare ::nullptr_t.
#if 0 /* expanded by -frewrite-includes */
#include_next <stddef.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 1 3
/*===---- stddef.h - Basic type definitions --------------------------------===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#if 0 /* disabled by -frewrite-includes */
#if !defined(__STDDEF_H) || defined(__need_ptrdiff_t) ||                       \
    defined(__need_size_t) || defined(__need_wchar_t) ||                       \
    defined(__need_NULL) || defined(__need_wint_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(__need_ptrdiff_t) && !defined(__need_size_t) &&                   \
    !defined(__need_wchar_t) && !defined(__need_NULL) &&                       \
    !defined(__need_wint_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define miscellaneous pieces when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define __STDDEF_H
#endif
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define __need_ptrdiff_t
#define __need_size_t
#define __need_wchar_t
#define __need_NULL
#define __need_STDDEF_H_misc
/* __need_wint_t is intentionally not defined here. */
#endif
# 28 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_ptrdiff_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 30 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if !defined(_PTRDIFF_T) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define ptrdiff_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 33 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _PTRDIFF_T
#endif
# 35 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __PTRDIFF_TYPE__ ptrdiff_t;
#endif
# 37 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_ptrdiff_t
#endif /* defined(__need_ptrdiff_t) */
# 39 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_size_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if !defined(_SIZE_T) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define size_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 44 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _SIZE_T
#endif
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __SIZE_TYPE__ size_t;
#endif
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_size_t
#endif /*defined(__need_size_t) */
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_STDDEF_H_misc)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 52 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* ISO9899:2011 7.20 (C11 Annex K): Define rsize_t if __STDC_WANT_LIB_EXT1__ is
 * enabled. */
#if 0 /* disabled by -frewrite-includes */
#if (defined(__STDC_WANT_LIB_EXT1__) && __STDC_WANT_LIB_EXT1__ >= 1 && \
     !defined(_RSIZE_T)) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 56 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define rsize_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _RSIZE_T
#endif
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __SIZE_TYPE__ rsize_t;
#endif
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif /* defined(__need_STDDEF_H_misc) */
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_wchar_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#ifndef __cplusplus
/* Always define wchar_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_WCHAR_T) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 68 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _WCHAR_T
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_EXTENSIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 71 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _WCHAR_T_DEFINED
#endif
# 73 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif
# 74 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __WCHAR_TYPE__ wchar_t;
#endif
# 76 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif
# 77 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_wchar_t
#endif /* defined(__need_wchar_t) */
# 79 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_NULL)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 81 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef NULL
#ifdef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#  if !defined(__MINGW32__) && !defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 84 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#    define NULL __null
#  else
# 86 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#    define NULL 0
#  endif
# 88 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#else
# 89 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#  define NULL ((void*)0)
#endif
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#ifdef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_EXTENSIONS) && defined(_NATIVE_NULLPTR_SUPPORTED)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 93 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
namespace std { typedef decltype(nullptr) nullptr_t; }
using ::std::nullptr_t;
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_NULL
#endif /* defined(__need_NULL) */
# 99 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_STDDEF_H_misc)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if __STDC_VERSION__ >= 201112L || __cplusplus >= 201103L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* expanded by -frewrite-includes */
#include "__stddef_max_align_t.h"
#endif /* expanded by -frewrite-includes */
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/__stddef_max_align_t.h" 1 3
/*===---- __stddef_max_align_t.h - Definition of max_align_t for modules ---===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __CLANG_MAX_ALIGN_T_DEFINED
#define __CLANG_MAX_ALIGN_T_DEFINED

#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/__stddef_max_align_t.h" 3
typedef double max_align_t;
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__APPLE__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/__stddef_max_align_t.h" 3
typedef long double max_align_t;
#else
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/__stddef_max_align_t.h" 3
// Define 'max_align_t' to match the GCC definition.
typedef struct {
  long long __clang_max_align_nonce1
      __attribute__((__aligned__(__alignof__(long long))));
  long double __clang_max_align_nonce2
      __attribute__((__aligned__(__alignof__(long double))));
} max_align_t;
#endif
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/__stddef_max_align_t.h" 3

#endif
# 28 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/__stddef_max_align_t.h" 3
# 103 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 2 3
#endif
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define offsetof(t, d) __builtin_offsetof(t, d)
#undef __need_STDDEF_H_misc
#endif  /* defined(__need_STDDEF_H_misc) */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

/* Some C libraries expect to see a wint_t here. Others (notably MinGW) will use
__WINT_TYPE__ directly; accommodate both by requiring __need_wint_t */
#if 0 /* disabled by -frewrite-includes */
#if defined(__need_wint_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define wint_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_WINT_T) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 113 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _WINT_T
#endif
# 116 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __WINT_TYPE__ wint_t;
#endif
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_wint_t
#endif /* __need_wint_t */
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#endif
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <__nullptr>
#endif /* expanded by -frewrite-includes */
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 1 3
// -*- C++ -*-
//===--------------------------- __nullptr --------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_NULLPTR
#define _LIBCPP_NULLPTR

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 3
#endif
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 3

#ifdef _LIBCPP_HAS_NO_NULLPTR

_LIBCPP_BEGIN_NAMESPACE_STD

struct _LIBCPP_TEMPLATE_VIS nullptr_t
{
    void* __lx;

    struct __nat {int __for_bool_;};

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR nullptr_t() : __lx(0) {}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR nullptr_t(int __nat::*) : __lx(0) {}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR operator int __nat::*() const {return 0;}

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
        operator _Tp* () const {return 0;}

    template <class _Tp, class _Up>
        _LIBCPP_INLINE_VISIBILITY
        operator _Tp _Up::* () const {return 0;}

    friend _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR bool operator==(nullptr_t, nullptr_t) {return true;}
    friend _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR bool operator!=(nullptr_t, nullptr_t) {return false;}
};

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR nullptr_t __get_nullptr_t() {return nullptr_t(0);}

#define nullptr _VSTD::__get_nullptr_t()

_LIBCPP_END_NAMESPACE_STD

#else  // _LIBCPP_HAS_NO_NULLPTR
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 3

namespace std
{
    typedef decltype(nullptr) nullptr_t;
}

#endif  // _LIBCPP_HAS_NO_NULLPTR
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 3

#endif  // _LIBCPP_NULLPTR
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__nullptr" 3
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 2 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::ptrdiff_t;
using ::size_t;

#if 0 /* disabled by -frewrite-includes */
#if defined(__CLANG_MAX_ALIGN_T_DEFINED) || defined(_GCC_MAX_ALIGN_T) || \
    defined(__DEFINED_max_align_t) || defined(__NetBSD__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 54 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
// Re-use the compiler's <stddef.h> max_align_t where possible.
using ::max_align_t;
#else
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
typedef long double max_align_t;
#endif
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3

template <class _Tp> struct __libcpp_is_integral                     { enum { value = 0 }; };
template <>          struct __libcpp_is_integral<bool>               { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<char>               { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<signed char>        { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<unsigned char>      { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<wchar_t>            { enum { value = 1 }; };
#ifndef _LIBCPP_NO_HAS_CHAR8_T
template <>          struct __libcpp_is_integral<char8_t>            { enum { value = 1 }; };
#endif
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
template <>          struct __libcpp_is_integral<char16_t>           { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<char32_t>           { enum { value = 1 }; };
#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 73 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
template <>          struct __libcpp_is_integral<short>              { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<unsigned short>     { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<int>                { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<unsigned int>       { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<long>               { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<unsigned long>      { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<long long>          { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<unsigned long long> { enum { value = 1 }; };
#ifndef _LIBCPP_HAS_NO_INT128
template <>          struct __libcpp_is_integral<__int128_t>         { enum { value = 1 }; };
template <>          struct __libcpp_is_integral<__uint128_t>        { enum { value = 1 }; };
#endif
# 85 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3

_LIBCPP_END_NAMESPACE_STD

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 89 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
namespace std  // purposefully not versioned
{
enum class byte : unsigned char {};


template <bool> struct __enable_if_integral_imp {};
template <> struct __enable_if_integral_imp<true> { using type = byte; };
template <class _Tp> using _EnableByteOverload = typename __enable_if_integral_imp<__libcpp_is_integral<_Tp>::value>::type;

constexpr byte  operator| (byte  __lhs, byte __rhs) noexcept
{
    return static_cast<byte>(
      static_cast<unsigned char>(
         static_cast<unsigned int>(__lhs) | static_cast<unsigned int>(__rhs)
    ));
}

constexpr byte& operator|=(byte& __lhs, byte __rhs) noexcept
{ return __lhs = __lhs | __rhs; }

constexpr byte  operator& (byte  __lhs, byte __rhs) noexcept
{
    return static_cast<byte>(
      static_cast<unsigned char>(
         static_cast<unsigned int>(__lhs) & static_cast<unsigned int>(__rhs)
    ));
}

constexpr byte& operator&=(byte& __lhs, byte __rhs) noexcept
{ return __lhs = __lhs & __rhs; }

constexpr byte  operator^ (byte  __lhs, byte __rhs) noexcept
{
    return static_cast<byte>(
      static_cast<unsigned char>(
         static_cast<unsigned int>(__lhs) ^ static_cast<unsigned int>(__rhs)
    ));
}

constexpr byte& operator^=(byte& __lhs, byte __rhs) noexcept
{ return __lhs = __lhs ^ __rhs; }

constexpr byte  operator~ (byte __b) noexcept
{
    return static_cast<byte>(
      static_cast<unsigned char>(
        ~static_cast<unsigned int>(__b)
    ));
}
template <class _Integer>
  constexpr _EnableByteOverload<_Integer> &
  operator<<=(byte& __lhs, _Integer __shift) noexcept
  { return __lhs = __lhs << __shift; }

template <class _Integer>
  constexpr _EnableByteOverload<_Integer>
  operator<< (byte  __lhs, _Integer __shift) noexcept
  { return static_cast<byte>(static_cast<unsigned char>(static_cast<unsigned int>(__lhs) << __shift)); }

template <class _Integer>
  constexpr _EnableByteOverload<_Integer> &
  operator>>=(byte& __lhs, _Integer __shift) noexcept
  { return __lhs = __lhs >> __shift; }

template <class _Integer>
  constexpr _EnableByteOverload<_Integer>
  operator>> (byte  __lhs, _Integer __shift) noexcept
  { return static_cast<byte>(static_cast<unsigned char>(static_cast<unsigned int>(__lhs) >> __shift)); }

template <class _Integer, class = _EnableByteOverload<_Integer> >
  constexpr _Integer
  to_integer(byte __b) noexcept { return static_cast<_Integer>(__b); }
}

#endif
# 164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3

#endif  // _LIBCPP_CSTDDEF
# 166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstddef" 3
# 81 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 81 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 1 3
// -*- C++ -*-
//===--------------------------- cstdlib ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDLIB
#define _LIBCPP_CSTDLIB

/*
    cstdlib synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

namespace std
{

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 84 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
# 85 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 85 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 1 3 4
/*
 * Copyright (c) 2000, 2002 - 2008 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)stdlib.h	8.5 (Berkeley) 5/19/95
 */

#ifndef _STDLIB_H_
#define _STDLIB_H_

#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 61 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 1 3 4
/*
 * Copyright (c) 2007-2016 by Apple Inc.. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
 
#ifndef __AVAILABILITY__
#define __AVAILABILITY__
 /*     
    These macros are for use in OS header files. They enable function prototypes
    and Objective-C methods to be tagged with the OS version in which they
    were first available; and, if applicable, the OS version in which they 
    became deprecated.  
     
    The desktop Mac OS X and iOS each have different version numbers.
    The __OSX_AVAILABLE_STARTING() macro allows you to specify both the desktop
    and iOS version numbers.  For instance:
        __OSX_AVAILABLE_STARTING(__MAC_10_2,__IPHONE_2_0)
    means the function/method was first available on Mac OS X 10.2 on the desktop
    and first available in iOS 2.0 on the iPhone.
    
    If a function is available on one platform, but not the other a _NA (not
    applicable) parameter is used.  For instance:
            __OSX_AVAILABLE_STARTING(__MAC_10_3,__IPHONE_NA)
    means that the function/method was first available on Mac OS X 10.3, and it
    currently not implemented on the iPhone.

    At some point, a function/method may be deprecated.  That means Apple
    recommends applications stop using the function, either because there is a 
    better replacement or the functionality is being phased out.  Deprecated
    functions/methods can be tagged with a __OSX_AVAILABLE_BUT_DEPRECATED()
    macro which specifies the OS version where the function became available
    as well as the OS version in which it became deprecated.  For instance:
        __OSX_AVAILABLE_BUT_DEPRECATED(__MAC_10_0,__MAC_10_5,__IPHONE_NA,__IPHONE_NA)
    means that the function/method was introduced in Mac OS X 10.0, then
    became deprecated beginning in Mac OS X 10.5.  On iOS the function 
    has never been available.  
    
    For these macros to function properly, a program must specify the OS version range 
    it is targeting.  The min OS version is specified as an option to the compiler:
    -mmacosx-version-min=10.x when building for Mac OS X, and -miphoneos-version-min=y.z
    when building for the iPhone.  The upper bound for the OS version is rarely needed,
    but it can be set on the command line via: -D__MAC_OS_X_VERSION_MAX_ALLOWED=10x0 for
    Mac OS X and __IPHONE_OS_VERSION_MAX_ALLOWED = y0z00 for iOS.  
    
    Examples:

        A function available in Mac OS X 10.5 and later, but not on the phone:
        
            extern void mymacfunc() __OSX_AVAILABLE_STARTING(__MAC_10_5,__IPHONE_NA);


        An Objective-C method in Mac OS X 10.5 and later, but not on the phone:
        
            @interface MyClass : NSObject
            -(void) mymacmethod __OSX_AVAILABLE_STARTING(__MAC_10_5,__IPHONE_NA);
            @end

        
        An enum available on the phone, but not available on Mac OS X:
        
            #if __IPHONE_OS_VERSION_MIN_REQUIRED
                enum { myEnum = 1 };
            #endif
           Note: this works when targeting the Mac OS X platform because 
           __IPHONE_OS_VERSION_MIN_REQUIRED is undefined which evaluates to zero. 
        

        An enum with values added in different iPhoneOS versions:
		
			enum {
			    myX  = 1,	// Usable on iPhoneOS 2.1 and later
			    myY  = 2,	// Usable on iPhoneOS 3.0 and later
			    myZ  = 3,	// Usable on iPhoneOS 3.0 and later
				...
		      Note: you do not want to use #if with enumeration values
			  when a client needs to see all values at compile time
			  and use runtime logic to only use the viable values.
			  

    It is also possible to use the *_VERSION_MIN_REQUIRED in source code to make one
    source base that can be compiled to target a range of OS versions.  It is best
    to not use the _MAC_* and __IPHONE_* macros for comparisons, but rather their values.
    That is because you might get compiled on an old OS that does not define a later
    OS version macro, and in the C preprocessor undefined values evaluate to zero
    in expresssions, which could cause the #if expression to evaluate in an unexpected
    way.
    
        #ifdef __MAC_OS_X_VERSION_MIN_REQUIRED
            // code only compiled when targeting Mac OS X and not iPhone
            // note use of 1050 instead of __MAC_10_5
            #if __MAC_OS_X_VERSION_MIN_REQUIRED < 1050
                // code in here might run on pre-Leopard OS
            #else
                // code here can assume Leopard or later
            #endif
        #endif


*/

/* 
 * __API_TO_BE_DEPRECATED is used as a version number in API that will be deprecated 
 * in an upcoming release. This soft deprecation is an intermediate step before formal 
 * deprecation to notify developers about the API before compiler warnings are generated.
 * You can find all places in your code that use soft deprecated API by redefining the 
 * value of this macro to your current minimum deployment target, for example:
 * (macOS)
 *   clang -D__API_TO_BE_DEPRECATED=10.12 <other compiler flags>
 * (iOS)
 *   clang -D__API_TO_BE_DEPRECATED=11.0 <other compiler flags>
 */
 
#ifndef __API_TO_BE_DEPRECATED
#define __API_TO_BE_DEPRECATED 100000
#endif
# 134 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#define __MAC_10_0            1000
#define __MAC_10_1            1010
#define __MAC_10_2            1020
#define __MAC_10_3            1030
#define __MAC_10_4            1040
#define __MAC_10_5            1050
#define __MAC_10_6            1060
#define __MAC_10_7            1070
#define __MAC_10_8            1080
#define __MAC_10_9            1090
#define __MAC_10_10         101000
#define __MAC_10_10_2       101002
#define __MAC_10_10_3       101003
#define __MAC_10_11         101100
#define __MAC_10_11_2       101102
#define __MAC_10_11_3       101103
#define __MAC_10_11_4       101104
#define __MAC_10_12         101200
#define __MAC_10_12_1       101201
#define __MAC_10_12_2       101202
#define __MAC_10_12_4       101204
#define __MAC_10_13         101300
#define __MAC_10_13_1       101301
#define __MAC_10_13_2       101302
#define __MAC_10_13_4       101304
#define __MAC_10_14         101400
#define __MAC_10_14_1       101401
#define __MAC_10_14_4       101404
/* __MAC_NA is not defined to a value but is uses as a token by macros to indicate that the API is unavailable */

#define __IPHONE_2_0      20000
#define __IPHONE_2_1      20100
#define __IPHONE_2_2      20200
#define __IPHONE_3_0      30000
#define __IPHONE_3_1      30100
#define __IPHONE_3_2      30200
#define __IPHONE_4_0      40000
#define __IPHONE_4_1      40100
#define __IPHONE_4_2      40200
#define __IPHONE_4_3      40300
#define __IPHONE_5_0      50000
#define __IPHONE_5_1      50100
#define __IPHONE_6_0      60000
#define __IPHONE_6_1      60100
#define __IPHONE_7_0      70000
#define __IPHONE_7_1      70100
#define __IPHONE_8_0      80000
#define __IPHONE_8_1      80100
#define __IPHONE_8_2      80200
#define __IPHONE_8_3      80300
#define __IPHONE_8_4      80400
#define __IPHONE_9_0      90000
#define __IPHONE_9_1      90100
#define __IPHONE_9_2      90200
#define __IPHONE_9_3      90300
#define __IPHONE_10_0    100000
#define __IPHONE_10_1    100100
#define __IPHONE_10_2    100200
#define __IPHONE_10_3    100300
#define __IPHONE_11_0    110000
#define __IPHONE_11_1    110100
#define __IPHONE_11_2    110200
#define __IPHONE_11_3    110300
#define __IPHONE_11_4    110400
#define __IPHONE_12_0    120000
#define __IPHONE_12_1    120100
#define __IPHONE_12_2    120200
/* __IPHONE_NA is not defined to a value but is uses as a token by macros to indicate that the API is unavailable */

#define __TVOS_9_0        90000
#define __TVOS_9_1        90100
#define __TVOS_9_2        90200
#define __TVOS_10_0      100000
#define __TVOS_10_0_1    100001
#define __TVOS_10_1      100100
#define __TVOS_10_2      100200
#define __TVOS_11_0      110000
#define __TVOS_11_1      110100
#define __TVOS_11_2      110200
#define __TVOS_11_3      110300
#define __TVOS_11_4      110400
#define __TVOS_12_0      120000
#define __TVOS_12_1      120100
#define __TVOS_12_2      120200

#define __WATCHOS_1_0     10000
#define __WATCHOS_2_0     20000
#define __WATCHOS_2_1     20100
#define __WATCHOS_2_2     20200
#define __WATCHOS_3_0     30000
#define __WATCHOS_3_1     30100
#define __WATCHOS_3_1_1   30101
#define __WATCHOS_3_2     30200
#define __WATCHOS_4_0     40000
#define __WATCHOS_4_1     40100
#define __WATCHOS_4_2     40200
#define __WATCHOS_4_3     40300
#define __WATCHOS_5_0     50000
#define __WATCHOS_5_1     50100
#define __WATCHOS_5_2     50200

#if 0 /* expanded by -frewrite-includes */
#include <AvailabilityInternal.h>
#endif /* expanded by -frewrite-includes */
# 236 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 1 3 4
/*
 * Copyright (c) 2007-2016 by Apple Inc.. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

/*
    File:       AvailabilityInternal.h
 
    Contains:   implementation details of __OSX_AVAILABLE_* macros from <Availability.h>

*/
#ifndef __AVAILABILITY_INTERNAL__
#define __AVAILABILITY_INTERNAL__

#if 0 /* disabled by -frewrite-includes */
#if __has_include(<AvailabilityInternalPrivate.h>)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
  #if 0 /* expanded by -frewrite-includes */
#include <AvailabilityInternalPrivate.h>
#endif /* expanded by -frewrite-includes */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#endif
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

#ifndef __IPHONE_OS_VERSION_MIN_REQUIRED
    #ifdef __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__
        /* compiler sets __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ when -miphoneos-version-min is used */
        #define __IPHONE_OS_VERSION_MIN_REQUIRED __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__
    #endif
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#endif
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

#ifndef __TV_OS_VERSION_MIN_REQUIRED
    #ifdef __ENVIRONMENT_TV_OS_VERSION_MIN_REQUIRED__
        /* compiler sets __ENVIRONMENT_TV_OS_VERSION_MIN_REQUIRED__ when -mtvos-version-min is used */
        #define __TV_OS_VERSION_MIN_REQUIRED __ENVIRONMENT_TV_OS_VERSION_MIN_REQUIRED__
        #define __TV_OS_VERSION_MAX_ALLOWED __TVOS_12_0 
        /* for compatibility with existing code.  New code should use platform specific checks */
        #define __IPHONE_OS_VERSION_MIN_REQUIRED 90000
    #endif
# 52 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#endif
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

#ifndef __WATCH_OS_VERSION_MIN_REQUIRED
    #ifdef __ENVIRONMENT_WATCH_OS_VERSION_MIN_REQUIRED__
        /* compiler sets __ENVIRONMENT_WATCH_OS_VERSION_MIN_REQUIRED__ when -mwatchos-version-min is used */
        #define __WATCH_OS_VERSION_MIN_REQUIRED __ENVIRONMENT_WATCH_OS_VERSION_MIN_REQUIRED__
        #define __WATCH_OS_VERSION_MAX_ALLOWED 50000
        /* for compatibility with existing code.  New code should use platform specific checks */
        #define __IPHONE_OS_VERSION_MIN_REQUIRED 90000
    #endif
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#endif
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

#ifndef __BRIDGE_OS_VERSION_MIN_REQUIRED
    #ifdef __ENVIRONMENT_BRIDGE_OS_VERSION_MIN_REQUIRED__
        
        #define __BRIDGE_OS_VERSION_MIN_REQUIRED __ENVIRONMENT_BRIDGE_OS_VERSION_MIN_REQUIRED__
        #define __BRIDGE_OS_VERSION_MAX_ALLOWED 20000
        /* for compatibility with existing code.  New code should use platform specific checks */
        #define __IPHONE_OS_VERSION_MIN_REQUIRED 110000
    #endif
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#endif
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4



#define __AVAILABILITY_INTERNAL_DEPRECATED            __attribute__((deprecated))
#ifdef __has_feature
    
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_deprecated_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)  __attribute__((deprecated(_msg)))
    #else
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)  __attribute__((deprecated))
    #endif
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__) && ((__GNUC__ >= 5) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 5)))
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
    #define __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)  __attribute__((deprecated(_msg)))
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
    #define __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)  __attribute__((deprecated))
#endif
# 88 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#define __AVAILABILITY_INTERNAL_UNAVAILABLE           __attribute__((unavailable))
#define __AVAILABILITY_INTERNAL_WEAK_IMPORT           __attribute__((weak_import))
#define __AVAILABILITY_INTERNAL_REGULAR            

#ifdef __IPHONE_OS_VERSION_MIN_REQUIRED
    /* make sure a default max version is set */
    #ifndef __IPHONE_OS_VERSION_MAX_ALLOWED
        #define __IPHONE_OS_VERSION_MAX_ALLOWED     __IPHONE_12_2
    #endif
# 97 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
    /* make sure a valid min is set */
    
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 99 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #undef __IPHONE_OS_VERSION_MIN_REQUIRED
        #define __IPHONE_OS_VERSION_MIN_REQUIRED    __IPHONE_2_0 
    #endif
# 102 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

    
#if 0 /* disabled by -frewrite-includes */
#if defined(__has_attribute) && defined(__has_feature)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 104 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(availability)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            /* use better attributes if possible */
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0                    __attribute__((availability(ios,introduced=2.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_0    __attribute__((availability(ios,introduced=2.0,deprecated=2.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=2.0,message=_msg)))
            #else
# 111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=2.0)))
            #endif
# 113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_1    __attribute__((availability(ios,introduced=2.0,deprecated=2.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=2.1,message=_msg)))
            #else
# 117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=2.1)))
            #endif
# 119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2    __attribute__((availability(ios,introduced=2.0,deprecated=2.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=2.2,message=_msg)))
            #else
# 123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=2.2)))
            #endif
# 125 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0    __attribute__((availability(ios,introduced=2.0,deprecated=3.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=3.0,message=_msg)))
            #else
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=3.0)))
            #endif
# 131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1    __attribute__((availability(ios,introduced=2.0,deprecated=3.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 133 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=3.1,message=_msg)))
            #else
# 135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=3.1)))
            #endif
# 137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2    __attribute__((availability(ios,introduced=2.0,deprecated=3.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=3.2,message=_msg)))
            #else
# 141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=3.2)))
            #endif
# 143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0    __attribute__((availability(ios,introduced=2.0,deprecated=4.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=4.0,message=_msg)))
            #else
# 147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=4.0)))
            #endif
# 149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1    __attribute__((availability(ios,introduced=2.0,deprecated=4.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=4.1,message=_msg)))
            #else
# 153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=4.1)))
            #endif
# 155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=2.0,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=4.2,message=_msg)))
            #else
# 159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=4.2)))
            #endif
# 161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=2.0,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=4.3,message=_msg)))
            #else
# 165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=4.3)))
            #endif
# 167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=2.0,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=5.0,message=_msg)))
            #else
# 171 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=5.0)))
            #endif
# 173 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=2.0,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=5.1,message=_msg)))
            #else
# 177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=5.1)))
            #endif
# 179 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=2.0,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 181 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=6.0,message=_msg)))
            #else
# 183 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=6.0)))
            #endif
# 185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=2.0,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=6.1,message=_msg)))
            #else
# 189 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=6.1)))
            #endif
# 191 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=2.0,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 193 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=7.0,message=_msg)))
            #else
# 195 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=7.0)))
            #endif
# 197 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=2.0,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 199 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=7.1,message=_msg)))
            #else
# 201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=7.1)))
            #endif
# 203 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=2.0,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 205 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.0,message=_msg)))
            #else
# 207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.0)))
            #endif
# 209 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=2.0,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.1,message=_msg)))
            #else
# 213 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.1)))
            #endif
# 215 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=2.0,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 217 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.2,message=_msg)))
            #else
# 219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.2)))
            #endif
# 221 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=2.0,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.3,message=_msg)))
            #else
# 225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.3)))
            #endif
# 227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=2.0,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.4,message=_msg)))
            #else
# 231 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=8.4)))
            #endif
# 233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=2.0,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 235 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=9.0,message=_msg)))
            #else
# 237 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=9.0)))
            #endif
# 239 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=2.0,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=9.1,message=_msg)))
            #else
# 243 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=9.1)))
            #endif
# 245 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=2.0,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 247 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=9.2,message=_msg)))
            #else
# 249 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=9.2)))
            #endif
# 251 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=2.0,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=9.3,message=_msg)))
            #else
# 255 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=9.3)))
            #endif
# 257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=2.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=10.0,message=_msg)))
            #else
# 261 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=10.0)))
            #endif
# 263 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=2.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 265 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=10.1,message=_msg)))
            #else
# 267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=10.1)))
            #endif
# 269 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=2.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=10.2,message=_msg)))
            #else
# 273 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=10.2)))
            #endif
# 275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=2.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 277 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=10.3,message=_msg)))
            #else
# 279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=10.3)))
            #endif
# 281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=2.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.0,message=_msg)))
            #else
# 285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.0)))
            #endif
# 287 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=2.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 289 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.1,message=_msg)))
            #else
# 291 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.1)))
            #endif
# 293 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=2.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 295 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.2,message=_msg)))
            #else
# 297 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.2)))
            #endif
# 299 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=2.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.3,message=_msg)))
            #else
# 303 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.3)))
            #endif
# 305 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=2.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 307 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.4,message=_msg)))
            #else
# 309 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=11.4)))
            #endif
# 311 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=2.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 313 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=12.0,message=_msg)))
            #else
# 315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=12.0)))
            #endif
# 317 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=2.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 319 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=12.1,message=_msg)))
            #else
# 321 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=12.1)))
            #endif
# 323 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=2.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=12.2,message=_msg)))
            #else
# 327 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.0,deprecated=12.2)))
            #endif
# 329 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=2.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=2.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1                    __attribute__((availability(ios,introduced=2.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_1    __attribute__((availability(ios,introduced=2.1,deprecated=2.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 334 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=2.1,message=_msg)))
            #else
# 336 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=2.1)))
            #endif
# 338 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2    __attribute__((availability(ios,introduced=2.1,deprecated=2.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 340 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=2.2,message=_msg)))
            #else
# 342 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=2.2)))
            #endif
# 344 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0    __attribute__((availability(ios,introduced=2.1,deprecated=3.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 346 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=3.0,message=_msg)))
            #else
# 348 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=3.0)))
            #endif
# 350 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1    __attribute__((availability(ios,introduced=2.1,deprecated=3.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=3.1,message=_msg)))
            #else
# 354 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=3.1)))
            #endif
# 356 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2    __attribute__((availability(ios,introduced=2.1,deprecated=3.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 358 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=3.2,message=_msg)))
            #else
# 360 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=3.2)))
            #endif
# 362 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0    __attribute__((availability(ios,introduced=2.1,deprecated=4.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 364 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=4.0,message=_msg)))
            #else
# 366 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=4.0)))
            #endif
# 368 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1    __attribute__((availability(ios,introduced=2.1,deprecated=4.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 370 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=4.1,message=_msg)))
            #else
# 372 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=4.1)))
            #endif
# 374 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=2.1,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=4.2,message=_msg)))
            #else
# 378 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=4.2)))
            #endif
# 380 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=2.1,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 382 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=4.3,message=_msg)))
            #else
# 384 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=4.3)))
            #endif
# 386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=2.1,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 388 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=5.0,message=_msg)))
            #else
# 390 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=5.0)))
            #endif
# 392 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=2.1,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 394 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=5.1,message=_msg)))
            #else
# 396 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=5.1)))
            #endif
# 398 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=2.1,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 400 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=6.0,message=_msg)))
            #else
# 402 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=6.0)))
            #endif
# 404 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=2.1,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 406 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=6.1,message=_msg)))
            #else
# 408 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=6.1)))
            #endif
# 410 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=2.1,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=7.0,message=_msg)))
            #else
# 414 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=7.0)))
            #endif
# 416 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=2.1,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 418 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=7.1,message=_msg)))
            #else
# 420 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=7.1)))
            #endif
# 422 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=2.1,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 424 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.0,message=_msg)))
            #else
# 426 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.0)))
            #endif
# 428 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=2.1,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 430 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.1,message=_msg)))
            #else
# 432 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.1)))
            #endif
# 434 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=2.1,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 436 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.2,message=_msg)))
            #else
# 438 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.2)))
            #endif
# 440 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=2.1,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 442 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.3,message=_msg)))
            #else
# 444 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.3)))
            #endif
# 446 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=2.1,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 448 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.4,message=_msg)))
            #else
# 450 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=8.4)))
            #endif
# 452 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=2.1,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 454 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=9.0,message=_msg)))
            #else
# 456 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=9.0)))
            #endif
# 458 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=2.1,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 460 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=9.1,message=_msg)))
            #else
# 462 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=9.1)))
            #endif
# 464 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=2.1,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 466 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=9.2,message=_msg)))
            #else
# 468 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=9.2)))
            #endif
# 470 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=2.1,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 472 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=9.3,message=_msg)))
            #else
# 474 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=9.3)))
            #endif
# 476 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=2.1,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 478 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=10.0,message=_msg)))
            #else
# 480 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=10.0)))
            #endif
# 482 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=2.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 484 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=10.1,message=_msg)))
            #else
# 486 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=10.1)))
            #endif
# 488 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=2.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 490 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=10.2,message=_msg)))
            #else
# 492 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=10.2)))
            #endif
# 494 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=2.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 496 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=10.3,message=_msg)))
            #else
# 498 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=10.3)))
            #endif
# 500 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=2.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 502 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.0,message=_msg)))
            #else
# 504 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.0)))
            #endif
# 506 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=2.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 508 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.1,message=_msg)))
            #else
# 510 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.1)))
            #endif
# 512 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=2.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 514 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.2,message=_msg)))
            #else
# 516 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.2)))
            #endif
# 518 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=2.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 520 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.3,message=_msg)))
            #else
# 522 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.3)))
            #endif
# 524 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=2.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 526 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.4,message=_msg)))
            #else
# 528 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=11.4)))
            #endif
# 530 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=2.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 532 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=12.0,message=_msg)))
            #else
# 534 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=12.0)))
            #endif
# 536 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=2.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 538 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=12.1,message=_msg)))
            #else
# 540 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=12.1)))
            #endif
# 542 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=2.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 544 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=12.2,message=_msg)))
            #else
# 546 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.1,deprecated=12.2)))
            #endif
# 548 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=2.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=2.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2                    __attribute__((availability(ios,introduced=2.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2    __attribute__((availability(ios,introduced=2.2,deprecated=2.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 553 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=2.2,message=_msg)))
            #else
# 555 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=2.2)))
            #endif
# 557 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0    __attribute__((availability(ios,introduced=2.2,deprecated=3.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 559 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=3.0,message=_msg)))
            #else
# 561 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=3.0)))
            #endif
# 563 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1    __attribute__((availability(ios,introduced=2.2,deprecated=3.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 565 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=3.1,message=_msg)))
            #else
# 567 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=3.1)))
            #endif
# 569 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2    __attribute__((availability(ios,introduced=2.2,deprecated=3.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 571 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=3.2,message=_msg)))
            #else
# 573 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=3.2)))
            #endif
# 575 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0    __attribute__((availability(ios,introduced=2.2,deprecated=4.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 577 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=4.0,message=_msg)))
            #else
# 579 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=4.0)))
            #endif
# 581 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1    __attribute__((availability(ios,introduced=2.2,deprecated=4.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 583 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=4.1,message=_msg)))
            #else
# 585 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=4.1)))
            #endif
# 587 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=2.2,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 589 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=4.2,message=_msg)))
            #else
# 591 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=4.2)))
            #endif
# 593 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=2.2,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 595 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=4.3,message=_msg)))
            #else
# 597 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=4.3)))
            #endif
# 599 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=2.2,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 601 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=5.0,message=_msg)))
            #else
# 603 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=5.0)))
            #endif
# 605 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=2.2,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 607 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=5.1,message=_msg)))
            #else
# 609 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=5.1)))
            #endif
# 611 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=2.2,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 613 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=6.0,message=_msg)))
            #else
# 615 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=6.0)))
            #endif
# 617 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=2.2,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 619 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=6.1,message=_msg)))
            #else
# 621 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=6.1)))
            #endif
# 623 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=2.2,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 625 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=7.0,message=_msg)))
            #else
# 627 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=7.0)))
            #endif
# 629 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=2.2,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 631 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=7.1,message=_msg)))
            #else
# 633 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=7.1)))
            #endif
# 635 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=2.2,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 637 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.0,message=_msg)))
            #else
# 639 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.0)))
            #endif
# 641 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=2.2,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 643 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.1,message=_msg)))
            #else
# 645 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.1)))
            #endif
# 647 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=2.2,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 649 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.2,message=_msg)))
            #else
# 651 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.2)))
            #endif
# 653 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=2.2,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 655 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.3,message=_msg)))
            #else
# 657 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.3)))
            #endif
# 659 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=2.2,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 661 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.4,message=_msg)))
            #else
# 663 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=8.4)))
            #endif
# 665 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=2.2,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 667 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=9.0,message=_msg)))
            #else
# 669 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=9.0)))
            #endif
# 671 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=2.2,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 673 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=9.1,message=_msg)))
            #else
# 675 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=9.1)))
            #endif
# 677 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=2.2,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 679 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=9.2,message=_msg)))
            #else
# 681 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=9.2)))
            #endif
# 683 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=2.2,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 685 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=9.3,message=_msg)))
            #else
# 687 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=9.3)))
            #endif
# 689 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=2.2,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 691 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=10.0,message=_msg)))
            #else
# 693 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=10.0)))
            #endif
# 695 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=2.2,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 697 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=10.1,message=_msg)))
            #else
# 699 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=10.1)))
            #endif
# 701 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=2.2,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 703 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=10.2,message=_msg)))
            #else
# 705 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=10.2)))
            #endif
# 707 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=2.2,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 709 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=10.3,message=_msg)))
            #else
# 711 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=10.3)))
            #endif
# 713 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=2.2,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 715 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.0,message=_msg)))
            #else
# 717 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.0)))
            #endif
# 719 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=2.2,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 721 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.1,message=_msg)))
            #else
# 723 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.1)))
            #endif
# 725 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=2.2,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 727 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.2,message=_msg)))
            #else
# 729 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.2)))
            #endif
# 731 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=2.2,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 733 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.3,message=_msg)))
            #else
# 735 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.3)))
            #endif
# 737 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=2.2,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 739 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.4,message=_msg)))
            #else
# 741 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=11.4)))
            #endif
# 743 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=2.2,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 745 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=12.0,message=_msg)))
            #else
# 747 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=12.0)))
            #endif
# 749 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=2.2,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 751 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=12.1,message=_msg)))
            #else
# 753 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=12.1)))
            #endif
# 755 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=2.2,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 757 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=12.2,message=_msg)))
            #else
# 759 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=2.2,deprecated=12.2)))
            #endif
# 761 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=2.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=2.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0                    __attribute__((availability(ios,introduced=3.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0    __attribute__((availability(ios,introduced=3.0,deprecated=3.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 766 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=3.0,message=_msg)))
            #else
# 768 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=3.0)))
            #endif
# 770 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1    __attribute__((availability(ios,introduced=3.0,deprecated=3.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 772 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=3.1,message=_msg)))
            #else
# 774 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=3.1)))
            #endif
# 776 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2    __attribute__((availability(ios,introduced=3.0,deprecated=3.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 778 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=3.2,message=_msg)))
            #else
# 780 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=3.2)))
            #endif
# 782 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0    __attribute__((availability(ios,introduced=3.0,deprecated=4.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=4.0,message=_msg)))
            #else
# 786 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=4.0)))
            #endif
# 788 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1    __attribute__((availability(ios,introduced=3.0,deprecated=4.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 790 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=4.1,message=_msg)))
            #else
# 792 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=4.1)))
            #endif
# 794 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=3.0,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 796 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=4.2,message=_msg)))
            #else
# 798 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=4.2)))
            #endif
# 800 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=3.0,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 802 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=4.3,message=_msg)))
            #else
# 804 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=4.3)))
            #endif
# 806 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=3.0,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 808 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=5.0,message=_msg)))
            #else
# 810 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=5.0)))
            #endif
# 812 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=3.0,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 814 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=5.1,message=_msg)))
            #else
# 816 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=5.1)))
            #endif
# 818 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=3.0,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 820 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=6.0,message=_msg)))
            #else
# 822 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=6.0)))
            #endif
# 824 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=3.0,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 826 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=6.1,message=_msg)))
            #else
# 828 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=6.1)))
            #endif
# 830 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=3.0,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 832 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=7.0,message=_msg)))
            #else
# 834 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=7.0)))
            #endif
# 836 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=3.0,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 838 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=7.1,message=_msg)))
            #else
# 840 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=7.1)))
            #endif
# 842 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=3.0,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 844 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.0,message=_msg)))
            #else
# 846 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.0)))
            #endif
# 848 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=3.0,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 850 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.1,message=_msg)))
            #else
# 852 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.1)))
            #endif
# 854 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=3.0,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 856 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.2,message=_msg)))
            #else
# 858 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.2)))
            #endif
# 860 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=3.0,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 862 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.3,message=_msg)))
            #else
# 864 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.3)))
            #endif
# 866 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=3.0,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 868 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.4,message=_msg)))
            #else
# 870 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=8.4)))
            #endif
# 872 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=3.0,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 874 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=9.0,message=_msg)))
            #else
# 876 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=9.0)))
            #endif
# 878 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=3.0,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 880 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=9.1,message=_msg)))
            #else
# 882 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=9.1)))
            #endif
# 884 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=3.0,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 886 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=9.2,message=_msg)))
            #else
# 888 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=9.2)))
            #endif
# 890 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=3.0,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 892 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=9.3,message=_msg)))
            #else
# 894 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=9.3)))
            #endif
# 896 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=3.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 898 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=10.0,message=_msg)))
            #else
# 900 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=10.0)))
            #endif
# 902 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=3.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 904 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=10.1,message=_msg)))
            #else
# 906 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=10.1)))
            #endif
# 908 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=3.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 910 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=10.2,message=_msg)))
            #else
# 912 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=10.2)))
            #endif
# 914 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=3.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 916 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=10.3,message=_msg)))
            #else
# 918 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=10.3)))
            #endif
# 920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=3.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 922 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.0,message=_msg)))
            #else
# 924 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.0)))
            #endif
# 926 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=3.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 928 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.1,message=_msg)))
            #else
# 930 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.1)))
            #endif
# 932 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=3.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 934 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.2,message=_msg)))
            #else
# 936 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.2)))
            #endif
# 938 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=3.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 940 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.3,message=_msg)))
            #else
# 942 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.3)))
            #endif
# 944 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=3.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 946 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.4,message=_msg)))
            #else
# 948 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=11.4)))
            #endif
# 950 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=3.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 952 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=12.0,message=_msg)))
            #else
# 954 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=12.0)))
            #endif
# 956 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=3.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 958 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=12.1,message=_msg)))
            #else
# 960 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=12.1)))
            #endif
# 962 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=3.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 964 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=12.2,message=_msg)))
            #else
# 966 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.0,deprecated=12.2)))
            #endif
# 968 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=3.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=3.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1                    __attribute__((availability(ios,introduced=3.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1    __attribute__((availability(ios,introduced=3.1,deprecated=3.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 973 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=3.1,message=_msg)))
            #else
# 975 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=3.1)))
            #endif
# 977 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2    __attribute__((availability(ios,introduced=3.1,deprecated=3.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 979 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=3.2,message=_msg)))
            #else
# 981 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=3.2)))
            #endif
# 983 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0    __attribute__((availability(ios,introduced=3.1,deprecated=4.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 985 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=4.0,message=_msg)))
            #else
# 987 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=4.0)))
            #endif
# 989 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1    __attribute__((availability(ios,introduced=3.1,deprecated=4.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 991 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=4.1,message=_msg)))
            #else
# 993 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=4.1)))
            #endif
# 995 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=3.1,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 997 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=4.2,message=_msg)))
            #else
# 999 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=4.2)))
            #endif
# 1001 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=3.1,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1003 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=4.3,message=_msg)))
            #else
# 1005 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=4.3)))
            #endif
# 1007 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=3.1,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1009 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=5.0,message=_msg)))
            #else
# 1011 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=5.0)))
            #endif
# 1013 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=3.1,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1015 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=5.1,message=_msg)))
            #else
# 1017 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=5.1)))
            #endif
# 1019 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=3.1,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1021 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=6.0,message=_msg)))
            #else
# 1023 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=6.0)))
            #endif
# 1025 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=3.1,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1027 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=6.1,message=_msg)))
            #else
# 1029 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=6.1)))
            #endif
# 1031 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=3.1,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1033 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=7.0,message=_msg)))
            #else
# 1035 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=7.0)))
            #endif
# 1037 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=3.1,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1039 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=7.1,message=_msg)))
            #else
# 1041 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=7.1)))
            #endif
# 1043 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=3.1,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1045 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.0,message=_msg)))
            #else
# 1047 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.0)))
            #endif
# 1049 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=3.1,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1051 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.1,message=_msg)))
            #else
# 1053 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.1)))
            #endif
# 1055 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=3.1,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1057 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.2,message=_msg)))
            #else
# 1059 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.2)))
            #endif
# 1061 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=3.1,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1063 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.3,message=_msg)))
            #else
# 1065 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.3)))
            #endif
# 1067 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=3.1,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1069 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.4,message=_msg)))
            #else
# 1071 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=8.4)))
            #endif
# 1073 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=3.1,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1075 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=9.0,message=_msg)))
            #else
# 1077 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=9.0)))
            #endif
# 1079 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=3.1,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1081 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=9.1,message=_msg)))
            #else
# 1083 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=9.1)))
            #endif
# 1085 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=3.1,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1087 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=9.2,message=_msg)))
            #else
# 1089 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=9.2)))
            #endif
# 1091 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=3.1,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1093 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=9.3,message=_msg)))
            #else
# 1095 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=9.3)))
            #endif
# 1097 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=3.1,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1099 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=10.0,message=_msg)))
            #else
# 1101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=10.0)))
            #endif
# 1103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=3.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=10.1,message=_msg)))
            #else
# 1107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=10.1)))
            #endif
# 1109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=3.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=10.2,message=_msg)))
            #else
# 1113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=10.2)))
            #endif
# 1115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=3.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=10.3,message=_msg)))
            #else
# 1119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=10.3)))
            #endif
# 1121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=3.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.0,message=_msg)))
            #else
# 1125 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.0)))
            #endif
# 1127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=3.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.1,message=_msg)))
            #else
# 1131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.1)))
            #endif
# 1133 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=3.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.2,message=_msg)))
            #else
# 1137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.2)))
            #endif
# 1139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=3.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.3,message=_msg)))
            #else
# 1143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.3)))
            #endif
# 1145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=3.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.4,message=_msg)))
            #else
# 1149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=11.4)))
            #endif
# 1151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=3.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=12.0,message=_msg)))
            #else
# 1155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=12.0)))
            #endif
# 1157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=3.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=12.1,message=_msg)))
            #else
# 1161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=12.1)))
            #endif
# 1163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=3.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=12.2,message=_msg)))
            #else
# 1167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.1,deprecated=12.2)))
            #endif
# 1169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=3.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=3.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2                    __attribute__((availability(ios,introduced=3.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2    __attribute__((availability(ios,introduced=3.2,deprecated=3.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=3.2,message=_msg)))
            #else
# 1176 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=3.2)))
            #endif
# 1178 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0    __attribute__((availability(ios,introduced=3.2,deprecated=4.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=4.0,message=_msg)))
            #else
# 1182 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=4.0)))
            #endif
# 1184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1    __attribute__((availability(ios,introduced=3.2,deprecated=4.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=4.1,message=_msg)))
            #else
# 1188 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=4.1)))
            #endif
# 1190 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=3.2,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1192 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=4.2,message=_msg)))
            #else
# 1194 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=4.2)))
            #endif
# 1196 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=3.2,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1198 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=4.3,message=_msg)))
            #else
# 1200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=4.3)))
            #endif
# 1202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=3.2,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=5.0,message=_msg)))
            #else
# 1206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=5.0)))
            #endif
# 1208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=3.2,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=5.1,message=_msg)))
            #else
# 1212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=5.1)))
            #endif
# 1214 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=3.2,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=6.0,message=_msg)))
            #else
# 1218 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=6.0)))
            #endif
# 1220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=3.2,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1222 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=6.1,message=_msg)))
            #else
# 1224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=6.1)))
            #endif
# 1226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=3.2,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=7.0,message=_msg)))
            #else
# 1230 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=7.0)))
            #endif
# 1232 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=3.2,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1234 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=7.1,message=_msg)))
            #else
# 1236 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=7.1)))
            #endif
# 1238 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=3.2,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1240 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.0,message=_msg)))
            #else
# 1242 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.0)))
            #endif
# 1244 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=3.2,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1246 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.1,message=_msg)))
            #else
# 1248 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.1)))
            #endif
# 1250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=3.2,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1252 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.2,message=_msg)))
            #else
# 1254 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.2)))
            #endif
# 1256 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=3.2,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1258 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.3,message=_msg)))
            #else
# 1260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.3)))
            #endif
# 1262 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=3.2,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1264 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.4,message=_msg)))
            #else
# 1266 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=8.4)))
            #endif
# 1268 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=3.2,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1270 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=9.0,message=_msg)))
            #else
# 1272 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=9.0)))
            #endif
# 1274 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=3.2,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1276 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=9.1,message=_msg)))
            #else
# 1278 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=9.1)))
            #endif
# 1280 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=3.2,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1282 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=9.2,message=_msg)))
            #else
# 1284 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=9.2)))
            #endif
# 1286 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=3.2,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1288 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=9.3,message=_msg)))
            #else
# 1290 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=9.3)))
            #endif
# 1292 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=3.2,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1294 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=10.0,message=_msg)))
            #else
# 1296 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=10.0)))
            #endif
# 1298 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=3.2,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1300 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=10.1,message=_msg)))
            #else
# 1302 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=10.1)))
            #endif
# 1304 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=3.2,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=10.2,message=_msg)))
            #else
# 1308 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=10.2)))
            #endif
# 1310 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=3.2,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1312 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=10.3,message=_msg)))
            #else
# 1314 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=10.3)))
            #endif
# 1316 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=3.2,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1318 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.0,message=_msg)))
            #else
# 1320 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.0)))
            #endif
# 1322 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=3.2,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1324 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.1,message=_msg)))
            #else
# 1326 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.1)))
            #endif
# 1328 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=3.2,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1330 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.2,message=_msg)))
            #else
# 1332 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.2)))
            #endif
# 1334 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=3.2,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1336 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.3,message=_msg)))
            #else
# 1338 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.3)))
            #endif
# 1340 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=3.2,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1342 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.4,message=_msg)))
            #else
# 1344 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=11.4)))
            #endif
# 1346 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=3.2,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1348 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=12.0,message=_msg)))
            #else
# 1350 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=12.0)))
            #endif
# 1352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=3.2,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1354 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=12.1,message=_msg)))
            #else
# 1356 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=12.1)))
            #endif
# 1358 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=3.2,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1360 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=12.2,message=_msg)))
            #else
# 1362 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=3.2,deprecated=12.2)))
            #endif
# 1364 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=3.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=3.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0                    __attribute__((availability(ios,introduced=4.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0    __attribute__((availability(ios,introduced=4.0,deprecated=4.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1369 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=4.0,message=_msg)))
            #else
# 1371 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=4.0)))
            #endif
# 1373 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1    __attribute__((availability(ios,introduced=4.0,deprecated=4.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1375 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=4.1,message=_msg)))
            #else
# 1377 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=4.1)))
            #endif
# 1379 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=4.0,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1381 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=4.2,message=_msg)))
            #else
# 1383 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=4.2)))
            #endif
# 1385 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=4.0,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1387 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=4.3,message=_msg)))
            #else
# 1389 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=4.3)))
            #endif
# 1391 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=4.0,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1393 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=5.0,message=_msg)))
            #else
# 1395 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=5.0)))
            #endif
# 1397 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=4.0,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1399 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=5.1,message=_msg)))
            #else
# 1401 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=5.1)))
            #endif
# 1403 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=4.0,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1405 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=6.0,message=_msg)))
            #else
# 1407 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=6.0)))
            #endif
# 1409 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=4.0,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1411 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=6.1,message=_msg)))
            #else
# 1413 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=6.1)))
            #endif
# 1415 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=4.0,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1417 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=7.0,message=_msg)))
            #else
# 1419 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=7.0)))
            #endif
# 1421 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=4.0,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1423 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=7.1,message=_msg)))
            #else
# 1425 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=7.1)))
            #endif
# 1427 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=4.0,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1429 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.0,message=_msg)))
            #else
# 1431 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.0)))
            #endif
# 1433 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=4.0,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1435 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.1,message=_msg)))
            #else
# 1437 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.1)))
            #endif
# 1439 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=4.0,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1441 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.2,message=_msg)))
            #else
# 1443 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.2)))
            #endif
# 1445 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=4.0,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1447 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.3,message=_msg)))
            #else
# 1449 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.3)))
            #endif
# 1451 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=4.0,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1453 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.4,message=_msg)))
            #else
# 1455 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=8.4)))
            #endif
# 1457 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=4.0,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1459 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=9.0,message=_msg)))
            #else
# 1461 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=9.0)))
            #endif
# 1463 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=4.0,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1465 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=9.1,message=_msg)))
            #else
# 1467 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=9.1)))
            #endif
# 1469 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=4.0,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1471 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=9.2,message=_msg)))
            #else
# 1473 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=9.2)))
            #endif
# 1475 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=4.0,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1477 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=9.3,message=_msg)))
            #else
# 1479 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=9.3)))
            #endif
# 1481 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=4.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1483 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=10.0,message=_msg)))
            #else
# 1485 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=10.0)))
            #endif
# 1487 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=4.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1489 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=10.1,message=_msg)))
            #else
# 1491 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=10.1)))
            #endif
# 1493 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=4.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1495 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=10.2,message=_msg)))
            #else
# 1497 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=10.2)))
            #endif
# 1499 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=4.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1501 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=10.3,message=_msg)))
            #else
# 1503 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=10.3)))
            #endif
# 1505 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=4.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1507 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.0,message=_msg)))
            #else
# 1509 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.0)))
            #endif
# 1511 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=4.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1513 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.1,message=_msg)))
            #else
# 1515 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.1)))
            #endif
# 1517 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=4.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1519 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.2,message=_msg)))
            #else
# 1521 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.2)))
            #endif
# 1523 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=4.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.3,message=_msg)))
            #else
# 1527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.3)))
            #endif
# 1529 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=4.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1531 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.4,message=_msg)))
            #else
# 1533 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=11.4)))
            #endif
# 1535 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=4.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=12.0,message=_msg)))
            #else
# 1539 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=12.0)))
            #endif
# 1541 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=4.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1543 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=12.1,message=_msg)))
            #else
# 1545 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=12.1)))
            #endif
# 1547 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=4.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1549 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=12.2,message=_msg)))
            #else
# 1551 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.0,deprecated=12.2)))
            #endif
# 1553 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=4.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=4.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1                    __attribute__((availability(ios,introduced=4.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1    __attribute__((availability(ios,introduced=4.1,deprecated=4.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1558 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=4.1,message=_msg)))
            #else
# 1560 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=4.1)))
            #endif
# 1562 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=4.1,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1564 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=4.2,message=_msg)))
            #else
# 1566 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=4.2)))
            #endif
# 1568 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=4.1,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1570 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=4.3,message=_msg)))
            #else
# 1572 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=4.3)))
            #endif
# 1574 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=4.1,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1576 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=5.0,message=_msg)))
            #else
# 1578 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=5.0)))
            #endif
# 1580 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=4.1,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1582 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=5.1,message=_msg)))
            #else
# 1584 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=5.1)))
            #endif
# 1586 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=4.1,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1588 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=6.0,message=_msg)))
            #else
# 1590 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=6.0)))
            #endif
# 1592 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=4.1,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1594 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=6.1,message=_msg)))
            #else
# 1596 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=6.1)))
            #endif
# 1598 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=4.1,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1600 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=7.0,message=_msg)))
            #else
# 1602 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=7.0)))
            #endif
# 1604 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=4.1,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1606 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=7.1,message=_msg)))
            #else
# 1608 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=7.1)))
            #endif
# 1610 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=4.1,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1612 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.0,message=_msg)))
            #else
# 1614 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.0)))
            #endif
# 1616 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=4.1,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1618 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.1,message=_msg)))
            #else
# 1620 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.1)))
            #endif
# 1622 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=4.1,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1624 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.2,message=_msg)))
            #else
# 1626 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.2)))
            #endif
# 1628 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=4.1,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1630 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.3,message=_msg)))
            #else
# 1632 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.3)))
            #endif
# 1634 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=4.1,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1636 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.4,message=_msg)))
            #else
# 1638 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=8.4)))
            #endif
# 1640 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=4.1,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1642 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=9.0,message=_msg)))
            #else
# 1644 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=9.0)))
            #endif
# 1646 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=4.1,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1648 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=9.1,message=_msg)))
            #else
# 1650 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=9.1)))
            #endif
# 1652 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=4.1,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1654 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=9.2,message=_msg)))
            #else
# 1656 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=9.2)))
            #endif
# 1658 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=4.1,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1660 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=9.3,message=_msg)))
            #else
# 1662 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=9.3)))
            #endif
# 1664 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=4.1,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1666 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=10.0,message=_msg)))
            #else
# 1668 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=10.0)))
            #endif
# 1670 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=4.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1672 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=10.1,message=_msg)))
            #else
# 1674 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=10.1)))
            #endif
# 1676 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=4.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1678 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=10.2,message=_msg)))
            #else
# 1680 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=10.2)))
            #endif
# 1682 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=4.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1684 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=10.3,message=_msg)))
            #else
# 1686 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=10.3)))
            #endif
# 1688 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=4.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1690 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.0,message=_msg)))
            #else
# 1692 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.0)))
            #endif
# 1694 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=4.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1696 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.1,message=_msg)))
            #else
# 1698 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.1)))
            #endif
# 1700 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=4.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1702 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.2,message=_msg)))
            #else
# 1704 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.2)))
            #endif
# 1706 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=4.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1708 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.3,message=_msg)))
            #else
# 1710 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.3)))
            #endif
# 1712 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=4.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1714 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.4,message=_msg)))
            #else
# 1716 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=11.4)))
            #endif
# 1718 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=4.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1720 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=12.0,message=_msg)))
            #else
# 1722 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=12.0)))
            #endif
# 1724 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=4.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1726 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=12.1,message=_msg)))
            #else
# 1728 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=12.1)))
            #endif
# 1730 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=4.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1732 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=12.2,message=_msg)))
            #else
# 1734 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.1,deprecated=12.2)))
            #endif
# 1736 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=4.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=4.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2                    __attribute__((availability(ios,introduced=4.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2    __attribute__((availability(ios,introduced=4.2,deprecated=4.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1741 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=4.2,message=_msg)))
            #else
# 1743 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=4.2)))
            #endif
# 1745 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=4.2,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1747 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=4.3,message=_msg)))
            #else
# 1749 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=4.3)))
            #endif
# 1751 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=4.2,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1753 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=5.0,message=_msg)))
            #else
# 1755 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=5.0)))
            #endif
# 1757 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=4.2,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1759 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=5.1,message=_msg)))
            #else
# 1761 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=5.1)))
            #endif
# 1763 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=4.2,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1765 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=6.0,message=_msg)))
            #else
# 1767 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=6.0)))
            #endif
# 1769 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=4.2,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1771 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=6.1,message=_msg)))
            #else
# 1773 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=6.1)))
            #endif
# 1775 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=4.2,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1777 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=7.0,message=_msg)))
            #else
# 1779 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=7.0)))
            #endif
# 1781 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=4.2,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1783 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=7.1,message=_msg)))
            #else
# 1785 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=7.1)))
            #endif
# 1787 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=4.2,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1789 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.0,message=_msg)))
            #else
# 1791 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.0)))
            #endif
# 1793 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=4.2,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1795 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.1,message=_msg)))
            #else
# 1797 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.1)))
            #endif
# 1799 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=4.2,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1801 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.2,message=_msg)))
            #else
# 1803 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.2)))
            #endif
# 1805 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=4.2,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1807 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.3,message=_msg)))
            #else
# 1809 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.3)))
            #endif
# 1811 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=4.2,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1813 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.4,message=_msg)))
            #else
# 1815 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=8.4)))
            #endif
# 1817 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=4.2,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1819 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=9.0,message=_msg)))
            #else
# 1821 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=9.0)))
            #endif
# 1823 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=4.2,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1825 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=9.1,message=_msg)))
            #else
# 1827 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=9.1)))
            #endif
# 1829 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=4.2,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1831 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=9.2,message=_msg)))
            #else
# 1833 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=9.2)))
            #endif
# 1835 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=4.2,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1837 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=9.3,message=_msg)))
            #else
# 1839 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=9.3)))
            #endif
# 1841 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=4.2,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1843 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=10.0,message=_msg)))
            #else
# 1845 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=10.0)))
            #endif
# 1847 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=4.2,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1849 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=10.1,message=_msg)))
            #else
# 1851 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=10.1)))
            #endif
# 1853 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=4.2,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1855 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=10.2,message=_msg)))
            #else
# 1857 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=10.2)))
            #endif
# 1859 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=4.2,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1861 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=10.3,message=_msg)))
            #else
# 1863 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=10.3)))
            #endif
# 1865 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=4.2,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1867 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.0,message=_msg)))
            #else
# 1869 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.0)))
            #endif
# 1871 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=4.2,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1873 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.1,message=_msg)))
            #else
# 1875 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.1)))
            #endif
# 1877 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=4.2,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1879 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.2,message=_msg)))
            #else
# 1881 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.2)))
            #endif
# 1883 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=4.2,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1885 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.3,message=_msg)))
            #else
# 1887 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.3)))
            #endif
# 1889 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=4.2,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1891 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.4,message=_msg)))
            #else
# 1893 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=11.4)))
            #endif
# 1895 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=4.2,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1897 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=12.0,message=_msg)))
            #else
# 1899 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=12.0)))
            #endif
# 1901 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=4.2,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1903 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=12.1,message=_msg)))
            #else
# 1905 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=12.1)))
            #endif
# 1907 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=4.2,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1909 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=12.2,message=_msg)))
            #else
# 1911 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.2,deprecated=12.2)))
            #endif
# 1913 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=4.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=4.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3                    __attribute__((availability(ios,introduced=4.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3    __attribute__((availability(ios,introduced=4.3,deprecated=4.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1918 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=4.3,message=_msg)))
            #else
# 1920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=4.3)))
            #endif
# 1922 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=4.3,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1924 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=5.0,message=_msg)))
            #else
# 1926 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=5.0)))
            #endif
# 1928 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=4.3,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1930 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=5.1,message=_msg)))
            #else
# 1932 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=5.1)))
            #endif
# 1934 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=4.3,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1936 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=6.0,message=_msg)))
            #else
# 1938 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=6.0)))
            #endif
# 1940 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=4.3,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1942 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=6.1,message=_msg)))
            #else
# 1944 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=6.1)))
            #endif
# 1946 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=4.3,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1948 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=7.0,message=_msg)))
            #else
# 1950 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=7.0)))
            #endif
# 1952 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=4.3,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1954 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=7.1,message=_msg)))
            #else
# 1956 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=7.1)))
            #endif
# 1958 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=4.3,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1960 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.0,message=_msg)))
            #else
# 1962 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.0)))
            #endif
# 1964 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=4.3,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1966 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.1,message=_msg)))
            #else
# 1968 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.1)))
            #endif
# 1970 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=4.3,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1972 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.2,message=_msg)))
            #else
# 1974 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.2)))
            #endif
# 1976 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=4.3,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1978 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.3,message=_msg)))
            #else
# 1980 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.3)))
            #endif
# 1982 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=4.3,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1984 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.4,message=_msg)))
            #else
# 1986 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=8.4)))
            #endif
# 1988 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=4.3,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1990 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=9.0,message=_msg)))
            #else
# 1992 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=9.0)))
            #endif
# 1994 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=4.3,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1996 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=9.1,message=_msg)))
            #else
# 1998 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=9.1)))
            #endif
# 2000 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=4.3,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2002 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=9.2,message=_msg)))
            #else
# 2004 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=9.2)))
            #endif
# 2006 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=4.3,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2008 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=9.3,message=_msg)))
            #else
# 2010 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=9.3)))
            #endif
# 2012 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=4.3,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2014 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=10.0,message=_msg)))
            #else
# 2016 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=10.0)))
            #endif
# 2018 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=4.3,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2020 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=10.1,message=_msg)))
            #else
# 2022 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=10.1)))
            #endif
# 2024 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=4.3,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2026 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=10.2,message=_msg)))
            #else
# 2028 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=10.2)))
            #endif
# 2030 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=4.3,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2032 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=10.3,message=_msg)))
            #else
# 2034 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=10.3)))
            #endif
# 2036 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=4.3,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2038 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.0,message=_msg)))
            #else
# 2040 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.0)))
            #endif
# 2042 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=4.3,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2044 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.1,message=_msg)))
            #else
# 2046 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.1)))
            #endif
# 2048 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=4.3,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2050 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.2,message=_msg)))
            #else
# 2052 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.2)))
            #endif
# 2054 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=4.3,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2056 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.3,message=_msg)))
            #else
# 2058 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.3)))
            #endif
# 2060 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=4.3,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2062 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.4,message=_msg)))
            #else
# 2064 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=11.4)))
            #endif
# 2066 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=4.3,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2068 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=12.0,message=_msg)))
            #else
# 2070 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=12.0)))
            #endif
# 2072 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=4.3,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2074 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=12.1,message=_msg)))
            #else
# 2076 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=12.1)))
            #endif
# 2078 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=4.3,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2080 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=12.2,message=_msg)))
            #else
# 2082 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=4.3,deprecated=12.2)))
            #endif
# 2084 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=4.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=4.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0                    __attribute__((availability(ios,introduced=5.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0    __attribute__((availability(ios,introduced=5.0,deprecated=5.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2089 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=5.0,message=_msg)))
            #else
# 2091 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=5.0)))
            #endif
# 2093 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=5.0,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2095 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=5.1,message=_msg)))
            #else
# 2097 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=5.1)))
            #endif
# 2099 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=5.0,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=6.0,message=_msg)))
            #else
# 2103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=6.0)))
            #endif
# 2105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=5.0,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=6.1,message=_msg)))
            #else
# 2109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=6.1)))
            #endif
# 2111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=5.0,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=7.0,message=_msg)))
            #else
# 2115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=7.0)))
            #endif
# 2117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=5.0,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=7.1,message=_msg)))
            #else
# 2121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=7.1)))
            #endif
# 2123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=5.0,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2125 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.0,message=_msg)))
            #else
# 2127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.0)))
            #endif
# 2129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=5.0,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.1,message=_msg)))
            #else
# 2133 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.1)))
            #endif
# 2135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=5.0,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.2,message=_msg)))
            #else
# 2139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.2)))
            #endif
# 2141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=5.0,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.3,message=_msg)))
            #else
# 2145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.3)))
            #endif
# 2147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=5.0,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.4,message=_msg)))
            #else
# 2151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=8.4)))
            #endif
# 2153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=5.0,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=9.0,message=_msg)))
            #else
# 2157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=9.0)))
            #endif
# 2159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=5.0,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=9.1,message=_msg)))
            #else
# 2163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=9.1)))
            #endif
# 2165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=5.0,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=9.2,message=_msg)))
            #else
# 2169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=9.2)))
            #endif
# 2171 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=5.0,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2173 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=9.3,message=_msg)))
            #else
# 2175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=9.3)))
            #endif
# 2177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=5.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2179 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=10.0,message=_msg)))
            #else
# 2181 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=10.0)))
            #endif
# 2183 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=5.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=10.1,message=_msg)))
            #else
# 2187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=10.1)))
            #endif
# 2189 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=5.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2191 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=10.2,message=_msg)))
            #else
# 2193 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=10.2)))
            #endif
# 2195 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=5.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2197 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=10.3,message=_msg)))
            #else
# 2199 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=10.3)))
            #endif
# 2201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=5.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2203 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.0,message=_msg)))
            #else
# 2205 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.0)))
            #endif
# 2207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=5.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2209 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.1,message=_msg)))
            #else
# 2211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.1)))
            #endif
# 2213 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=5.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2215 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.2,message=_msg)))
            #else
# 2217 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.2)))
            #endif
# 2219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=5.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2221 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.3,message=_msg)))
            #else
# 2223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.3)))
            #endif
# 2225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=5.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.4,message=_msg)))
            #else
# 2229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=11.4)))
            #endif
# 2231 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=5.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=12.0,message=_msg)))
            #else
# 2235 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=12.0)))
            #endif
# 2237 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=5.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2239 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=12.1,message=_msg)))
            #else
# 2241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=12.1)))
            #endif
# 2243 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=5.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2245 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=12.2,message=_msg)))
            #else
# 2247 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.0,deprecated=12.2)))
            #endif
# 2249 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=5.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=5.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1                    __attribute__((availability(ios,introduced=5.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1    __attribute__((availability(ios,introduced=5.1,deprecated=5.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2254 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=5.1,message=_msg)))
            #else
# 2256 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=5.1)))
            #endif
# 2258 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=5.1,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=6.0,message=_msg)))
            #else
# 2262 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=6.0)))
            #endif
# 2264 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=5.1,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2266 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=6.1,message=_msg)))
            #else
# 2268 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=6.1)))
            #endif
# 2270 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=5.1,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2272 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=7.0,message=_msg)))
            #else
# 2274 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=7.0)))
            #endif
# 2276 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=5.1,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2278 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=7.1,message=_msg)))
            #else
# 2280 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=7.1)))
            #endif
# 2282 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=5.1,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2284 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.0,message=_msg)))
            #else
# 2286 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.0)))
            #endif
# 2288 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=5.1,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2290 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.1,message=_msg)))
            #else
# 2292 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.1)))
            #endif
# 2294 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=5.1,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2296 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.2,message=_msg)))
            #else
# 2298 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.2)))
            #endif
# 2300 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=5.1,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2302 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.3,message=_msg)))
            #else
# 2304 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.3)))
            #endif
# 2306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=5.1,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2308 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.4,message=_msg)))
            #else
# 2310 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=8.4)))
            #endif
# 2312 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=5.1,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2314 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=9.0,message=_msg)))
            #else
# 2316 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=9.0)))
            #endif
# 2318 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=5.1,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2320 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=9.1,message=_msg)))
            #else
# 2322 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=9.1)))
            #endif
# 2324 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=5.1,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2326 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=9.2,message=_msg)))
            #else
# 2328 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=9.2)))
            #endif
# 2330 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=5.1,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2332 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=9.3,message=_msg)))
            #else
# 2334 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=9.3)))
            #endif
# 2336 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=5.1,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2338 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=10.0,message=_msg)))
            #else
# 2340 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=10.0)))
            #endif
# 2342 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=5.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2344 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=10.1,message=_msg)))
            #else
# 2346 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=10.1)))
            #endif
# 2348 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=5.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2350 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=10.2,message=_msg)))
            #else
# 2352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=10.2)))
            #endif
# 2354 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=5.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2356 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=10.3,message=_msg)))
            #else
# 2358 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=10.3)))
            #endif
# 2360 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=5.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2362 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.0,message=_msg)))
            #else
# 2364 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.0)))
            #endif
# 2366 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=5.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2368 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.1,message=_msg)))
            #else
# 2370 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.1)))
            #endif
# 2372 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=5.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2374 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.2,message=_msg)))
            #else
# 2376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.2)))
            #endif
# 2378 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=5.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2380 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.3,message=_msg)))
            #else
# 2382 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.3)))
            #endif
# 2384 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=5.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.4,message=_msg)))
            #else
# 2388 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=11.4)))
            #endif
# 2390 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=5.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2392 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=12.0,message=_msg)))
            #else
# 2394 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=12.0)))
            #endif
# 2396 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=5.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2398 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=12.1,message=_msg)))
            #else
# 2400 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=12.1)))
            #endif
# 2402 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=5.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2404 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=12.2,message=_msg)))
            #else
# 2406 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=5.1,deprecated=12.2)))
            #endif
# 2408 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=5.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=5.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0                    __attribute__((availability(ios,introduced=6.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0    __attribute__((availability(ios,introduced=6.0,deprecated=6.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2413 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=6.0,message=_msg)))
            #else
# 2415 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=6.0)))
            #endif
# 2417 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=6.0,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2419 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=6.1,message=_msg)))
            #else
# 2421 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=6.1)))
            #endif
# 2423 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=6.0,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2425 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=7.0,message=_msg)))
            #else
# 2427 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=7.0)))
            #endif
# 2429 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=6.0,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2431 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=7.1,message=_msg)))
            #else
# 2433 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=7.1)))
            #endif
# 2435 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=6.0,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2437 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.0,message=_msg)))
            #else
# 2439 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.0)))
            #endif
# 2441 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=6.0,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2443 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.1,message=_msg)))
            #else
# 2445 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.1)))
            #endif
# 2447 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=6.0,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2449 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.2,message=_msg)))
            #else
# 2451 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.2)))
            #endif
# 2453 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=6.0,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2455 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.3,message=_msg)))
            #else
# 2457 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.3)))
            #endif
# 2459 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=6.0,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2461 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.4,message=_msg)))
            #else
# 2463 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=8.4)))
            #endif
# 2465 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=6.0,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2467 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=9.0,message=_msg)))
            #else
# 2469 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=9.0)))
            #endif
# 2471 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=6.0,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2473 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=9.1,message=_msg)))
            #else
# 2475 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=9.1)))
            #endif
# 2477 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=6.0,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2479 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=9.2,message=_msg)))
            #else
# 2481 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=9.2)))
            #endif
# 2483 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=6.0,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2485 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=9.3,message=_msg)))
            #else
# 2487 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=9.3)))
            #endif
# 2489 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=6.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2491 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=10.0,message=_msg)))
            #else
# 2493 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=10.0)))
            #endif
# 2495 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=6.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2497 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=10.1,message=_msg)))
            #else
# 2499 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=10.1)))
            #endif
# 2501 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=6.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2503 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=10.2,message=_msg)))
            #else
# 2505 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=10.2)))
            #endif
# 2507 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=6.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2509 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=10.3,message=_msg)))
            #else
# 2511 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=10.3)))
            #endif
# 2513 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=6.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2515 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.0,message=_msg)))
            #else
# 2517 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.0)))
            #endif
# 2519 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=6.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2521 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.1,message=_msg)))
            #else
# 2523 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.1)))
            #endif
# 2525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=6.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.2,message=_msg)))
            #else
# 2529 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.2)))
            #endif
# 2531 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=6.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2533 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.3,message=_msg)))
            #else
# 2535 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.3)))
            #endif
# 2537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=6.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2539 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.4,message=_msg)))
            #else
# 2541 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=11.4)))
            #endif
# 2543 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=6.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2545 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=12.0,message=_msg)))
            #else
# 2547 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=12.0)))
            #endif
# 2549 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=6.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2551 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=12.1,message=_msg)))
            #else
# 2553 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=12.1)))
            #endif
# 2555 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=6.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2557 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=12.2,message=_msg)))
            #else
# 2559 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.0,deprecated=12.2)))
            #endif
# 2561 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=6.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=6.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1                    __attribute__((availability(ios,introduced=6.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1    __attribute__((availability(ios,introduced=6.1,deprecated=6.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2566 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=6.1,message=_msg)))
            #else
# 2568 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=6.1)))
            #endif
# 2570 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=6.1,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2572 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=7.0,message=_msg)))
            #else
# 2574 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=7.0)))
            #endif
# 2576 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=6.1,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2578 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=7.1,message=_msg)))
            #else
# 2580 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=7.1)))
            #endif
# 2582 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=6.1,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2584 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.0,message=_msg)))
            #else
# 2586 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.0)))
            #endif
# 2588 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=6.1,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2590 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.1,message=_msg)))
            #else
# 2592 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.1)))
            #endif
# 2594 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=6.1,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2596 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.2,message=_msg)))
            #else
# 2598 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.2)))
            #endif
# 2600 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=6.1,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2602 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.3,message=_msg)))
            #else
# 2604 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.3)))
            #endif
# 2606 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=6.1,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2608 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.4,message=_msg)))
            #else
# 2610 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=8.4)))
            #endif
# 2612 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=6.1,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2614 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=9.0,message=_msg)))
            #else
# 2616 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=9.0)))
            #endif
# 2618 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=6.1,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2620 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=9.1,message=_msg)))
            #else
# 2622 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=9.1)))
            #endif
# 2624 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=6.1,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2626 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=9.2,message=_msg)))
            #else
# 2628 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=9.2)))
            #endif
# 2630 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=6.1,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2632 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=9.3,message=_msg)))
            #else
# 2634 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=9.3)))
            #endif
# 2636 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=6.1,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2638 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=10.0,message=_msg)))
            #else
# 2640 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=10.0)))
            #endif
# 2642 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=6.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2644 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=10.1,message=_msg)))
            #else
# 2646 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=10.1)))
            #endif
# 2648 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=6.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2650 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=10.2,message=_msg)))
            #else
# 2652 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=10.2)))
            #endif
# 2654 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=6.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2656 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=10.3,message=_msg)))
            #else
# 2658 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=10.3)))
            #endif
# 2660 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=6.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2662 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.0,message=_msg)))
            #else
# 2664 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.0)))
            #endif
# 2666 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=6.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2668 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.1,message=_msg)))
            #else
# 2670 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.1)))
            #endif
# 2672 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=6.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2674 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.2,message=_msg)))
            #else
# 2676 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.2)))
            #endif
# 2678 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=6.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2680 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.3,message=_msg)))
            #else
# 2682 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.3)))
            #endif
# 2684 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=6.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2686 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.4,message=_msg)))
            #else
# 2688 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=11.4)))
            #endif
# 2690 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=6.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2692 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=12.0,message=_msg)))
            #else
# 2694 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=12.0)))
            #endif
# 2696 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=6.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2698 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=12.1,message=_msg)))
            #else
# 2700 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=12.1)))
            #endif
# 2702 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=6.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2704 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=12.2,message=_msg)))
            #else
# 2706 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=6.1,deprecated=12.2)))
            #endif
# 2708 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=6.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=6.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0                    __attribute__((availability(ios,introduced=7.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0    __attribute__((availability(ios,introduced=7.0,deprecated=7.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2713 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=7.0,message=_msg)))
            #else
# 2715 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=7.0)))
            #endif
# 2717 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=7.0,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2719 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=7.1,message=_msg)))
            #else
# 2721 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=7.1)))
            #endif
# 2723 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=7.0,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2725 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.0,message=_msg)))
            #else
# 2727 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.0)))
            #endif
# 2729 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=7.0,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2731 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.1,message=_msg)))
            #else
# 2733 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.1)))
            #endif
# 2735 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=7.0,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2737 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.2,message=_msg)))
            #else
# 2739 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.2)))
            #endif
# 2741 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=7.0,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2743 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.3,message=_msg)))
            #else
# 2745 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.3)))
            #endif
# 2747 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=7.0,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2749 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.4,message=_msg)))
            #else
# 2751 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=8.4)))
            #endif
# 2753 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=7.0,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2755 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=9.0,message=_msg)))
            #else
# 2757 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=9.0)))
            #endif
# 2759 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=7.0,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2761 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=9.1,message=_msg)))
            #else
# 2763 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=9.1)))
            #endif
# 2765 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=7.0,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2767 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=9.2,message=_msg)))
            #else
# 2769 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=9.2)))
            #endif
# 2771 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=7.0,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2773 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=9.3,message=_msg)))
            #else
# 2775 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=9.3)))
            #endif
# 2777 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=7.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2779 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=10.0,message=_msg)))
            #else
# 2781 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=10.0)))
            #endif
# 2783 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=7.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2785 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=10.1,message=_msg)))
            #else
# 2787 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=10.1)))
            #endif
# 2789 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=7.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2791 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=10.2,message=_msg)))
            #else
# 2793 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=10.2)))
            #endif
# 2795 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=7.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2797 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=10.3,message=_msg)))
            #else
# 2799 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=10.3)))
            #endif
# 2801 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=7.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2803 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.0,message=_msg)))
            #else
# 2805 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.0)))
            #endif
# 2807 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=7.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2809 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.1,message=_msg)))
            #else
# 2811 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.1)))
            #endif
# 2813 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=7.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2815 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.2,message=_msg)))
            #else
# 2817 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.2)))
            #endif
# 2819 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=7.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2821 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.3,message=_msg)))
            #else
# 2823 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.3)))
            #endif
# 2825 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=7.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2827 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.4,message=_msg)))
            #else
# 2829 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=11.4)))
            #endif
# 2831 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=7.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2833 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=12.0,message=_msg)))
            #else
# 2835 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=12.0)))
            #endif
# 2837 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=7.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2839 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=12.1,message=_msg)))
            #else
# 2841 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=12.1)))
            #endif
# 2843 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=7.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2845 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=12.2,message=_msg)))
            #else
# 2847 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.0,deprecated=12.2)))
            #endif
# 2849 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=7.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=7.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1                    __attribute__((availability(ios,introduced=7.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1    __attribute__((availability(ios,introduced=7.1,deprecated=7.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2854 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=7.1,message=_msg)))
            #else
# 2856 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=7.1)))
            #endif
# 2858 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=7.1,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2860 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.0,message=_msg)))
            #else
# 2862 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.0)))
            #endif
# 2864 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=7.1,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2866 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.1,message=_msg)))
            #else
# 2868 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.1)))
            #endif
# 2870 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=7.1,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2872 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.2,message=_msg)))
            #else
# 2874 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.2)))
            #endif
# 2876 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=7.1,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2878 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.3,message=_msg)))
            #else
# 2880 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.3)))
            #endif
# 2882 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=7.1,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2884 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.4,message=_msg)))
            #else
# 2886 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=8.4)))
            #endif
# 2888 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=7.1,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2890 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=9.0,message=_msg)))
            #else
# 2892 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=9.0)))
            #endif
# 2894 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=7.1,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2896 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=9.1,message=_msg)))
            #else
# 2898 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=9.1)))
            #endif
# 2900 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=7.1,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2902 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=9.2,message=_msg)))
            #else
# 2904 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=9.2)))
            #endif
# 2906 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=7.1,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2908 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=9.3,message=_msg)))
            #else
# 2910 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=9.3)))
            #endif
# 2912 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=7.1,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2914 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=10.0,message=_msg)))
            #else
# 2916 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=10.0)))
            #endif
# 2918 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=7.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=10.1,message=_msg)))
            #else
# 2922 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=10.1)))
            #endif
# 2924 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=7.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2926 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=10.2,message=_msg)))
            #else
# 2928 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=10.2)))
            #endif
# 2930 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=7.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2932 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=10.3,message=_msg)))
            #else
# 2934 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=10.3)))
            #endif
# 2936 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=7.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2938 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.0,message=_msg)))
            #else
# 2940 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.0)))
            #endif
# 2942 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=7.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2944 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.1,message=_msg)))
            #else
# 2946 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.1)))
            #endif
# 2948 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=7.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2950 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.2,message=_msg)))
            #else
# 2952 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.2)))
            #endif
# 2954 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=7.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2956 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.3,message=_msg)))
            #else
# 2958 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.3)))
            #endif
# 2960 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=7.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2962 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.4,message=_msg)))
            #else
# 2964 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=11.4)))
            #endif
# 2966 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=7.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2968 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=12.0,message=_msg)))
            #else
# 2970 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=12.0)))
            #endif
# 2972 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=7.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2974 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=12.1,message=_msg)))
            #else
# 2976 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=12.1)))
            #endif
# 2978 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=7.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2980 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=12.2,message=_msg)))
            #else
# 2982 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=7.1,deprecated=12.2)))
            #endif
# 2984 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=7.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=7.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0                    __attribute__((availability(ios,introduced=8.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0    __attribute__((availability(ios,introduced=8.0,deprecated=8.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2989 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.0,message=_msg)))
            #else
# 2991 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.0)))
            #endif
# 2993 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=8.0,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2995 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.1,message=_msg)))
            #else
# 2997 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.1)))
            #endif
# 2999 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=8.0,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3001 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.2,message=_msg)))
            #else
# 3003 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.2)))
            #endif
# 3005 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=8.0,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3007 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.3,message=_msg)))
            #else
# 3009 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.3)))
            #endif
# 3011 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=8.0,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3013 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.4,message=_msg)))
            #else
# 3015 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=8.4)))
            #endif
# 3017 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=8.0,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3019 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=9.0,message=_msg)))
            #else
# 3021 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=9.0)))
            #endif
# 3023 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=8.0,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3025 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=9.1,message=_msg)))
            #else
# 3027 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=9.1)))
            #endif
# 3029 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=8.0,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3031 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=9.2,message=_msg)))
            #else
# 3033 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=9.2)))
            #endif
# 3035 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=8.0,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3037 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=9.3,message=_msg)))
            #else
# 3039 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=9.3)))
            #endif
# 3041 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=8.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3043 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=10.0,message=_msg)))
            #else
# 3045 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=10.0)))
            #endif
# 3047 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=8.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3049 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=10.1,message=_msg)))
            #else
# 3051 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=10.1)))
            #endif
# 3053 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=8.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3055 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=10.2,message=_msg)))
            #else
# 3057 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=10.2)))
            #endif
# 3059 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=8.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3061 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=10.3,message=_msg)))
            #else
# 3063 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=10.3)))
            #endif
# 3065 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=8.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3067 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.0,message=_msg)))
            #else
# 3069 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.0)))
            #endif
# 3071 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=8.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3073 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.1,message=_msg)))
            #else
# 3075 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.1)))
            #endif
# 3077 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=8.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3079 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.2,message=_msg)))
            #else
# 3081 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.2)))
            #endif
# 3083 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=8.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3085 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.3,message=_msg)))
            #else
# 3087 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.3)))
            #endif
# 3089 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=8.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3091 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.4,message=_msg)))
            #else
# 3093 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=11.4)))
            #endif
# 3095 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=8.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3097 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=12.0,message=_msg)))
            #else
# 3099 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=12.0)))
            #endif
# 3101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=8.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=12.1,message=_msg)))
            #else
# 3105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=12.1)))
            #endif
# 3107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=8.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=12.2,message=_msg)))
            #else
# 3111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.0,deprecated=12.2)))
            #endif
# 3113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=8.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=8.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1                    __attribute__((availability(ios,introduced=8.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1    __attribute__((availability(ios,introduced=8.1,deprecated=8.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=8.1,message=_msg)))
            #else
# 3120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=8.1)))
            #endif
# 3122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=8.1,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3124 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=8.2,message=_msg)))
            #else
# 3126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=8.2)))
            #endif
# 3128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=8.1,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3130 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=8.3,message=_msg)))
            #else
# 3132 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=8.3)))
            #endif
# 3134 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=8.1,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3136 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=8.4,message=_msg)))
            #else
# 3138 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=8.4)))
            #endif
# 3140 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=8.1,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3142 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=9.0,message=_msg)))
            #else
# 3144 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=9.0)))
            #endif
# 3146 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=8.1,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=9.1,message=_msg)))
            #else
# 3150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=9.1)))
            #endif
# 3152 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=8.1,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=9.2,message=_msg)))
            #else
# 3156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=9.2)))
            #endif
# 3158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=8.1,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3160 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=9.3,message=_msg)))
            #else
# 3162 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=9.3)))
            #endif
# 3164 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=8.1,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3166 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=10.0,message=_msg)))
            #else
# 3168 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=10.0)))
            #endif
# 3170 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=8.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3172 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=10.1,message=_msg)))
            #else
# 3174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=10.1)))
            #endif
# 3176 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=8.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3178 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=10.2,message=_msg)))
            #else
# 3180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=10.2)))
            #endif
# 3182 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=8.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=10.3,message=_msg)))
            #else
# 3186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=10.3)))
            #endif
# 3188 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=8.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3190 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.0,message=_msg)))
            #else
# 3192 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.0)))
            #endif
# 3194 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=8.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3196 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.1,message=_msg)))
            #else
# 3198 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.1)))
            #endif
# 3200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=8.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.2,message=_msg)))
            #else
# 3204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.2)))
            #endif
# 3206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=8.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.3,message=_msg)))
            #else
# 3210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.3)))
            #endif
# 3212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=8.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3214 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.4,message=_msg)))
            #else
# 3216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=11.4)))
            #endif
# 3218 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=8.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=12.0,message=_msg)))
            #else
# 3222 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=12.0)))
            #endif
# 3224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=8.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=12.1,message=_msg)))
            #else
# 3228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=12.1)))
            #endif
# 3230 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=8.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3232 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=12.2,message=_msg)))
            #else
# 3234 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.1,deprecated=12.2)))
            #endif
# 3236 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=8.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=8.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2                    __attribute__((availability(ios,introduced=8.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2    __attribute__((availability(ios,introduced=8.2,deprecated=8.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=8.2,message=_msg)))
            #else
# 3243 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=8.2)))
            #endif
# 3245 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=8.2,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3247 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=8.3,message=_msg)))
            #else
# 3249 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=8.3)))
            #endif
# 3251 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=8.2,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=8.4,message=_msg)))
            #else
# 3255 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=8.4)))
            #endif
# 3257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=8.2,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=9.0,message=_msg)))
            #else
# 3261 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=9.0)))
            #endif
# 3263 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=8.2,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3265 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=9.1,message=_msg)))
            #else
# 3267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=9.1)))
            #endif
# 3269 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=8.2,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=9.2,message=_msg)))
            #else
# 3273 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=9.2)))
            #endif
# 3275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=8.2,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3277 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=9.3,message=_msg)))
            #else
# 3279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=9.3)))
            #endif
# 3281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=8.2,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=10.0,message=_msg)))
            #else
# 3285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=10.0)))
            #endif
# 3287 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=8.2,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3289 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=10.1,message=_msg)))
            #else
# 3291 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=10.1)))
            #endif
# 3293 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=8.2,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3295 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=10.2,message=_msg)))
            #else
# 3297 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=10.2)))
            #endif
# 3299 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=8.2,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=10.3,message=_msg)))
            #else
# 3303 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=10.3)))
            #endif
# 3305 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=8.2,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3307 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.0,message=_msg)))
            #else
# 3309 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.0)))
            #endif
# 3311 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=8.2,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3313 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.1,message=_msg)))
            #else
# 3315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.1)))
            #endif
# 3317 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=8.2,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3319 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.2,message=_msg)))
            #else
# 3321 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.2)))
            #endif
# 3323 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=8.2,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.3,message=_msg)))
            #else
# 3327 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.3)))
            #endif
# 3329 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=8.2,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3331 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.4,message=_msg)))
            #else
# 3333 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=11.4)))
            #endif
# 3335 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=8.2,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3337 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=12.0,message=_msg)))
            #else
# 3339 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=12.0)))
            #endif
# 3341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=8.2,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3343 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=12.1,message=_msg)))
            #else
# 3345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=12.1)))
            #endif
# 3347 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=8.2,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3349 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=12.2,message=_msg)))
            #else
# 3351 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.2,deprecated=12.2)))
            #endif
# 3353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=8.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=8.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3                    __attribute__((availability(ios,introduced=8.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3    __attribute__((availability(ios,introduced=8.3,deprecated=8.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3358 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=8.3,message=_msg)))
            #else
# 3360 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=8.3)))
            #endif
# 3362 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=8.3,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3364 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=8.4,message=_msg)))
            #else
# 3366 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=8.4)))
            #endif
# 3368 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=8.3,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3370 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=9.0,message=_msg)))
            #else
# 3372 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=9.0)))
            #endif
# 3374 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=8.3,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=9.1,message=_msg)))
            #else
# 3378 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=9.1)))
            #endif
# 3380 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=8.3,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3382 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=9.2,message=_msg)))
            #else
# 3384 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=9.2)))
            #endif
# 3386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=8.3,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3388 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=9.3,message=_msg)))
            #else
# 3390 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=9.3)))
            #endif
# 3392 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=8.3,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3394 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=10.0,message=_msg)))
            #else
# 3396 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=10.0)))
            #endif
# 3398 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=8.3,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3400 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=10.1,message=_msg)))
            #else
# 3402 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=10.1)))
            #endif
# 3404 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=8.3,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3406 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=10.2,message=_msg)))
            #else
# 3408 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=10.2)))
            #endif
# 3410 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=8.3,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=10.3,message=_msg)))
            #else
# 3414 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=10.3)))
            #endif
# 3416 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=8.3,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3418 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.0,message=_msg)))
            #else
# 3420 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.0)))
            #endif
# 3422 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=8.3,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3424 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.1,message=_msg)))
            #else
# 3426 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.1)))
            #endif
# 3428 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=8.3,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3430 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.2,message=_msg)))
            #else
# 3432 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.2)))
            #endif
# 3434 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=8.3,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3436 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.3,message=_msg)))
            #else
# 3438 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.3)))
            #endif
# 3440 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=8.3,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3442 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.4,message=_msg)))
            #else
# 3444 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=11.4)))
            #endif
# 3446 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=8.3,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3448 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=12.0,message=_msg)))
            #else
# 3450 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=12.0)))
            #endif
# 3452 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=8.3,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3454 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=12.1,message=_msg)))
            #else
# 3456 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=12.1)))
            #endif
# 3458 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=8.3,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3460 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=12.2,message=_msg)))
            #else
# 3462 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.3,deprecated=12.2)))
            #endif
# 3464 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=8.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=8.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4                    __attribute__((availability(ios,introduced=8.4)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4    __attribute__((availability(ios,introduced=8.4,deprecated=8.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3469 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=8.4,message=_msg)))
            #else
# 3471 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=8.4)))
            #endif
# 3473 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=8.4,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3475 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=9.0,message=_msg)))
            #else
# 3477 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=9.0)))
            #endif
# 3479 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=8.4,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3481 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=9.1,message=_msg)))
            #else
# 3483 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=9.1)))
            #endif
# 3485 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=8.4,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3487 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=9.2,message=_msg)))
            #else
# 3489 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=9.2)))
            #endif
# 3491 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=8.4,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3493 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=9.3,message=_msg)))
            #else
# 3495 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=9.3)))
            #endif
# 3497 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=8.4,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3499 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=10.0,message=_msg)))
            #else
# 3501 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=10.0)))
            #endif
# 3503 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=8.4,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3505 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=10.1,message=_msg)))
            #else
# 3507 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=10.1)))
            #endif
# 3509 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=8.4,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3511 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=10.2,message=_msg)))
            #else
# 3513 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=10.2)))
            #endif
# 3515 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=8.4,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3517 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=10.3,message=_msg)))
            #else
# 3519 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=10.3)))
            #endif
# 3521 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=8.4,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3523 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.0,message=_msg)))
            #else
# 3525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.0)))
            #endif
# 3527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=8.4,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3529 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.1,message=_msg)))
            #else
# 3531 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.1)))
            #endif
# 3533 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=8.4,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3535 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.2,message=_msg)))
            #else
# 3537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.2)))
            #endif
# 3539 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=8.4,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3541 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.3,message=_msg)))
            #else
# 3543 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.3)))
            #endif
# 3545 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=8.4,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3547 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.4,message=_msg)))
            #else
# 3549 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=11.4)))
            #endif
# 3551 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=8.4,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3553 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=12.0,message=_msg)))
            #else
# 3555 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=12.0)))
            #endif
# 3557 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=8.4,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3559 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=12.1,message=_msg)))
            #else
# 3561 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=12.1)))
            #endif
# 3563 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=8.4,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3565 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=12.2,message=_msg)))
            #else
# 3567 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=8.4,deprecated=12.2)))
            #endif
# 3569 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=8.4)))
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=8.4)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0                    __attribute__((availability(ios,introduced=9.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0    __attribute__((availability(ios,introduced=9.0,deprecated=9.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3574 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=9.0,message=_msg)))
            #else
# 3576 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=9.0)))
            #endif
# 3578 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=9.0,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3580 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=9.1,message=_msg)))
            #else
# 3582 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=9.1)))
            #endif
# 3584 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=9.0,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3586 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=9.2,message=_msg)))
            #else
# 3588 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=9.2)))
            #endif
# 3590 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=9.0,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3592 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=9.3,message=_msg)))
            #else
# 3594 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=9.3)))
            #endif
# 3596 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=9.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3598 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=10.0,message=_msg)))
            #else
# 3600 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=10.0)))
            #endif
# 3602 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=9.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3604 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=10.1,message=_msg)))
            #else
# 3606 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=10.1)))
            #endif
# 3608 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=9.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3610 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=10.2,message=_msg)))
            #else
# 3612 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=10.2)))
            #endif
# 3614 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=9.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3616 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=10.3,message=_msg)))
            #else
# 3618 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=10.3)))
            #endif
# 3620 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=9.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3622 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.0,message=_msg)))
            #else
# 3624 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.0)))
            #endif
# 3626 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=9.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3628 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.1,message=_msg)))
            #else
# 3630 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.1)))
            #endif
# 3632 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=9.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3634 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.2,message=_msg)))
            #else
# 3636 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.2)))
            #endif
# 3638 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=9.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3640 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.3,message=_msg)))
            #else
# 3642 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.3)))
            #endif
# 3644 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=9.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3646 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.4,message=_msg)))
            #else
# 3648 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=11.4)))
            #endif
# 3650 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=9.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3652 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=12.0,message=_msg)))
            #else
# 3654 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=12.0)))
            #endif
# 3656 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=9.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3658 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=12.1,message=_msg)))
            #else
# 3660 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=12.1)))
            #endif
# 3662 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=9.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3664 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=12.2,message=_msg)))
            #else
# 3666 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.0,deprecated=12.2)))
            #endif
# 3668 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=9.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=9.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1                    __attribute__((availability(ios,introduced=9.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1    __attribute__((availability(ios,introduced=9.1,deprecated=9.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3673 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=9.1,message=_msg)))
            #else
# 3675 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=9.1)))
            #endif
# 3677 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=9.1,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3679 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=9.2,message=_msg)))
            #else
# 3681 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=9.2)))
            #endif
# 3683 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=9.1,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3685 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=9.3,message=_msg)))
            #else
# 3687 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=9.3)))
            #endif
# 3689 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=9.1,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3691 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=10.0,message=_msg)))
            #else
# 3693 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=10.0)))
            #endif
# 3695 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=9.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3697 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=10.1,message=_msg)))
            #else
# 3699 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=10.1)))
            #endif
# 3701 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=9.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3703 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=10.2,message=_msg)))
            #else
# 3705 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=10.2)))
            #endif
# 3707 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=9.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3709 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=10.3,message=_msg)))
            #else
# 3711 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=10.3)))
            #endif
# 3713 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=9.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3715 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.0,message=_msg)))
            #else
# 3717 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.0)))
            #endif
# 3719 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=9.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3721 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.1,message=_msg)))
            #else
# 3723 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.1)))
            #endif
# 3725 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=9.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3727 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.2,message=_msg)))
            #else
# 3729 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.2)))
            #endif
# 3731 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=9.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3733 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.3,message=_msg)))
            #else
# 3735 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.3)))
            #endif
# 3737 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=9.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3739 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.4,message=_msg)))
            #else
# 3741 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=11.4)))
            #endif
# 3743 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=9.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3745 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=12.0,message=_msg)))
            #else
# 3747 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=12.0)))
            #endif
# 3749 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=9.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3751 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=12.1,message=_msg)))
            #else
# 3753 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=12.1)))
            #endif
# 3755 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=9.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3757 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=12.2,message=_msg)))
            #else
# 3759 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.1,deprecated=12.2)))
            #endif
# 3761 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=9.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=9.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2                    __attribute__((availability(ios,introduced=9.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2    __attribute__((availability(ios,introduced=9.2,deprecated=9.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3766 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=9.2,message=_msg)))
            #else
# 3768 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=9.2)))
            #endif
# 3770 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=9.2,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3772 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=9.3,message=_msg)))
            #else
# 3774 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=9.3)))
            #endif
# 3776 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=9.2,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3778 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=10.0,message=_msg)))
            #else
# 3780 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=10.0)))
            #endif
# 3782 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=9.2,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=10.1,message=_msg)))
            #else
# 3786 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=10.1)))
            #endif
# 3788 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=9.2,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3790 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=10.2,message=_msg)))
            #else
# 3792 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=10.2)))
            #endif
# 3794 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=9.2,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3796 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=10.3,message=_msg)))
            #else
# 3798 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=10.3)))
            #endif
# 3800 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=9.2,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3802 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.0,message=_msg)))
            #else
# 3804 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.0)))
            #endif
# 3806 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=9.2,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3808 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.1,message=_msg)))
            #else
# 3810 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.1)))
            #endif
# 3812 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=9.2,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3814 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.2,message=_msg)))
            #else
# 3816 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.2)))
            #endif
# 3818 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=9.2,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3820 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.3,message=_msg)))
            #else
# 3822 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.3)))
            #endif
# 3824 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=9.2,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3826 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.4,message=_msg)))
            #else
# 3828 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=11.4)))
            #endif
# 3830 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=9.2,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3832 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=12.0,message=_msg)))
            #else
# 3834 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=12.0)))
            #endif
# 3836 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=9.2,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3838 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=12.1,message=_msg)))
            #else
# 3840 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=12.1)))
            #endif
# 3842 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=9.2,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3844 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=12.2,message=_msg)))
            #else
# 3846 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.2,deprecated=12.2)))
            #endif
# 3848 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=9.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=9.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3                    __attribute__((availability(ios,introduced=9.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3    __attribute__((availability(ios,introduced=9.3,deprecated=9.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3853 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=9.3,message=_msg)))
            #else
# 3855 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=9.3)))
            #endif
# 3857 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=9.3,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3859 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=10.0,message=_msg)))
            #else
# 3861 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=10.0)))
            #endif
# 3863 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=9.3,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3865 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=10.1,message=_msg)))
            #else
# 3867 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=10.1)))
            #endif
# 3869 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=9.3,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3871 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=10.2,message=_msg)))
            #else
# 3873 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=10.2)))
            #endif
# 3875 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=9.3,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3877 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=10.3,message=_msg)))
            #else
# 3879 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=10.3)))
            #endif
# 3881 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=9.3,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3883 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.0,message=_msg)))
            #else
# 3885 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.0)))
            #endif
# 3887 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=9.3,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3889 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.1,message=_msg)))
            #else
# 3891 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.1)))
            #endif
# 3893 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=9.3,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3895 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.2,message=_msg)))
            #else
# 3897 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.2)))
            #endif
# 3899 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=9.3,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3901 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.3,message=_msg)))
            #else
# 3903 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.3)))
            #endif
# 3905 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=9.3,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3907 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.4,message=_msg)))
            #else
# 3909 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=11.4)))
            #endif
# 3911 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=9.3,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3913 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=12.0,message=_msg)))
            #else
# 3915 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=12.0)))
            #endif
# 3917 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=9.3,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3919 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=12.1,message=_msg)))
            #else
# 3921 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=12.1)))
            #endif
# 3923 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=9.3,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3925 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=12.2,message=_msg)))
            #else
# 3927 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=9.3,deprecated=12.2)))
            #endif
# 3929 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=9.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=9.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0                    __attribute__((availability(ios,introduced=10.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0    __attribute__((availability(ios,introduced=10.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3934 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=10.0,message=_msg)))
            #else
# 3936 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=10.0)))
            #endif
# 3938 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=10.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3940 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=10.1,message=_msg)))
            #else
# 3942 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=10.1)))
            #endif
# 3944 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=10.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3946 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=10.2,message=_msg)))
            #else
# 3948 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=10.2)))
            #endif
# 3950 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=10.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3952 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=10.3,message=_msg)))
            #else
# 3954 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=10.3)))
            #endif
# 3956 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=10.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3958 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.0,message=_msg)))
            #else
# 3960 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.0)))
            #endif
# 3962 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=10.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3964 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.1,message=_msg)))
            #else
# 3966 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.1)))
            #endif
# 3968 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=10.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3970 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.2,message=_msg)))
            #else
# 3972 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.2)))
            #endif
# 3974 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=10.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3976 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.3,message=_msg)))
            #else
# 3978 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.3)))
            #endif
# 3980 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=10.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3982 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.4,message=_msg)))
            #else
# 3984 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=11.4)))
            #endif
# 3986 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=10.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3988 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=12.0,message=_msg)))
            #else
# 3990 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=12.0)))
            #endif
# 3992 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=10.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3994 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=12.1,message=_msg)))
            #else
# 3996 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=12.1)))
            #endif
# 3998 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=10.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4000 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=12.2,message=_msg)))
            #else
# 4002 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.0,deprecated=12.2)))
            #endif
# 4004 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=10.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=10.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1                    __attribute__((availability(ios,introduced=10.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1    __attribute__((availability(ios,introduced=10.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4009 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=10.1,message=_msg)))
            #else
# 4011 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=10.1)))
            #endif
# 4013 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=10.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4015 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=10.2,message=_msg)))
            #else
# 4017 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=10.2)))
            #endif
# 4019 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=10.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4021 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=10.3,message=_msg)))
            #else
# 4023 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=10.3)))
            #endif
# 4025 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=10.1,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4027 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.0,message=_msg)))
            #else
# 4029 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.0)))
            #endif
# 4031 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=10.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4033 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.1,message=_msg)))
            #else
# 4035 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.1)))
            #endif
# 4037 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=10.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4039 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.2,message=_msg)))
            #else
# 4041 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.2)))
            #endif
# 4043 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=10.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4045 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.3,message=_msg)))
            #else
# 4047 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.3)))
            #endif
# 4049 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=10.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4051 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.4,message=_msg)))
            #else
# 4053 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=11.4)))
            #endif
# 4055 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=10.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4057 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=12.0,message=_msg)))
            #else
# 4059 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=12.0)))
            #endif
# 4061 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=10.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4063 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=12.1,message=_msg)))
            #else
# 4065 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=12.1)))
            #endif
# 4067 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=10.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4069 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=12.2,message=_msg)))
            #else
# 4071 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.1,deprecated=12.2)))
            #endif
# 4073 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=10.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=10.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2                    __attribute__((availability(ios,introduced=10.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2    __attribute__((availability(ios,introduced=10.2,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4078 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=10.2,message=_msg)))
            #else
# 4080 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=10.2)))
            #endif
# 4082 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=10.2,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4084 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=10.3,message=_msg)))
            #else
# 4086 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=10.3)))
            #endif
# 4088 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=10.2,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4090 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.0,message=_msg)))
            #else
# 4092 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.0)))
            #endif
# 4094 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=10.2,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4096 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.1,message=_msg)))
            #else
# 4098 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.1)))
            #endif
# 4100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=10.2,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4102 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.2,message=_msg)))
            #else
# 4104 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.2)))
            #endif
# 4106 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=10.2,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.3,message=_msg)))
            #else
# 4110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.3)))
            #endif
# 4112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=10.2,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4114 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.4,message=_msg)))
            #else
# 4116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=11.4)))
            #endif
# 4118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=10.2,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=12.0,message=_msg)))
            #else
# 4122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=12.0)))
            #endif
# 4124 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=10.2,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=12.1,message=_msg)))
            #else
# 4128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=12.1)))
            #endif
# 4130 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=10.2,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4132 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=12.2,message=_msg)))
            #else
# 4134 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.2,deprecated=12.2)))
            #endif
# 4136 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=10.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=10.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3                    __attribute__((availability(ios,introduced=10.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3    __attribute__((availability(ios,introduced=10.3,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=10.3,message=_msg)))
            #else
# 4143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=10.3)))
            #endif
# 4145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=10.3,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.0,message=_msg)))
            #else
# 4149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.0)))
            #endif
# 4151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=10.3,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.1,message=_msg)))
            #else
# 4155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.1)))
            #endif
# 4157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=10.3,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.2,message=_msg)))
            #else
# 4161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.2)))
            #endif
# 4163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=10.3,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.3,message=_msg)))
            #else
# 4167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.3)))
            #endif
# 4169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=10.3,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4171 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.4,message=_msg)))
            #else
# 4173 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=11.4)))
            #endif
# 4175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=10.3,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=12.0,message=_msg)))
            #else
# 4179 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=12.0)))
            #endif
# 4181 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=10.3,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4183 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=12.1,message=_msg)))
            #else
# 4185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=12.1)))
            #endif
# 4187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=10.3,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4189 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=12.2,message=_msg)))
            #else
# 4191 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=10.3,deprecated=12.2)))
            #endif
# 4193 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=10.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=10.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0                    __attribute__((availability(ios,introduced=11.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0    __attribute__((availability(ios,introduced=11.0,deprecated=11.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4198 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.0,message=_msg)))
            #else
# 4200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.0)))
            #endif
# 4202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=11.0,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.1,message=_msg)))
            #else
# 4206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.1)))
            #endif
# 4208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=11.0,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.2,message=_msg)))
            #else
# 4212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.2)))
            #endif
# 4214 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=11.0,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.3,message=_msg)))
            #else
# 4218 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.3)))
            #endif
# 4220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=11.0,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4222 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.4,message=_msg)))
            #else
# 4224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=11.4)))
            #endif
# 4226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=11.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=12.0,message=_msg)))
            #else
# 4230 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=12.0)))
            #endif
# 4232 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=11.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4234 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=12.1,message=_msg)))
            #else
# 4236 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=12.1)))
            #endif
# 4238 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=11.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4240 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=12.2,message=_msg)))
            #else
# 4242 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.0,deprecated=12.2)))
            #endif
# 4244 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=11.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=11.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1                    __attribute__((availability(ios,introduced=11.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1    __attribute__((availability(ios,introduced=11.1,deprecated=11.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4249 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=11.1,message=_msg)))
            #else
# 4251 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=11.1)))
            #endif
# 4253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=11.1,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4255 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=11.2,message=_msg)))
            #else
# 4257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=11.2)))
            #endif
# 4259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=11.1,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4261 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=11.3,message=_msg)))
            #else
# 4263 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=11.3)))
            #endif
# 4265 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=11.1,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=11.4,message=_msg)))
            #else
# 4269 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=11.4)))
            #endif
# 4271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=11.1,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4273 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=12.0,message=_msg)))
            #else
# 4275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=12.0)))
            #endif
# 4277 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=11.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=12.1,message=_msg)))
            #else
# 4281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=12.1)))
            #endif
# 4283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=11.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=12.2,message=_msg)))
            #else
# 4287 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.1,deprecated=12.2)))
            #endif
# 4289 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=11.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=11.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2                    __attribute__((availability(ios,introduced=11.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2    __attribute__((availability(ios,introduced=11.2,deprecated=11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4294 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=11.2,message=_msg)))
            #else
# 4296 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=11.2)))
            #endif
# 4298 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=11.2,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4300 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=11.3,message=_msg)))
            #else
# 4302 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=11.3)))
            #endif
# 4304 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=11.2,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=11.4,message=_msg)))
            #else
# 4308 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=11.4)))
            #endif
# 4310 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=11.2,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4312 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=12.0,message=_msg)))
            #else
# 4314 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=12.0)))
            #endif
# 4316 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=11.2,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4318 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=12.1,message=_msg)))
            #else
# 4320 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=12.1)))
            #endif
# 4322 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=11.2,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4324 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=12.2,message=_msg)))
            #else
# 4326 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.2,deprecated=12.2)))
            #endif
# 4328 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=11.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=11.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3                    __attribute__((availability(ios,introduced=11.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3    __attribute__((availability(ios,introduced=11.3,deprecated=11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4333 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=11.3,message=_msg)))
            #else
# 4335 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=11.3)))
            #endif
# 4337 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=11.3,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4339 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=11.4,message=_msg)))
            #else
# 4341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=11.4)))
            #endif
# 4343 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=11.3,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=12.0,message=_msg)))
            #else
# 4347 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=12.0)))
            #endif
# 4349 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=11.3,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4351 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=12.1,message=_msg)))
            #else
# 4353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=12.1)))
            #endif
# 4355 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=11.3,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4357 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=12.2,message=_msg)))
            #else
# 4359 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.3,deprecated=12.2)))
            #endif
# 4361 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=11.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=11.3)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4                    __attribute__((availability(ios,introduced=11.4)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4    __attribute__((availability(ios,introduced=11.4,deprecated=11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4366 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.4,deprecated=11.4,message=_msg)))
            #else
# 4368 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __attribute__((availability(ios,introduced=11.4,deprecated=11.4)))
            #endif
# 4370 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=11.4,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4372 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.4,deprecated=12.0,message=_msg)))
            #else
# 4374 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=11.4,deprecated=12.0)))
            #endif
# 4376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=11.4,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4378 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.4,deprecated=12.1,message=_msg)))
            #else
# 4380 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=11.4,deprecated=12.1)))
            #endif
# 4382 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=11.4,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4384 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.4,deprecated=12.2,message=_msg)))
            #else
# 4386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=11.4,deprecated=12.2)))
            #endif
# 4388 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=11.4)))
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=11.4)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0                    __attribute__((availability(ios,introduced=12.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0    __attribute__((availability(ios,introduced=12.0,deprecated=12.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4393 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=12.0,deprecated=12.0,message=_msg)))
            #else
# 4395 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __attribute__((availability(ios,introduced=12.0,deprecated=12.0)))
            #endif
# 4397 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=12.0,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4399 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=12.0,deprecated=12.1,message=_msg)))
            #else
# 4401 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=12.0,deprecated=12.1)))
            #endif
# 4403 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=12.0,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4405 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=12.0,deprecated=12.2,message=_msg)))
            #else
# 4407 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=12.0,deprecated=12.2)))
            #endif
# 4409 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=12.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=12.0)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1                    __attribute__((availability(ios,introduced=12.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1    __attribute__((availability(ios,introduced=12.1,deprecated=12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4414 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=12.1,deprecated=12.1,message=_msg)))
            #else
# 4416 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __attribute__((availability(ios,introduced=12.1,deprecated=12.1)))
            #endif
# 4418 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=12.1,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4420 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=12.1,deprecated=12.2,message=_msg)))
            #else
# 4422 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=12.1,deprecated=12.2)))
            #endif
# 4424 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=12.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=12.1)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2                    __attribute__((availability(ios,introduced=12.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2    __attribute__((availability(ios,introduced=12.2,deprecated=12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4429 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=12.2,deprecated=12.2,message=_msg)))
            #else
# 4431 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                    #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __attribute__((availability(ios,introduced=12.2,deprecated=12.2)))
            #endif
# 4433 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_NA               __attribute__((availability(ios,introduced=12.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_NA_MSG(_msg)     __attribute__((availability(ios,introduced=12.2)))
            #define __AVAILABILITY_INTERNAL__IPHONE_NA                               __attribute__((availability(ios,unavailable)))
            #define __AVAILABILITY_INTERNAL__IPHONE_NA_DEP__IPHONE_NA                __attribute__((availability(ios,unavailable)))
            #define __AVAILABILITY_INTERNAL__IPHONE_NA_DEP__IPHONE_NA_MSG(_msg)      __attribute__((availability(ios,unavailable)))
        #endif
# 4439 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
    #endif
# 4440 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

    #ifndef __AVAILABILITY_INTERNAL__IPHONE_2_0
        /* set up old style internal macros (up to 2.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_2_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4444 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4446 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4448 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4450 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_2_0
        #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_2_0
        #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_0              __AVAILABILITY_INTERNAL_DEPRECATED
        #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        /* set up old style internal macros (up to 2.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4456 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4458 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4460 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4462 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_2_1
        #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4465 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        #else
# 4470 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 4475 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 2.2) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4477 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4479 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4481 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4483 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_2_2
        #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4486 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4493 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        #else
# 4500 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_2_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 4507 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 3.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4509 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4511 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4513 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4515 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_3_0
        #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4518 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4536 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        #else
# 4545 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 4554 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 3.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4556 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4558 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4560 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4562 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_3_1
        #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4565 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4576 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4587 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4598 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        #else
# 4609 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 4620 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 3.2) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4622 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4624 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4626 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4628 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_3_2
        #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4631 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4644 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4657 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4670 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4683 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        #else
# 4696 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_3_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 4709 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 4.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4711 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4713 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4715 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4717 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_4_0
        #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4720 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4735 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4750 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4765 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4780 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4795 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        #else
# 4810 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 4825 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 4.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4827 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4829 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4831 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4833 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_4_1
        #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4836 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4853 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4870 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4887 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4904 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4921 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4938 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        #else
# 4955 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 4972 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 4.2) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4974 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 4976 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 4978 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 4980 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_4_2
        #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4983 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5002 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5021 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5040 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5059 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5078 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5097 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        #else
# 5135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 5154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 4.3) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 5160 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 5162 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_4_3
        #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5249 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5270 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5291 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5312 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5333 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        #else
# 5354 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_4_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 5375 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 5.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5377 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5379 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 5381 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 5383 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_5_0
        #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5409 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5432 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5455 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5478 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5501 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5524 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5547 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5570 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5593 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        #else
# 5616 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 5639 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 5.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5641 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5643 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 5645 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 5647 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_5_1
        #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5650 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5675 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5700 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5725 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5750 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5775 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5800 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5825 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5850 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5875 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5900 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        #else
# 5925 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_5_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 5950 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 6.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5952 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5954 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 5956 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 5958 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_6_0
        #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5961 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 5988 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6015 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6042 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6069 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6096 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6231 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6258 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        #else
# 6285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 6312 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 6.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 6314 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6316 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 6318 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 6320 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_6_1
        #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 6323 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6381 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6410 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6439 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6468 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6497 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6526 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6555 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6584 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6613 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6642 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6671 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        #else
# 6700 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_6_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 6729 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 7.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 6731 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6733 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 6735 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 6737 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_7_0
        #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 6740 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6771 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6802 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6833 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6864 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6895 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6926 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6957 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 6988 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7019 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7050 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7081 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        #else
# 7174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 7205 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 7.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 7207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7209 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 7211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 7213 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_7_1
        #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 7216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7249 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7282 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7348 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7381 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7414 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7447 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7480 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7513 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7546 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7579 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7612 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7645 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7678 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        #else
# 7711 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_7_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 7744 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 8.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 7746 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7748 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 7750 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 7752 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_8_0
        #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 7755 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7790 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7825 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7860 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7895 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7930 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 7965 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8000 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8035 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8070 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8140 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8245 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8280 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        #else
# 8315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 8350 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 8.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 8352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8354 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 8356 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 8358 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_8_1
        #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 8361 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8398 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8435 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8472 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8509 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8546 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8583 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8620 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8657 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8694 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8731 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8768 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8805 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8842 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8879 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8916 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 8953 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        #else
# 8990 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 9027 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 8.2) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 9029 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9031 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 9033 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 9035 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_8_2
        #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 9038 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9077 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9194 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9272 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9311 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9350 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9389 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9428 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9467 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9506 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9545 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9584 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9623 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9662 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9701 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        #else
# 9740 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 9779 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 8.3) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 9781 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9783 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 9785 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 9787 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_8_3
        #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 9790 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9831 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9872 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9913 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9954 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 9995 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10036 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10077 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10282 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10323 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10364 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10405 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10446 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10487 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10528 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        #else
# 10569 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 10610 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 8.4) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 10612 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10614 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 10616 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 10618 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_8_4
        #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 10621 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10664 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10707 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10750 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10793 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10836 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10879 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10922 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 10965 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11008 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11051 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11094 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11266 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11309 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11395 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11438 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        #else
# 11481 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_8_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 11524 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 9.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11526 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11528 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 11530 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 11532 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_9_0
        #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11535 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11580 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11625 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11670 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11715 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11760 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11805 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11850 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11895 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11940 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 11985 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12030 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12075 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12255 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12300 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12390 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12435 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        #else
# 12480 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 12525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 9.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 12527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12529 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 12531 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 12533 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_9_1
        #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 12536 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12583 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12630 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12677 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12724 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12771 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12818 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12865 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12912 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 12959 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13006 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13053 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13194 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13288 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13335 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13382 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13429 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13476 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13523 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        #else
# 13570 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 13617 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 9.2) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13619 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13621 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 13623 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 13625 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_9_2
        #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13628 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13677 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13726 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13775 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13824 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13873 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13922 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 13971 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14020 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14069 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14265 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14314 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14363 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14461 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14510 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14559 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14608 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14657 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14706 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        #else
# 14755 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 14804 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 9.3) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14806 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14808 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 14810 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 14812 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_9_3
        #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14815 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14866 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14917 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 14968 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15019 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15070 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15172 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15274 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15427 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15478 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15529 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15580 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15631 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15682 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15733 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15835 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15886 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15937 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 15988 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        #else
# 16039 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_9_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 16090 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 10.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 16092 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16094 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 16096 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 16098 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_10_0
        #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 16101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16313 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16366 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16419 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16472 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16578 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16631 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16684 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16737 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16790 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16843 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16896 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 16949 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17002 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17055 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17214 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17320 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17373 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        #else
# 17426 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 17479 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 10.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17481 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17483 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 17485 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 17487 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_10_1
        #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17490 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17545 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17600 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17655 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17710 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17765 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17820 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17875 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17930 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 17985 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18040 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18095 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18205 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18370 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18425 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18480 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18535 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18590 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18645 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18700 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18755 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18810 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18865 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        #else
# 18920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 18975 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 10.2) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 18977 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 18979 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 18981 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 18983 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_10_2
        #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 18986 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19043 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19214 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19328 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19385 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19442 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19499 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19556 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19613 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19670 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19727 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19841 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19898 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19955 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20012 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20069 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20183 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20240 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20297 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20354 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20411 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20468 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        #else
# 20525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 20582 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 10.3) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 20584 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20586 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 20588 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 20590 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_10_3
        #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 20593 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20652 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20711 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20770 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20829 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20888 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 20947 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21006 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21065 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21124 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21183 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21242 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21360 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21419 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21478 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21596 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21655 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21714 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21773 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21832 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21891 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 21950 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22009 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22068 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        #else
# 22245 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 22304 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 11.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 22306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22308 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 22310 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 22312 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_11_0
        #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_11_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 22315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22437 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22498 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22559 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22620 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22681 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22742 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22803 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22864 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22925 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 22986 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23047 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23230 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23291 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23413 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23474 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23535 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23596 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23657 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23718 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23779 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23840 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23901 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23962 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24023 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
        #else
# 24084 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 24145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 11.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 24147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 24151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 24153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_11_1
        #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_11_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 24156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24282 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24408 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24471 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24534 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24597 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24660 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24723 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24786 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24849 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24912 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24975 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25038 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25164 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25290 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25416 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25479 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25542 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25605 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25668 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25731 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25794 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25857 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 25983 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
        #else
# 26046 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 26109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 11.2) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_11_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 26115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 26117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_11_2
        #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_11_2
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26380 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26445 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26510 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26575 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26640 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26705 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26770 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26835 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26900 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 26965 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27030 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27095 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27160 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27290 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27355 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27420 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27485 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27550 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27615 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27680 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27745 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27810 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27875 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 27940 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28005 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28070 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
        #else
# 28135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 28200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 11.3) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_11_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 28202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 28206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 28208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_11_3
        #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_11_3
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 28211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28278 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28479 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28546 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28613 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28680 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28747 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28814 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28881 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28948 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29015 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29082 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29350 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29417 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29484 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29551 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29618 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29685 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29752 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29819 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29886 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 29953 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30020 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30087 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30221 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30288 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
        #else
# 30355 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 30422 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 11.4) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_11_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 30424 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30426 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 30428 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 30430 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_11_4
        #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_11_4
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 30433 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30502 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30571 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30640 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30709 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30778 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30847 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30916 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30985 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31054 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31192 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31261 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31330 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31399 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31468 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31606 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31675 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31744 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31813 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31882 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 31951 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32020 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32089 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32296 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32365 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32434 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32503 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32572 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32641 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
        #else
# 32710 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 32779 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 12.0) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_12_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 32781 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32783 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 32785 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 32787 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_12_0
        #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_12_0
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 32790 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32861 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 32932 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33003 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33074 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33287 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33358 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33429 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33500 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33571 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33642 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33713 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33855 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33926 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 33997 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34068 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34423 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34494 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34565 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34636 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34707 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34778 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34849 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 34991 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35062 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35133 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_0
        #else
# 35204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_0_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 35275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 12.1) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_12_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 35277 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 35281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 35283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_12_1
        #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_12_1
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 35286 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35359 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35432 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35505 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35578 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35651 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35724 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35797 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35870 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35943 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36016 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36089 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36162 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36235 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36308 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36381 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36454 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36600 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36673 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36746 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36819 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36892 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 36965 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37038 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37330 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37403 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37476 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37549 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37622 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37695 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37768 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL__IPHONE_12_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_1
        #else
# 37841 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 37914 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up old style internal macros (up to 12.2) */
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MAX_ALLOWED < __IPHONE_12_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 37916 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2                      __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 37918 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2                      __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 37920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2                      __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 37922 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_NA           __AVAILABILITY_INTERNAL__IPHONE_12_2
        #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_NA_MSG(_msg) __AVAILABILITY_INTERNAL__IPHONE_12_2
        
#if 0 /* disabled by -frewrite-includes */
#if __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 37925 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_2_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38000 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38075 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_3_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_3_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38300 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38375 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38450 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_4_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_4_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_4_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38600 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_5_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38675 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_5_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_5_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38750 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_6_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38825 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_6_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_6_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38900 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_7_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 38975 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_7_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_7_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39050 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39125 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_8_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39350 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_8_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_8_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39425 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39500 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39575 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_9_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39650 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_9_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_9_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39725 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39800 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39875 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 39950 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_10_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_10_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 40025 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 40100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 40175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_2
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 40250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_3
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_3
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_11_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 40325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_11_4
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_11_4
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 40400 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_12_0
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_0
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 40475 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_12_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_12_1
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_1
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_12_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 40550 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_REGULAR
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_2_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL__IPHONE_12_2
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__IPHONE_12_2
        #else
# 40625 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_2_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_3_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_4_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_5_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_6_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_7_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_8_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_9_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_10_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_3_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_11_4_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_12_0_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_12_1_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__IPHONE_12_2_DEP__IPHONE_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #endif
# 40700 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        /* set up internal macros (n/a) */
        #define __AVAILABILITY_INTERNAL__IPHONE_NA                               __AVAILABILITY_INTERNAL_UNAVAILABLE
        #define __AVAILABILITY_INTERNAL__IPHONE_NA_DEP__IPHONE_NA                __AVAILABILITY_INTERNAL_UNAVAILABLE
        #define __AVAILABILITY_INTERNAL__IPHONE_NA_DEP__IPHONE_NA_MSG(_msg)      __AVAILABILITY_INTERNAL_UNAVAILABLE
    #endif
# 40705 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 40707 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
    /* compiler for Mac OS X sets __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ */
    #define __MAC_OS_X_VERSION_MIN_REQUIRED __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__
    /* make sure a default max version is set */
    #ifndef __MAC_OS_X_VERSION_MAX_ALLOWED
        #define __MAC_OS_X_VERSION_MAX_ALLOWED __MAC_10_14_4
    #endif
# 40713 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

    
#if 0 /* disabled by -frewrite-includes */
#if defined(__has_attribute) && defined(__has_feature)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40715 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(availability)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40716 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            /* use better attributes if possible */
            #define __AVAILABILITY_INTERNAL__MAC_10_0                  __attribute__((availability(macosx,introduced=10.0)))
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_0    __attribute__((availability(macosx,introduced=10.0,deprecated=10.0)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40720 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_0_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.0,message=_msg)))
            #else
# 40722 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_0_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.0)))
            #endif
# 40724 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_1    __attribute__((availability(macosx,introduced=10.0,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40726 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.1,message=_msg)))
            #else
# 40728 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.1)))
            #endif
# 40730 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_2    __attribute__((availability(macosx,introduced=10.0,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40732 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.2,message=_msg)))
            #else
# 40734 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.2)))
            #endif
# 40736 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_3    __attribute__((availability(macosx,introduced=10.0,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40738 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.3,message=_msg)))
            #else
# 40740 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.3)))
            #endif
# 40742 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_4    __attribute__((availability(macosx,introduced=10.0,deprecated=10.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40744 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.4,message=_msg)))
            #else
# 40746 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.4)))
            #endif
# 40748 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_5    __attribute__((availability(macosx,introduced=10.0,deprecated=10.5)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40750 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.5,message=_msg)))
            #else
# 40752 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.5)))
            #endif
# 40754 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_6    __attribute__((availability(macosx,introduced=10.0,deprecated=10.6)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40756 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.6,message=_msg)))
            #else
# 40758 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.6)))
            #endif
# 40760 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_7    __attribute__((availability(macosx,introduced=10.0,deprecated=10.7)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40762 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.7,message=_msg)))
            #else
# 40764 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.7)))
            #endif
# 40766 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.0,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40768 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.8,message=_msg)))
            #else
# 40770 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.8)))
            #endif
# 40772 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.0,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40774 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.9,message=_msg)))
            #else
# 40776 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.9)))
            #endif
# 40778 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40780 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10,message=_msg)))
            #else
# 40782 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10)))
            #endif
# 40784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40786 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10.2,message=_msg)))
            #else
# 40788 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10.2)))
            #endif
# 40790 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40792 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10.3,message=_msg)))
            #else
# 40794 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.10.3)))
            #endif
# 40796 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40798 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11,message=_msg)))
            #else
# 40800 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11)))
            #endif
# 40802 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40804 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.2,message=_msg)))
            #else
# 40806 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.2)))
            #endif
# 40808 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40810 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.3,message=_msg)))
            #else
# 40812 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.3)))
            #endif
# 40814 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40816 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.4,message=_msg)))
            #else
# 40818 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.11.4)))
            #endif
# 40820 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40822 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12,message=_msg)))
            #else
# 40824 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12)))
            #endif
# 40826 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40828 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.1,message=_msg)))
            #else
# 40830 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.1)))
            #endif
# 40832 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40834 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.2,message=_msg)))
            #else
# 40836 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.2)))
            #endif
# 40838 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40840 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.4,message=_msg)))
            #else
# 40842 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.12.4)))
            #endif
# 40844 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40846 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13,message=_msg)))
            #else
# 40848 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13)))
            #endif
# 40850 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40852 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.1,message=_msg)))
            #else
# 40854 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.1)))
            #endif
# 40856 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40858 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.2,message=_msg)))
            #else
# 40860 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.2)))
            #endif
# 40862 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40864 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.4,message=_msg)))
            #else
# 40866 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.13.4)))
            #endif
# 40868 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40870 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14,message=_msg)))
            #else
# 40872 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14)))
            #endif
# 40874 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40876 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14.1,message=_msg)))
            #else
# 40878 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14.1)))
            #endif
# 40880 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40882 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14.4,message=_msg)))
            #else
# 40884 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.0,deprecated=10.14.4)))
            #endif
# 40886 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.0)))
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.0)))
            #define __AVAILABILITY_INTERNAL__MAC_10_1                  __attribute__((availability(macosx,introduced=10.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_1    __attribute__((availability(macosx,introduced=10.1,deprecated=10.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40891 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.1,message=_msg)))
            #else
# 40893 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.1)))
            #endif
# 40895 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_2    __attribute__((availability(macosx,introduced=10.1,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40897 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.2,message=_msg)))
            #else
# 40899 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.2)))
            #endif
# 40901 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_3    __attribute__((availability(macosx,introduced=10.1,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40903 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.3,message=_msg)))
            #else
# 40905 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.3)))
            #endif
# 40907 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_4    __attribute__((availability(macosx,introduced=10.1,deprecated=10.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40909 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.4,message=_msg)))
            #else
# 40911 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.4)))
            #endif
# 40913 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_5    __attribute__((availability(macosx,introduced=10.1,deprecated=10.5)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40915 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.5,message=_msg)))
            #else
# 40917 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.5)))
            #endif
# 40919 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_6    __attribute__((availability(macosx,introduced=10.1,deprecated=10.6)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40921 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.6,message=_msg)))
            #else
# 40923 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.6)))
            #endif
# 40925 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_7    __attribute__((availability(macosx,introduced=10.1,deprecated=10.7)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40927 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.7,message=_msg)))
            #else
# 40929 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.7)))
            #endif
# 40931 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.1,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40933 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.8,message=_msg)))
            #else
# 40935 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.8)))
            #endif
# 40937 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.1,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40939 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.9,message=_msg)))
            #else
# 40941 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.9)))
            #endif
# 40943 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40945 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10,message=_msg)))
            #else
# 40947 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10)))
            #endif
# 40949 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40951 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10.2,message=_msg)))
            #else
# 40953 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10.2)))
            #endif
# 40955 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40957 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10.3,message=_msg)))
            #else
# 40959 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.10.3)))
            #endif
# 40961 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40963 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11,message=_msg)))
            #else
# 40965 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11)))
            #endif
# 40967 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40969 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.2,message=_msg)))
            #else
# 40971 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.2)))
            #endif
# 40973 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40975 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.3,message=_msg)))
            #else
# 40977 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.3)))
            #endif
# 40979 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40981 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.4,message=_msg)))
            #else
# 40983 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.11.4)))
            #endif
# 40985 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40987 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12,message=_msg)))
            #else
# 40989 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12)))
            #endif
# 40991 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40993 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.1,message=_msg)))
            #else
# 40995 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.1)))
            #endif
# 40997 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 40999 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.2,message=_msg)))
            #else
# 41001 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.2)))
            #endif
# 41003 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41005 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.4,message=_msg)))
            #else
# 41007 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.12.4)))
            #endif
# 41009 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41011 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13,message=_msg)))
            #else
# 41013 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13)))
            #endif
# 41015 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41017 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.1,message=_msg)))
            #else
# 41019 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.1)))
            #endif
# 41021 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41023 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.2,message=_msg)))
            #else
# 41025 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.2)))
            #endif
# 41027 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41029 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.4,message=_msg)))
            #else
# 41031 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.13.4)))
            #endif
# 41033 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41035 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14,message=_msg)))
            #else
# 41037 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14)))
            #endif
# 41039 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41041 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14.1,message=_msg)))
            #else
# 41043 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14.1)))
            #endif
# 41045 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41047 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14.4,message=_msg)))
            #else
# 41049 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.1,deprecated=10.14.4)))
            #endif
# 41051 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_2                  __attribute__((availability(macosx,introduced=10.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_2    __attribute__((availability(macosx,introduced=10.2,deprecated=10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41056 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.2,message=_msg)))
            #else
# 41058 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.2)))
            #endif
# 41060 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_3    __attribute__((availability(macosx,introduced=10.2,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41062 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.3,message=_msg)))
            #else
# 41064 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.3)))
            #endif
# 41066 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_4    __attribute__((availability(macosx,introduced=10.2,deprecated=10.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41068 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.4,message=_msg)))
            #else
# 41070 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.4)))
            #endif
# 41072 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_5    __attribute__((availability(macosx,introduced=10.2,deprecated=10.5)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41074 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.5,message=_msg)))
            #else
# 41076 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.5)))
            #endif
# 41078 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_6    __attribute__((availability(macosx,introduced=10.2,deprecated=10.6)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41080 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.6,message=_msg)))
            #else
# 41082 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.6)))
            #endif
# 41084 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_7    __attribute__((availability(macosx,introduced=10.2,deprecated=10.7)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41086 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.7,message=_msg)))
            #else
# 41088 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.7)))
            #endif
# 41090 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.2,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41092 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.8,message=_msg)))
            #else
# 41094 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.8)))
            #endif
# 41096 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.2,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41098 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.9,message=_msg)))
            #else
# 41100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.9)))
            #endif
# 41102 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41104 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10,message=_msg)))
            #else
# 41106 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10)))
            #endif
# 41108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10.2,message=_msg)))
            #else
# 41112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10.2)))
            #endif
# 41114 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10.3,message=_msg)))
            #else
# 41118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.10.3)))
            #endif
# 41120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11,message=_msg)))
            #else
# 41124 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11)))
            #endif
# 41126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.2,message=_msg)))
            #else
# 41130 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.2)))
            #endif
# 41132 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41134 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.3,message=_msg)))
            #else
# 41136 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.3)))
            #endif
# 41138 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41140 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.4,message=_msg)))
            #else
# 41142 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.11.4)))
            #endif
# 41144 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41146 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12,message=_msg)))
            #else
# 41148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12)))
            #endif
# 41150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41152 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.1,message=_msg)))
            #else
# 41154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.1)))
            #endif
# 41156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.2,message=_msg)))
            #else
# 41160 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.2)))
            #endif
# 41162 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41164 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.4,message=_msg)))
            #else
# 41166 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.12.4)))
            #endif
# 41168 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41170 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13,message=_msg)))
            #else
# 41172 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13)))
            #endif
# 41174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41176 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.1,message=_msg)))
            #else
# 41178 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.1)))
            #endif
# 41180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41182 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.2,message=_msg)))
            #else
# 41184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.2)))
            #endif
# 41186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41188 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.4,message=_msg)))
            #else
# 41190 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.13.4)))
            #endif
# 41192 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41194 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14,message=_msg)))
            #else
# 41196 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14)))
            #endif
# 41198 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14.1,message=_msg)))
            #else
# 41202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14.1)))
            #endif
# 41204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14.4,message=_msg)))
            #else
# 41208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.2,deprecated=10.14.4)))
            #endif
# 41210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_3                  __attribute__((availability(macosx,introduced=10.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_3    __attribute__((availability(macosx,introduced=10.3,deprecated=10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41215 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.3,message=_msg)))
            #else
# 41217 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.3)))
            #endif
# 41219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_4    __attribute__((availability(macosx,introduced=10.3,deprecated=10.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41221 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.4,message=_msg)))
            #else
# 41223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.4)))
            #endif
# 41225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_5    __attribute__((availability(macosx,introduced=10.3,deprecated=10.5)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.5,message=_msg)))
            #else
# 41229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.5)))
            #endif
# 41231 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_6    __attribute__((availability(macosx,introduced=10.3,deprecated=10.6)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.6,message=_msg)))
            #else
# 41235 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.6)))
            #endif
# 41237 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_7    __attribute__((availability(macosx,introduced=10.3,deprecated=10.7)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41239 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.7,message=_msg)))
            #else
# 41241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.7)))
            #endif
# 41243 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.3,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41245 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.8,message=_msg)))
            #else
# 41247 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.8)))
            #endif
# 41249 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.3,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41251 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.9,message=_msg)))
            #else
# 41253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.9)))
            #endif
# 41255 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10,message=_msg)))
            #else
# 41259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10)))
            #endif
# 41261 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41263 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10.2,message=_msg)))
            #else
# 41265 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10.2)))
            #endif
# 41267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41269 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10.3,message=_msg)))
            #else
# 41271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.10.3)))
            #endif
# 41273 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11,message=_msg)))
            #else
# 41277 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11)))
            #endif
# 41279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.2,message=_msg)))
            #else
# 41283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.2)))
            #endif
# 41285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41287 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.3,message=_msg)))
            #else
# 41289 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.3)))
            #endif
# 41291 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41293 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.4,message=_msg)))
            #else
# 41295 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.11.4)))
            #endif
# 41297 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41299 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12,message=_msg)))
            #else
# 41301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12)))
            #endif
# 41303 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41305 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.1,message=_msg)))
            #else
# 41307 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.1)))
            #endif
# 41309 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41311 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.2,message=_msg)))
            #else
# 41313 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.2)))
            #endif
# 41315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41317 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.4,message=_msg)))
            #else
# 41319 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.12.4)))
            #endif
# 41321 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41323 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13,message=_msg)))
            #else
# 41325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13)))
            #endif
# 41327 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41329 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.1,message=_msg)))
            #else
# 41331 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.1)))
            #endif
# 41333 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41335 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.2,message=_msg)))
            #else
# 41337 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.2)))
            #endif
# 41339 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.4,message=_msg)))
            #else
# 41343 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.13.4)))
            #endif
# 41345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41347 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14,message=_msg)))
            #else
# 41349 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14)))
            #endif
# 41351 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14.1,message=_msg)))
            #else
# 41355 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14.1)))
            #endif
# 41357 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41359 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14.4,message=_msg)))
            #else
# 41361 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.3,deprecated=10.14.4)))
            #endif
# 41363 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_4                  __attribute__((availability(macosx,introduced=10.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_4    __attribute__((availability(macosx,introduced=10.4,deprecated=10.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41368 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.4,message=_msg)))
            #else
# 41370 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.4)))
            #endif
# 41372 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_5    __attribute__((availability(macosx,introduced=10.4,deprecated=10.5)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41374 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.5,message=_msg)))
            #else
# 41376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.5)))
            #endif
# 41378 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_6    __attribute__((availability(macosx,introduced=10.4,deprecated=10.6)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41380 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.6,message=_msg)))
            #else
# 41382 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.6)))
            #endif
# 41384 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_7    __attribute__((availability(macosx,introduced=10.4,deprecated=10.7)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.7,message=_msg)))
            #else
# 41388 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.7)))
            #endif
# 41390 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.4,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41392 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.8,message=_msg)))
            #else
# 41394 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.8)))
            #endif
# 41396 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.4,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41398 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.9,message=_msg)))
            #else
# 41400 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.9)))
            #endif
# 41402 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41404 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10,message=_msg)))
            #else
# 41406 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10)))
            #endif
# 41408 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41410 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10.2,message=_msg)))
            #else
# 41412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10.2)))
            #endif
# 41414 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41416 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10.3,message=_msg)))
            #else
# 41418 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.10.3)))
            #endif
# 41420 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41422 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11,message=_msg)))
            #else
# 41424 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11)))
            #endif
# 41426 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41428 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.2,message=_msg)))
            #else
# 41430 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.2)))
            #endif
# 41432 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41434 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.3,message=_msg)))
            #else
# 41436 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.3)))
            #endif
# 41438 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41440 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.4,message=_msg)))
            #else
# 41442 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.11.4)))
            #endif
# 41444 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41446 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12,message=_msg)))
            #else
# 41448 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12)))
            #endif
# 41450 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41452 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.1,message=_msg)))
            #else
# 41454 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.1)))
            #endif
# 41456 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41458 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.2,message=_msg)))
            #else
# 41460 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.2)))
            #endif
# 41462 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41464 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.4,message=_msg)))
            #else
# 41466 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.12.4)))
            #endif
# 41468 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41470 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13,message=_msg)))
            #else
# 41472 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13)))
            #endif
# 41474 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41476 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.1,message=_msg)))
            #else
# 41478 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.1)))
            #endif
# 41480 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41482 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.2,message=_msg)))
            #else
# 41484 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.2)))
            #endif
# 41486 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41488 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.4,message=_msg)))
            #else
# 41490 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.13.4)))
            #endif
# 41492 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41494 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14,message=_msg)))
            #else
# 41496 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14)))
            #endif
# 41498 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41500 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14.1,message=_msg)))
            #else
# 41502 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14.1)))
            #endif
# 41504 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41506 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14.4,message=_msg)))
            #else
# 41508 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.4,deprecated=10.14.4)))
            #endif
# 41510 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_5                  __attribute__((availability(macosx,introduced=10.5)))
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_5    __attribute__((availability(macosx,introduced=10.5,deprecated=10.5)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41515 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.5,message=_msg)))
            #else
# 41517 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_5_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.5)))
            #endif
# 41519 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_6    __attribute__((availability(macosx,introduced=10.5,deprecated=10.6)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41521 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.6,message=_msg)))
            #else
# 41523 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.6)))
            #endif
# 41525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_7    __attribute__((availability(macosx,introduced=10.5,deprecated=10.7)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.7,message=_msg)))
            #else
# 41529 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.7)))
            #endif
# 41531 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.5,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41533 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.8,message=_msg)))
            #else
# 41535 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.8)))
            #endif
# 41537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.5,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41539 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.9,message=_msg)))
            #else
# 41541 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.9)))
            #endif
# 41543 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41545 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10,message=_msg)))
            #else
# 41547 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10)))
            #endif
# 41549 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41551 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10.2,message=_msg)))
            #else
# 41553 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10.2)))
            #endif
# 41555 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41557 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10.3,message=_msg)))
            #else
# 41559 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.10.3)))
            #endif
# 41561 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41563 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11,message=_msg)))
            #else
# 41565 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11)))
            #endif
# 41567 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41569 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.2,message=_msg)))
            #else
# 41571 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.2)))
            #endif
# 41573 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41575 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.3,message=_msg)))
            #else
# 41577 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.3)))
            #endif
# 41579 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41581 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.4,message=_msg)))
            #else
# 41583 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.11.4)))
            #endif
# 41585 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41587 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12,message=_msg)))
            #else
# 41589 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12)))
            #endif
# 41591 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41593 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.1,message=_msg)))
            #else
# 41595 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.1)))
            #endif
# 41597 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41599 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.2,message=_msg)))
            #else
# 41601 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.2)))
            #endif
# 41603 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41605 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.4,message=_msg)))
            #else
# 41607 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.12.4)))
            #endif
# 41609 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41611 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13,message=_msg)))
            #else
# 41613 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13)))
            #endif
# 41615 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41617 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.1,message=_msg)))
            #else
# 41619 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.1)))
            #endif
# 41621 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41623 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.2,message=_msg)))
            #else
# 41625 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.2)))
            #endif
# 41627 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41629 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.4,message=_msg)))
            #else
# 41631 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.13.4)))
            #endif
# 41633 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41635 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14,message=_msg)))
            #else
# 41637 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14)))
            #endif
# 41639 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41641 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14.1,message=_msg)))
            #else
# 41643 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14.1)))
            #endif
# 41645 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41647 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14.4,message=_msg)))
            #else
# 41649 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.5,deprecated=10.14.4)))
            #endif
# 41651 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.5)))
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.5)))
            #define __AVAILABILITY_INTERNAL__MAC_10_6                  __attribute__((availability(macosx,introduced=10.6)))
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_6    __attribute__((availability(macosx,introduced=10.6,deprecated=10.6)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41656 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.6,message=_msg)))
            #else
# 41658 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_6_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.6)))
            #endif
# 41660 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_7    __attribute__((availability(macosx,introduced=10.6,deprecated=10.7)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41662 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.7,message=_msg)))
            #else
# 41664 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.7)))
            #endif
# 41666 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.6,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41668 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.8,message=_msg)))
            #else
# 41670 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.8)))
            #endif
# 41672 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.6,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41674 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.9,message=_msg)))
            #else
# 41676 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.9)))
            #endif
# 41678 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41680 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10,message=_msg)))
            #else
# 41682 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10)))
            #endif
# 41684 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41686 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10.2,message=_msg)))
            #else
# 41688 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10.2)))
            #endif
# 41690 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41692 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10.3,message=_msg)))
            #else
# 41694 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.10.3)))
            #endif
# 41696 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41698 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11,message=_msg)))
            #else
# 41700 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11)))
            #endif
# 41702 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41704 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.2,message=_msg)))
            #else
# 41706 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.2)))
            #endif
# 41708 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41710 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.3,message=_msg)))
            #else
# 41712 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.3)))
            #endif
# 41714 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41716 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.4,message=_msg)))
            #else
# 41718 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.11.4)))
            #endif
# 41720 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41722 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12,message=_msg)))
            #else
# 41724 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12)))
            #endif
# 41726 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41728 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.1,message=_msg)))
            #else
# 41730 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.1)))
            #endif
# 41732 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41734 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.2,message=_msg)))
            #else
# 41736 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.2)))
            #endif
# 41738 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41740 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.4,message=_msg)))
            #else
# 41742 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.12.4)))
            #endif
# 41744 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41746 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13,message=_msg)))
            #else
# 41748 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13)))
            #endif
# 41750 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41752 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.1,message=_msg)))
            #else
# 41754 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.1)))
            #endif
# 41756 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41758 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.2,message=_msg)))
            #else
# 41760 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.2)))
            #endif
# 41762 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41764 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.4,message=_msg)))
            #else
# 41766 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.13.4)))
            #endif
# 41768 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41770 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14,message=_msg)))
            #else
# 41772 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14)))
            #endif
# 41774 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41776 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14.1,message=_msg)))
            #else
# 41778 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14.1)))
            #endif
# 41780 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41782 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14.4,message=_msg)))
            #else
# 41784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.6,deprecated=10.14.4)))
            #endif
# 41786 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.6)))
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.6)))
            #define __AVAILABILITY_INTERNAL__MAC_10_7                  __attribute__((availability(macosx,introduced=10.7)))
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_7    __attribute__((availability(macosx,introduced=10.7,deprecated=10.7)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41791 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.7,message=_msg)))
            #else
# 41793 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_7_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.7)))
            #endif
# 41795 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.7,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41797 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.8,message=_msg)))
            #else
# 41799 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.8)))
            #endif
# 41801 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.7,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41803 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.9,message=_msg)))
            #else
# 41805 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.9)))
            #endif
# 41807 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41809 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10,message=_msg)))
            #else
# 41811 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10)))
            #endif
# 41813 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41815 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10.2,message=_msg)))
            #else
# 41817 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10.2)))
            #endif
# 41819 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41821 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10.3,message=_msg)))
            #else
# 41823 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.10.3)))
            #endif
# 41825 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41827 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11,message=_msg)))
            #else
# 41829 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11)))
            #endif
# 41831 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41833 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.2,message=_msg)))
            #else
# 41835 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.2)))
            #endif
# 41837 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41839 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.3,message=_msg)))
            #else
# 41841 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.3)))
            #endif
# 41843 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41845 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.4,message=_msg)))
            #else
# 41847 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.11.4)))
            #endif
# 41849 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41851 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12,message=_msg)))
            #else
# 41853 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12)))
            #endif
# 41855 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41857 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.1,message=_msg)))
            #else
# 41859 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.1)))
            #endif
# 41861 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41863 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.2,message=_msg)))
            #else
# 41865 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.2)))
            #endif
# 41867 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41869 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.4,message=_msg)))
            #else
# 41871 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.12.4)))
            #endif
# 41873 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41875 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13,message=_msg)))
            #else
# 41877 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13)))
            #endif
# 41879 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41881 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.1,message=_msg)))
            #else
# 41883 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.1)))
            #endif
# 41885 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41887 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.2,message=_msg)))
            #else
# 41889 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.2)))
            #endif
# 41891 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41893 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.4,message=_msg)))
            #else
# 41895 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.13.4)))
            #endif
# 41897 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41899 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14,message=_msg)))
            #else
# 41901 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14)))
            #endif
# 41903 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41905 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14.1,message=_msg)))
            #else
# 41907 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14.1)))
            #endif
# 41909 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41911 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14.4,message=_msg)))
            #else
# 41913 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.7,deprecated=10.14.4)))
            #endif
# 41915 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.7)))
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.7)))
            #define __AVAILABILITY_INTERNAL__MAC_10_8                  __attribute__((availability(macosx,introduced=10.8)))
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_8    __attribute__((availability(macosx,introduced=10.8,deprecated=10.8)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.8,message=_msg)))
            #else
# 41922 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_8_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.8)))
            #endif
# 41924 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.8,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41926 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.9,message=_msg)))
            #else
# 41928 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.9)))
            #endif
# 41930 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41932 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10,message=_msg)))
            #else
# 41934 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10)))
            #endif
# 41936 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41938 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10.2,message=_msg)))
            #else
# 41940 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10.2)))
            #endif
# 41942 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41944 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10.3,message=_msg)))
            #else
# 41946 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.10.3)))
            #endif
# 41948 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41950 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11,message=_msg)))
            #else
# 41952 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11)))
            #endif
# 41954 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41956 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.2,message=_msg)))
            #else
# 41958 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.2)))
            #endif
# 41960 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41962 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.3,message=_msg)))
            #else
# 41964 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.3)))
            #endif
# 41966 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41968 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.4,message=_msg)))
            #else
# 41970 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.11.4)))
            #endif
# 41972 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41974 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12,message=_msg)))
            #else
# 41976 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12)))
            #endif
# 41978 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41980 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.1,message=_msg)))
            #else
# 41982 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.1)))
            #endif
# 41984 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41986 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.2,message=_msg)))
            #else
# 41988 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.2)))
            #endif
# 41990 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41992 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.4,message=_msg)))
            #else
# 41994 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.12.4)))
            #endif
# 41996 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41998 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13,message=_msg)))
            #else
# 42000 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13)))
            #endif
# 42002 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42004 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.1,message=_msg)))
            #else
# 42006 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.1)))
            #endif
# 42008 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42010 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.2,message=_msg)))
            #else
# 42012 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.2)))
            #endif
# 42014 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42016 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.4,message=_msg)))
            #else
# 42018 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.13.4)))
            #endif
# 42020 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42022 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14,message=_msg)))
            #else
# 42024 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14)))
            #endif
# 42026 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42028 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14.1,message=_msg)))
            #else
# 42030 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14.1)))
            #endif
# 42032 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42034 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14.4,message=_msg)))
            #else
# 42036 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.8,deprecated=10.14.4)))
            #endif
# 42038 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.8)))
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.8)))
            #define __AVAILABILITY_INTERNAL__MAC_10_9                  __attribute__((availability(macosx,introduced=10.9)))
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_9    __attribute__((availability(macosx,introduced=10.9,deprecated=10.9)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42043 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.9,message=_msg)))
            #else
# 42045 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_9_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.9)))
            #endif
# 42047 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42049 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10,message=_msg)))
            #else
# 42051 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10)))
            #endif
# 42053 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42055 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10.2,message=_msg)))
            #else
# 42057 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10.2)))
            #endif
# 42059 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42061 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10.3,message=_msg)))
            #else
# 42063 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.10.3)))
            #endif
# 42065 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42067 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11,message=_msg)))
            #else
# 42069 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11)))
            #endif
# 42071 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42073 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.2,message=_msg)))
            #else
# 42075 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.2)))
            #endif
# 42077 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42079 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.3,message=_msg)))
            #else
# 42081 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.3)))
            #endif
# 42083 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42085 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.4,message=_msg)))
            #else
# 42087 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.11.4)))
            #endif
# 42089 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42091 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12,message=_msg)))
            #else
# 42093 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12)))
            #endif
# 42095 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42097 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.1,message=_msg)))
            #else
# 42099 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.1)))
            #endif
# 42101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.2,message=_msg)))
            #else
# 42105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.2)))
            #endif
# 42107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.4,message=_msg)))
            #else
# 42111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.12.4)))
            #endif
# 42113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13,message=_msg)))
            #else
# 42117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13)))
            #endif
# 42119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.1,message=_msg)))
            #else
# 42123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.1)))
            #endif
# 42125 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.2,message=_msg)))
            #else
# 42129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.2)))
            #endif
# 42131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42133 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.4,message=_msg)))
            #else
# 42135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.13.4)))
            #endif
# 42137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14,message=_msg)))
            #else
# 42141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14)))
            #endif
# 42143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14.1,message=_msg)))
            #else
# 42147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14.1)))
            #endif
# 42149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14.4,message=_msg)))
            #else
# 42153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.9,deprecated=10.14.4)))
            #endif
# 42155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.9)))
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.9)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10                  __attribute__((availability(macosx,introduced=10.10)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42160 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10,message=_msg)))
            #else
# 42162 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10)))
            #endif
# 42164 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42166 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10.2,message=_msg)))
            #else
# 42168 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10.2)))
            #endif
# 42170 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42172 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10.3,message=_msg)))
            #else
# 42174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.10.3)))
            #endif
# 42176 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42178 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11,message=_msg)))
            #else
# 42180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11)))
            #endif
# 42182 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.2,message=_msg)))
            #else
# 42186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.2)))
            #endif
# 42188 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42190 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.3,message=_msg)))
            #else
# 42192 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.3)))
            #endif
# 42194 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42196 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.4,message=_msg)))
            #else
# 42198 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.11.4)))
            #endif
# 42200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12,message=_msg)))
            #else
# 42204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12)))
            #endif
# 42206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.1,message=_msg)))
            #else
# 42210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.1)))
            #endif
# 42212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42214 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.2,message=_msg)))
            #else
# 42216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.2)))
            #endif
# 42218 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.4,message=_msg)))
            #else
# 42222 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.12.4)))
            #endif
# 42224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13,message=_msg)))
            #else
# 42228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13)))
            #endif
# 42230 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42232 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.1,message=_msg)))
            #else
# 42234 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.1)))
            #endif
# 42236 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42238 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.2,message=_msg)))
            #else
# 42240 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.2)))
            #endif
# 42242 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42244 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.4,message=_msg)))
            #else
# 42246 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.13.4)))
            #endif
# 42248 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14,message=_msg)))
            #else
# 42252 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14)))
            #endif
# 42254 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42256 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14.1,message=_msg)))
            #else
# 42258 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14.1)))
            #endif
# 42260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42262 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14.4,message=_msg)))
            #else
# 42264 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10,deprecated=10.14.4)))
            #endif
# 42266 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.10)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.10)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2                  __attribute__((availability(macosx,introduced=10.10.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_2    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.10.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.10.2,message=_msg)))
            #else
# 42273 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.10.2)))
            #endif
# 42275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42277 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.10.3,message=_msg)))
            #else
# 42279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.10.3)))
            #endif
# 42281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11,message=_msg)))
            #else
# 42285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11)))
            #endif
# 42287 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42289 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.2,message=_msg)))
            #else
# 42291 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.2)))
            #endif
# 42293 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42295 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.3,message=_msg)))
            #else
# 42297 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.3)))
            #endif
# 42299 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.4,message=_msg)))
            #else
# 42303 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.11.4)))
            #endif
# 42305 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42307 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12,message=_msg)))
            #else
# 42309 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12)))
            #endif
# 42311 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42313 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.1,message=_msg)))
            #else
# 42315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.1)))
            #endif
# 42317 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42319 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.2,message=_msg)))
            #else
# 42321 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.2)))
            #endif
# 42323 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.4,message=_msg)))
            #else
# 42327 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.12.4)))
            #endif
# 42329 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42331 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13,message=_msg)))
            #else
# 42333 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13)))
            #endif
# 42335 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42337 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.1,message=_msg)))
            #else
# 42339 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.1)))
            #endif
# 42341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42343 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.2,message=_msg)))
            #else
# 42345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.2)))
            #endif
# 42347 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42349 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.4,message=_msg)))
            #else
# 42351 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.13.4)))
            #endif
# 42353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42355 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14,message=_msg)))
            #else
# 42357 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14)))
            #endif
# 42359 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42361 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14.1,message=_msg)))
            #else
# 42363 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14.1)))
            #endif
# 42365 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42367 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14.4,message=_msg)))
            #else
# 42369 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.2,deprecated=10.14.4)))
            #endif
# 42371 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.10.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.10.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3                  __attribute__((availability(macosx,introduced=10.10.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_10_3    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.10.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.10.3,message=_msg)))
            #else
# 42378 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_10_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.10.3)))
            #endif
# 42380 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42382 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11,message=_msg)))
            #else
# 42384 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11)))
            #endif
# 42386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42388 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.2,message=_msg)))
            #else
# 42390 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.2)))
            #endif
# 42392 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42394 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.3,message=_msg)))
            #else
# 42396 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.3)))
            #endif
# 42398 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42400 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.4,message=_msg)))
            #else
# 42402 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.11.4)))
            #endif
# 42404 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42406 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12,message=_msg)))
            #else
# 42408 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12)))
            #endif
# 42410 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.1,message=_msg)))
            #else
# 42414 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.1)))
            #endif
# 42416 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42418 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.2,message=_msg)))
            #else
# 42420 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.2)))
            #endif
# 42422 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42424 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.4,message=_msg)))
            #else
# 42426 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.12.4)))
            #endif
# 42428 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42430 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13,message=_msg)))
            #else
# 42432 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13)))
            #endif
# 42434 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42436 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.1,message=_msg)))
            #else
# 42438 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.1)))
            #endif
# 42440 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42442 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.2,message=_msg)))
            #else
# 42444 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.2)))
            #endif
# 42446 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42448 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.4,message=_msg)))
            #else
# 42450 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.13.4)))
            #endif
# 42452 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42454 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14,message=_msg)))
            #else
# 42456 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14)))
            #endif
# 42458 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42460 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14.1,message=_msg)))
            #else
# 42462 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14.1)))
            #endif
# 42464 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42466 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14.4,message=_msg)))
            #else
# 42468 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.10.3,deprecated=10.14.4)))
            #endif
# 42470 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.10.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.10.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11                  __attribute__((availability(macosx,introduced=10.11)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42475 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11,message=_msg)))
            #else
# 42477 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11)))
            #endif
# 42479 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42481 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.2,message=_msg)))
            #else
# 42483 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.2)))
            #endif
# 42485 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42487 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.3,message=_msg)))
            #else
# 42489 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.3)))
            #endif
# 42491 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42493 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.4,message=_msg)))
            #else
# 42495 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.11.4)))
            #endif
# 42497 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42499 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12,message=_msg)))
            #else
# 42501 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12)))
            #endif
# 42503 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42505 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.1,message=_msg)))
            #else
# 42507 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.1)))
            #endif
# 42509 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42511 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.2,message=_msg)))
            #else
# 42513 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.2)))
            #endif
# 42515 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42517 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.4,message=_msg)))
            #else
# 42519 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.12.4)))
            #endif
# 42521 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42523 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13,message=_msg)))
            #else
# 42525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13)))
            #endif
# 42527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42529 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.1,message=_msg)))
            #else
# 42531 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.1)))
            #endif
# 42533 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42535 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.2,message=_msg)))
            #else
# 42537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.2)))
            #endif
# 42539 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42541 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.4,message=_msg)))
            #else
# 42543 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.13.4)))
            #endif
# 42545 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42547 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14,message=_msg)))
            #else
# 42549 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14)))
            #endif
# 42551 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42553 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14.1,message=_msg)))
            #else
# 42555 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14.1)))
            #endif
# 42557 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42559 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14.4,message=_msg)))
            #else
# 42561 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11,deprecated=10.14.4)))
            #endif
# 42563 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.11)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.11)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2                  __attribute__((availability(macosx,introduced=10.11.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_2    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42568 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.2,message=_msg)))
            #else
# 42570 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.2)))
            #endif
# 42572 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42574 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.3,message=_msg)))
            #else
# 42576 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.3)))
            #endif
# 42578 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42580 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.4,message=_msg)))
            #else
# 42582 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.11.4)))
            #endif
# 42584 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42586 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12,message=_msg)))
            #else
# 42588 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12)))
            #endif
# 42590 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42592 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.1,message=_msg)))
            #else
# 42594 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.1)))
            #endif
# 42596 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42598 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.2,message=_msg)))
            #else
# 42600 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.2)))
            #endif
# 42602 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42604 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.4,message=_msg)))
            #else
# 42606 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.12.4)))
            #endif
# 42608 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42610 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13,message=_msg)))
            #else
# 42612 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13)))
            #endif
# 42614 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42616 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.1,message=_msg)))
            #else
# 42618 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.1)))
            #endif
# 42620 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42622 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.2,message=_msg)))
            #else
# 42624 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.2)))
            #endif
# 42626 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42628 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.4,message=_msg)))
            #else
# 42630 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.13.4)))
            #endif
# 42632 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42634 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14,message=_msg)))
            #else
# 42636 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14)))
            #endif
# 42638 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42640 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14.1,message=_msg)))
            #else
# 42642 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14.1)))
            #endif
# 42644 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42646 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14.4,message=_msg)))
            #else
# 42648 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.2,deprecated=10.14.4)))
            #endif
# 42650 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.11.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.11.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3                  __attribute__((availability(macosx,introduced=10.11.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_3    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.11.3)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42655 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.11.3,message=_msg)))
            #else
# 42657 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_3_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.11.3)))
            #endif
# 42659 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42661 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.11.4,message=_msg)))
            #else
# 42663 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.11.4)))
            #endif
# 42665 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42667 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12,message=_msg)))
            #else
# 42669 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12)))
            #endif
# 42671 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42673 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.1,message=_msg)))
            #else
# 42675 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.1)))
            #endif
# 42677 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42679 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.2,message=_msg)))
            #else
# 42681 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.2)))
            #endif
# 42683 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42685 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.4,message=_msg)))
            #else
# 42687 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.12.4)))
            #endif
# 42689 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42691 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13,message=_msg)))
            #else
# 42693 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13)))
            #endif
# 42695 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42697 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.1,message=_msg)))
            #else
# 42699 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.1)))
            #endif
# 42701 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42703 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.2,message=_msg)))
            #else
# 42705 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.2)))
            #endif
# 42707 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42709 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.4,message=_msg)))
            #else
# 42711 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.13.4)))
            #endif
# 42713 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42715 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14,message=_msg)))
            #else
# 42717 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14)))
            #endif
# 42719 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42721 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14.1,message=_msg)))
            #else
# 42723 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14.1)))
            #endif
# 42725 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42727 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14.4,message=_msg)))
            #else
# 42729 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.3,deprecated=10.14.4)))
            #endif
# 42731 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.11.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.11.3)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4                  __attribute__((availability(macosx,introduced=10.11.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_11_4    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.11.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42736 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.11.4,message=_msg)))
            #else
# 42738 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_11_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.11.4)))
            #endif
# 42740 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42742 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12,message=_msg)))
            #else
# 42744 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12)))
            #endif
# 42746 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42748 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.1,message=_msg)))
            #else
# 42750 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.1)))
            #endif
# 42752 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42754 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.2,message=_msg)))
            #else
# 42756 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.2)))
            #endif
# 42758 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42760 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.4,message=_msg)))
            #else
# 42762 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.12.4)))
            #endif
# 42764 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42766 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13,message=_msg)))
            #else
# 42768 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13)))
            #endif
# 42770 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42772 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.1,message=_msg)))
            #else
# 42774 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.1)))
            #endif
# 42776 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42778 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.2,message=_msg)))
            #else
# 42780 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.2)))
            #endif
# 42782 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.4,message=_msg)))
            #else
# 42786 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.13.4)))
            #endif
# 42788 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42790 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14,message=_msg)))
            #else
# 42792 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14)))
            #endif
# 42794 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42796 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14.1,message=_msg)))
            #else
# 42798 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14.1)))
            #endif
# 42800 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42802 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14.4,message=_msg)))
            #else
# 42804 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.11.4,deprecated=10.14.4)))
            #endif
# 42806 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.11.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.11.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12                  __attribute__((availability(macosx,introduced=10.12)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42811 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12,message=_msg)))
            #else
# 42813 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12)))
            #endif
# 42815 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42817 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.1,message=_msg)))
            #else
# 42819 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.1)))
            #endif
# 42821 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42823 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.2,message=_msg)))
            #else
# 42825 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.2)))
            #endif
# 42827 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42829 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.4,message=_msg)))
            #else
# 42831 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.12.4)))
            #endif
# 42833 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42835 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13,message=_msg)))
            #else
# 42837 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13)))
            #endif
# 42839 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42841 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.1,message=_msg)))
            #else
# 42843 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.1)))
            #endif
# 42845 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42847 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.2,message=_msg)))
            #else
# 42849 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.2)))
            #endif
# 42851 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42853 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.4,message=_msg)))
            #else
# 42855 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.13.4)))
            #endif
# 42857 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42859 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14,message=_msg)))
            #else
# 42861 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14)))
            #endif
# 42863 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42865 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14.1,message=_msg)))
            #else
# 42867 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14.1)))
            #endif
# 42869 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42871 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14.4,message=_msg)))
            #else
# 42873 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12,deprecated=10.14.4)))
            #endif
# 42875 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.12)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.12)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1                  __attribute__((availability(macosx,introduced=10.12.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_1    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42880 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.1,message=_msg)))
            #else
# 42882 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.1)))
            #endif
# 42884 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42886 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.2,message=_msg)))
            #else
# 42888 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.2)))
            #endif
# 42890 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42892 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.4,message=_msg)))
            #else
# 42894 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.12.4)))
            #endif
# 42896 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42898 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13,message=_msg)))
            #else
# 42900 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13)))
            #endif
# 42902 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42904 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.1,message=_msg)))
            #else
# 42906 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.1)))
            #endif
# 42908 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42910 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.2,message=_msg)))
            #else
# 42912 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.2)))
            #endif
# 42914 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42916 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.4,message=_msg)))
            #else
# 42918 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.13.4)))
            #endif
# 42920 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42922 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14,message=_msg)))
            #else
# 42924 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14)))
            #endif
# 42926 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42928 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14.1,message=_msg)))
            #else
# 42930 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14.1)))
            #endif
# 42932 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42934 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14.4,message=_msg)))
            #else
# 42936 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.1,deprecated=10.14.4)))
            #endif
# 42938 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.12.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.12.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2                  __attribute__((availability(macosx,introduced=10.12.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_2    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.12.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42943 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.12.2,message=_msg)))
            #else
# 42945 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.12.2)))
            #endif
# 42947 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42949 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.12.4,message=_msg)))
            #else
# 42951 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.12.4)))
            #endif
# 42953 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42955 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13,message=_msg)))
            #else
# 42957 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13)))
            #endif
# 42959 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42961 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.1,message=_msg)))
            #else
# 42963 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.1)))
            #endif
# 42965 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42967 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.2,message=_msg)))
            #else
# 42969 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.2)))
            #endif
# 42971 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42973 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.4,message=_msg)))
            #else
# 42975 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.13.4)))
            #endif
# 42977 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42979 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14,message=_msg)))
            #else
# 42981 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14)))
            #endif
# 42983 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42985 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14.1,message=_msg)))
            #else
# 42987 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14.1)))
            #endif
# 42989 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42991 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14.4,message=_msg)))
            #else
# 42993 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.2,deprecated=10.14.4)))
            #endif
# 42995 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.12.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.12.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4                  __attribute__((availability(macosx,introduced=10.12.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_12_4    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.12.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43000 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.12.4,message=_msg)))
            #else
# 43002 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_12_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.12.4)))
            #endif
# 43004 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43006 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13,message=_msg)))
            #else
# 43008 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13)))
            #endif
# 43010 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43012 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.1,message=_msg)))
            #else
# 43014 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.1)))
            #endif
# 43016 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43018 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.2,message=_msg)))
            #else
# 43020 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.2)))
            #endif
# 43022 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43024 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.4,message=_msg)))
            #else
# 43026 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.13.4)))
            #endif
# 43028 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43030 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14,message=_msg)))
            #else
# 43032 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14)))
            #endif
# 43034 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43036 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14.1,message=_msg)))
            #else
# 43038 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14.1)))
            #endif
# 43040 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43042 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14.4,message=_msg)))
            #else
# 43044 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.12.4,deprecated=10.14.4)))
            #endif
# 43046 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.12.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.12.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13                  __attribute__((availability(macosx,introduced=10.13)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43051 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13,message=_msg)))
            #else
# 43053 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13)))
            #endif
# 43055 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43057 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.1,message=_msg)))
            #else
# 43059 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.1)))
            #endif
# 43061 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43063 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.2,message=_msg)))
            #else
# 43065 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.2)))
            #endif
# 43067 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43069 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.4,message=_msg)))
            #else
# 43071 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.13.4)))
            #endif
# 43073 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43075 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14,message=_msg)))
            #else
# 43077 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14)))
            #endif
# 43079 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43081 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14.1,message=_msg)))
            #else
# 43083 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14.1)))
            #endif
# 43085 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43087 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14.4,message=_msg)))
            #else
# 43089 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13,deprecated=10.14.4)))
            #endif
# 43091 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.13)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.13)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1                  __attribute__((availability(macosx,introduced=10.13.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_1    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43096 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.1,message=_msg)))
            #else
# 43098 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.1)))
            #endif
# 43100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43102 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.2,message=_msg)))
            #else
# 43104 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.2)))
            #endif
# 43106 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.4,message=_msg)))
            #else
# 43110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.13.4)))
            #endif
# 43112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43114 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14,message=_msg)))
            #else
# 43116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14)))
            #endif
# 43118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14.1,message=_msg)))
            #else
# 43122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14.1)))
            #endif
# 43124 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14.4,message=_msg)))
            #else
# 43128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.1,deprecated=10.14.4)))
            #endif
# 43130 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.13.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.13.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2                  __attribute__((availability(macosx,introduced=10.13.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_2    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.13.2)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.13.2,message=_msg)))
            #else
# 43137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_2_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.13.2)))
            #endif
# 43139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.13.4,message=_msg)))
            #else
# 43143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.13.4)))
            #endif
# 43145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14,message=_msg)))
            #else
# 43149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14)))
            #endif
# 43151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14.1,message=_msg)))
            #else
# 43155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14.1)))
            #endif
# 43157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14.4,message=_msg)))
            #else
# 43161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.2,deprecated=10.14.4)))
            #endif
# 43163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.13.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.13.2)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4                  __attribute__((availability(macosx,introduced=10.13.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_13_4    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.13.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43168 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.13.4,message=_msg)))
            #else
# 43170 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_13_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.13.4)))
            #endif
# 43172 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14,message=_msg)))
            #else
# 43176 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14)))
            #endif
# 43178 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14.1,message=_msg)))
            #else
# 43182 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14.1)))
            #endif
# 43184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14.4,message=_msg)))
            #else
# 43188 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.13.4,deprecated=10.14.4)))
            #endif
# 43190 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.13.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.13.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14                  __attribute__((availability(macosx,introduced=10.14)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43195 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14,message=_msg)))
            #else
# 43197 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14)))
            #endif
# 43199 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14.1,message=_msg)))
            #else
# 43203 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14.1)))
            #endif
# 43205 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14.4,message=_msg)))
            #else
# 43209 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14,deprecated=10.14.4)))
            #endif
# 43211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.14)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.14)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1                  __attribute__((availability(macosx,introduced=10.14.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_1    __attribute__((availability(macosx,introduced=10.14.1,deprecated=10.14.1)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14.1,deprecated=10.14.1,message=_msg)))
            #else
# 43218 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_1_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14.1,deprecated=10.14.1)))
            #endif
# 43220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.14.1,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43222 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14.1,deprecated=10.14.4,message=_msg)))
            #else
# 43224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14.1,deprecated=10.14.4)))
            #endif
# 43226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.14.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.14.1)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4                  __attribute__((availability(macosx,introduced=10.14.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_10_14_4    __attribute__((availability(macosx,introduced=10.14.4,deprecated=10.14.4)))
            
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43231 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14.4,deprecated=10.14.4,message=_msg)))
            #else
# 43233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
                #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_10_14_4_MSG(_msg)    __attribute__((availability(macosx,introduced=10.14.4,deprecated=10.14.4)))
            #endif
# 43235 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_NA_MSG(_msg)      __attribute__((availability(macosx,introduced=10.14.4)))
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_NA                __attribute__((availability(macosx,introduced=10.14.4)))
            #define __AVAILABILITY_INTERNAL__MAC_NA                        __attribute__((availability(macosx,unavailable)))
            #define __AVAILABILITY_INTERNAL__MAC_NA_DEP__MAC_NA            __attribute__((availability(macosx,unavailable)))
            #define __AVAILABILITY_INTERNAL__MAC_NA_DEP__MAC_NA_MSG(_msg)  __attribute__((availability(macosx,unavailable)))
        #endif
# 43241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
    #endif
# 43242 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

    #ifndef __AVAILABILITY_INTERNAL__MAC_10_0
        /* use old style attributes */
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_14_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43246 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_14_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43248 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43252 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_14_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_14_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43255 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_14
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43262 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43264 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_14        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43266 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_13_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_13_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43269 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43273 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_13_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43274 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_13_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43276 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43278 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43280 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_13_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_13_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43287 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_13
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43288 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_13
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43290 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43292 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_13        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43294 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_12_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43295 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_12_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43297 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43299 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_12_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43302 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_12_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43304 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43308 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_12_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43309 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_12_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43311 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43313 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_12
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43316 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_12
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43318 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43320 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_12        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43322 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_11_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43323 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_11_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43327 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43329 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_11_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43330 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_11_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43332 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43334 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43336 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_11_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43337 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_11_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43339 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43343 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_11
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43344 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_11
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43346 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43348 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_11        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43350 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_10_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43351 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43355 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43357 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_10_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43358 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43360 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43362 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43364 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_10
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43365 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_10
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43367 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43369 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_10        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43371 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_9
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43372 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_9
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43374 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43376 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_9        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43378 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_8
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43379 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_8
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43381 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43383 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_8        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43385 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_7
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_7
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43388 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43390 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_7        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43392 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_6
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43393 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_6
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43395 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43397 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_6        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43399 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_5
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43400 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_5
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43402 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43404 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_5        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43406 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43407 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_4
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43409 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43411 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_4        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43413 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43414 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_3
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43416 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43418 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_3        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43420 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43421 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_2
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43423 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43425 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_2        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43427 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43428 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43430 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43432 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_1        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43434 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MAX_ALLOWED < __MAC_10_0
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43435 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0        __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 43437 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0        __AVAILABILITY_INTERNAL_WEAK_IMPORT
        #else
# 43439 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0        __AVAILABILITY_INTERNAL_REGULAR
        #endif
# 43441 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__MAC_NA             __AVAILABILITY_INTERNAL_UNAVAILABLE
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43443 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43448 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_1              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_1              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
        #endif
# 43453 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43454 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43461 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_2              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_2              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_2              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
        #endif
# 43468 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43469 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43478 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_3              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_3              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_3              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_3              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
        #endif
# 43487 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43488 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43499 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_4              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_4              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_4              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_4              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_4              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
        #endif
# 43510 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_5
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43511 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_5              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_5              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_5              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_5              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_5              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_5              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43524 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_5              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_5              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_5              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_5              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_5              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_5              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_5_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
        #endif
# 43537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_6
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43538 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_6              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_6              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_6              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_6              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_6              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_6              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_6              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43553 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_6              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_6              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_6              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_6              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_6              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_6              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_6              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_6_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
        #endif
# 43568 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_7
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43569 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_7              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_7              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_7              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_7              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_7              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_7              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_7              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_7              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43586 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_7              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_7              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_7              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_7              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_7              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_7              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_7              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_7              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_7_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
        #endif
# 43603 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_8
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43604 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_8              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43623 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_8              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_8_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
        #endif
# 43642 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_9
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43643 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_9              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43664 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_9              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_9_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
        #endif
# 43685 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_10
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43686 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43709 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
        #endif
# 43732 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_10_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43733 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43758 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_2              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
        #endif
# 43783 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_10_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43811 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_10_3              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_10_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
        #endif
# 43838 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_11
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43839 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43868 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
        #endif
# 43897 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_11_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43898 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43929 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_2              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
        #endif
# 43960 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_11_3
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43961 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 43994 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_3              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_3_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
        #endif
# 44027 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_11_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44028 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44063 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_11_4              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_11_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
        #endif
# 44098 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_12
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44099 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44136 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
        #endif
# 44173 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_12_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44213 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_1              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
        #endif
# 44252 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_12_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44294 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_2              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
        #endif
# 44335 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_12_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44336 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44379 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_12_4              __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_12_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_4
        #endif
# 44422 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_13
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44423 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44468 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13              __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13
        #endif
# 44513 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_13_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44514 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44561 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_1              __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_1
        #endif
# 44608 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_13_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44609 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44658 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_2              __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_2_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_2
        #endif
# 44707 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_13_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44708 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44759 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_13_4              __AVAILABILITY_INTERNAL__MAC_10_13_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_13_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_4
        #endif
# 44810 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44811 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44864 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_13_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14              __AVAILABILITY_INTERNAL__MAC_10_14
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_14
        #endif
# 44917 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_14_1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44918 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 44973 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_13_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_14
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_14
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_1              __AVAILABILITY_INTERNAL__MAC_10_14_1
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_1_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_14_1
        #endif
# 45028 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        
#if 0 /* disabled by -frewrite-includes */
#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_14_4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 45029 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL_DEPRECATED
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL_DEPRECATED_MSG(_msg)
        #else
# 45086 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_0
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_1
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_4
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_5
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_6
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_7
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_8
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_9
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_2
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_10_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_2
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_3
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_11_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_1
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_2
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_12_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_1
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_2
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_13_4
            #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_13_4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_14
            #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_14
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_14_1
            #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_14_1
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_10_14_4              __AVAILABILITY_INTERNAL__MAC_10_14_4
            #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_10_14_4_MSG(_msg)    __AVAILABILITY_INTERNAL__MAC_10_14_4
        #endif
# 45143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_0
        #define __AVAILABILITY_INTERNAL__MAC_10_0_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_0
        #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_1
        #define __AVAILABILITY_INTERNAL__MAC_10_1_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_1
        #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_2
        #define __AVAILABILITY_INTERNAL__MAC_10_2_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_2
        #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_3
        #define __AVAILABILITY_INTERNAL__MAC_10_3_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_3
        #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_4
        #define __AVAILABILITY_INTERNAL__MAC_10_4_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_4
        #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_5
        #define __AVAILABILITY_INTERNAL__MAC_10_5_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_5
        #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_6
        #define __AVAILABILITY_INTERNAL__MAC_10_6_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_6
        #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_7
        #define __AVAILABILITY_INTERNAL__MAC_10_7_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_7
        #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_8
        #define __AVAILABILITY_INTERNAL__MAC_10_8_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_8
        #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_9
        #define __AVAILABILITY_INTERNAL__MAC_10_9_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_9
        #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_10
        #define __AVAILABILITY_INTERNAL__MAC_10_10_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_10
        #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_10_2
        #define __AVAILABILITY_INTERNAL__MAC_10_10_2_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_10_2
        #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_10_3
        #define __AVAILABILITY_INTERNAL__MAC_10_10_3_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_10_3
        #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_11
        #define __AVAILABILITY_INTERNAL__MAC_10_11_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_11
        #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_11_2
        #define __AVAILABILITY_INTERNAL__MAC_10_11_2_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_11_2
        #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_11_3
        #define __AVAILABILITY_INTERNAL__MAC_10_11_3_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_11_3
        #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_11_4
        #define __AVAILABILITY_INTERNAL__MAC_10_11_4_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_11_4
        #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_12
        #define __AVAILABILITY_INTERNAL__MAC_10_12_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_12
        #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_12_1
        #define __AVAILABILITY_INTERNAL__MAC_10_12_1_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_12_1
        #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_12_2
        #define __AVAILABILITY_INTERNAL__MAC_10_12_2_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_12_2
        #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_12_4
        #define __AVAILABILITY_INTERNAL__MAC_10_12_4_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_12_4
        #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_13
        #define __AVAILABILITY_INTERNAL__MAC_10_13_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_13
        #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_13_1
        #define __AVAILABILITY_INTERNAL__MAC_10_13_1_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_13_1
        #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_13_2
        #define __AVAILABILITY_INTERNAL__MAC_10_13_2_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_13_2
        #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_13_4
        #define __AVAILABILITY_INTERNAL__MAC_10_13_4_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_13_4
        #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_14
        #define __AVAILABILITY_INTERNAL__MAC_10_14_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_14
        #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_14_1
        #define __AVAILABILITY_INTERNAL__MAC_10_14_1_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_14_1
        #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_NA             __AVAILABILITY_INTERNAL__MAC_10_14_4
        #define __AVAILABILITY_INTERNAL__MAC_10_14_4_DEP__MAC_NA_MSG(_msg)   __AVAILABILITY_INTERNAL__MAC_10_14_4
        #define __AVAILABILITY_INTERNAL__MAC_NA_DEP__MAC_NA               __AVAILABILITY_INTERNAL_UNAVAILABLE
        #define __AVAILABILITY_INTERNAL__MAC_NA_DEP__MAC_NA_MSG(_msg)     __AVAILABILITY_INTERNAL_UNAVAILABLE
    #endif
# 45202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#endif
# 45203 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

/*
 Macros for defining which versions/platform a given symbol can be used.
 
 @see http://clang.llvm.org/docs/AttributeReference.html#availability
 */

#if 0 /* disabled by -frewrite-includes */
#if defined(__has_feature) && defined(__has_attribute)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 45211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
 
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(availability)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 45212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

    
    #define __API_AVAILABLE_PLATFORM_macos(x) macos,introduced=x
    #define __API_AVAILABLE_PLATFORM_macosx(x) macosx,introduced=x
    #define __API_AVAILABLE_PLATFORM_ios(x) ios,introduced=x
    #define __API_AVAILABLE_PLATFORM_watchos(x) watchos,introduced=x
    #define __API_AVAILABLE_PLATFORM_tvos(x) tvos,introduced=x
    

    #define __API_A(x) __attribute__((availability(__API_AVAILABLE_PLATFORM_##x)))
    #define __API_AVAILABLE1(x) __API_A(x)
    #define __API_AVAILABLE2(x,y) __API_A(x) __API_A(y)
    #define __API_AVAILABLE3(x,y,z)  __API_A(x) __API_A(y) __API_A(z)
    #define __API_AVAILABLE4(x,y,z,t) __API_A(x) __API_A(y) __API_A(z) __API_A(t)
    #define __API_AVAILABLE5(x,y,z,t,b) __API_A(x) __API_A(y) __API_A(z) __API_A(t) __API_A(b)
    #define __API_AVAILABLE6(x,y,z,t,b,m) __API_A(x) __API_A(y) __API_A(z) __API_A(t) __API_A(b) __API_A(m)
    #define __API_AVAILABLE_GET_MACRO(_1,_2,_3,_4,_5,_6,NAME,...) NAME

    
    #define __API_DEPRECATED_PLATFORM_macos(x,y) macos,introduced=x,deprecated=y
    #define __API_DEPRECATED_PLATFORM_macosx(x,y) macosx,introduced=x,deprecated=y
    #define __API_DEPRECATED_PLATFORM_ios(x,y) ios,introduced=x,deprecated=y
    #define __API_DEPRECATED_PLATFORM_watchos(x,y) watchos,introduced=x,deprecated=y
    #define __API_DEPRECATED_PLATFORM_tvos(x,y) tvos,introduced=x,deprecated=y
    

    #define __API_D(msg,x) __attribute__((availability(__API_DEPRECATED_PLATFORM_##x,message=msg)))
    #define __API_DEPRECATED_MSG2(msg,x) __API_D(msg,x)
    #define __API_DEPRECATED_MSG3(msg,x,y) __API_D(msg,x) __API_D(msg,y)
    #define __API_DEPRECATED_MSG4(msg,x,y,z) __API_DEPRECATED_MSG3(msg,x,y) __API_D(msg,z)
    #define __API_DEPRECATED_MSG5(msg,x,y,z,t) __API_DEPRECATED_MSG4(msg,x,y,z) __API_D(msg,t)
    #define __API_DEPRECATED_MSG6(msg,x,y,z,t,b) __API_DEPRECATED_MSG5(msg,x,y,z,t) __API_D(msg,b)
    #define __API_DEPRECATED_MSG7(msg,x,y,z,t,b,m) __API_DEPRECATED_MSG6(msg,x,y,z,t,b) __API_D(msg,m)
    #define __API_DEPRECATED_MSG_GET_MACRO(_1,_2,_3,_4,_5,_6,_7,NAME,...) NAME

    
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_replacement)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 45248 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __API_R(rep,x) __attribute__((availability(__API_DEPRECATED_PLATFORM_##x,replacement=rep)))
    #else
# 45250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
        #define __API_R(rep,x) __attribute__((availability(__API_DEPRECATED_PLATFORM_##x)))
    #endif
# 45252 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

    #define __API_DEPRECATED_REP2(rep,x) __API_R(rep,x)
    #define __API_DEPRECATED_REP3(rep,x,y) __API_R(rep,x) __API_R(rep,y)
    #define __API_DEPRECATED_REP4(rep,x,y,z)  __API_DEPRECATED_REP3(rep,x,y) __API_R(rep,z)
    #define __API_DEPRECATED_REP5(rep,x,y,z,t) __API_DEPRECATED_REP4(rep,x,y,z) __API_R(rep,t)
    #define __API_DEPRECATED_REP6(rep,x,y,z,t,b) __API_DEPRECATED_REP5(rep,x,y,z,t) __API_R(rep,b)
    #define __API_DEPRECATED_REP7(rep,x,y,z,t,b,m) __API_DEPRECATED_REP6(rep,x,y,z,t,b) __API_R(rep,m)
    #define __API_DEPRECATED_REP_GET_MACRO(_1,_2,_3,_4,_5,_6,_7,NAME,...) NAME

    /*
     * API Unavailability
     * Use to specify that an API is unavailable for a particular platform.
     *
     * Example:
     *    __API_UNAVAILABLE(macos)
     *    __API_UNAVAILABLE(watchos, tvos)
     */
    #define __API_UNAVAILABLE_PLATFORM_macos macos,unavailable
    #define __API_UNAVAILABLE_PLATFORM_macosx macosx,unavailable
    #define __API_UNAVAILABLE_PLATFORM_ios ios,unavailable
    #define __API_UNAVAILABLE_PLATFORM_watchos watchos,unavailable
    #define __API_UNAVAILABLE_PLATFORM_tvos tvos,unavailable
    

    #define __API_U(x) __attribute__((availability(__API_UNAVAILABLE_PLATFORM_##x)))
    #define __API_UNAVAILABLE1(x) __API_U(x)
    #define __API_UNAVAILABLE2(x,y) __API_U(x) __API_U(y)
    #define __API_UNAVAILABLE3(x,y,z) __API_UNAVAILABLE2(x,y) __API_U(z)
    #define __API_UNAVAILABLE4(x,y,z,t) __API_UNAVAILABLE3(x,y,z) __API_U(t)
    #define __API_UNAVAILABLE5(x,y,z,t,b) __API_UNAVAILABLE4(x,y,z,t) __API_U(b)
    #define __API_UNAVAILABLE6(x,y,z,t,b,m) __API_UNAVAILABLE5(x,y,z,t,b) __API_U(m)
    #define __API_UNAVAILABLE_GET_MACRO(_1,_2,_3,_4,_5,_6,NAME,...) NAME
 #else 
# 45285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

 /* 
  * Evaluate to nothing for compilers that don't support availability.
  */
    
  #define __API_AVAILABLE_GET_MACRO(...)
  #define __API_DEPRECATED_MSG_GET_MACRO(...)
  #define __API_DEPRECATED_REP_GET_MACRO(...)
  #define __API_UNAVAILABLE_GET_MACRO(...)
 #endif /* __has_attribute(availability) */
# 45295 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
#else
# 45296 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

    /* 
     * Evaluate to nothing for compilers that don't support clang language extensions.
     */
    
    #define __API_AVAILABLE(...)
    #define __API_DEPRECATED(...)
    #define __API_DEPRECATED_WITH_REPLACEMENT(...)
    #define __API_UNAVAILABLE(...)
#endif /* #if defined(__has_feature) && defined(__has_attribute) */
# 45306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

/*
 * Swift compiler version
 * Allows for project-agnostic “epochs” for frameworks imported into Swift via the Clang importer, like #if _compiler_version for Swift
 * Example:
 *
 *  #if __swift_compiler_version_at_least(800, 2, 20)
 *  - (nonnull NSString *)description;
 *  #else
 *  - (NSString *)description;
 *  #endif
 */
 
#ifdef __SWIFT_COMPILER_VERSION
    #define __swift_compiler_version_at_least_impl(X, Y, Z, a, b, ...) \
    __SWIFT_COMPILER_VERSION >= ((X * UINT64_C(1000) * 1000 * 1000) + (Z * 1000 * 1000) + (a * 1000) + b)
    #define __swift_compiler_version_at_least(...) __swift_compiler_version_at_least_impl(__VA_ARGS__, 0, 0, 0, 0)
#else
# 45324 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
    #define __swift_compiler_version_at_least(...) 1
#endif
# 45326 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

/*
 * If __SPI_AVAILABLE has not been defined elsewhere, disable it.
 */
 
#ifndef __SPI_AVAILABLE
  #define __SPI_AVAILABLE(...)
#endif
# 45334 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4

#endif /* __AVAILABILITY_INTERNAL__ */
# 45336 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/AvailabilityInternal.h" 3 4
# 237 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 2 3 4

#ifdef __IPHONE_OS_VERSION_MIN_REQUIRED
    #define __OSX_AVAILABLE_STARTING(_osx, _ios) __AVAILABILITY_INTERNAL##_ios
    #define __OSX_AVAILABLE_BUT_DEPRECATED(_osxIntro, _osxDep, _iosIntro, _iosDep) \
                                                    __AVAILABILITY_INTERNAL##_iosIntro##_DEP##_iosDep
    #define __OSX_AVAILABLE_BUT_DEPRECATED_MSG(_osxIntro, _osxDep, _iosIntro, _iosDep, _msg) \
                                                    __AVAILABILITY_INTERNAL##_iosIntro##_DEP##_iosDep##_MSG(_msg)

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__MAC_OS_X_VERSION_MIN_REQUIRED)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 246 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OSX_AVAILABLE_STARTING(_osx, _ios) __AVAILABILITY_INTERNAL##_osx
    #define __OSX_AVAILABLE_BUT_DEPRECATED(_osxIntro, _osxDep, _iosIntro, _iosDep) \
                                                    __AVAILABILITY_INTERNAL##_osxIntro##_DEP##_osxDep
    #define __OSX_AVAILABLE_BUT_DEPRECATED_MSG(_osxIntro, _osxDep, _iosIntro, _iosDep, _msg) \
                                                    __AVAILABILITY_INTERNAL##_osxIntro##_DEP##_osxDep##_MSG(_msg)

#else
# 253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OSX_AVAILABLE_STARTING(_osx, _ios)
    #define __OSX_AVAILABLE_BUT_DEPRECATED(_osxIntro, _osxDep, _iosIntro, _iosDep)
    #define __OSX_AVAILABLE_BUT_DEPRECATED_MSG(_osxIntro, _osxDep, _iosIntro, _iosDep, _msg)
#endif
# 257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4


#if 0 /* disabled by -frewrite-includes */
#if defined(__has_feature)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
  
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 261 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OS_AVAILABILITY(_target, _availability)            __attribute__((availability(_target,_availability)))
    #define __OS_AVAILABILITY_MSG(_target, _availability, _msg)  __attribute__((availability(_target,_availability,message=_msg)))
  
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __has_feature(attribute_availability)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 264 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OS_AVAILABILITY(_target, _availability)            __attribute__((availability(_target,_availability)))
    #define __OS_AVAILABILITY_MSG(_target, _availability, _msg)  __attribute__((availability(_target,_availability)))
  #else
# 267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OS_AVAILABILITY(_target, _availability)
    #define __OS_AVAILABILITY_MSG(_target, _availability, _msg)
  #endif
# 270 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#else
# 271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OS_AVAILABILITY(_target, _availability)
    #define __OS_AVAILABILITY_MSG(_target, _availability, _msg)
#endif
# 274 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4


/* for use to document app extension usage */
#if 0 /* disabled by -frewrite-includes */
#if defined(__has_feature)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 278 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
  
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_app_extension)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OSX_EXTENSION_UNAVAILABLE(_msg)  __OS_AVAILABILITY_MSG(macosx_app_extension,unavailable,_msg)
    #define __IOS_EXTENSION_UNAVAILABLE(_msg)  __OS_AVAILABILITY_MSG(ios_app_extension,unavailable,_msg)
  #else
# 282 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OSX_EXTENSION_UNAVAILABLE(_msg)
    #define __IOS_EXTENSION_UNAVAILABLE(_msg)
  #endif
# 285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#else
# 286 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OSX_EXTENSION_UNAVAILABLE(_msg)
    #define __IOS_EXTENSION_UNAVAILABLE(_msg)
#endif
# 289 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#define __OS_EXTENSION_UNAVAILABLE(_msg)  __OSX_EXTENSION_UNAVAILABLE(_msg) __IOS_EXTENSION_UNAVAILABLE(_msg)



/* for use marking APIs available info for Mac OSX */
#if 0 /* disabled by -frewrite-includes */
#if defined(__has_attribute)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 296 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
  
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(availability)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 297 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __OSX_UNAVAILABLE                    __OS_AVAILABILITY(macosx,unavailable)
    #define __OSX_AVAILABLE(_vers)               __OS_AVAILABILITY(macosx,introduced=_vers)
    #define __OSX_DEPRECATED(_start, _dep, _msg) __OSX_AVAILABLE(_start) __OS_AVAILABILITY_MSG(macosx,deprecated=_dep,_msg)
  #endif
# 301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#endif
# 302 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __OSX_UNAVAILABLE
  #define __OSX_UNAVAILABLE
#endif
# 306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __OSX_AVAILABLE
  #define __OSX_AVAILABLE(_vers)
#endif
# 310 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __OSX_DEPRECATED
  #define __OSX_DEPRECATED(_start, _dep, _msg)
#endif
# 314 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4


/* for use marking APIs available info for iOS */
#if 0 /* disabled by -frewrite-includes */
#if defined(__has_attribute)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 318 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
  
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(availability)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 319 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __IOS_UNAVAILABLE                    __OS_AVAILABILITY(ios,unavailable)
    #define __IOS_PROHIBITED                     __OS_AVAILABILITY(ios,unavailable)
    #define __IOS_AVAILABLE(_vers)               __OS_AVAILABILITY(ios,introduced=_vers)
    #define __IOS_DEPRECATED(_start, _dep, _msg) __IOS_AVAILABLE(_start) __OS_AVAILABILITY_MSG(ios,deprecated=_dep,_msg)
  #endif
# 324 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#endif
# 325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __IOS_UNAVAILABLE
  #define __IOS_UNAVAILABLE
#endif
# 329 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __IOS_PROHIBITED
  #define __IOS_PROHIBITED
#endif
# 333 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __IOS_AVAILABLE
  #define __IOS_AVAILABLE(_vers)
#endif
# 337 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __IOS_DEPRECATED
  #define __IOS_DEPRECATED(_start, _dep, _msg)
#endif
# 341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4


/* for use marking APIs available info for tvOS */
#if 0 /* disabled by -frewrite-includes */
#if defined(__has_feature)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
  
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_tvos)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 346 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __TVOS_UNAVAILABLE                    __OS_AVAILABILITY(tvos,unavailable)
    #define __TVOS_PROHIBITED                     __OS_AVAILABILITY(tvos,unavailable)
    #define __TVOS_AVAILABLE(_vers)               __OS_AVAILABILITY(tvos,introduced=_vers)
    #define __TVOS_DEPRECATED(_start, _dep, _msg) __TVOS_AVAILABLE(_start) __OS_AVAILABILITY_MSG(tvos,deprecated=_dep,_msg)
  #endif
# 351 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#endif
# 352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __TVOS_UNAVAILABLE
  #define __TVOS_UNAVAILABLE
#endif
# 356 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __TVOS_PROHIBITED
  #define __TVOS_PROHIBITED
#endif
# 360 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __TVOS_AVAILABLE
  #define __TVOS_AVAILABLE(_vers)
#endif
# 364 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __TVOS_DEPRECATED
  #define __TVOS_DEPRECATED(_start, _dep, _msg)
#endif
# 368 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4


/* for use marking APIs available info for Watch OS */
#if 0 /* disabled by -frewrite-includes */
#if defined(__has_feature)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 372 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
  
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_watchos)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 373 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __WATCHOS_UNAVAILABLE                    __OS_AVAILABILITY(watchos,unavailable)
    #define __WATCHOS_PROHIBITED                     __OS_AVAILABILITY(watchos,unavailable)
    #define __WATCHOS_AVAILABLE(_vers)               __OS_AVAILABILITY(watchos,introduced=_vers)
    #define __WATCHOS_DEPRECATED(_start, _dep, _msg) __WATCHOS_AVAILABLE(_start) __OS_AVAILABILITY_MSG(watchos,deprecated=_dep,_msg)
  #endif
# 378 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#endif
# 379 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __WATCHOS_UNAVAILABLE
  #define __WATCHOS_UNAVAILABLE
#endif
# 383 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __WATCHOS_PROHIBITED
  #define __WATCHOS_PROHIBITED
#endif
# 387 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __WATCHOS_AVAILABLE
  #define __WATCHOS_AVAILABLE(_vers)
#endif
# 391 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __WATCHOS_DEPRECATED
  #define __WATCHOS_DEPRECATED(_start, _dep, _msg)
#endif
# 395 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4


/* for use marking APIs unavailable for swift */
#if 0 /* disabled by -frewrite-includes */
#if defined(__has_feature)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 399 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
  
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_swift)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 400 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
    #define __SWIFT_UNAVAILABLE                   __OS_AVAILABILITY(swift,unavailable)
    #define __SWIFT_UNAVAILABLE_MSG(_msg)         __OS_AVAILABILITY_MSG(swift,unavailable,_msg)
  #endif
# 403 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#endif
# 404 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __SWIFT_UNAVAILABLE
  #define __SWIFT_UNAVAILABLE
#endif
# 408 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#ifndef __SWIFT_UNAVAILABLE_MSG
  #define __SWIFT_UNAVAILABLE_MSG(_msg)
#endif
# 412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

/*
 Macros for defining which versions/platform a given symbol can be used.
 
 @see http://clang.llvm.org/docs/AttributeReference.html#availability
 
 * Note that these macros are only compatible with clang compilers that
 * support the following target selection options:
 *
 * -mmacosx-version-min
 * -miphoneos-version-min
 * -mwatchos-version-min
 * -mtvos-version-min
 */

#if 0 /* disabled by -frewrite-includes */
#if defined(__has_feature) && defined(__has_attribute)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 428 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
 
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(availability)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 429 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

    /*
     * API Introductions
     *
     * Use to specify the release that a particular API became available.
     *
     * Platform names:
     *   macos, ios, tvos, watchos
     *
     * Examples:
     *    __API_AVAILABLE(macos(10.10))
     *    __API_AVAILABLE(macos(10.9), ios(10.0))
     *    __API_AVAILABLE(macos(10.4), ios(8.0), watchos(2.0), tvos(10.0))
     */
    #define __API_AVAILABLE(...) __API_AVAILABLE_GET_MACRO(__VA_ARGS__,__API_AVAILABLE6, __API_AVAILABLE5, __API_AVAILABLE4, __API_AVAILABLE3, __API_AVAILABLE2, __API_AVAILABLE1, 0)(__VA_ARGS__)


    /*
     * API Deprecations
     *
     * Use to specify the release that a particular API became unavailable.
     *
     * Platform names:
     *   macos, ios, tvos, watchos
     *
     * Examples:
     *
     *    __API_DEPRECATED("No longer supported", macos(10.4, 10.8))
     *    __API_DEPRECATED("No longer supported", macos(10.4, 10.8), ios(2.0, 3.0), watchos(2.0, 3.0), tvos(9.0, 10.0))
     *
     *    __API_DEPRECATED_WITH_REPLACEMENT("-setName:", tvos(10.0, 10.4), ios(9.0, 10.0))
     *    __API_DEPRECATED_WITH_REPLACEMENT("SomeClassName", macos(10.4, 10.6), watchos(2.0, 3.0))
     */
    #define __API_DEPRECATED(...) __API_DEPRECATED_MSG_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_MSG7,__API_DEPRECATED_MSG6,__API_DEPRECATED_MSG5,__API_DEPRECATED_MSG4,__API_DEPRECATED_MSG3,__API_DEPRECATED_MSG2,__API_DEPRECATED_MSG1, 0)(__VA_ARGS__)
    #define __API_DEPRECATED_WITH_REPLACEMENT(...) __API_DEPRECATED_REP_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_REP7,__API_DEPRECATED_REP6,__API_DEPRECATED_REP5,__API_DEPRECATED_REP4,__API_DEPRECATED_REP3,__API_DEPRECATED_REP2,__API_DEPRECATED_REP1, 0)(__VA_ARGS__)

    /*
     * API Unavailability
     * Use to specify that an API is unavailable for a particular platform.
     *
     * Example:
     *    __API_UNAVAILABLE(macos)
     *    __API_UNAVAILABLE(watchos, tvos)
     */
    #define __API_UNAVAILABLE(...) __API_UNAVAILABLE_GET_MACRO(__VA_ARGS__,__API_UNAVAILABLE6,__API_UNAVAILABLE5,__API_UNAVAILABLE4,__API_UNAVAILABLE3,__API_UNAVAILABLE2,__API_UNAVAILABLE1, 0)(__VA_ARGS__)
 #else 
# 475 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

    /* 
     * Evaluate to nothing for compilers that don't support availability.
     */
    
    #define __API_AVAILABLE(...)
    #define __API_DEPRECATED(...)
    #define __API_DEPRECATED_WITH_REPLACEMENT(...)
    #define __API_UNAVAILABLE(...)
 #endif /* __has_attribute(availability) */
# 485 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#else
# 486 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

    /* 
     * Evaluate to nothing for compilers that don't support clang language extensions.
     */
    
    #define __API_AVAILABLE(...)
    #define __API_DEPRECATED(...)
    #define __API_DEPRECATED_WITH_REPLACEMENT(...)
    #define __API_UNAVAILABLE(...)
#endif /*  #if defined(__has_feature) && defined(__has_attribute) */
# 496 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __has_include(<AvailabilityProhibitedInternal.h>)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 498 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
  #if 0 /* expanded by -frewrite-includes */
#include <AvailabilityProhibitedInternal.h>
#endif /* expanded by -frewrite-includes */
# 498 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
# 499 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4
#endif
# 500 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

#endif /* __AVAILABILITY__ */
# 502 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/Availability.h" 3 4

# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 1 3 4
/*
 * Copyright (c) 2000-2018 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/* Copyright 1995 NeXT Computer, Inc. All rights reserved. */
/*
 * Copyright (c) 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Berkeley Software Design, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)cdefs.h	8.8 (Berkeley) 1/9/95
 */

#ifndef _CDEFS_H_
#define _CDEFS_H_

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __BEGIN_DECLS   extern "C" {
#define __END_DECLS     }
#else
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __BEGIN_DECLS
#define __END_DECLS
#endif
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* This SDK is designed to work with clang and specific versions of
 * gcc >= 4.0 with Apple's patch sets */
#if 0 /* disabled by -frewrite-includes */
#if !defined(__GNUC__) || __GNUC__ < 4
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#warning "Unsupported compiler detected"
#endif
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * Compatibility with compilers and environments that don't support compiler
 * feature checking function-like macros.
 */
#ifndef __has_builtin
#define __has_builtin(x) 0
#endif
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef __has_include
#define __has_include(x) 0
#endif
# 94 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef __has_feature
#define __has_feature(x) 0
#endif
# 97 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef __has_attribute
#define __has_attribute(x) 0
#endif
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef __has_extension
#define __has_extension(x) 0
#endif
# 103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * The __CONCAT macro is used to concatenate parts of symbol names, e.g.
 * with "#define OLD(foo) __CONCAT(old,foo)", OLD(foo) produces oldfoo.
 * The __CONCAT macro is a bit tricky -- make sure you don't put spaces
 * in between its arguments.  __CONCAT can also concatenate double-quoted
 * strings produced by the __STRING macro, but this only works with ANSI C.
 */
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC__) || defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __P(protos)     protos          /* full-blown ANSI C */
#define __CONCAT(x, y)   x ## y
#define __STRING(x)     #x

#define __const         const           /* define reserved names to standard */
#define __signed        signed
#define __volatile      volatile
#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __inline        inline          /* convert to C++ keyword */
#else
# 122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef __GNUC__
#define __inline                        /* delete GCC keyword */
#endif /* !__GNUC__ */
# 125 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif /* !__cplusplus */
# 126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#else   /* !(__STDC__ || __cplusplus) */
# 128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __P(protos)     ()              /* traditional C preprocessor */
#define __CONCAT(x, y)   x /**/ y
#define __STRING(x)     "x"

#ifndef __GNUC__
#define __const                         /* delete pseudo-ANSI C keywords */
#define __inline
#define __signed
#define __volatile
#endif  /* !__GNUC__ */
# 138 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * In non-ANSI C environments, new programs will want ANSI-only C keywords
 * deleted from the program and old programs will want them left alone.
 * When using a compiler other than gcc, programs using the ANSI C keywords
 * const, inline etc. as normal identifiers should define -DNO_ANSI_KEYWORDS.
 * When using "gcc -traditional", we assume that this is the intent; if
 * __GNUC__ is defined but __STDC__ is not, we leave the new keywords alone.
 */
#ifndef NO_ANSI_KEYWORDS
#define const           __const                 /* convert ANSI C keywords */
#define inline          __inline
#define signed          __signed
#define volatile        __volatile
#endif /* !NO_ANSI_KEYWORDS */
# 153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif /* !(__STDC__ || __cplusplus) */
# 154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#define __dead2         __attribute__((noreturn))
#define __pure2         __attribute__((const))

/* __unused denotes variables and functions that may not be used, preventing
 * the compiler from warning about it if not used.
 */
#define __unused        __attribute__((unused))

/* __used forces variables and functions to be included even if it appears
 * to the compiler that they are not used (and would thust be discarded).
 */
#define __used          __attribute__((used))

/* __deprecated causes the compiler to produce a warning when encountering
 * code using the deprecated functionality.
 * __deprecated_msg() does the same, and compilers that support it will print
 * a message along with the deprecation warning.
 * This may require turning on such warning with the -Wdeprecated flag.
 * __deprecated_enum_msg() should be used on enums, and compilers that support
 * it will print the deprecation warning.
 */
#define __deprecated    __attribute__((deprecated))

#if 0 /* disabled by -frewrite-includes */
#if __has_extension(attribute_deprecated_with_message) || \
        (defined(__GNUC__) && ((__GNUC__ >= 5) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 5))))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
	#define __deprecated_msg(_msg) __attribute__((deprecated(_msg)))
#else
# 182 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
	#define __deprecated_msg(_msg) __attribute__((deprecated))
#endif
# 184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __has_extension(enumerator_attributes)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
	#define __deprecated_enum_msg(_msg) __deprecated_msg(_msg)
#else
# 188 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
	#define __deprecated_enum_msg(_msg)
#endif
# 190 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* __unavailable causes the compiler to error out when encountering
 * code using the tagged function of variable.
 */
#define __unavailable   __attribute__((unavailable))

/* Delete pseudo-keywords wherever they are not available or needed. */
#ifndef __dead
#define __dead
#define __pure
#endif
# 201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * We use `__restrict' as a way to define the `restrict' type qualifier
 * without disturbing older software that is unaware of C99 keywords.
 */
#if 0 /* disabled by -frewrite-includes */
#if __STDC_VERSION__ < 199901
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __restrict
#else
# 209 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __restrict      restrict
#endif
# 211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* Compatibility with compilers and environments that don't support the
 * nullability feature.
 */

#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(nullability)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 217 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef __nullable
#define __nullable
#endif
# 220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef __nonnull
#define __nonnull
#endif
# 223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef __null_unspecified
#define __null_unspecified
#endif
# 226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef _Nullable
#define _Nullable
#endif
# 229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef _Nonnull
#define _Nonnull
#endif
# 232 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#ifndef _Null_unspecified
#define _Null_unspecified
#endif
# 235 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif
# 236 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * __disable_tail_calls causes the compiler to not perform tail call
 * optimization inside the marked function.
 */
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(disable_tail_calls)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 242 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __disable_tail_calls    __attribute__((__disable_tail_calls__))
#else
# 244 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __disable_tail_calls
#endif
# 246 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * __not_tail_called causes the compiler to prevent tail call optimization
 * on statically bound calls to the function.  It has no effect on indirect
 * calls.  Virtual functions, objective-c methods, and functions marked as
 * "always_inline" cannot be marked as __not_tail_called.
 */
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(not_tail_called)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 254 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __not_tail_called       __attribute__((__not_tail_called__))
#else
# 256 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __not_tail_called
#endif
# 258 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * __result_use_check warns callers of a function that not using the function
 * return value is a bug, i.e. dismissing malloc() return value results in a
 * memory leak.
 */
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(warn_unused_result)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 265 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __result_use_check __attribute__((__warn_unused_result__))
#else
# 267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __result_use_check
#endif
# 269 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * __swift_unavailable causes the compiler to mark a symbol as specifically
 * unavailable in Swift, regardless of any other availability in C.
 */
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_availability_swift)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __swift_unavailable(_msg)       __attribute__((__availability__(swift, unavailable, message=_msg)))
#else
# 277 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __swift_unavailable(_msg)
#endif
# 279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* Declaring inline functions within headers is error-prone due to differences
 * across various versions of the C language and extensions.  __header_inline
 * can be used to declare inline functions within system headers.  In cases
 * where you want to force inlining instead of letting the compiler make
 * the decision, you can use __header_always_inline.
 *
 * Be aware that using inline for functions which compilers may also provide
 * builtins can behave differently under various compilers.  If you intend to
 * provide an inline version of such a function, you may want to use a macro
 * instead.
 *
 * The check for !__GNUC__ || __clang__ is because gcc doesn't correctly
 * support c99 inline in some cases:
 * http://gcc.gnu.org/bugzilla/show_bug.cgi?id=55965
 */

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) || \
        (__STDC_VERSION__ >= 199901L && \
        !defined(__GNUC_GNU_INLINE__) && \
        (!defined(__GNUC__) || defined(__clang__)))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 300 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# define __header_inline           inline
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__) && defined(__GNUC_STDC_INLINE__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 302 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# define __header_inline           extern __inline __attribute__((__gnu_inline__))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 304 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# define __header_inline           extern __inline
#else
# 306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
/* If we land here, we've encountered an unsupported compiler,
 * so hopefully it understands static __inline as a fallback.
 */
# define __header_inline           static __inline
#endif
# 311 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#ifdef __GNUC__
# define __header_always_inline    __header_inline __attribute__ ((__always_inline__))
#else
# 315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
/* Unfortunately, we're using a compiler that we don't know how to force to
 * inline.  Oh well.
 */
# define __header_always_inline    __header_inline
#endif
# 320 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * Compiler-dependent macros that bracket portions of code where the
 * "-Wunreachable-code" warning should be ignored. Please use sparingly.
 */
#if 0 /* disabled by -frewrite-includes */
#if defined(__clang__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 326 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# define __unreachable_ok_push \
	 _Pragma("clang diagnostic push") \
	 _Pragma("clang diagnostic ignored \"-Wunreachable-code\"")
# define __unreachable_ok_pop \
	 _Pragma("clang diagnostic pop")
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__) && ((__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 332 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# define __unreachable_ok_push \
	 _Pragma("GCC diagnostic push") \
	 _Pragma("GCC diagnostic ignored \"-Wunreachable-code\"")
# define __unreachable_ok_pop \
	 _Pragma("GCC diagnostic pop")
#else
# 338 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# define __unreachable_ok_push
# define __unreachable_ok_pop
#endif
# 341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * Compiler-dependent macros to declare that functions take printf-like
 * or scanf-like arguments.  They are null except for versions of gcc
 * that are known to support the features properly.  Functions declared
 * with these attributes will cause compilation warnings if there is a
 * mismatch between the format string and subsequent function parameter
 * types.
 */
#define __printflike(fmtarg, firstvararg) \
	        __attribute__((__format__ (__printf__, fmtarg, firstvararg)))
#define __printf0like(fmtarg, firstvararg) \
	        __attribute__((__format__ (__printf0__, fmtarg, firstvararg)))
#define __scanflike(fmtarg, firstvararg) \
	        __attribute__((__format__ (__scanf__, fmtarg, firstvararg)))

#define __IDSTRING(name, string) static const char name[] __used = string

#ifndef __COPYRIGHT
#define __COPYRIGHT(s) __IDSTRING(copyright,s)
#endif
# 362 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#ifndef __RCSID
#define __RCSID(s) __IDSTRING(rcsid,s)
#endif
# 366 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#ifndef __SCCSID
#define __SCCSID(s) __IDSTRING(sccsid,s)
#endif
# 370 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#ifndef __PROJECT_VERSION
#define __PROJECT_VERSION(s) __IDSTRING(project_version,s)
#endif
# 374 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* Source compatibility only, ID string not emitted in object file */
#ifndef __FBSDID
#define __FBSDID(s)
#endif
# 379 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#ifndef __DECONST
#define __DECONST(type, var)    __CAST_AWAY_QUALIFIER(var, const, type)
#endif
# 383 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#ifndef __DEVOLATILE
#define __DEVOLATILE(type, var) __CAST_AWAY_QUALIFIER(var, volatile, type)
#endif
# 387 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#ifndef __DEQUALIFY
#define __DEQUALIFY(type, var)  __CAST_AWAY_QUALIFIER(var, const volatile, type)
#endif
# 391 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * __alloc_size can be used to label function arguments that represent the
 * size of memory that the function allocates and returns. The one-argument
 * form labels a single argument that gives the allocation size (where the
 * arguments are numbered from 1):
 *
 * void	*malloc(size_t __size) __alloc_size(1);
 *
 * The two-argument form handles the case where the size is calculated as the
 * product of two arguments:
 *
 * void	*calloc(size_t __count, size_t __size) __alloc_size(1,2);
 */
#ifndef __alloc_size
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(alloc_size)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 407 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __alloc_size(...) __attribute__((alloc_size(__VA_ARGS__)))
#else
# 409 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __alloc_size(...)
#endif
# 411 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif // __alloc_size
# 412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * COMPILATION ENVIRONMENTS -- see compat(5) for additional detail
 *
 * DEFAULT	By default newly complied code will get POSIX APIs plus
 *		Apple API extensions in scope.
 *
 *		Most users will use this compilation environment to avoid
 *		behavioral differences between 32 and 64 bit code.
 *
 * LEGACY	Defining _NONSTD_SOURCE will get pre-POSIX APIs plus Apple
 *		API extensions in scope.
 *
 *		This is generally equivalent to the Tiger release compilation
 *		environment, except that it cannot be applied to 64 bit code;
 *		its use is discouraged.
 *
 *		We expect this environment to be deprecated in the future.
 *
 * STRICT	Defining _POSIX_C_SOURCE or _XOPEN_SOURCE restricts the
 *		available APIs to exactly the set of APIs defined by the
 *		corresponding standard, based on the value defined.
 *
 *		A correct, portable definition for _POSIX_C_SOURCE is 200112L.
 *		A correct, portable definition for _XOPEN_SOURCE is 600L.
 *
 *		Apple API extensions are not visible in this environment,
 *		which can cause Apple specific code to fail to compile,
 *		or behave incorrectly if prototypes are not in scope or
 *		warnings about missing prototypes are not enabled or ignored.
 *
 * In any compilation environment, for correct symbol resolution to occur,
 * function prototypes must be in scope.  It is recommended that all Apple
 * tools users add either the "-Wall" or "-Wimplicit-function-declaration"
 * compiler flags to their projects to be warned when a function is being
 * used without a prototype in scope.
 */

/* These settings are particular to each product. */
/* Platform: MacOSX */
#define __DARWIN_ONLY_64_BIT_INO_T      0
/* #undef __DARWIN_ONLY_UNIX_CONFORMANCE (automatically set for 64-bit) */
#define __DARWIN_ONLY_VERS_1050         0

/*
 * The __DARWIN_ALIAS macros are used to do symbol renaming; they allow
 * legacy code to use the old symbol, thus maintaining binary compatibility
 * while new code can use a standards compliant version of the same function.
 *
 * __DARWIN_ALIAS is used by itself if the function signature has not
 * changed, it is used along with a #ifdef check for __DARWIN_UNIX03
 * if the signature has changed.  Because the __LP64__ environment
 * only supports UNIX03 semantics it causes __DARWIN_UNIX03 to be
 * defined, but causes __DARWIN_ALIAS to do no symbol mangling.
 *
 * As a special case, when XCode is used to target a specific version of the
 * OS, the manifest constant __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__
 * will be defined by the compiler, with the digits representing major version
 * time 100 + minor version times 10 (e.g. 10.5 := 1050).  If we are targeting
 * pre-10.5, and it is the default compilation environment, revert the
 * compilation environment to pre-__DARWIN_UNIX03.
 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(__DARWIN_ONLY_UNIX_CONFORMANCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 475 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#  if defined(__LP64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 476 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_ONLY_UNIX_CONFORMANCE 1
#  else /* !__LP64__ */
# 478 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_ONLY_UNIX_CONFORMANCE 0
#  endif /* __LP64__ */
# 480 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif /* !__DARWIN_ONLY_UNIX_CONFORMANCE */
# 481 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(__DARWIN_UNIX03)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 483 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#  if   __DARWIN_ONLY_UNIX_CONFORMANCE
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 484 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#    if defined(_NONSTD_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 485 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      error "Can't define _NONSTD_SOURCE when only UNIX conformance is available."
#    endif /* _NONSTD_SOURCE */
# 487 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_UNIX03     1
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ - 0) < 1040)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 489 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_UNIX03     0
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(_DARWIN_C_SOURCE) || defined(_XOPEN_SOURCE) || defined(_POSIX_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 491 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#    if defined(_NONSTD_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 492 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      error "Can't define both _NONSTD_SOURCE and any of _DARWIN_C_SOURCE, _XOPEN_SOURCE or _POSIX_C_SOURCE."
#    endif /* _NONSTD_SOURCE */
# 494 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_UNIX03     1
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(_NONSTD_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 496 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_UNIX03     0
#  else /* default */
# 498 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#    if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ - 0) < 1050)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 499 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_UNIX03   0
#    else /* __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1050 */
# 501 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_UNIX03   1
#    endif /* __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1050 */
# 503 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#  endif /* _DARWIN_C_SOURCE || _XOPEN_SOURCE || _POSIX_C_SOURCE || __LP64__ */
# 504 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif /* !__DARWIN_UNIX03 */
# 505 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(__DARWIN_64_BIT_INO_T)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 507 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#  if   defined(_DARWIN_USE_64_BIT_INODE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 508 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#    if defined(_DARWIN_NO_64_BIT_INODE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 509 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      error "Can't define both _DARWIN_USE_64_BIT_INODE and _DARWIN_NO_64_BIT_INODE."
#    endif /* _DARWIN_NO_64_BIT_INODE */
# 511 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_64_BIT_INO_T 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(_DARWIN_NO_64_BIT_INODE)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 513 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#    if __DARWIN_ONLY_64_BIT_INO_T
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 514 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      error "Can't define _DARWIN_NO_64_BIT_INODE when only 64-bit inodes are available."
#    endif /* __DARWIN_ONLY_64_BIT_INO_T */
# 516 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_64_BIT_INO_T 0
#  else /* default */
# 518 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#    if __DARWIN_ONLY_64_BIT_INO_T
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 519 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_64_BIT_INO_T 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#    elif defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ - 0) < 1060) || __DARWIN_UNIX03 == 0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 521 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_64_BIT_INO_T 0
#    else /* default */
# 523 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_64_BIT_INO_T 1
#    endif /* __DARWIN_ONLY_64_BIT_INO_T */
# 525 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#  endif
# 526 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif /* !__DARWIN_64_BIT_INO_T */
# 527 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(__DARWIN_VERS_1050)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 529 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#  if   __DARWIN_ONLY_VERS_1050
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 530 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_VERS_1050 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#  elif defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ - 0) < 1050) || __DARWIN_UNIX03 == 0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 532 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_VERS_1050 0
#  else /* default */
# 534 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_VERS_1050 1
#  endif
# 536 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif /* !__DARWIN_VERS_1050 */
# 537 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(__DARWIN_NON_CANCELABLE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 539 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_NON_CANCELABLE 0
#endif /* !__DARWIN_NON_CANCELABLE */
# 541 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * symbol suffixes used for symbol versioning
 */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 546 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#  if __DARWIN_ONLY_UNIX_CONFORMANCE
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 547 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_SUF_UNIX03         /* nothing */
#  else /* !__DARWIN_ONLY_UNIX_CONFORMANCE */
# 549 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_SUF_UNIX03         "$UNIX2003"
#  endif /* __DARWIN_ONLY_UNIX_CONFORMANCE */
# 551 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#  if __DARWIN_64_BIT_INO_T
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 553 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#    if __DARWIN_ONLY_64_BIT_INO_T
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 554 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_SUF_64_BIT_INO_T /* nothing */
#    else /* !__DARWIN_ONLY_64_BIT_INO_T */
# 556 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_SUF_64_BIT_INO_T "$INODE64"
#    endif /* __DARWIN_ONLY_64_BIT_INO_T */
# 558 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#  else /* !__DARWIN_64_BIT_INO_T */
# 559 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_SUF_64_BIT_INO_T   /* nothing */
#  endif /* __DARWIN_64_BIT_INO_T */
# 561 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#  if __DARWIN_VERS_1050
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 563 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#    if __DARWIN_ONLY_VERS_1050
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 564 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_SUF_1050         /* nothing */
#    else /* !__DARWIN_ONLY_VERS_1050 */
# 566 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#      define __DARWIN_SUF_1050         "$1050"
#    endif /* __DARWIN_ONLY_VERS_1050 */
# 568 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#  else /* !__DARWIN_VERS_1050 */
# 569 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_SUF_1050           /* nothing */
#  endif /* __DARWIN_VERS_1050 */
# 571 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#  if __DARWIN_NON_CANCELABLE
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 573 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_SUF_NON_CANCELABLE "$NOCANCEL"
#  else /* !__DARWIN_NON_CANCELABLE */
# 575 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#    define __DARWIN_SUF_NON_CANCELABLE /* nothing */
#  endif /* __DARWIN_NON_CANCELABLE */
# 577 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#else /* !__DARWIN_UNIX03 */
# 579 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#  define __DARWIN_SUF_UNIX03           /* nothing */
#  define __DARWIN_SUF_64_BIT_INO_T     /* nothing */
#  define __DARWIN_SUF_NON_CANCELABLE   /* nothing */
#  define __DARWIN_SUF_1050             /* nothing */
#endif /* __DARWIN_UNIX03 */
# 584 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

#define __DARWIN_SUF_EXTSN              "$DARWIN_EXTSN"

/*
 * symbol versioning macros
 */
#define __DARWIN_ALIAS(sym)             __asm("_" __STRING(sym) __DARWIN_SUF_UNIX03)
#define __DARWIN_ALIAS_C(sym)           __asm("_" __STRING(sym) __DARWIN_SUF_NON_CANCELABLE __DARWIN_SUF_UNIX03)
#define __DARWIN_ALIAS_I(sym)           __asm("_" __STRING(sym) __DARWIN_SUF_64_BIT_INO_T __DARWIN_SUF_UNIX03)
#define __DARWIN_NOCANCEL(sym)          __asm("_" __STRING(sym) __DARWIN_SUF_NON_CANCELABLE)
#define __DARWIN_INODE64(sym)           __asm("_" __STRING(sym) __DARWIN_SUF_64_BIT_INO_T)

#define __DARWIN_1050(sym)              __asm("_" __STRING(sym) __DARWIN_SUF_1050)
#define __DARWIN_1050ALIAS(sym)         __asm("_" __STRING(sym) __DARWIN_SUF_1050 __DARWIN_SUF_UNIX03)
#define __DARWIN_1050ALIAS_C(sym)       __asm("_" __STRING(sym) __DARWIN_SUF_1050 __DARWIN_SUF_NON_CANCELABLE __DARWIN_SUF_UNIX03)
#define __DARWIN_1050ALIAS_I(sym)       __asm("_" __STRING(sym) __DARWIN_SUF_1050 __DARWIN_SUF_64_BIT_INO_T __DARWIN_SUF_UNIX03)
#define __DARWIN_1050INODE64(sym)       __asm("_" __STRING(sym) __DARWIN_SUF_1050 __DARWIN_SUF_64_BIT_INO_T)

#define __DARWIN_EXTSN(sym)             __asm("_" __STRING(sym) __DARWIN_SUF_EXTSN)
#define __DARWIN_EXTSN_C(sym)           __asm("_" __STRING(sym) __DARWIN_SUF_EXTSN __DARWIN_SUF_NON_CANCELABLE)

/*
 * symbol release macros
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_symbol_aliasing.h>
#endif /* expanded by -frewrite-includes */
# 608 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 1 3 4
/* Copyright (c) 2010 Apple Inc. All rights reserved.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _CDEFS_H_
# error "Never use <sys/_symbol_aliasing.h> directly.  Use <sys/cdefs.h> instead."
#endif
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 20000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_2_0(x) x
#else
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_2_0(x)
#endif
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 20100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_2_1(x) x
#else
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_2_1(x)
#endif
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 20200
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_2_2(x) x
#else
# 47 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_2_2(x)
#endif
# 49 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 30000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 51 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_3_0(x) x
#else
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_3_0(x)
#endif
# 55 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 30100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 57 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_3_1(x) x
#else
# 59 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_3_1(x)
#endif
# 61 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 30200
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_3_2(x) x
#else
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_3_2(x)
#endif
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 40000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_4_0(x) x
#else
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_4_0(x)
#endif
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 40100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_4_1(x) x
#else
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_4_1(x)
#endif
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 40200
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_4_2(x) x
#else
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_4_2(x)
#endif
# 85 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 40300
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 87 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_4_3(x) x
#else
# 89 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_4_3(x)
#endif
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 50000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_5_0(x) x
#else
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_5_0(x)
#endif
# 97 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 50100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 99 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_5_1(x) x
#else
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_5_1(x)
#endif
# 103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 60000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_6_0(x) x
#else
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_6_0(x)
#endif
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 60100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_6_1(x) x
#else
# 113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_6_1(x)
#endif
# 115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 70000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_7_0(x) x
#else
# 119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_7_0(x)
#endif
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 70100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_7_1(x) x
#else
# 125 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_7_1(x)
#endif
# 127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 80000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_0(x) x
#else
# 131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_0(x)
#endif
# 133 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 80100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_1(x) x
#else
# 137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_1(x)
#endif
# 139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 80200
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_2(x) x
#else
# 143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_2(x)
#endif
# 145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 80300
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_3(x) x
#else
# 149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_3(x)
#endif
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 80400
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_4(x) x
#else
# 155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_8_4(x)
#endif
# 157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 90000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_9_0(x) x
#else
# 161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_9_0(x)
#endif
# 163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 90100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_9_1(x) x
#else
# 167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_9_1(x)
#endif
# 169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 90200
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 171 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_9_2(x) x
#else
# 173 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_9_2(x)
#endif
# 175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 90300
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_9_3(x) x
#else
# 179 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_9_3(x)
#endif
# 181 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 100000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 183 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_10_0(x) x
#else
# 185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_10_0(x)
#endif
# 187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 100100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 189 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_10_1(x) x
#else
# 191 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_10_1(x)
#endif
# 193 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 100200
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 195 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_10_2(x) x
#else
# 197 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_10_2(x)
#endif
# 199 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 100300
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_10_3(x) x
#else
# 203 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_10_3(x)
#endif
# 205 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 110000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_0(x) x
#else
# 209 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_0(x)
#endif
# 211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 110100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 213 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_1(x) x
#else
# 215 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_1(x)
#endif
# 217 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 110200
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_2(x) x
#else
# 221 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_2(x)
#endif
# 223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 110300
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_3(x) x
#else
# 227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_3(x)
#endif
# 229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 110400
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 231 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_4(x) x
#else
# 233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_11_4(x)
#endif
# 235 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 120000
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 237 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_12_0(x) x
#else
# 239 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_12_0(x)
#endif
# 241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 120100
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 243 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_12_1(x) x
#else
# 245 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_12_1(x)
#endif
# 247 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__ >= 120200
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 249 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_12_2(x) x
#else
# 251 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_IPHONE___IPHONE_12_2(x)
#endif
# 253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1000
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 255 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_0(x) x
#else
# 257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_0(x)
#endif
# 259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1010
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 261 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_1(x) x
#else
# 263 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_1(x)
#endif
# 265 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1020
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_2(x) x
#else
# 269 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_2(x)
#endif
# 271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1030
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 273 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_3(x) x
#else
# 275 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_3(x)
#endif
# 277 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1040
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 279 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_4(x) x
#else
# 281 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_4(x)
#endif
# 283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1050
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 285 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_5(x) x
#else
# 287 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_5(x)
#endif
# 289 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1060
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 291 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_6(x) x
#else
# 293 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_6(x)
#endif
# 295 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1070
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 297 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_7(x) x
#else
# 299 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_7(x)
#endif
# 301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1080
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 303 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_8(x) x
#else
# 305 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_8(x)
#endif
# 307 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1090
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 309 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_9(x) x
#else
# 311 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_9(x)
#endif
# 313 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101000
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_10(x) x
#else
# 317 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_10(x)
#endif
# 319 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101002
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 321 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_10_2(x) x
#else
# 323 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_10_2(x)
#endif
# 325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101003
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 327 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_10_3(x) x
#else
# 329 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_10_3(x)
#endif
# 331 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101100
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 333 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_11(x) x
#else
# 335 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_11(x)
#endif
# 337 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101102
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 339 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_11_2(x) x
#else
# 341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_11_2(x)
#endif
# 343 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101103
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_11_3(x) x
#else
# 347 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_11_3(x)
#endif
# 349 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101104
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 351 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_11_4(x) x
#else
# 353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_11_4(x)
#endif
# 355 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101200
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 357 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_12(x) x
#else
# 359 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_12(x)
#endif
# 361 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101201
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 363 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_12_1(x) x
#else
# 365 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_12_1(x)
#endif
# 367 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101202
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 369 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_12_2(x) x
#else
# 371 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_12_2(x)
#endif
# 373 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101204
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 375 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_12_4(x) x
#else
# 377 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_12_4(x)
#endif
# 379 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101300
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 381 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_13(x) x
#else
# 383 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_13(x)
#endif
# 385 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101301
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 387 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_13_1(x) x
#else
# 389 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_13_1(x)
#endif
# 391 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101302
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 393 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_13_2(x) x
#else
# 395 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_13_2(x)
#endif
# 397 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101304
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 399 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_13_4(x) x
#else
# 401 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_13_4(x)
#endif
# 403 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101400
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 405 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_14(x) x
#else
# 407 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_14(x)
#endif
# 409 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101401
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 411 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_14_1(x) x
#else
# 413 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_14_1(x)
#endif
# 415 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 101404
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 417 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_14_4(x) x
#else
# 419 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4
#define __DARWIN_ALIAS_STARTING_MAC___MAC_10_14_4(x)
#endif
# 421 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_symbol_aliasing.h" 3 4

# 609 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 611 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __DARWIN_ALIAS_STARTING(_mac, _iphone, x)   __DARWIN_ALIAS_STARTING_IPHONE_##_iphone(x)
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 613 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __DARWIN_ALIAS_STARTING(_mac, _iphone, x)   __DARWIN_ALIAS_STARTING_MAC_##_mac(x)
#else
# 615 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __DARWIN_ALIAS_STARTING(_mac, _iphone, x)   x
#endif
# 617 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4


/*
 * POSIX.1 requires that the macros we test be defined before any standard
 * header file is included.  This permits us to convert values for feature
 * testing, as necessary, using only _POSIX_C_SOURCE.
 *
 * Here's a quick run-down of the versions:
 *  defined(_POSIX_SOURCE)		1003.1-1988
 *  _POSIX_C_SOURCE == 1L		1003.1-1990
 *  _POSIX_C_SOURCE == 2L		1003.2-1992 C Language Binding Option
 *  _POSIX_C_SOURCE == 199309L		1003.1b-1993
 *  _POSIX_C_SOURCE == 199506L		1003.1c-1995, 1003.1i-1995,
 *					and the omnibus ISO/IEC 9945-1: 1996
 *  _POSIX_C_SOURCE == 200112L		1003.1-2001
 *  _POSIX_C_SOURCE == 200809L		1003.1-2008
 *
 * In addition, the X/Open Portability Guide, which is now the Single UNIX
 * Specification, defines a feature-test macro which indicates the version of
 * that specification, and which subsumes _POSIX_C_SOURCE.
 */

/* Deal with IEEE Std. 1003.1-1990, in which _POSIX_C_SOURCE == 1L. */
#if 0 /* disabled by -frewrite-includes */
#if defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE == 1L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 641 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#undef _POSIX_C_SOURCE
#define _POSIX_C_SOURCE         199009L
#endif
# 644 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* Deal with IEEE Std. 1003.2-1992, in which _POSIX_C_SOURCE == 2L. */
#if 0 /* disabled by -frewrite-includes */
#if defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE == 2L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 647 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#undef _POSIX_C_SOURCE
#define _POSIX_C_SOURCE         199209L
#endif
# 650 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* Deal with various X/Open Portability Guides and Single UNIX Spec. */
#ifdef _XOPEN_SOURCE
#if 0 /* disabled by -frewrite-includes */
#if _XOPEN_SOURCE - 0L >= 700L && (!defined(_POSIX_C_SOURCE) || _POSIX_C_SOURCE - 0L < 200809L)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 654 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#undef _POSIX_C_SOURCE
#define _POSIX_C_SOURCE         200809L
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _XOPEN_SOURCE - 0L >= 600L && (!defined(_POSIX_C_SOURCE) || _POSIX_C_SOURCE - 0L < 200112L)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 657 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#undef _POSIX_C_SOURCE
#define _POSIX_C_SOURCE         200112L
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _XOPEN_SOURCE - 0L >= 500L && (!defined(_POSIX_C_SOURCE) || _POSIX_C_SOURCE - 0L < 199506L)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 660 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#undef _POSIX_C_SOURCE
#define _POSIX_C_SOURCE         199506L
#endif
# 663 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#endif
# 664 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * Deal with all versions of POSIX.  The ordering relative to the tests above is
 * important.
 */
#if 0 /* disabled by -frewrite-includes */
#if defined(_POSIX_SOURCE) && !defined(_POSIX_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 670 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define _POSIX_C_SOURCE         198808L
#endif
# 672 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* POSIX C deprecation macros */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_posix_availability.h>
#endif /* expanded by -frewrite-includes */
# 674 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 1 3 4
/* Copyright (c) 2010 Apple Inc. All rights reserved.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _CDEFS_H_
# error "Never use <sys/_posix_availability.h> directly.  Use <sys/cdefs.h> instead."
#endif
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_DARWIN_C_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 198808L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_198808L __deprecated
#else
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_198808L
#endif
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_DARWIN_C_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 199009L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_199009L __deprecated
#else
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_199009L
#endif
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_DARWIN_C_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 199209L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_199209L __deprecated
#else
# 47 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_199209L
#endif
# 49 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_DARWIN_C_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 199309L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 51 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_199309L __deprecated
#else
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_199309L
#endif
# 55 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_DARWIN_C_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 199506L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 57 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_199506L __deprecated
#else
# 59 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_199506L
#endif
# 61 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_DARWIN_C_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 200112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_200112L __deprecated
#else
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_200112L
#endif
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_DARWIN_C_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 200809L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_200809L __deprecated
#else
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4
#define ___POSIX_C_DEPRECATED_STARTING_200809L
#endif
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_posix_availability.h" 3 4

# 675 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 2 3 4

#define __POSIX_C_DEPRECATED(ver) ___POSIX_C_DEPRECATED_STARTING_##ver

/*
 * Set a single macro which will always be defined and can be used to determine
 * the appropriate namespace.  For POSIX, these values will correspond to
 * _POSIX_C_SOURCE value.  Currently there are two additional levels corresponding
 * to ANSI (_ANSI_SOURCE) and Darwin extensions (_DARWIN_C_SOURCE)
 */
#define __DARWIN_C_ANSI         010000L
#define __DARWIN_C_FULL         900000L

#if 0 /* disabled by -frewrite-includes */
#if   defined(_ANSI_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 688 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __DARWIN_C_LEVEL        __DARWIN_C_ANSI
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_POSIX_C_SOURCE) && !defined(_DARWIN_C_SOURCE) && !defined(_NONSTD_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 690 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __DARWIN_C_LEVEL        _POSIX_C_SOURCE
#else
# 692 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __DARWIN_C_LEVEL        __DARWIN_C_FULL
#endif
# 694 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/* If the developer has neither requested a strict language mode nor a version
 * of POSIX, turn on functionality provided by __STDC_WANT_LIB_EXT1__ as part
 * of __DARWIN_C_FULL.
 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(__STDC_WANT_LIB_EXT1__) && !defined(__STRICT_ANSI__) && __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 700 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __STDC_WANT_LIB_EXT1__ 1
#endif
# 702 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * long long is not supported in c89 (__STRICT_ANSI__), but g++ -ansi and
 * c99 still want long longs.  While not perfect, we allow long longs for
 * g++.
 */
#if 0 /* disabled by -frewrite-includes */
#if (defined(__STRICT_ANSI__) && (__STDC_VERSION__ - 0 < 199901L) && !defined(__GNUG__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 709 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __DARWIN_NO_LONG_LONG 1
#else
# 711 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define __DARWIN_NO_LONG_LONG 0
#endif
# 713 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*****************************************
*  Public darwin-specific feature macros
*****************************************/

/*
 * _DARWIN_FEATURE_64_BIT_INODE indicates that the ino_t type is 64-bit, and
 * structures modified for 64-bit inodes (like struct stat) will be used.
 */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_64_BIT_INO_T
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 723 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define _DARWIN_FEATURE_64_BIT_INODE            1
#endif
# 725 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * _DARWIN_FEATURE_64_ONLY_BIT_INODE indicates that the ino_t type may only
 * be 64-bit; there is no support for 32-bit ino_t when this macro is defined
 * (and non-zero).  There is no struct stat64 either, as the regular
 * struct stat will already be the 64-bit version.
 */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_ONLY_64_BIT_INO_T
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 733 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define _DARWIN_FEATURE_ONLY_64_BIT_INODE       1
#endif
# 735 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * _DARWIN_FEATURE_ONLY_VERS_1050 indicates that only those APIs updated
 * in 10.5 exists; no pre-10.5 variants are available.
 */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_ONLY_VERS_1050
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 741 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define _DARWIN_FEATURE_ONLY_VERS_1050          1
#endif
# 743 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * _DARWIN_FEATURE_ONLY_UNIX_CONFORMANCE indicates only UNIX conforming API
 * are available (the legacy BSD APIs are not available)
 */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_ONLY_UNIX_CONFORMANCE
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 749 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define _DARWIN_FEATURE_ONLY_UNIX_CONFORMANCE   1
#endif
# 751 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * _DARWIN_FEATURE_UNIX_CONFORMANCE indicates whether UNIX conformance is on,
 * and specifies the conformance level (3 is SUSv3)
 */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 757 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#define _DARWIN_FEATURE_UNIX_CONFORMANCE        3
#endif
# 759 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * This macro casts away the qualifier from the variable
 *
 * Note: use at your own risk, removing qualifiers can result in
 * catastrophic run-time failures.
 */
#ifndef __CAST_AWAY_QUALIFIER
#define __CAST_AWAY_QUALIFIER(variable, qualifier, type)  (type) (long)(variable)
#endif
# 769 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * __XNU_PRIVATE_EXTERN is a linkage decoration indicating that a symbol can be
 * used from other compilation units, but not other libraries or executables.
 */
#ifndef __XNU_PRIVATE_EXTERN
#define __XNU_PRIVATE_EXTERN __attribute__((visibility("hidden")))
#endif
# 777 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4

/*
 * Architecture validation for current SDK
 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(__sys_cdefs_arch_unknown__) && defined(__i386__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 782 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(__sys_cdefs_arch_unknown__) && defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 783 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#else
# 784 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
#error Unsupported architecture
#endif
# 786 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4



#define __compiler_barrier() __asm__ __volatile__("" ::: "memory")

#endif /* !_CDEFS_H_ */
# 792 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/cdefs.h" 3 4
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4

#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 1 3 4
/*
 * Copyright (c) 2004, 2008, 2009 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

#ifndef __TYPES_H_
#define __TYPES_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 27 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 1 3 4
/*
 * Copyright (c) 2003-2007 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _SYS__TYPES_H_
#define _SYS__TYPES_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h>
#endif /* expanded by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_types.h" 1 3 4
/*
 * Copyright (c) 2003-2007 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _BSD_MACHINE__TYPES_H_
#define _BSD_MACHINE__TYPES_H_

#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include "i386/_types.h"
#endif /* expanded by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 1 3 4
/*
 * Copyright (c) 2000-2003 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _BSD_I386__TYPES_H_
#define _BSD_I386__TYPES_H_

/*
 * This header file contains integer types.  It's intended to also contain
 * flotaing point and other arithmetic types, as needed, later.
 */

#ifdef __GNUC__
typedef __signed char           __int8_t;
#else   /* !__GNUC__ */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef char                    __int8_t;
#endif  /* !__GNUC__ */
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef unsigned char           __uint8_t;
typedef short                   __int16_t;
typedef unsigned short          __uint16_t;
typedef int                     __int32_t;
typedef unsigned int            __uint32_t;
typedef long long               __int64_t;
typedef unsigned long long      __uint64_t;

typedef long                    __darwin_intptr_t;
typedef unsigned int            __darwin_natural_t;

/*
 * The rune type below is declared to be an ``int'' instead of the more natural
 * ``unsigned long'' or ``long''.  Two things are happening here.  It is not
 * unsigned so that EOF (-1) can be naturally assigned to it and used.  Also,
 * it looks like 10646 will be a 31 bit standard.  This means that if your
 * ints cannot hold 32 bits, you will be in trouble.  The reason an int was
 * chosen over a long is that the is*() and to*() routines take ints (says
 * ANSI C), but they use __darwin_ct_rune_t instead of int.  By changing it
 * here, you lose a bit of ANSI conformance, but your programs will still
 * work.
 *
 * NOTE: rune_t is not covered by ANSI nor other standards, and should not
 * be instantiated outside of lib/libc/locale.  Use wchar_t.  wchar_t and
 * rune_t must be the same type.  Also wint_t must be no narrower than
 * wchar_t, and should also be able to hold all members of the largest
 * character set plus one extra value (WEOF). wint_t must be at least 16 bits.
 */

typedef int                     __darwin_ct_rune_t;     /* ct_rune_t */

/*
 * mbstate_t is an opaque object to keep conversion state, during multibyte
 * stream conversions.  The content must not be referenced by user programs.
 */
typedef union {
	char            __mbstate8[128];
	long long       _mbstateL;                      /* for alignment */
} __mbstate_t;

typedef __mbstate_t             __darwin_mbstate_t;     /* mbstate_t */

#if 0 /* disabled by -frewrite-includes */
#if defined(__PTRDIFF_TYPE__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef __PTRDIFF_TYPE__        __darwin_ptrdiff_t;     /* ptr1 - ptr2 */
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__LP64__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef long                    __darwin_ptrdiff_t;     /* ptr1 - ptr2 */
#else
# 88 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef int                     __darwin_ptrdiff_t;     /* ptr1 - ptr2 */
#endif /* __GNUC__ */
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__SIZE_TYPE__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef __SIZE_TYPE__           __darwin_size_t;        /* sizeof() */
#else
# 94 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef unsigned long           __darwin_size_t;        /* sizeof() */
#endif
# 96 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if (__GNUC__ > 2)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef __builtin_va_list       __darwin_va_list;       /* va_list */
#else
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef void *                  __darwin_va_list;       /* va_list */
#endif
# 102 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__WCHAR_TYPE__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 104 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef __WCHAR_TYPE__          __darwin_wchar_t;       /* wchar_t */
#else
# 106 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef __darwin_ct_rune_t      __darwin_wchar_t;       /* wchar_t */
#endif
# 108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4

typedef __darwin_wchar_t        __darwin_rune_t;        /* rune_t */

#if 0 /* disabled by -frewrite-includes */
#if defined(__WINT_TYPE__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef __WINT_TYPE__           __darwin_wint_t;        /* wint_t */
#else
# 114 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
typedef __darwin_ct_rune_t      __darwin_wint_t;        /* wint_t */
#endif
# 116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4

typedef unsigned long           __darwin_clock_t;       /* clock() */
typedef __uint32_t              __darwin_socklen_t;     /* socklen_t (duh) */
typedef long                    __darwin_ssize_t;       /* byte count or error */
typedef long                    __darwin_time_t;        /* time() */

#endif  /* _BSD_I386__TYPES_H_ */
# 123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_types.h" 3 4
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_types.h" 2 3 4
#else
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_types.h" 3 4
#error architecture not supported
#endif
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_types.h" 3 4

#endif /* _BSD_MACHINE__TYPES_H_ */
# 38 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_types.h" 3 4
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 2 3 4

/*
 * Type definitions; takes common type definitions that must be used
 * in multiple header files due to [XSI], removes them from the system
 * space, and puts them in the implementation space.
 */

#ifdef __cplusplus
#ifdef __GNUG__
#define __DARWIN_NULL __null
#else /* ! __GNUG__ */
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
#ifdef __LP64__
#define __DARWIN_NULL (0L)
#else /* !__LP64__ */
# 48 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
#define __DARWIN_NULL 0
#endif /* __LP64__ */
# 50 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
#endif /* __GNUG__ */
# 51 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
#else /* ! __cplusplus */
# 52 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
#define __DARWIN_NULL ((void *)0)
#endif /* __cplusplus */
# 54 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4

typedef __int64_t       __darwin_blkcnt_t;      /* total blocks */
typedef __int32_t       __darwin_blksize_t;     /* preferred block size */
typedef __int32_t       __darwin_dev_t;         /* dev_t */
typedef unsigned int    __darwin_fsblkcnt_t;    /* Used by statvfs and fstatvfs */
typedef unsigned int    __darwin_fsfilcnt_t;    /* Used by statvfs and fstatvfs */
typedef __uint32_t      __darwin_gid_t;         /* [???] process and group IDs */
typedef __uint32_t      __darwin_id_t;          /* [XSI] pid_t, uid_t, or gid_t*/
typedef __uint64_t      __darwin_ino64_t;       /* [???] Used for 64 bit inodes */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_64_BIT_INO_T
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
typedef __darwin_ino64_t __darwin_ino_t;        /* [???] Used for inodes */
#else /* !__DARWIN_64_BIT_INO_T */
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
typedef __uint32_t      __darwin_ino_t;         /* [???] Used for inodes */
#endif /* __DARWIN_64_BIT_INO_T */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
typedef __darwin_natural_t __darwin_mach_port_name_t; /* Used by mach */
typedef __darwin_mach_port_name_t __darwin_mach_port_t; /* Used by mach */
typedef __uint16_t      __darwin_mode_t;        /* [???] Some file attributes */
typedef __int64_t       __darwin_off_t;         /* [???] Used for file sizes */
typedef __int32_t       __darwin_pid_t;         /* [???] process and group IDs */
typedef __uint32_t      __darwin_sigset_t;      /* [???] signal set */
typedef __int32_t       __darwin_suseconds_t;   /* [???] microseconds */
typedef __uint32_t      __darwin_uid_t;         /* [???] user IDs */
typedef __uint32_t      __darwin_useconds_t;    /* [???] microseconds */
typedef unsigned char   __darwin_uuid_t[16];
typedef char    __darwin_uuid_string_t[37];

#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h>
#endif /* expanded by -frewrite-includes */
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_types.h" 1 3 4
/*
 * Copyright (c) 2003-2013 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _SYS__PTHREAD_TYPES_H_
#define _SYS__PTHREAD_TYPES_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_types.h" 3 4
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_types.h" 3 4

// pthread opaque structures
#if 0 /* disabled by -frewrite-includes */
#if defined(__LP64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_types.h" 3 4
#define __PTHREAD_SIZE__		8176
#define __PTHREAD_ATTR_SIZE__		56
#define __PTHREAD_MUTEXATTR_SIZE__	8
#define __PTHREAD_MUTEX_SIZE__		56
#define __PTHREAD_CONDATTR_SIZE__	8
#define __PTHREAD_COND_SIZE__		40
#define __PTHREAD_ONCE_SIZE__		8
#define __PTHREAD_RWLOCK_SIZE__		192
#define __PTHREAD_RWLOCKATTR_SIZE__	16
#else // !__LP64__
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_types.h" 3 4
#define __PTHREAD_SIZE__		4088
#define __PTHREAD_ATTR_SIZE__		36
#define __PTHREAD_MUTEXATTR_SIZE__	8
#define __PTHREAD_MUTEX_SIZE__		40
#define __PTHREAD_CONDATTR_SIZE__	4
#define __PTHREAD_COND_SIZE__		24
#define __PTHREAD_ONCE_SIZE__		4
#define __PTHREAD_RWLOCK_SIZE__		124
#define __PTHREAD_RWLOCKATTR_SIZE__	12
#endif // !__LP64__
# 56 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_types.h" 3 4

struct __darwin_pthread_handler_rec {
	void (*__routine)(void *);	// Routine to call
	void *__arg;			// Argument to pass
	struct __darwin_pthread_handler_rec *__next;
};

struct _opaque_pthread_attr_t {
	long __sig;
	char __opaque[__PTHREAD_ATTR_SIZE__];
};

struct _opaque_pthread_cond_t {
	long __sig;
	char __opaque[__PTHREAD_COND_SIZE__];
};

struct _opaque_pthread_condattr_t {
	long __sig;
	char __opaque[__PTHREAD_CONDATTR_SIZE__];
};

struct _opaque_pthread_mutex_t {
	long __sig;
	char __opaque[__PTHREAD_MUTEX_SIZE__];
};

struct _opaque_pthread_mutexattr_t {
	long __sig;
	char __opaque[__PTHREAD_MUTEXATTR_SIZE__];
};

struct _opaque_pthread_once_t {
	long __sig;
	char __opaque[__PTHREAD_ONCE_SIZE__];
};

struct _opaque_pthread_rwlock_t {
	long __sig;
	char __opaque[__PTHREAD_RWLOCK_SIZE__];
};

struct _opaque_pthread_rwlockattr_t {
	long __sig;
	char __opaque[__PTHREAD_RWLOCKATTR_SIZE__];
};

struct _opaque_pthread_t {
	long __sig;
	struct __darwin_pthread_handler_rec  *__cleanup_stack;
	char __opaque[__PTHREAD_SIZE__];
};

typedef struct _opaque_pthread_attr_t __darwin_pthread_attr_t;
typedef struct _opaque_pthread_cond_t __darwin_pthread_cond_t;
typedef struct _opaque_pthread_condattr_t __darwin_pthread_condattr_t;
typedef unsigned long __darwin_pthread_key_t;
typedef struct _opaque_pthread_mutex_t __darwin_pthread_mutex_t;
typedef struct _opaque_pthread_mutexattr_t __darwin_pthread_mutexattr_t;
typedef struct _opaque_pthread_once_t __darwin_pthread_once_t;
typedef struct _opaque_pthread_rwlock_t __darwin_pthread_rwlock_t;
typedef struct _opaque_pthread_rwlockattr_t __darwin_pthread_rwlockattr_t;
typedef struct _opaque_pthread_t *__darwin_pthread_t;

#endif // _SYS__PTHREAD_TYPES_H_
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_types.h" 3 4
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ >= 5 || __GNUC__ > 3)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
#define __offsetof(type, field) __builtin_offsetof(type, field)
#else /* !(gcc >= 3.5) */
# 85 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
#define __offsetof(type, field) ((size_t)(&((type *)0)->field))
#endif /* (gcc >= 3.5) */
# 87 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4


#endif  /* _SYS__TYPES_H_ */
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types.h" 3 4
# 28 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __uint32_t */
#endif /* expanded by -frewrite-includes */
# 28 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __GNUC__ > 2 || __GNUC__ == 2 && __GNUC_MINOR__ >= 7
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#define __strfmonlike(fmtarg, firstvararg) \
		__attribute__((__format__ (__strfmon__, fmtarg, firstvararg)))
#define __strftimelike(fmtarg) \
		__attribute__((__format__ (__strftime__, fmtarg, 0)))
#else
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#define __strfmonlike(fmtarg, firstvararg)
#define __strftimelike(fmtarg)
#endif
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4

typedef	int		__darwin_nl_item;
typedef	int		__darwin_wctrans_t;
#ifdef __LP64__
typedef	__uint32_t	__darwin_wctype_t;
#else /* !__LP64__ */
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
typedef	unsigned long	__darwin_wctype_t;
#endif /* __LP64__ */
# 47 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4

#ifdef __WCHAR_MAX__
#define __DARWIN_WCHAR_MAX	__WCHAR_MAX__
#else /* ! __WCHAR_MAX__ */
# 51 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#define __DARWIN_WCHAR_MAX	0x7fffffff
#endif /* __WCHAR_MAX__ */
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_WCHAR_MAX > 0xffffU
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 55 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#define __DARWIN_WCHAR_MIN	(-0x7fffffff - 1)
#else
# 57 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#define __DARWIN_WCHAR_MIN	0
#endif
# 59 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#define	__DARWIN_WEOF 	((__darwin_wint_t)-1)

#ifndef _FORTIFY_SOURCE
#if 0 /* disabled by -frewrite-includes */
#  if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1050)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#    define _FORTIFY_SOURCE 0
#  else
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#    define _FORTIFY_SOURCE 2	/* on by default */
#  endif
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
#endif
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4

#endif /* __TYPES_H_ */
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types.h" 3 4
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4
#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/wait.h>
#endif /* expanded by -frewrite-includes */
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 1 3 4
/*
 * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/* Copyright (c) 1995 NeXT Computer, Inc. All Rights Reserved */
/*
 * Copyright (c) 1982, 1986, 1989, 1993, 1994
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)wait.h	8.2 (Berkeley) 7/10/94
 */

#ifndef _SYS_WAIT_H_
#define _SYS_WAIT_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4

/*
 * This file holds definitions relevent to the wait4 system call
 * and the alternate interfaces that use it (wait, wait3, waitpid).
 */

/*
 * [XSI] The type idtype_t shall be defined as an enumeration type whose
 * possible values shall include at least P_ALL, P_PID, and P_PGID.
 */
typedef enum {
	P_ALL,
	P_PID,
	P_PGID
} idtype_t;

/*
 * [XSI] The id_t and pid_t types shall be defined as described
 * in <sys/types.h>
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_pid_t.h>
#endif /* expanded by -frewrite-includes */
# 89 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_pid_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PID_T
#define _PID_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_pid_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_pid_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_pid_t.h" 3 4
typedef __darwin_pid_t        pid_t;
#endif  /* _PID_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_pid_t.h" 3 4
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_id_t.h>
#endif /* expanded by -frewrite-includes */
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_id_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _ID_T
#define _ID_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_id_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_id_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_id_t.h" 3 4
typedef __darwin_id_t   id_t;           /* can hold pid_t, gid_t, or uid_t */
#endif /* _ID_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_id_t.h" 3 4
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 2 3 4

/*
 * [XSI] The siginfo_t type shall be defined as described in <signal.h>
 * [XSI] The rusage structure shall be defined as described in <sys/resource.h>
 * [XSI] Inclusion of the <sys/wait.h> header may also make visible all
 * symbols from <signal.h> and <sys/resource.h>
 *
 * NOTE:	This requirement is currently being satisfied by the direct
 *		inclusion of <sys/signal.h> and <sys/resource.h>, below.
 *
 *		Software should not depend on the exposure of anything other
 *		than the types siginfo_t and struct rusage as a result of
 *		this inclusion.  If you depend on any types or manifest
 *		values othe than siginfo_t and struct rusage from either of
 *		those files, you should explicitly include them yourself, as
 *		well, or in future releases your stware may not compile
 *		without modification.
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/signal.h>         /* [XSI] for siginfo_t */
#endif /* expanded by -frewrite-includes */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 1 3 4
/*
 * Copyright (c) 2000-2006 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/* Copyright (c) 1995 NeXT Computer, Inc. All Rights Reserved */
/*
 * Copyright (c) 1982, 1986, 1989, 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)signal.h	8.2 (Berkeley) 1/21/94
 */

#ifndef _SYS_SIGNAL_H_
#define _SYS_SIGNAL_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/appleapiopts.h>
#endif /* expanded by -frewrite-includes */
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 1 3 4
/*
 * Copyright (c) 2002 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef __SYS_APPLEAPIOPTS_H__
#define __SYS_APPLEAPIOPTS_H__


#ifndef __APPLE_API_STANDARD
#define __APPLE_API_STANDARD
#endif /* __APPLE_API_STANDARD */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 3 4

#ifndef __APPLE_API_STABLE
#define __APPLE_API_STABLE
#endif /* __APPLE_API_STABLE */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 3 4

#ifndef __APPLE_API_STRICT_CONFORMANCE

#ifndef __APPLE_API_EVOLVING
#define __APPLE_API_EVOLVING
#endif /* __APPLE_API_EVOLVING */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 3 4

#ifndef __APPLE_API_UNSTABLE
#define __APPLE_API_UNSTABLE
#endif /* __APPLE_API_UNSTABLE */
# 50 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 3 4

#ifndef __APPLE_API_PRIVATE
#define __APPLE_API_PRIVATE
#endif /* __APPLE_API_PRIVATE */
# 54 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 3 4

#ifndef __APPLE_API_OBSOLETE
#define __APPLE_API_OBSOLETE
#endif /* __APPLE_API_OBSOLETE */
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 3 4

#endif /* __APPLE_API_STRICT_CONFORMANCE */
# 60 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 3 4

#endif /* __SYS_APPLEAPIOPTS_H__ */
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/appleapiopts.h" 3 4
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4

#define __DARWIN_NSIG   32      /* counting 0; could be 33 (mask is 1-32) */

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define NSIG    __DARWIN_NSIG
#endif
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <machine/signal.h>     /* sigcontext; codes for SIGILL, SIGFPE */
#endif /* expanded by -frewrite-includes */
# 82 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/signal.h" 1 3 4
/*
 * Copyright (c) 2000-2007 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _BSD_MACHINE_SIGNAL_H_
#define _BSD_MACHINE_SIGNAL_H_

#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/signal.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include "i386/signal.h"
#endif /* expanded by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/signal.h" 1 3 4
/*
 * Copyright (c) 2000-2002 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 1992 NeXT Computer, Inc.
 *
 */

#ifndef _I386_SIGNAL_H_
#define _I386_SIGNAL_H_ 1

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/signal.h" 3 4
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/signal.h" 3 4

#ifndef _ANSI_SOURCE
typedef int sig_atomic_t;

#endif /* ! _ANSI_SOURCE */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/signal.h" 3 4

#endif  /* _I386_SIGNAL_H_ */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/signal.h" 3 4
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/signal.h" 2 3 4
#else
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/signal.h" 3 4
#error architecture not supported
#endif
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/signal.h" 3 4

#endif /* _BSD_MACHINE_SIGNAL_H_ */
# 38 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/signal.h" 3 4
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4

#define SIGHUP  1       /* hangup */
#define SIGINT  2       /* interrupt */
#define SIGQUIT 3       /* quit */
#define SIGILL  4       /* illegal instruction (not reset when caught) */
#define SIGTRAP 5       /* trace trap (not reset when caught) */
#define SIGABRT 6       /* abort() */
#if 0 /* disabled by -frewrite-includes */
#if  (defined(_POSIX_C_SOURCE) && !defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SIGPOLL 7       /* pollable event ([XSR] generated, not supported) */
#else   /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SIGIOT  SIGABRT /* compatibility */
#define SIGEMT  7       /* EMT instruction */
#endif  /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 96 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SIGFPE  8       /* floating point exception */
#define SIGKILL 9       /* kill (cannot be caught or ignored) */
#define SIGBUS  10      /* bus error */
#define SIGSEGV 11      /* segmentation violation */
#define SIGSYS  12      /* bad argument to system call */
#define SIGPIPE 13      /* write on a pipe with no one to read it */
#define SIGALRM 14      /* alarm clock */
#define SIGTERM 15      /* software termination signal from kill */
#define SIGURG  16      /* urgent condition on IO channel */
#define SIGSTOP 17      /* sendable stop signal not from tty */
#define SIGTSTP 18      /* stop signal from tty */
#define SIGCONT 19      /* continue a stopped process */
#define SIGCHLD 20      /* to parent on child stop or exit */
#define SIGTTIN 21      /* to readers pgrp upon background tty read */
#define SIGTTOU 22      /* like TTIN for output if (tp->t_local&LTOSTOP) */
#if 0 /* disabled by -frewrite-includes */
#if  (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SIGIO   23      /* input/output possible signal */
#endif
# 114 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SIGXCPU 24      /* exceeded CPU time limit */
#define SIGXFSZ 25      /* exceeded file size limit */
#define SIGVTALRM 26    /* virtual time alarm */
#define SIGPROF 27      /* profiling time alarm */
#if 0 /* disabled by -frewrite-includes */
#if  (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SIGWINCH 28     /* window size changes */
#define SIGINFO 29      /* information request */
#endif
# 122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SIGUSR1 30      /* user defined signal 1 */
#define SIGUSR2 31      /* user defined signal 2 */

#if 0 /* disabled by -frewrite-includes */
#if defined(_ANSI_SOURCE) || __DARWIN_UNIX03 || defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
/*
 * Language spec sez we must list exactly one parameter, even though we
 * actually supply three.  Ugh!
 * SIG_HOLD is chosen to avoid KERN_SIG_* values in <sys/signalvar.h>
 */
#define SIG_DFL         (void (*)(int))0
#define SIG_IGN         (void (*)(int))1
#define SIG_HOLD        (void (*)(int))5
#define SIG_ERR         ((void (*)(int))-1)
#else
# 136 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
/* DO NOT REMOVE THE COMMENTED OUT int: fixincludes needs to see them */
#define SIG_DFL         (void (*)( /*int*/ ))0
#define SIG_IGN         (void (*)( /*int*/ ))1
#define SIG_HOLD        (void (*)( /*int*/ ))5
#define SIG_ERR         ((void (*)( /*int*/ ))-1)
#endif
# 142 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4

#ifndef _ANSI_SOURCE
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 144 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <machine/_mcontext.h>
#endif /* expanded by -frewrite-includes */
# 146 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined (__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include "i386/_mcontext.h"
#endif /* expanded by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef __I386_MCONTEXT_H_
#define __I386_MCONTEXT_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h> /* __DARWIN_UNIX03 */
#endif /* expanded by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/appleapiopts.h>
#endif /* expanded by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <mach/machine/_structs.h>
#endif /* expanded by -frewrite-includes */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/machine/_structs.h" 1 3 4
/*
 * Copyright (c) 2017 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _MACH_MACHINE__STRUCTS_H_
#define _MACH_MACHINE__STRUCTS_H_

#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/machine/_structs.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include "mach/i386/_structs.h"
#endif /* expanded by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/machine/_structs.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 1 3 4
/*
 * Copyright (c) 2004-2006 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*
 * @OSF_COPYRIGHT@
 */

#ifndef	_MACH_I386__STRUCTS_H_
#define	_MACH_I386__STRUCTS_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h> /* __DARWIN_UNIX03 */
#endif /* expanded by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __uint8_t */
#endif /* expanded by -frewrite-includes */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 1 3 4
/*
 * Copyright (c) 2000-2007 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*
 * Copyright 1995 NeXT Computer, Inc. All rights reserved.
 */
#ifndef _BSD_MACHINE_TYPES_H_
#define _BSD_MACHINE_TYPES_H_

#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include "i386/types.h"
#endif /* expanded by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 1 3 4
/*
 * Copyright (c) 2000-2008 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*
 * Copyright 1995 NeXT Computer, Inc. All rights reserved.
 */
/*
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)types.h	8.3 (Berkeley) 1/5/94
 */

#ifndef _MACHTYPES_H_
#define _MACHTYPES_H_

#ifndef __ASSEMBLER__
#if 0 /* expanded by -frewrite-includes */
#include <i386/_types.h>
#endif /* expanded by -frewrite-includes */
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
/*
 * Basic integral types.  Omit the typedef if
 * not possible for a machine/compiler combination.
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_int8_t.h>
#endif /* expanded by -frewrite-includes */
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_int8_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _INT8_T
#define _INT8_T
typedef __signed char           int8_t;
#endif /* _INT8_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_int8_t.h" 3 4
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_int16_t.h>
#endif /* expanded by -frewrite-includes */
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_int16_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _INT16_T
#define _INT16_T
typedef short                   int16_t;
#endif /* _INT16_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_int16_t.h" 3 4
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_int32_t.h>
#endif /* expanded by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_int32_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _INT32_T
#define _INT32_T
typedef int                     int32_t;
#endif /* _INT32_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_int32_t.h" 3 4
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_int64_t.h>
#endif /* expanded by -frewrite-includes */
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_int64_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _INT64_T
#define _INT64_T
typedef long long               int64_t;
#endif /* _INT64_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_int64_t.h" 3 4
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_u_int8_t.h>
#endif /* expanded by -frewrite-includes */
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int8_t.h" 1 3 4
/*
 * Copyright (c) 2016 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _U_INT8_T
#define _U_INT8_T
typedef unsigned char           u_int8_t;
#endif /* _U_INT8_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int8_t.h" 3 4
# 82 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_u_int16_t.h>
#endif /* expanded by -frewrite-includes */
# 82 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int16_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _U_INT16_T
#define _U_INT16_T
typedef unsigned short                  u_int16_t;
#endif /* _U_INT16_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int16_t.h" 3 4
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_u_int32_t.h>
#endif /* expanded by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int32_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _U_INT32_T
#define _U_INT32_T
typedef unsigned int            u_int32_t;
#endif /* _U_INT32_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int32_t.h" 3 4
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_u_int64_t.h>
#endif /* expanded by -frewrite-includes */
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int64_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _U_INT64_T
#define _U_INT64_T
typedef unsigned long long      u_int64_t;
#endif /* _U_INT64_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int64_t.h" 3 4
# 85 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if __LP64__
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 87 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
typedef int64_t                 register_t;
#else
# 89 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
typedef int32_t                 register_t;
#endif
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_intptr_t.h>
#endif /* expanded by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_intptr_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _INTPTR_T
#define _INTPTR_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_intptr_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_intptr_t.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 1 3 4
/*
 * Copyright (c) 2000-2007 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*
 * Copyright 1995 NeXT Computer, Inc. All rights reserved.
 */
#ifndef _BSD_MACHINE_TYPES_H_
#define _BSD_MACHINE_TYPES_H_

#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include "i386/types.h"
#endif /* expanded by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
#else
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
#error architecture not supported
#endif
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4

#endif /* _BSD_MACHINE_TYPES_H_ */
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_intptr_t.h" 2 3 4

typedef __darwin_intptr_t       intptr_t;
#endif /* _INTPTR_T */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_intptr_t.h" 3 4
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_uintptr_t.h>
#endif /* expanded by -frewrite-includes */
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_uintptr_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _UINTPTR_T
#define _UINTPTR_T
typedef unsigned long           uintptr_t;
#endif /* _UINTPTR_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_uintptr_t.h" 3 4
# 94 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 96 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
/* These types are used for reserving the largest possible size. */
typedef u_int64_t               user_addr_t;
typedef u_int64_t               user_size_t;
typedef int64_t                 user_ssize_t;
typedef int64_t                 user_long_t;
typedef u_int64_t               user_ulong_t;
typedef int64_t                 user_time_t;
typedef int64_t                 user_off_t;
#define USER_ADDR_NULL  ((user_addr_t) 0)
#define CAST_USER_ADDR_T(a_ptr)   ((user_addr_t)((uintptr_t)(a_ptr)))


#endif /* !_ANSI_SOURCE && (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4

/* This defines the size of syscall arguments after copying into the kernel: */
typedef u_int64_t               syscall_arg_t;

#endif /* __ASSEMBLER__ */
# 114 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
#endif  /* _MACHTYPES_H_ */
# 115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/types.h" 3 4
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 2 3 4
#else
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
#error architecture not supported
#endif
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4

#endif /* _BSD_MACHINE_TYPES_H_ */
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/types.h" 3 4
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 2 3 4

/*
 * i386 is the structure that is exported to user threads for 
 * use in status/mutate calls.  This structure should never change.
 *
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define	_STRUCT_X86_THREAD_STATE32	struct __darwin_i386_thread_state
_STRUCT_X86_THREAD_STATE32
{
    unsigned int	__eax;
    unsigned int	__ebx;
    unsigned int	__ecx;
    unsigned int	__edx;
    unsigned int	__edi;
    unsigned int	__esi;
    unsigned int	__ebp;
    unsigned int	__esp;
    unsigned int	__ss;
    unsigned int	__eflags;
    unsigned int	__eip;
    unsigned int	__cs;
    unsigned int	__ds;
    unsigned int	__es;
    unsigned int	__fs;
    unsigned int	__gs;
};
#else /* !__DARWIN_UNIX03 */
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define	_STRUCT_X86_THREAD_STATE32	struct i386_thread_state
_STRUCT_X86_THREAD_STATE32
{
    unsigned int	eax;
    unsigned int	ebx;
    unsigned int	ecx;
    unsigned int	edx;
    unsigned int	edi;
    unsigned int	esi;
    unsigned int	ebp;
    unsigned int	esp;
    unsigned int	ss;
    unsigned int	eflags;
    unsigned int	eip;
    unsigned int	cs;
    unsigned int	ds;
    unsigned int	es;
    unsigned int	fs;
    unsigned int	gs;
};
#endif /* !__DARWIN_UNIX03 */
# 87 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

/* This structure should be double-word aligned for performance */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_FP_CONTROL	struct __darwin_fp_control
_STRUCT_FP_CONTROL
{
    unsigned short		__invalid	:1,
    				__denorm	:1,
				__zdiv		:1,
				__ovrfl		:1,
				__undfl		:1,
				__precis	:1,
						:2,
				__pc		:2,
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define FP_PREC_24B		0
#define	FP_PREC_53B		2
#define FP_PREC_64B		3
#endif /* !_POSIX_C_SOURCE || _DARWIN_C_SOURCE */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
				__rc		:2,
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define FP_RND_NEAR		0
#define FP_RND_DOWN		1
#define FP_RND_UP		2
#define FP_CHOP			3
#endif /* !_POSIX_C_SOURCE || _DARWIN_C_SOURCE */
# 114 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
					/*inf*/	:1,
						:3;
};
typedef _STRUCT_FP_CONTROL	__darwin_fp_control_t;
#else /* !__DARWIN_UNIX03 */
# 119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_FP_CONTROL	struct fp_control
_STRUCT_FP_CONTROL
{
    unsigned short		invalid	:1,
    				denorm	:1,
				zdiv	:1,
				ovrfl	:1,
				undfl	:1,
				precis	:1,
					:2,
				pc	:2,
#define FP_PREC_24B		0
#define	FP_PREC_53B		2
#define FP_PREC_64B		3
				rc	:2,
#define FP_RND_NEAR		0
#define FP_RND_DOWN		1
#define FP_RND_UP		2
#define FP_CHOP			3
				/*inf*/	:1,
					:3;
};
typedef _STRUCT_FP_CONTROL	fp_control_t;
#endif /* !__DARWIN_UNIX03 */
# 143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

/*
 * Status word.
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_FP_STATUS	struct __darwin_fp_status
_STRUCT_FP_STATUS
{
    unsigned short		__invalid	:1,
    				__denorm	:1,
				__zdiv		:1,
				__ovrfl		:1,
				__undfl		:1,
				__precis	:1,
				__stkflt	:1,
				__errsumm	:1,
				__c0		:1,
				__c1		:1,
				__c2		:1,
				__tos		:3,
				__c3		:1,
				__busy		:1;
};
typedef _STRUCT_FP_STATUS	__darwin_fp_status_t;
#else /* !__DARWIN_UNIX03 */
# 169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_FP_STATUS	struct fp_status
_STRUCT_FP_STATUS
{
    unsigned short		invalid	:1,
    				denorm	:1,
				zdiv	:1,
				ovrfl	:1,
				undfl	:1,
				precis	:1,
				stkflt	:1,
				errsumm	:1,
				c0	:1,
				c1	:1,
				c2	:1,
				tos	:3,
				c3	:1,
				busy	:1;
};
typedef _STRUCT_FP_STATUS	fp_status_t;
#endif /* !__DARWIN_UNIX03 */
# 189 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
				
/* defn of 80bit x87 FPU or MMX register  */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 193 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_MMST_REG	struct __darwin_mmst_reg
_STRUCT_MMST_REG
{
	char	__mmst_reg[10];
	char	__mmst_rsrv[6];
};
#else /* !__DARWIN_UNIX03 */
# 200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_MMST_REG	struct mmst_reg
_STRUCT_MMST_REG
{
	char	mmst_reg[10];
	char	mmst_rsrv[6];
};
#endif /* !__DARWIN_UNIX03 */
# 207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4


/* defn of 128 bit XMM regs */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_XMM_REG		struct __darwin_xmm_reg
_STRUCT_XMM_REG
{
	char		__xmm_reg[16];
};
#else /* !__DARWIN_UNIX03 */
# 218 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_XMM_REG		struct xmm_reg
_STRUCT_XMM_REG
{
	char		xmm_reg[16];
};
#endif /* !__DARWIN_UNIX03 */
# 224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

/* defn of 256 bit YMM regs */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_YMM_REG		struct __darwin_ymm_reg
_STRUCT_YMM_REG
{
	char		__ymm_reg[32];
};
#else /* !__DARWIN_UNIX03 */
# 234 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_YMM_REG		struct ymm_reg
_STRUCT_YMM_REG
{
	char		ymm_reg[32];
};
#endif /* !__DARWIN_UNIX03 */
# 240 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

/* defn of 512 bit ZMM regs */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 244 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_ZMM_REG		struct __darwin_zmm_reg
_STRUCT_ZMM_REG
{
	char		__zmm_reg[64];
};
#else /* !__DARWIN_UNIX03 */
# 250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_ZMM_REG		struct zmm_reg
_STRUCT_ZMM_REG
{
	char		zmm_reg[64];
};
#endif /* !__DARWIN_UNIX03 */
# 256 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 258 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_OPMASK_REG	struct __darwin_opmask_reg
_STRUCT_OPMASK_REG
{
	char		__opmask_reg[8];
};
#else /* !__DARWIN_UNIX03 */
# 264 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_OPMASK_REG	struct opmask_reg
_STRUCT_OPMASK_REG
{
	char		opmask_reg[8];
};
#endif /* !__DARWIN_UNIX03 */
# 270 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

/* 
 * Floating point state.
 */

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 276 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define FP_STATE_BYTES		512	/* number of chars worth of data from fpu_fcw */
#endif /* !_POSIX_C_SOURCE || _DARWIN_C_SOURCE */
# 278 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 280 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define	_STRUCT_X86_FLOAT_STATE32	struct __darwin_i386_float_state
_STRUCT_X86_FLOAT_STATE32
{
	int 			__fpu_reserved[2];
	_STRUCT_FP_CONTROL	__fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	__fpu_fsw;		/* x87 FPU status word */
	__uint8_t		__fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		__fpu_rsrv1;		/* reserved */ 
	__uint16_t		__fpu_fop;		/* x87 FPU Opcode */
	__uint32_t		__fpu_ip;		/* x87 FPU Instruction Pointer offset */
	__uint16_t		__fpu_cs;		/* x87 FPU Instruction Pointer Selector */
	__uint16_t		__fpu_rsrv2;		/* reserved */
	__uint32_t		__fpu_dp;		/* x87 FPU Instruction Operand(Data) Pointer offset */
	__uint16_t		__fpu_ds;		/* x87 FPU Instruction Operand(Data) Pointer Selector */
	__uint16_t		__fpu_rsrv3;		/* reserved */
	__uint32_t		__fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		__fpu_mxcsrmask;	/* MXCSR mask */
	_STRUCT_MMST_REG	__fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	__fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	__fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	__fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	__fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	__fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	__fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	__fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		__fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		__fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		__fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		__fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		__fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		__fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		__fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		__fpu_xmm7;		/* XMM 7  */
	char			__fpu_rsrv4[14*16];	/* reserved */
	int 			__fpu_reserved1;
};

#define	_STRUCT_X86_AVX_STATE32	struct __darwin_i386_avx_state
_STRUCT_X86_AVX_STATE32
{
	int 			__fpu_reserved[2];
	_STRUCT_FP_CONTROL	__fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	__fpu_fsw;		/* x87 FPU status word */
	__uint8_t		__fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		__fpu_rsrv1;		/* reserved */ 
	__uint16_t		__fpu_fop;		/* x87 FPU Opcode */
	__uint32_t		__fpu_ip;		/* x87 FPU Instruction Pointer offset */
	__uint16_t		__fpu_cs;		/* x87 FPU Instruction Pointer Selector */
	__uint16_t		__fpu_rsrv2;		/* reserved */
	__uint32_t		__fpu_dp;		/* x87 FPU Instruction Operand(Data) Pointer offset */
	__uint16_t		__fpu_ds;		/* x87 FPU Instruction Operand(Data) Pointer Selector */
	__uint16_t		__fpu_rsrv3;		/* reserved */
	__uint32_t		__fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		__fpu_mxcsrmask;	/* MXCSR mask */
	_STRUCT_MMST_REG	__fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	__fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	__fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	__fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	__fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	__fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	__fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	__fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		__fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		__fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		__fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		__fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		__fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		__fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		__fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		__fpu_xmm7;		/* XMM 7  */
	char			__fpu_rsrv4[14*16];	/* reserved */
	int 			__fpu_reserved1;
	char			__avx_reserved1[64];
	_STRUCT_XMM_REG		__fpu_ymmh0;		/* YMMH 0  */
	_STRUCT_XMM_REG		__fpu_ymmh1;		/* YMMH 1  */
	_STRUCT_XMM_REG		__fpu_ymmh2;		/* YMMH 2  */
	_STRUCT_XMM_REG		__fpu_ymmh3;		/* YMMH 3  */
	_STRUCT_XMM_REG		__fpu_ymmh4;		/* YMMH 4  */
	_STRUCT_XMM_REG		__fpu_ymmh5;		/* YMMH 5  */
	_STRUCT_XMM_REG		__fpu_ymmh6;		/* YMMH 6  */
	_STRUCT_XMM_REG		__fpu_ymmh7;		/* YMMH 7  */
};

#define	_STRUCT_X86_AVX512_STATE32	struct __darwin_i386_avx512_state
_STRUCT_X86_AVX512_STATE32
{
	int 			__fpu_reserved[2];
	_STRUCT_FP_CONTROL	__fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	__fpu_fsw;		/* x87 FPU status word */
	__uint8_t		__fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		__fpu_rsrv1;		/* reserved */ 
	__uint16_t		__fpu_fop;		/* x87 FPU Opcode */
	__uint32_t		__fpu_ip;		/* x87 FPU Instruction Pointer offset */
	__uint16_t		__fpu_cs;		/* x87 FPU Instruction Pointer Selector */
	__uint16_t		__fpu_rsrv2;		/* reserved */
	__uint32_t		__fpu_dp;		/* x87 FPU Instruction Operand(Data) Pointer offset */
	__uint16_t		__fpu_ds;		/* x87 FPU Instruction Operand(Data) Pointer Selector */
	__uint16_t		__fpu_rsrv3;		/* reserved */
	__uint32_t		__fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		__fpu_mxcsrmask;	/* MXCSR mask */
	_STRUCT_MMST_REG	__fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	__fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	__fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	__fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	__fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	__fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	__fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	__fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		__fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		__fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		__fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		__fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		__fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		__fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		__fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		__fpu_xmm7;		/* XMM 7  */
	char			__fpu_rsrv4[14*16];	/* reserved */
	int 			__fpu_reserved1;
	char			__avx_reserved1[64];
	_STRUCT_XMM_REG		__fpu_ymmh0;		/* YMMH 0  */
	_STRUCT_XMM_REG		__fpu_ymmh1;		/* YMMH 1  */
	_STRUCT_XMM_REG		__fpu_ymmh2;		/* YMMH 2  */
	_STRUCT_XMM_REG		__fpu_ymmh3;		/* YMMH 3  */
	_STRUCT_XMM_REG		__fpu_ymmh4;		/* YMMH 4  */
	_STRUCT_XMM_REG		__fpu_ymmh5;		/* YMMH 5  */
	_STRUCT_XMM_REG		__fpu_ymmh6;		/* YMMH 6  */
	_STRUCT_XMM_REG		__fpu_ymmh7;		/* YMMH 7  */
	_STRUCT_OPMASK_REG	__fpu_k0;		/* K0 */
	_STRUCT_OPMASK_REG	__fpu_k1;		/* K1 */
	_STRUCT_OPMASK_REG	__fpu_k2;		/* K2 */
	_STRUCT_OPMASK_REG	__fpu_k3;		/* K3 */
	_STRUCT_OPMASK_REG	__fpu_k4;		/* K4 */
	_STRUCT_OPMASK_REG	__fpu_k5;		/* K5 */
	_STRUCT_OPMASK_REG	__fpu_k6;		/* K6 */
	_STRUCT_OPMASK_REG	__fpu_k7;		/* K7 */
	_STRUCT_YMM_REG		__fpu_zmmh0;		/* ZMMH 0  */
	_STRUCT_YMM_REG		__fpu_zmmh1;		/* ZMMH 1  */
	_STRUCT_YMM_REG		__fpu_zmmh2;		/* ZMMH 2  */
	_STRUCT_YMM_REG		__fpu_zmmh3;		/* ZMMH 3  */
	_STRUCT_YMM_REG		__fpu_zmmh4;		/* ZMMH 4  */
	_STRUCT_YMM_REG		__fpu_zmmh5;		/* ZMMH 5  */
	_STRUCT_YMM_REG		__fpu_zmmh6;		/* ZMMH 6  */
	_STRUCT_YMM_REG		__fpu_zmmh7;		/* ZMMH 7  */
};

#else /* !__DARWIN_UNIX03 */
# 426 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define	_STRUCT_X86_FLOAT_STATE32	struct i386_float_state
_STRUCT_X86_FLOAT_STATE32
{
	int 			fpu_reserved[2];
	_STRUCT_FP_CONTROL	fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	fpu_fsw;		/* x87 FPU status word */
	__uint8_t		fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		fpu_rsrv1;		/* reserved */ 
	__uint16_t		fpu_fop;		/* x87 FPU Opcode */
	__uint32_t		fpu_ip;			/* x87 FPU Instruction Pointer offset */
	__uint16_t		fpu_cs;			/* x87 FPU Instruction Pointer Selector */
	__uint16_t		fpu_rsrv2;		/* reserved */
	__uint32_t		fpu_dp;			/* x87 FPU Instruction Operand(Data) Pointer offset */
	__uint16_t		fpu_ds;			/* x87 FPU Instruction Operand(Data) Pointer Selector */
	__uint16_t		fpu_rsrv3;		/* reserved */
	__uint32_t		fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		fpu_mxcsrmask;		/* MXCSR mask */
	_STRUCT_MMST_REG	fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		fpu_xmm7;		/* XMM 7  */
	char			fpu_rsrv4[14*16];	/* reserved */
	int 			fpu_reserved1;
};

#define	_STRUCT_X86_AVX_STATE32	struct i386_avx_state
_STRUCT_X86_AVX_STATE32
{
	int 			fpu_reserved[2];
	_STRUCT_FP_CONTROL	fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	fpu_fsw;		/* x87 FPU status word */
	__uint8_t		fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		fpu_rsrv1;		/* reserved */ 
	__uint16_t		fpu_fop;		/* x87 FPU Opcode */
	__uint32_t		fpu_ip;			/* x87 FPU Instruction Pointer offset */
	__uint16_t		fpu_cs;			/* x87 FPU Instruction Pointer Selector */
	__uint16_t		fpu_rsrv2;		/* reserved */
	__uint32_t		fpu_dp;			/* x87 FPU Instruction Operand(Data) Pointer offset */
	__uint16_t		fpu_ds;			/* x87 FPU Instruction Operand(Data) Pointer Selector */
	__uint16_t		fpu_rsrv3;		/* reserved */
	__uint32_t		fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		fpu_mxcsrmask;		/* MXCSR mask */
	_STRUCT_MMST_REG	fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		fpu_xmm7;		/* XMM 7  */
	char			fpu_rsrv4[14*16];	/* reserved */
	int 			fpu_reserved1;
	char			avx_reserved1[64];
	_STRUCT_XMM_REG		fpu_ymmh0;		/* YMMH 0  */
	_STRUCT_XMM_REG		fpu_ymmh1;		/* YMMH 1  */
	_STRUCT_XMM_REG		fpu_ymmh2;		/* YMMH 2  */
	_STRUCT_XMM_REG		fpu_ymmh3;		/* YMMH 3  */
	_STRUCT_XMM_REG		fpu_ymmh4;		/* YMMH 4  */
	_STRUCT_XMM_REG		fpu_ymmh5;		/* YMMH 5  */
	_STRUCT_XMM_REG		fpu_ymmh6;		/* YMMH 6  */
	_STRUCT_XMM_REG		fpu_ymmh7;		/* YMMH 7  */
};

#define	_STRUCT_X86_AVX512_STATE32	struct i386_avx512_state
_STRUCT_X86_AVX512_STATE32
{
	int 			fpu_reserved[2];
	_STRUCT_FP_CONTROL	fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	fpu_fsw;		/* x87 FPU status word */
	__uint8_t		fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		fpu_rsrv1;		/* reserved */ 
	__uint16_t		fpu_fop;		/* x87 FPU Opcode */
	__uint32_t		fpu_ip;			/* x87 FPU Instruction Pointer offset */
	__uint16_t		fpu_cs;			/* x87 FPU Instruction Pointer Selector */
	__uint16_t		fpu_rsrv2;		/* reserved */
	__uint32_t		fpu_dp;			/* x87 FPU Instruction Operand(Data) Pointer offset */
	__uint16_t		fpu_ds;			/* x87 FPU Instruction Operand(Data) Pointer Selector */
	__uint16_t		fpu_rsrv3;		/* reserved */
	__uint32_t		fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		fpu_mxcsrmask;		/* MXCSR mask */
	_STRUCT_MMST_REG	fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		fpu_xmm7;		/* XMM 7  */
	char			fpu_rsrv4[14*16];	/* reserved */
	int 			fpu_reserved1;
	char			avx_reserved1[64];
	_STRUCT_XMM_REG		fpu_ymmh0;		/* YMMH 0  */
	_STRUCT_XMM_REG		fpu_ymmh1;		/* YMMH 1  */
	_STRUCT_XMM_REG		fpu_ymmh2;		/* YMMH 2  */
	_STRUCT_XMM_REG		fpu_ymmh3;		/* YMMH 3  */
	_STRUCT_XMM_REG		fpu_ymmh4;		/* YMMH 4  */
	_STRUCT_XMM_REG		fpu_ymmh5;		/* YMMH 5  */
	_STRUCT_XMM_REG		fpu_ymmh6;		/* YMMH 6  */
	_STRUCT_XMM_REG		fpu_ymmh7;		/* YMMH 7  */
	_STRUCT_OPMASK_REG	fpu_k0;			/* K0 */
	_STRUCT_OPMASK_REG	fpu_k1;			/* K1 */
	_STRUCT_OPMASK_REG	fpu_k2;			/* K2 */
	_STRUCT_OPMASK_REG	fpu_k3;			/* K3 */
	_STRUCT_OPMASK_REG	fpu_k4;			/* K4 */
	_STRUCT_OPMASK_REG	fpu_k5;			/* K5 */
	_STRUCT_OPMASK_REG	fpu_k6;			/* K6 */
	_STRUCT_OPMASK_REG	fpu_k7;			/* K7 */
	_STRUCT_YMM_REG		fpu_zmmh0;		/* ZMMH 0  */
	_STRUCT_YMM_REG		fpu_zmmh1;		/* ZMMH 1  */
	_STRUCT_YMM_REG		fpu_zmmh2;		/* ZMMH 2  */
	_STRUCT_YMM_REG		fpu_zmmh3;		/* ZMMH 3  */
	_STRUCT_YMM_REG		fpu_zmmh4;		/* ZMMH 4  */
	_STRUCT_YMM_REG		fpu_zmmh5;		/* ZMMH 5  */
	_STRUCT_YMM_REG		fpu_zmmh6;		/* ZMMH 6  */
	_STRUCT_YMM_REG		fpu_zmmh7;		/* ZMMH 7  */
};

#endif /* !__DARWIN_UNIX03 */
# 572 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 574 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_EXCEPTION_STATE32	struct __darwin_i386_exception_state
_STRUCT_X86_EXCEPTION_STATE32
{
	__uint16_t	__trapno;
	__uint16_t	__cpu;
	__uint32_t	__err;
	__uint32_t	__faultvaddr;
};
#else /* !__DARWIN_UNIX03 */
# 583 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_EXCEPTION_STATE32	struct i386_exception_state
_STRUCT_X86_EXCEPTION_STATE32
{
	__uint16_t	trapno;
	__uint16_t	cpu;
	__uint32_t	err;
	__uint32_t	faultvaddr;
};
#endif /* !__DARWIN_UNIX03 */
# 592 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 594 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_DEBUG_STATE32	struct __darwin_x86_debug_state32
_STRUCT_X86_DEBUG_STATE32
{
	unsigned int	__dr0;
	unsigned int	__dr1;
	unsigned int	__dr2;
	unsigned int	__dr3;
	unsigned int	__dr4;
	unsigned int	__dr5;
	unsigned int	__dr6;
	unsigned int	__dr7;
};
#else /* !__DARWIN_UNIX03 */
# 607 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_DEBUG_STATE32	struct x86_debug_state32
_STRUCT_X86_DEBUG_STATE32
{
	unsigned int	dr0;
	unsigned int	dr1;
	unsigned int	dr2;
	unsigned int	dr3;
	unsigned int	dr4;
	unsigned int	dr5;
	unsigned int	dr6;
	unsigned int	dr7;
};
#endif /* !__DARWIN_UNIX03 */
# 620 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

/*
 * 64 bit versions of the above
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 626 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define	_STRUCT_X86_THREAD_STATE64	struct __darwin_x86_thread_state64
_STRUCT_X86_THREAD_STATE64
{
	__uint64_t	__rax;
	__uint64_t	__rbx;
	__uint64_t	__rcx;
	__uint64_t	__rdx;
	__uint64_t	__rdi;
	__uint64_t	__rsi;
	__uint64_t	__rbp;
	__uint64_t	__rsp;
	__uint64_t	__r8;
	__uint64_t	__r9;
	__uint64_t	__r10;
	__uint64_t	__r11;
	__uint64_t	__r12;
	__uint64_t	__r13;
	__uint64_t	__r14;
	__uint64_t	__r15;
	__uint64_t	__rip;
	__uint64_t	__rflags;
	__uint64_t	__cs;
	__uint64_t	__fs;
	__uint64_t	__gs;
};
#else /* !__DARWIN_UNIX03 */
# 652 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define	_STRUCT_X86_THREAD_STATE64	struct x86_thread_state64
_STRUCT_X86_THREAD_STATE64
{
	__uint64_t	rax;
	__uint64_t	rbx;
	__uint64_t	rcx;
	__uint64_t	rdx;
	__uint64_t	rdi;
	__uint64_t	rsi;
	__uint64_t	rbp;
	__uint64_t	rsp;
	__uint64_t	r8;
	__uint64_t	r9;
	__uint64_t	r10;
	__uint64_t	r11;
	__uint64_t	r12;
	__uint64_t	r13;
	__uint64_t	r14;
	__uint64_t	r15;
	__uint64_t	rip;
	__uint64_t	rflags;
	__uint64_t	cs;
	__uint64_t	fs;
	__uint64_t	gs;
};
#endif /* !__DARWIN_UNIX03 */
# 678 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4


#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 681 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define	_STRUCT_X86_FLOAT_STATE64	struct __darwin_x86_float_state64
_STRUCT_X86_FLOAT_STATE64
{
	int 			__fpu_reserved[2];
	_STRUCT_FP_CONTROL	__fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	__fpu_fsw;		/* x87 FPU status word */
	__uint8_t		__fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		__fpu_rsrv1;		/* reserved */ 
	__uint16_t		__fpu_fop;		/* x87 FPU Opcode */

	/* x87 FPU Instruction Pointer */
	__uint32_t		__fpu_ip;		/* offset */
	__uint16_t		__fpu_cs;		/* Selector */

	__uint16_t		__fpu_rsrv2;		/* reserved */

	/* x87 FPU Instruction Operand(Data) Pointer */
	__uint32_t		__fpu_dp;		/* offset */
	__uint16_t		__fpu_ds;		/* Selector */

	__uint16_t		__fpu_rsrv3;		/* reserved */
	__uint32_t		__fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		__fpu_mxcsrmask;	/* MXCSR mask */
	_STRUCT_MMST_REG	__fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	__fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	__fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	__fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	__fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	__fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	__fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	__fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		__fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		__fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		__fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		__fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		__fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		__fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		__fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		__fpu_xmm7;		/* XMM 7  */
	_STRUCT_XMM_REG		__fpu_xmm8;		/* XMM 8  */
	_STRUCT_XMM_REG		__fpu_xmm9;		/* XMM 9  */
	_STRUCT_XMM_REG		__fpu_xmm10;		/* XMM 10  */
	_STRUCT_XMM_REG		__fpu_xmm11;		/* XMM 11 */
	_STRUCT_XMM_REG		__fpu_xmm12;		/* XMM 12  */
	_STRUCT_XMM_REG		__fpu_xmm13;		/* XMM 13  */
	_STRUCT_XMM_REG		__fpu_xmm14;		/* XMM 14  */
	_STRUCT_XMM_REG		__fpu_xmm15;		/* XMM 15  */
	char			__fpu_rsrv4[6*16];	/* reserved */
	int 			__fpu_reserved1;
};

#define	_STRUCT_X86_AVX_STATE64	struct __darwin_x86_avx_state64
_STRUCT_X86_AVX_STATE64
{
	int 			__fpu_reserved[2];
	_STRUCT_FP_CONTROL	__fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	__fpu_fsw;		/* x87 FPU status word */
	__uint8_t		__fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		__fpu_rsrv1;		/* reserved */ 
	__uint16_t		__fpu_fop;		/* x87 FPU Opcode */

	/* x87 FPU Instruction Pointer */
	__uint32_t		__fpu_ip;		/* offset */
	__uint16_t		__fpu_cs;		/* Selector */

	__uint16_t		__fpu_rsrv2;		/* reserved */

	/* x87 FPU Instruction Operand(Data) Pointer */
	__uint32_t		__fpu_dp;		/* offset */
	__uint16_t		__fpu_ds;		/* Selector */

	__uint16_t		__fpu_rsrv3;		/* reserved */
	__uint32_t		__fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		__fpu_mxcsrmask;	/* MXCSR mask */
	_STRUCT_MMST_REG	__fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	__fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	__fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	__fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	__fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	__fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	__fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	__fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		__fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		__fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		__fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		__fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		__fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		__fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		__fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		__fpu_xmm7;		/* XMM 7  */
	_STRUCT_XMM_REG		__fpu_xmm8;		/* XMM 8  */
	_STRUCT_XMM_REG		__fpu_xmm9;		/* XMM 9  */
	_STRUCT_XMM_REG		__fpu_xmm10;		/* XMM 10  */
	_STRUCT_XMM_REG		__fpu_xmm11;		/* XMM 11 */
	_STRUCT_XMM_REG		__fpu_xmm12;		/* XMM 12  */
	_STRUCT_XMM_REG		__fpu_xmm13;		/* XMM 13  */
	_STRUCT_XMM_REG		__fpu_xmm14;		/* XMM 14  */
	_STRUCT_XMM_REG		__fpu_xmm15;		/* XMM 15  */
	char			__fpu_rsrv4[6*16];	/* reserved */
	int 			__fpu_reserved1;
	char			__avx_reserved1[64];
	_STRUCT_XMM_REG		__fpu_ymmh0;		/* YMMH 0  */
	_STRUCT_XMM_REG		__fpu_ymmh1;		/* YMMH 1  */
	_STRUCT_XMM_REG		__fpu_ymmh2;		/* YMMH 2  */
	_STRUCT_XMM_REG		__fpu_ymmh3;		/* YMMH 3  */
	_STRUCT_XMM_REG		__fpu_ymmh4;		/* YMMH 4  */
	_STRUCT_XMM_REG		__fpu_ymmh5;		/* YMMH 5  */
	_STRUCT_XMM_REG		__fpu_ymmh6;		/* YMMH 6  */
	_STRUCT_XMM_REG		__fpu_ymmh7;		/* YMMH 7  */
	_STRUCT_XMM_REG		__fpu_ymmh8;		/* YMMH 8  */
	_STRUCT_XMM_REG		__fpu_ymmh9;		/* YMMH 9  */
	_STRUCT_XMM_REG		__fpu_ymmh10;		/* YMMH 10  */
	_STRUCT_XMM_REG		__fpu_ymmh11;		/* YMMH 11  */
	_STRUCT_XMM_REG		__fpu_ymmh12;		/* YMMH 12  */
	_STRUCT_XMM_REG		__fpu_ymmh13;		/* YMMH 13  */
	_STRUCT_XMM_REG		__fpu_ymmh14;		/* YMMH 14  */
	_STRUCT_XMM_REG		__fpu_ymmh15;		/* YMMH 15  */
};

#define	_STRUCT_X86_AVX512_STATE64	struct __darwin_x86_avx512_state64
_STRUCT_X86_AVX512_STATE64
{
	int 			__fpu_reserved[2];
	_STRUCT_FP_CONTROL	__fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	__fpu_fsw;		/* x87 FPU status word */
	__uint8_t		__fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		__fpu_rsrv1;		/* reserved */ 
	__uint16_t		__fpu_fop;		/* x87 FPU Opcode */

	/* x87 FPU Instruction Pointer */
	__uint32_t		__fpu_ip;		/* offset */
	__uint16_t		__fpu_cs;		/* Selector */

	__uint16_t		__fpu_rsrv2;		/* reserved */

	/* x87 FPU Instruction Operand(Data) Pointer */
	__uint32_t		__fpu_dp;		/* offset */
	__uint16_t		__fpu_ds;		/* Selector */

	__uint16_t		__fpu_rsrv3;		/* reserved */
	__uint32_t		__fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		__fpu_mxcsrmask;	/* MXCSR mask */
	_STRUCT_MMST_REG	__fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	__fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	__fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	__fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	__fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	__fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	__fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	__fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		__fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		__fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		__fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		__fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		__fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		__fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		__fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		__fpu_xmm7;		/* XMM 7  */
	_STRUCT_XMM_REG		__fpu_xmm8;		/* XMM 8  */
	_STRUCT_XMM_REG		__fpu_xmm9;		/* XMM 9  */
	_STRUCT_XMM_REG		__fpu_xmm10;		/* XMM 10  */
	_STRUCT_XMM_REG		__fpu_xmm11;		/* XMM 11 */
	_STRUCT_XMM_REG		__fpu_xmm12;		/* XMM 12  */
	_STRUCT_XMM_REG		__fpu_xmm13;		/* XMM 13  */
	_STRUCT_XMM_REG		__fpu_xmm14;		/* XMM 14  */
	_STRUCT_XMM_REG		__fpu_xmm15;		/* XMM 15  */
	char			__fpu_rsrv4[6*16];	/* reserved */
	int 			__fpu_reserved1;
	char			__avx_reserved1[64];
	_STRUCT_XMM_REG		__fpu_ymmh0;		/* YMMH 0  */
	_STRUCT_XMM_REG		__fpu_ymmh1;		/* YMMH 1  */
	_STRUCT_XMM_REG		__fpu_ymmh2;		/* YMMH 2  */
	_STRUCT_XMM_REG		__fpu_ymmh3;		/* YMMH 3  */
	_STRUCT_XMM_REG		__fpu_ymmh4;		/* YMMH 4  */
	_STRUCT_XMM_REG		__fpu_ymmh5;		/* YMMH 5  */
	_STRUCT_XMM_REG		__fpu_ymmh6;		/* YMMH 6  */
	_STRUCT_XMM_REG		__fpu_ymmh7;		/* YMMH 7  */
	_STRUCT_XMM_REG		__fpu_ymmh8;		/* YMMH 8  */
	_STRUCT_XMM_REG		__fpu_ymmh9;		/* YMMH 9  */
	_STRUCT_XMM_REG		__fpu_ymmh10;		/* YMMH 10  */
	_STRUCT_XMM_REG		__fpu_ymmh11;		/* YMMH 11  */
	_STRUCT_XMM_REG		__fpu_ymmh12;		/* YMMH 12  */
	_STRUCT_XMM_REG		__fpu_ymmh13;		/* YMMH 13  */
	_STRUCT_XMM_REG		__fpu_ymmh14;		/* YMMH 14  */
	_STRUCT_XMM_REG		__fpu_ymmh15;		/* YMMH 15  */
	_STRUCT_OPMASK_REG	__fpu_k0;		/* K0 */
	_STRUCT_OPMASK_REG	__fpu_k1;		/* K1 */
	_STRUCT_OPMASK_REG	__fpu_k2;		/* K2 */
	_STRUCT_OPMASK_REG	__fpu_k3;		/* K3 */
	_STRUCT_OPMASK_REG	__fpu_k4;		/* K4 */
	_STRUCT_OPMASK_REG	__fpu_k5;		/* K5 */
	_STRUCT_OPMASK_REG	__fpu_k6;		/* K6 */
	_STRUCT_OPMASK_REG	__fpu_k7;		/* K7 */
	_STRUCT_YMM_REG		__fpu_zmmh0;		/* ZMMH 0  */
	_STRUCT_YMM_REG		__fpu_zmmh1;		/* ZMMH 1  */
	_STRUCT_YMM_REG		__fpu_zmmh2;		/* ZMMH 2  */
	_STRUCT_YMM_REG		__fpu_zmmh3;		/* ZMMH 3  */
	_STRUCT_YMM_REG		__fpu_zmmh4;		/* ZMMH 4  */
	_STRUCT_YMM_REG		__fpu_zmmh5;		/* ZMMH 5  */
	_STRUCT_YMM_REG		__fpu_zmmh6;		/* ZMMH 6  */
	_STRUCT_YMM_REG		__fpu_zmmh7;		/* ZMMH 7  */
	_STRUCT_YMM_REG		__fpu_zmmh8;		/* ZMMH 8  */
	_STRUCT_YMM_REG		__fpu_zmmh9;		/* ZMMH 9  */
	_STRUCT_YMM_REG		__fpu_zmmh10;		/* ZMMH 10  */
	_STRUCT_YMM_REG		__fpu_zmmh11;		/* ZMMH 11  */
	_STRUCT_YMM_REG		__fpu_zmmh12;		/* ZMMH 12  */
	_STRUCT_YMM_REG		__fpu_zmmh13;		/* ZMMH 13  */
	_STRUCT_YMM_REG		__fpu_zmmh14;		/* ZMMH 14  */
	_STRUCT_YMM_REG		__fpu_zmmh15;		/* ZMMH 15  */
	_STRUCT_ZMM_REG		__fpu_zmm16;		/* ZMM 16  */
	_STRUCT_ZMM_REG		__fpu_zmm17;		/* ZMM 17  */
	_STRUCT_ZMM_REG		__fpu_zmm18;		/* ZMM 18  */
	_STRUCT_ZMM_REG		__fpu_zmm19;		/* ZMM 19  */
	_STRUCT_ZMM_REG		__fpu_zmm20;		/* ZMM 20  */
	_STRUCT_ZMM_REG		__fpu_zmm21;		/* ZMM 21  */
	_STRUCT_ZMM_REG		__fpu_zmm22;		/* ZMM 22  */
	_STRUCT_ZMM_REG		__fpu_zmm23;		/* ZMM 23  */
	_STRUCT_ZMM_REG		__fpu_zmm24;		/* ZMM 24  */
	_STRUCT_ZMM_REG		__fpu_zmm25;		/* ZMM 25  */
	_STRUCT_ZMM_REG		__fpu_zmm26;		/* ZMM 26  */
	_STRUCT_ZMM_REG		__fpu_zmm27;		/* ZMM 27  */
	_STRUCT_ZMM_REG		__fpu_zmm28;		/* ZMM 28  */
	_STRUCT_ZMM_REG		__fpu_zmm29;		/* ZMM 29  */
	_STRUCT_ZMM_REG		__fpu_zmm30;		/* ZMM 30  */
	_STRUCT_ZMM_REG		__fpu_zmm31;		/* ZMM 31  */
};

#else /* !__DARWIN_UNIX03 */
# 909 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define	_STRUCT_X86_FLOAT_STATE64	struct x86_float_state64
_STRUCT_X86_FLOAT_STATE64
{
	int 			fpu_reserved[2];
	_STRUCT_FP_CONTROL	fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	fpu_fsw;		/* x87 FPU status word */
	__uint8_t		fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		fpu_rsrv1;		/* reserved */ 
	__uint16_t		fpu_fop;		/* x87 FPU Opcode */

	/* x87 FPU Instruction Pointer */
	__uint32_t		fpu_ip;			/* offset */
	__uint16_t		fpu_cs;			/* Selector */

	__uint16_t		fpu_rsrv2;		/* reserved */

	/* x87 FPU Instruction Operand(Data) Pointer */
	__uint32_t		fpu_dp;			/* offset */
	__uint16_t		fpu_ds;			/* Selector */

	__uint16_t		fpu_rsrv3;		/* reserved */
	__uint32_t		fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		fpu_mxcsrmask;		/* MXCSR mask */
	_STRUCT_MMST_REG	fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		fpu_xmm7;		/* XMM 7  */
	_STRUCT_XMM_REG		fpu_xmm8;		/* XMM 8  */
	_STRUCT_XMM_REG		fpu_xmm9;		/* XMM 9  */
	_STRUCT_XMM_REG		fpu_xmm10;		/* XMM 10  */
	_STRUCT_XMM_REG		fpu_xmm11;		/* XMM 11 */
	_STRUCT_XMM_REG		fpu_xmm12;		/* XMM 12  */
	_STRUCT_XMM_REG		fpu_xmm13;		/* XMM 13  */
	_STRUCT_XMM_REG		fpu_xmm14;		/* XMM 14  */
	_STRUCT_XMM_REG		fpu_xmm15;		/* XMM 15  */
	char			fpu_rsrv4[6*16];	/* reserved */
	int 			fpu_reserved1;
};

#define	_STRUCT_X86_AVX_STATE64	struct x86_avx_state64
_STRUCT_X86_AVX_STATE64
{
	int 			fpu_reserved[2];
	_STRUCT_FP_CONTROL	fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	fpu_fsw;		/* x87 FPU status word */
	__uint8_t		fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		fpu_rsrv1;		/* reserved */ 
	__uint16_t		fpu_fop;		/* x87 FPU Opcode */

	/* x87 FPU Instruction Pointer */
	__uint32_t		fpu_ip;			/* offset */
	__uint16_t		fpu_cs;			/* Selector */

	__uint16_t		fpu_rsrv2;		/* reserved */

	/* x87 FPU Instruction Operand(Data) Pointer */
	__uint32_t		fpu_dp;			/* offset */
	__uint16_t		fpu_ds;			/* Selector */

	__uint16_t		fpu_rsrv3;		/* reserved */
	__uint32_t		fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		fpu_mxcsrmask;		/* MXCSR mask */
	_STRUCT_MMST_REG	fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		fpu_xmm7;		/* XMM 7  */
	_STRUCT_XMM_REG		fpu_xmm8;		/* XMM 8  */
	_STRUCT_XMM_REG		fpu_xmm9;		/* XMM 9  */
	_STRUCT_XMM_REG		fpu_xmm10;		/* XMM 10  */
	_STRUCT_XMM_REG		fpu_xmm11;		/* XMM 11 */
	_STRUCT_XMM_REG		fpu_xmm12;		/* XMM 12  */
	_STRUCT_XMM_REG		fpu_xmm13;		/* XMM 13  */
	_STRUCT_XMM_REG		fpu_xmm14;		/* XMM 14  */
	_STRUCT_XMM_REG		fpu_xmm15;		/* XMM 15  */
	char			fpu_rsrv4[6*16];	/* reserved */
	int 			fpu_reserved1;
	char			avx_reserved1[64];
	_STRUCT_XMM_REG		fpu_ymmh0;		/* YMMH 0  */
	_STRUCT_XMM_REG		fpu_ymmh1;		/* YMMH 1  */
	_STRUCT_XMM_REG		fpu_ymmh2;		/* YMMH 2  */
	_STRUCT_XMM_REG		fpu_ymmh3;		/* YMMH 3  */
	_STRUCT_XMM_REG		fpu_ymmh4;		/* YMMH 4  */
	_STRUCT_XMM_REG		fpu_ymmh5;		/* YMMH 5  */
	_STRUCT_XMM_REG		fpu_ymmh6;		/* YMMH 6  */
	_STRUCT_XMM_REG		fpu_ymmh7;		/* YMMH 7  */
	_STRUCT_XMM_REG		fpu_ymmh8;		/* YMMH 8  */
	_STRUCT_XMM_REG		fpu_ymmh9;		/* YMMH 9  */
	_STRUCT_XMM_REG		fpu_ymmh10;		/* YMMH 10  */
	_STRUCT_XMM_REG		fpu_ymmh11;		/* YMMH 11  */
	_STRUCT_XMM_REG		fpu_ymmh12;		/* YMMH 12  */
	_STRUCT_XMM_REG		fpu_ymmh13;		/* YMMH 13  */
	_STRUCT_XMM_REG		fpu_ymmh14;		/* YMMH 14  */
	_STRUCT_XMM_REG		fpu_ymmh15;		/* YMMH 15  */
};

#define	_STRUCT_X86_AVX512_STATE64	struct x86_avx512_state64
_STRUCT_X86_AVX512_STATE64
{
	int 			fpu_reserved[2];
	_STRUCT_FP_CONTROL	fpu_fcw;		/* x87 FPU control word */
	_STRUCT_FP_STATUS	fpu_fsw;		/* x87 FPU status word */
	__uint8_t		fpu_ftw;		/* x87 FPU tag word */
	__uint8_t		fpu_rsrv1;		/* reserved */ 
	__uint16_t		fpu_fop;		/* x87 FPU Opcode */

	/* x87 FPU Instruction Pointer */
	__uint32_t		fpu_ip;		/* offset */
	__uint16_t		fpu_cs;		/* Selector */

	__uint16_t		fpu_rsrv2;		/* reserved */

	/* x87 FPU Instruction Operand(Data) Pointer */
	__uint32_t		fpu_dp;		/* offset */
	__uint16_t		fpu_ds;		/* Selector */

	__uint16_t		fpu_rsrv3;		/* reserved */
	__uint32_t		fpu_mxcsr;		/* MXCSR Register state */
	__uint32_t		fpu_mxcsrmask;	/* MXCSR mask */
	_STRUCT_MMST_REG	fpu_stmm0;		/* ST0/MM0   */
	_STRUCT_MMST_REG	fpu_stmm1;		/* ST1/MM1  */
	_STRUCT_MMST_REG	fpu_stmm2;		/* ST2/MM2  */
	_STRUCT_MMST_REG	fpu_stmm3;		/* ST3/MM3  */
	_STRUCT_MMST_REG	fpu_stmm4;		/* ST4/MM4  */
	_STRUCT_MMST_REG	fpu_stmm5;		/* ST5/MM5  */
	_STRUCT_MMST_REG	fpu_stmm6;		/* ST6/MM6  */
	_STRUCT_MMST_REG	fpu_stmm7;		/* ST7/MM7  */
	_STRUCT_XMM_REG		fpu_xmm0;		/* XMM 0  */
	_STRUCT_XMM_REG		fpu_xmm1;		/* XMM 1  */
	_STRUCT_XMM_REG		fpu_xmm2;		/* XMM 2  */
	_STRUCT_XMM_REG		fpu_xmm3;		/* XMM 3  */
	_STRUCT_XMM_REG		fpu_xmm4;		/* XMM 4  */
	_STRUCT_XMM_REG		fpu_xmm5;		/* XMM 5  */
	_STRUCT_XMM_REG		fpu_xmm6;		/* XMM 6  */
	_STRUCT_XMM_REG		fpu_xmm7;		/* XMM 7  */
	_STRUCT_XMM_REG		fpu_xmm8;		/* XMM 8  */
	_STRUCT_XMM_REG		fpu_xmm9;		/* XMM 9  */
	_STRUCT_XMM_REG		fpu_xmm10;		/* XMM 10  */
	_STRUCT_XMM_REG		fpu_xmm11;		/* XMM 11 */
	_STRUCT_XMM_REG		fpu_xmm12;		/* XMM 12  */
	_STRUCT_XMM_REG		fpu_xmm13;		/* XMM 13  */
	_STRUCT_XMM_REG		fpu_xmm14;		/* XMM 14  */
	_STRUCT_XMM_REG		fpu_xmm15;		/* XMM 15  */
	char			fpu_rsrv4[6*16];	/* reserved */
	int 			fpu_reserved1;
	char			avx_reserved1[64];
	_STRUCT_XMM_REG		fpu_ymmh0;		/* YMMH 0  */
	_STRUCT_XMM_REG		fpu_ymmh1;		/* YMMH 1  */
	_STRUCT_XMM_REG		fpu_ymmh2;		/* YMMH 2  */
	_STRUCT_XMM_REG		fpu_ymmh3;		/* YMMH 3  */
	_STRUCT_XMM_REG		fpu_ymmh4;		/* YMMH 4  */
	_STRUCT_XMM_REG		fpu_ymmh5;		/* YMMH 5  */
	_STRUCT_XMM_REG		fpu_ymmh6;		/* YMMH 6  */
	_STRUCT_XMM_REG		fpu_ymmh7;		/* YMMH 7  */
	_STRUCT_XMM_REG		fpu_ymmh8;		/* YMMH 8  */
	_STRUCT_XMM_REG		fpu_ymmh9;		/* YMMH 9  */
	_STRUCT_XMM_REG		fpu_ymmh10;		/* YMMH 10  */
	_STRUCT_XMM_REG		fpu_ymmh11;		/* YMMH 11  */
	_STRUCT_XMM_REG		fpu_ymmh12;		/* YMMH 12  */
	_STRUCT_XMM_REG		fpu_ymmh13;		/* YMMH 13  */
	_STRUCT_XMM_REG		fpu_ymmh14;		/* YMMH 14  */
	_STRUCT_XMM_REG		fpu_ymmh15;		/* YMMH 15  */
	_STRUCT_OPMASK_REG	fpu_k0;			/* K0 */
	_STRUCT_OPMASK_REG	fpu_k1;			/* K1 */
	_STRUCT_OPMASK_REG	fpu_k2;			/* K2 */
	_STRUCT_OPMASK_REG	fpu_k3;			/* K3 */
	_STRUCT_OPMASK_REG	fpu_k4;			/* K4 */
	_STRUCT_OPMASK_REG	fpu_k5;			/* K5 */
	_STRUCT_OPMASK_REG	fpu_k6;			/* K6 */
	_STRUCT_OPMASK_REG	fpu_k7;			/* K7 */
	_STRUCT_YMM_REG		fpu_zmmh0;		/* ZMMH 0  */
	_STRUCT_YMM_REG		fpu_zmmh1;		/* ZMMH 1  */
	_STRUCT_YMM_REG		fpu_zmmh2;		/* ZMMH 2  */
	_STRUCT_YMM_REG		fpu_zmmh3;		/* ZMMH 3  */
	_STRUCT_YMM_REG		fpu_zmmh4;		/* ZMMH 4  */
	_STRUCT_YMM_REG		fpu_zmmh5;		/* ZMMH 5  */
	_STRUCT_YMM_REG		fpu_zmmh6;		/* ZMMH 6  */
	_STRUCT_YMM_REG		fpu_zmmh7;		/* ZMMH 7  */
	_STRUCT_YMM_REG		fpu_zmmh8;		/* ZMMH 8  */
	_STRUCT_YMM_REG		fpu_zmmh9;		/* ZMMH 9  */
	_STRUCT_YMM_REG		fpu_zmmh10;		/* ZMMH 10  */
	_STRUCT_YMM_REG		fpu_zmmh11;		/* ZMMH 11  */
	_STRUCT_YMM_REG		fpu_zmmh12;		/* ZMMH 12  */
	_STRUCT_YMM_REG		fpu_zmmh13;		/* ZMMH 13  */
	_STRUCT_YMM_REG		fpu_zmmh14;		/* ZMMH 14  */
	_STRUCT_YMM_REG		fpu_zmmh15;		/* ZMMH 15  */
	_STRUCT_ZMM_REG		fpu_zmm16;		/* ZMM 16  */
	_STRUCT_ZMM_REG		fpu_zmm17;		/* ZMM 17  */
	_STRUCT_ZMM_REG		fpu_zmm18;		/* ZMM 18  */
	_STRUCT_ZMM_REG		fpu_zmm19;		/* ZMM 19  */
	_STRUCT_ZMM_REG		fpu_zmm20;		/* ZMM 20  */
	_STRUCT_ZMM_REG		fpu_zmm21;		/* ZMM 21  */
	_STRUCT_ZMM_REG		fpu_zmm22;		/* ZMM 22  */
	_STRUCT_ZMM_REG		fpu_zmm23;		/* ZMM 23  */
	_STRUCT_ZMM_REG		fpu_zmm24;		/* ZMM 24  */
	_STRUCT_ZMM_REG		fpu_zmm25;		/* ZMM 25  */
	_STRUCT_ZMM_REG		fpu_zmm26;		/* ZMM 26  */
	_STRUCT_ZMM_REG		fpu_zmm27;		/* ZMM 27  */
	_STRUCT_ZMM_REG		fpu_zmm28;		/* ZMM 28  */
	_STRUCT_ZMM_REG		fpu_zmm29;		/* ZMM 29  */
	_STRUCT_ZMM_REG		fpu_zmm30;		/* ZMM 30  */
	_STRUCT_ZMM_REG		fpu_zmm31;		/* ZMM 31  */
};

#endif /* !__DARWIN_UNIX03 */
# 1137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_EXCEPTION_STATE64	struct __darwin_x86_exception_state64
_STRUCT_X86_EXCEPTION_STATE64
{
    __uint16_t	__trapno;
    __uint16_t	__cpu;
    __uint32_t	__err;
    __uint64_t	__faultvaddr;
};
#else /* !__DARWIN_UNIX03 */
# 1148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_EXCEPTION_STATE64	struct x86_exception_state64
_STRUCT_X86_EXCEPTION_STATE64
{
    __uint16_t	trapno;
    __uint16_t	cpu;
    __uint32_t	err;
    __uint64_t	faultvaddr;
};
#endif /* !__DARWIN_UNIX03 */
# 1157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_DEBUG_STATE64	struct __darwin_x86_debug_state64
_STRUCT_X86_DEBUG_STATE64
{
	__uint64_t	__dr0;
	__uint64_t	__dr1;
	__uint64_t	__dr2;
	__uint64_t	__dr3;
	__uint64_t	__dr4;
	__uint64_t	__dr5;
	__uint64_t	__dr6;
	__uint64_t	__dr7;
};
#else /* !__DARWIN_UNIX03 */
# 1172 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_DEBUG_STATE64	struct x86_debug_state64
_STRUCT_X86_DEBUG_STATE64
{
	__uint64_t	dr0;
	__uint64_t	dr1;
	__uint64_t	dr2;
	__uint64_t	dr3;
	__uint64_t	dr4;
	__uint64_t	dr5;
	__uint64_t	dr6;
	__uint64_t	dr7;
};
#endif /* !__DARWIN_UNIX03 */
# 1185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_CPMU_STATE64	struct __darwin_x86_cpmu_state64
_STRUCT_X86_CPMU_STATE64
{
	__uint64_t __ctrs[16];
};
#else /* __DARWIN_UNIX03 */
# 1193 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
#define _STRUCT_X86_CPMU_STATE64	struct x86_cpmu_state64
_STRUCT_X86_CPMU_STATE64
{
	__uint64_t ctrs[16];
};
#endif /* !__DARWIN_UNIX03 */
# 1199 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4

#endif /* _MACH_I386__STRUCTS_H_ */
# 1201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/i386/_structs.h" 3 4
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/machine/_structs.h" 2 3 4
#else
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/machine/_structs.h" 3 4
#error architecture not supported
#endif
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/machine/_structs.h" 3 4

#endif /* _MACH_MACHINE__STRUCTS_H_ */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/mach/machine/_structs.h" 3 4
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 2 3 4

#ifndef _STRUCT_MCONTEXT32
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 38 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#define _STRUCT_MCONTEXT32      struct __darwin_mcontext32
_STRUCT_MCONTEXT32
{
	_STRUCT_X86_EXCEPTION_STATE32   __es;
	_STRUCT_X86_THREAD_STATE32      __ss;
	_STRUCT_X86_FLOAT_STATE32       __fs;
};

#define _STRUCT_MCONTEXT_AVX32  struct __darwin_mcontext_avx32
_STRUCT_MCONTEXT_AVX32
{
	_STRUCT_X86_EXCEPTION_STATE32   __es;
	_STRUCT_X86_THREAD_STATE32      __ss;
	_STRUCT_X86_AVX_STATE32         __fs;
};

#if 0 /* disabled by -frewrite-includes */
#if defined(_STRUCT_X86_AVX512_STATE32)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 55 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#define _STRUCT_MCONTEXT_AVX512_32      struct __darwin_mcontext_avx512_32
_STRUCT_MCONTEXT_AVX512_32
{
	_STRUCT_X86_EXCEPTION_STATE32   __es;
	_STRUCT_X86_THREAD_STATE32      __ss;
	_STRUCT_X86_AVX512_STATE32      __fs;
};
#endif /* _STRUCT_X86_AVX512_STATE32 */
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4

#else /* !__DARWIN_UNIX03 */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#define _STRUCT_MCONTEXT32      struct mcontext32
_STRUCT_MCONTEXT32
{
	_STRUCT_X86_EXCEPTION_STATE32   es;
	_STRUCT_X86_THREAD_STATE32      ss;
	_STRUCT_X86_FLOAT_STATE32       fs;
};

#define _STRUCT_MCONTEXT_AVX32  struct mcontext_avx32
_STRUCT_MCONTEXT_AVX32
{
	_STRUCT_X86_EXCEPTION_STATE32   es;
	_STRUCT_X86_THREAD_STATE32      ss;
	_STRUCT_X86_AVX_STATE32         fs;
};

#if 0 /* disabled by -frewrite-includes */
#if defined(_STRUCT_X86_AVX512_STATE32)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 82 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#define _STRUCT_MCONTEXT_AVX512_32      struct mcontext_avx512_32
_STRUCT_MCONTEXT_AVX512_32
{
	_STRUCT_X86_EXCEPTION_STATE32   es;
	_STRUCT_X86_THREAD_STATE32      ss;
	_STRUCT_X86_AVX512_STATE32      fs;
};
#endif /* _STRUCT_X86_AVX512_STATE32 */
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4

#endif /* __DARWIN_UNIX03 */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#endif /* _STRUCT_MCONTEXT32 */
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4

#ifndef _STRUCT_MCONTEXT64
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 96 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#define _STRUCT_MCONTEXT64      struct __darwin_mcontext64
_STRUCT_MCONTEXT64
{
	_STRUCT_X86_EXCEPTION_STATE64   __es;
	_STRUCT_X86_THREAD_STATE64      __ss;
	_STRUCT_X86_FLOAT_STATE64       __fs;
};

#define _STRUCT_MCONTEXT_AVX64  struct __darwin_mcontext_avx64
_STRUCT_MCONTEXT_AVX64
{
	_STRUCT_X86_EXCEPTION_STATE64   __es;
	_STRUCT_X86_THREAD_STATE64      __ss;
	_STRUCT_X86_AVX_STATE64         __fs;
};

#if 0 /* disabled by -frewrite-includes */
#if defined(_STRUCT_X86_AVX512_STATE64)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#define _STRUCT_MCONTEXT_AVX512_64      struct __darwin_mcontext_avx512_64
_STRUCT_MCONTEXT_AVX512_64
{
	_STRUCT_X86_EXCEPTION_STATE64   __es;
	_STRUCT_X86_THREAD_STATE64      __ss;
	_STRUCT_X86_AVX512_STATE64      __fs;
};
#endif /* _STRUCT_X86_AVX512_STATE64 */
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4

#else /* !__DARWIN_UNIX03 */
# 123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#define _STRUCT_MCONTEXT64      struct mcontext64
_STRUCT_MCONTEXT64
{
	_STRUCT_X86_EXCEPTION_STATE64   es;
	_STRUCT_X86_THREAD_STATE64      ss;
	_STRUCT_X86_FLOAT_STATE64       fs;
};

#define _STRUCT_MCONTEXT_AVX64  struct mcontext_avx64
_STRUCT_MCONTEXT_AVX64
{
	_STRUCT_X86_EXCEPTION_STATE64   es;
	_STRUCT_X86_THREAD_STATE64      ss;
	_STRUCT_X86_AVX_STATE64         fs;
};

#if 0 /* disabled by -frewrite-includes */
#if defined(_STRUCT_X86_AVX512_STATE64)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 140 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#define _STRUCT_MCONTEXT_AVX512_64      struct mcontext_avx512_64
_STRUCT_MCONTEXT_AVX512_64
{
	_STRUCT_X86_EXCEPTION_STATE64   es;
	_STRUCT_X86_THREAD_STATE64      ss;
	_STRUCT_X86_AVX512_STATE64      fs;
};
#endif /* _STRUCT_X86_AVX512_STATE64 */
# 148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4

#endif /* __DARWIN_UNIX03 */
# 150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#endif /* _STRUCT_MCONTEXT64 */
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4


#ifndef _MCONTEXT_T
#define _MCONTEXT_T
#if 0 /* disabled by -frewrite-includes */
#if defined(__LP64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
typedef _STRUCT_MCONTEXT64      *mcontext_t;
#define _STRUCT_MCONTEXT _STRUCT_MCONTEXT64
#else
# 159 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
typedef _STRUCT_MCONTEXT32      *mcontext_t;
#define _STRUCT_MCONTEXT        _STRUCT_MCONTEXT32
#endif
# 162 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
#endif /* _MCONTEXT_T */
# 163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4

#endif /* __I386_MCONTEXT_H_ */
# 165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_mcontext.h" 3 4
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 2 3 4
#else
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
#error architecture not supported
#endif
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
# 147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_attr_t.h>
#endif /* expanded by -frewrite-includes */
# 148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_attr_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_ATTR_T 
#define _PTHREAD_ATTR_T 
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_attr_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_attr_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_attr_t.h" 3 4
typedef __darwin_pthread_attr_t pthread_attr_t;
#endif  /* _PTHREAD_ATTR_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_attr_t.h" 3 4
# 149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_sigaltstack.h>
#endif /* expanded by -frewrite-includes */
# 150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

/* Structure used in sigaltstack call. */
#ifndef _STRUCT_SIGALTSTACK

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h> /* __DARWIN_UNIX03 */
#endif /* expanded by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 3 4
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 3 4
#define _STRUCT_SIGALTSTACK     struct __darwin_sigaltstack
#else /* !__DARWIN_UNIX03 */
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 3 4
#define _STRUCT_SIGALTSTACK     struct sigaltstack
#endif /* __DARWIN_UNIX03 */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 3 4
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 3 4

_STRUCT_SIGALTSTACK
{
	void            *ss_sp;         /* signal stack base */
	__darwin_size_t ss_size;        /* signal stack length */
	int             ss_flags;       /* SA_DISABLE and/or SA_ONSTACK */
};
typedef _STRUCT_SIGALTSTACK     stack_t; /* [???] signal stack */

#endif /* _STRUCT_SIGALTSTACK */
# 51 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigaltstack.h" 3 4
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ucontext.h>
#endif /* expanded by -frewrite-includes */
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _STRUCT_UCONTEXT

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h> /* __DARWIN_UNIX03 */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
#define _STRUCT_UCONTEXT        struct __darwin_ucontext
#else /* !__DARWIN_UNIX03 */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
#define _STRUCT_UCONTEXT        struct ucontext
#endif /* __DARWIN_UNIX03 */
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 38 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_mcontext.h> /* _STRUCT_MCONTEXT */
#endif /* expanded by -frewrite-includes */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined (__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include "i386/_mcontext.h"
#endif /* expanded by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
#else
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
#error architecture not supported
#endif
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/_mcontext.h" 3 4
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_sigset_t */
#endif /* expanded by -frewrite-includes */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4

_STRUCT_UCONTEXT
{
	int                     uc_onstack;
	__darwin_sigset_t       uc_sigmask;     /* signal mask used by this context */
	_STRUCT_SIGALTSTACK     uc_stack;       /* stack used by this context */
	_STRUCT_UCONTEXT        *uc_link;       /* pointer to resuming context */
	__darwin_size_t         uc_mcsize;      /* size of the machine context passed in */
	_STRUCT_MCONTEXT        *uc_mcontext;   /* pointer to machine specific context */
#ifdef _XOPEN_SOURCE
	_STRUCT_MCONTEXT        __mcontext_data;
#endif /* _XOPEN_SOURCE */
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
};

/* user context */
typedef _STRUCT_UCONTEXT        ucontext_t;     /* [???] user context */

#endif /* _STRUCT_UCONTEXT */
# 59 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ucontext.h" 3 4
# 152 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_pid_t.h>
#endif /* expanded by -frewrite-includes */
# 153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_sigset_t.h>
#endif /* expanded by -frewrite-includes */
# 154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigset_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIGSET_T
#define _SIGSET_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_sigset_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigset_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigset_t.h" 3 4
typedef __darwin_sigset_t               sigset_t;
#endif  /* _SIGSET_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_sigset_t.h" 3 4
# 155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_uid_t.h>
#endif /* expanded by -frewrite-includes */
# 156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_uid_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _UID_T
#define _UID_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_uid_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_uid_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_uid_t.h" 3 4
typedef __darwin_uid_t        uid_t;
#endif  /* _UID_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_uid_t.h" 3 4
# 157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 2 3 4

union sigval {
	/* Members as suggested by Annex C of POSIX 1003.1b. */
	int     sival_int;
	void    *sival_ptr;
};

#define SIGEV_NONE      0       /* No async notification */
#define SIGEV_SIGNAL    1       /* aio - completion notification */
#define SIGEV_THREAD    3       /* [NOTIMP] [RTS] call notification function */

struct sigevent {
	int                             sigev_notify;                           /* Notification type */
	int                             sigev_signo;                            /* Signal number */
	union sigval    sigev_value;                            /* Signal value */
	void                    (*sigev_notify_function)(union sigval);   /* Notification function */
	pthread_attr_t  *sigev_notify_attributes;       /* Notification attributes */
};


typedef struct __siginfo {
	int     si_signo;               /* signal number */
	int     si_errno;               /* errno association */
	int     si_code;                /* signal code */
	pid_t   si_pid;                 /* sending process */
	uid_t   si_uid;                 /* sender's ruid */
	int     si_status;              /* exit value */
	void    *si_addr;               /* faulting instruction */
	union sigval si_value;          /* signal value */
	long    si_band;                /* band event for SIGPOLL */
	unsigned long   __pad[7];       /* Reserved for Future Use */
} siginfo_t;


/*
 * When the signal is SIGILL or SIGFPE, si_addr contains the address of
 * the faulting instruction.
 * When the signal is SIGSEGV or SIGBUS, si_addr contains the address of
 * the faulting memory reference. Although for x86 there are cases of SIGSEGV
 * for which si_addr cannot be determined and is NULL.
 * If the signal is SIGCHLD, the si_pid field will contain the child process ID,
 *  si_status contains the exit value or signal and
 *  si_uid contains the real user ID of the process that sent the signal.
 */

/* Values for si_code */

/* Codes for SIGILL */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define ILL_NOOP        0       /* if only I knew... */
#endif
# 208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define ILL_ILLOPC      1       /* [XSI] illegal opcode */
#define ILL_ILLTRP      2       /* [XSI] illegal trap */
#define ILL_PRVOPC      3       /* [XSI] privileged opcode */
#define ILL_ILLOPN      4       /* [XSI] illegal operand -NOTIMP */
#define ILL_ILLADR      5       /* [XSI] illegal addressing mode -NOTIMP */
#define ILL_PRVREG      6       /* [XSI] privileged register -NOTIMP */
#define ILL_COPROC      7       /* [XSI] coprocessor error -NOTIMP */
#define ILL_BADSTK      8       /* [XSI] internal stack error -NOTIMP */

/* Codes for SIGFPE */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define FPE_NOOP        0       /* if only I knew... */
#endif
# 221 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define FPE_FLTDIV      1       /* [XSI] floating point divide by zero */
#define FPE_FLTOVF      2       /* [XSI] floating point overflow */
#define FPE_FLTUND      3       /* [XSI] floating point underflow */
#define FPE_FLTRES      4       /* [XSI] floating point inexact result */
#define FPE_FLTINV      5       /* [XSI] invalid floating point operation */
#define FPE_FLTSUB      6       /* [XSI] subscript out of range -NOTIMP */
#define FPE_INTDIV      7       /* [XSI] integer divide by zero */
#define FPE_INTOVF      8       /* [XSI] integer overflow */

/* Codes for SIGSEGV */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 232 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SEGV_NOOP       0       /* if only I knew... */
#endif
# 234 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SEGV_MAPERR     1       /* [XSI] address not mapped to object */
#define SEGV_ACCERR     2       /* [XSI] invalid permission for mapped object */

/* Codes for SIGBUS */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 239 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define BUS_NOOP        0       /* if only I knew... */
#endif
# 241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define BUS_ADRALN      1       /* [XSI] Invalid address alignment */
#define BUS_ADRERR      2       /* [XSI] Nonexistent physical address -NOTIMP */
#define BUS_OBJERR      3       /* [XSI] Object-specific HW error - NOTIMP */

/* Codes for SIGTRAP */
#define TRAP_BRKPT      1       /* [XSI] Process breakpoint -NOTIMP */
#define TRAP_TRACE      2       /* [XSI] Process trace trap -NOTIMP */

/* Codes for SIGCHLD */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 251 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define CLD_NOOP        0       /* if only I knew... */
#endif
# 253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define CLD_EXITED      1       /* [XSI] child has exited */
#define CLD_KILLED      2       /* [XSI] terminated abnormally, no core file */
#define CLD_DUMPED      3       /* [XSI] terminated abnormally, core file */
#define CLD_TRAPPED     4       /* [XSI] traced child has trapped */
#define CLD_STOPPED     5       /* [XSI] child has stopped */
#define CLD_CONTINUED   6       /* [XSI] stopped child has continued */

/* Codes for SIGPOLL */
#define POLL_IN         1       /* [XSR] Data input available */
#define POLL_OUT        2       /* [XSR] Output buffers available */
#define POLL_MSG        3       /* [XSR] Input message available */
#define POLL_ERR        4       /* [XSR] I/O error */
#define POLL_PRI        5       /* [XSR] High priority input available */
#define POLL_HUP        6       /* [XSR] Device disconnected */

/* union for signal handlers */
union __sigaction_u {
	void    (*__sa_handler)(int);
	void    (*__sa_sigaction)(int, struct __siginfo *,
	    void *);
};

/* Signal vector template for Kernel user boundary */
struct  __sigaction {
	union __sigaction_u __sigaction_u;  /* signal handler */
	void    (*sa_tramp)(void *, int, int, siginfo_t *, void *);
	sigset_t sa_mask;               /* signal mask to apply */
	int     sa_flags;               /* see signal options below */
};

/*
 * Signal vector "template" used in sigaction call.
 */
struct  sigaction {
	union __sigaction_u __sigaction_u;  /* signal handler */
	sigset_t sa_mask;               /* signal mask to apply */
	int     sa_flags;               /* see signal options below */
};



/* if SA_SIGINFO is set, sa_sigaction is to be used instead of sa_handler. */
#define sa_handler      __sigaction_u.__sa_handler
#define sa_sigaction    __sigaction_u.__sa_sigaction

#define SA_ONSTACK      0x0001  /* take signal on signal stack */
#define SA_RESTART      0x0002  /* restart system on signal return */
#define SA_RESETHAND    0x0004  /* reset to SIG_DFL when taking signal */
#define SA_NOCLDSTOP    0x0008  /* do not generate SIGCHLD on child stop */
#define SA_NODEFER      0x0010  /* don't mask the signal we're delivering */
#define SA_NOCLDWAIT    0x0020  /* don't keep zombies around */
#define SA_SIGINFO      0x0040  /* signal handler with SA_SIGINFO args */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#define SA_USERTRAMP    0x0100  /* do not bounce off kernel's sigtramp */
/* This will provide 64bit register set in a 32bit user address space */
#define SA_64REGSET     0x0200  /* signal handler with SA_SIGINFO args with 64bit regs information */
#endif /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 310 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4

/* the following are the only bits we support from user space, the
 * rest are for kernel use only.
 */
#define SA_USERSPACE_MASK (SA_ONSTACK | SA_RESTART | SA_RESETHAND | SA_NOCLDSTOP | SA_NODEFER | SA_NOCLDWAIT | SA_SIGINFO)

/*
 * Flags for sigprocmask:
 */
#define SIG_BLOCK       1       /* block specified signal set */
#define SIG_UNBLOCK     2       /* unblock specified signal set */
#define SIG_SETMASK     3       /* set specified signal set */

/* POSIX 1003.1b required values. */
#define SI_USER         0x10001 /* [CX] signal from kill() */
#define SI_QUEUE        0x10002 /* [CX] signal from sigqueue() */
#define SI_TIMER        0x10003 /* [CX] timer expiration */
#define SI_ASYNCIO      0x10004 /* [CX] aio request completion */
#define SI_MESGQ        0x10005 /* [CX]	from message arrival on empty queue */

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 331 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
typedef void (*sig_t)(int);     /* type of signal function */
#endif
# 333 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4

/*
 * Structure used in sigaltstack call.
 */

#define SS_ONSTACK      0x0001  /* take signal on signal stack */
#define SS_DISABLE      0x0004  /* disable taking signals on alternate stack */
#define MINSIGSTKSZ     32768   /* (32K)minimum allowable stack */
#define SIGSTKSZ        131072  /* (128K)recommended stack size */

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 344 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
/*
 * 4.3 compatibility:
 * Signal vector "template" used in sigvec call.
 */
struct  sigvec {
	void    (*sv_handler)(int);     /* signal handler */
	int     sv_mask;                /* signal mask to apply */
	int     sv_flags;               /* see signal options below */
};

#define SV_ONSTACK      SA_ONSTACK
#define SV_INTERRUPT    SA_RESTART      /* same bit, opposite sense */
#define SV_RESETHAND    SA_RESETHAND
#define SV_NODEFER      SA_NODEFER
#define SV_NOCLDSTOP    SA_NOCLDSTOP
#define SV_SIGINFO      SA_SIGINFO

#define sv_onstack sv_flags     /* isn't compatibility wonderful! */
#endif /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 363 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4

/*
 * Structure used in sigstack call.
 */
struct  sigstack {
	char    *ss_sp;                 /* signal stack pointer */
	int     ss_onstack;             /* current status */
};

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 373 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
/*
 * Macro for converting signal number to a mask suitable for
 * sigblock().
 */
#define sigmask(m)      (1 << ((m)-1))


#define BADSIG          SIG_ERR

#endif  /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 383 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
#endif  /* !_ANSI_SOURCE */
# 384 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4

/*
 * For historical reasons; programs expect signal's return value to be
 * defined by <sys/signal.h>.
 */
__BEGIN_DECLS
    void(*signal(int, void (*)(int)))(int);
__END_DECLS
#endif  /* !_SYS_SIGNAL_H_ */
# 393 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/signal.h" 3 4
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/resource.h>       /* [XSI] for struct rusage */
#endif /* expanded by -frewrite-includes */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 1 3 4
/*
 * Copyright (c) 2000-2018 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/* Copyright (c) 1995 NeXT Computer, Inc. All Rights Reserved */
/*
 * Copyright (c) 1982, 1986, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)resource.h	8.2 (Berkeley) 1/4/94
 */

#ifndef _SYS_RESOURCE_H_
#define _SYS_RESOURCE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/appleapiopts.h>
#endif /* expanded by -frewrite-includes */
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <stdint.h>
#endif /* expanded by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 1 3 4
// -*- C++ -*-
//===---------------------------- stdint.h --------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STDINT_H
// AIX system headers need stdint.h to be re-enterable while _STD_TYPES_T
// is defined until an inclusion of it without _STD_TYPES_T occurs, in which
// case the header guard macro is defined.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_AIX) || !defined(_STD_TYPES_T)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3 4
#define _LIBCPP_STDINT_H
#endif // _STD_TYPES_T
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3 4

/*
    stdint.h synopsis

Macros:

    INT8_MIN
    INT16_MIN
    INT32_MIN
    INT64_MIN

    INT8_MAX
    INT16_MAX
    INT32_MAX
    INT64_MAX

    UINT8_MAX
    UINT16_MAX
    UINT32_MAX
    UINT64_MAX

    INT_LEAST8_MIN
    INT_LEAST16_MIN
    INT_LEAST32_MIN
    INT_LEAST64_MIN

    INT_LEAST8_MAX
    INT_LEAST16_MAX
    INT_LEAST32_MAX
    INT_LEAST64_MAX

    UINT_LEAST8_MAX
    UINT_LEAST16_MAX
    UINT_LEAST32_MAX
    UINT_LEAST64_MAX

    INT_FAST8_MIN
    INT_FAST16_MIN
    INT_FAST32_MIN
    INT_FAST64_MIN

    INT_FAST8_MAX
    INT_FAST16_MAX
    INT_FAST32_MAX
    INT_FAST64_MAX

    UINT_FAST8_MAX
    UINT_FAST16_MAX
    UINT_FAST32_MAX
    UINT_FAST64_MAX

    INTPTR_MIN
    INTPTR_MAX
    UINTPTR_MAX

    INTMAX_MIN
    INTMAX_MAX

    UINTMAX_MAX

    PTRDIFF_MIN
    PTRDIFF_MAX

    SIG_ATOMIC_MIN
    SIG_ATOMIC_MAX

    SIZE_MAX

    WCHAR_MIN
    WCHAR_MAX

    WINT_MIN
    WINT_MAX

    INT8_C(value)
    INT16_C(value)
    INT32_C(value)
    INT64_C(value)

    UINT8_C(value)
    UINT16_C(value)
    UINT32_C(value)
    UINT64_C(value)

    INTMAX_C(value)
    UINTMAX_C(value)

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3 4
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3
#endif
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3

/* C99 stdlib (e.g. glibc < 2.18) does not provide macros needed
   for C++11 unless __STDC_LIMIT_MACROS and __STDC_CONSTANT_MACROS
   are defined
*/
#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && !defined(__STDC_LIMIT_MACROS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 117 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3
#   define __STDC_LIMIT_MACROS
#endif
# 119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && !defined(__STDC_CONSTANT_MACROS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3
#   define __STDC_CONSTANT_MACROS
#endif
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdint.h>
#endif /* expanded by -frewrite-includes */
# 123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 1 3
/*===---- stdint.h - Standard header for sized integer types --------------===*\
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
\*===----------------------------------------------------------------------===*/

#ifndef __CLANG_STDINT_H
// AIX system headers need stdint.h to be re-enterable while _STD_TYPES_T
// is defined until an inclusion of it without _STD_TYPES_T occurs, in which
// case the header guard macro is defined.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_AIX) || !defined(_STD_TYPES_T) || !defined(__STDC_HOSTED__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#define __CLANG_STDINT_H
#endif
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

/* If we're hosted, fall back to the system's stdint.h, which might have
 * additional definitions.
 */
#if 0 /* disabled by -frewrite-includes */
#if __STDC_HOSTED__ && __has_include_next(<stdint.h>)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

// C99 7.18.3 Limits of other integer types
//
//  Footnote 219, 220: C++ implementations should define these macros only when
//  __STDC_LIMIT_MACROS is defined before <stdint.h> is included.
//
//  Footnote 222: C++ implementations should define these macros only when
//  __STDC_CONSTANT_MACROS is defined before <stdint.h> is included.
//
// C++11 [cstdint.syn]p2:
//
//  The macros defined by <cstdint> are provided unconditionally. In particular,
//  the symbols __STDC_LIMIT_MACROS and __STDC_CONSTANT_MACROS (mentioned in
//  footnotes 219, 220, and 222 in the C standard) play no role in C++.
//
// C11 removed the problematic footnotes.
//
// Work around this inconsistency by always defining those macros in C++ mode,
// so that a C library implementation which follows the C99 standard can be
// used in C++.
# ifdef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#  if !defined(__STDC_LIMIT_MACROS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#   define __STDC_LIMIT_MACROS
#   define __STDC_LIMIT_MACROS_DEFINED_BY_CLANG
#  endif
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#if 0 /* disabled by -frewrite-includes */
#  if !defined(__STDC_CONSTANT_MACROS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 47 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#   define __STDC_CONSTANT_MACROS
#   define __STDC_CONSTANT_MACROS_DEFINED_BY_CLANG
#  endif
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
# endif
# 51 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#if 0 /* expanded by -frewrite-includes */
# include_next <stdint.h>
#endif /* expanded by -frewrite-includes */
# 52 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 1 3 4
/*
 * Copyright (c) 2000-2010 Apple Inc.
 * All rights reserved.
 */

#ifndef _STDINT_H_
#define _STDINT_H_

#if 0 /* disabled by -frewrite-includes */
#if __LP64__
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 10 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define __WORDSIZE 64
#else
# 12 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define __WORDSIZE 32
#endif
# 14 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4

/* from ISO/IEC 988:1999 spec */

/* 7.18.1.1 Exact-width integer types */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_int8_t.h>
#endif /* expanded by -frewrite-includes */
# 18 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 19 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_int16_t.h>
#endif /* expanded by -frewrite-includes */
# 19 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 20 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_int32_t.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 21 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_int64_t.h>
#endif /* expanded by -frewrite-includes */
# 21 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 22 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <_types/_uint8_t.h>
#endif /* expanded by -frewrite-includes */
# 23 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uint8_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _UINT8_T
#define _UINT8_T
typedef unsigned char uint8_t;
#endif /* _UINT8_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uint8_t.h" 3 4
# 24 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types/_uint16_t.h>
#endif /* expanded by -frewrite-includes */
# 24 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uint16_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _UINT16_T
#define _UINT16_T
typedef unsigned short uint16_t;
#endif /* _UINT16_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uint16_t.h" 3 4
# 25 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types/_uint32_t.h>
#endif /* expanded by -frewrite-includes */
# 25 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uint32_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _UINT32_T
#define _UINT32_T
typedef unsigned int uint32_t;
#endif /* _UINT32_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uint32_t.h" 3 4
# 26 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types/_uint64_t.h>
#endif /* expanded by -frewrite-includes */
# 26 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uint64_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _UINT64_T
#define _UINT64_T
typedef unsigned long long uint64_t;
#endif /* _UINT64_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uint64_t.h" 3 4
# 27 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 2 3 4

/* 7.18.1.2 Minimum-width integer types */
typedef int8_t           int_least8_t;
typedef int16_t         int_least16_t;
typedef int32_t         int_least32_t;
typedef int64_t         int_least64_t;
typedef uint8_t         uint_least8_t;
typedef uint16_t       uint_least16_t;
typedef uint32_t       uint_least32_t;
typedef uint64_t       uint_least64_t;


/* 7.18.1.3 Fastest-width integer types */
typedef int8_t            int_fast8_t;
typedef int16_t          int_fast16_t;
typedef int32_t          int_fast32_t;
typedef int64_t          int_fast64_t;
typedef uint8_t          uint_fast8_t;
typedef uint16_t        uint_fast16_t;
typedef uint32_t        uint_fast32_t;
typedef uint64_t        uint_fast64_t;


/* 7.18.1.4 Integer types capable of holding object pointers */

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 52 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_intptr_t.h>
#endif /* expanded by -frewrite-includes */
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 54 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_uintptr_t.h>
#endif /* expanded by -frewrite-includes */
# 54 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 55 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4


/* 7.18.1.5 Greatest-width integer types */
#if 0 /* expanded by -frewrite-includes */
#include <_types/_intmax_t.h>
#endif /* expanded by -frewrite-includes */
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_intmax_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _INTMAX_T
#define _INTMAX_T
#ifdef __INTMAX_TYPE__
typedef __INTMAX_TYPE__ intmax_t;
#else
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_intmax_t.h" 3 4
#ifdef __LP64__
typedef long int intmax_t;
#else
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_intmax_t.h" 3 4
typedef long long int intmax_t;
#endif /* __LP64__ */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_intmax_t.h" 3 4
#endif /* __INTMAX_TYPE__ */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_intmax_t.h" 3 4
#endif /* _INTMAX_T */
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_intmax_t.h" 3 4
# 59 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types/_uintmax_t.h>
#endif /* expanded by -frewrite-includes */
# 59 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uintmax_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _UINTMAX_T
#define _UINTMAX_T
#ifdef __UINTMAX_TYPE__
typedef __UINTMAX_TYPE__ uintmax_t;
#else
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uintmax_t.h" 3 4
#ifdef __LP64__
typedef long unsigned int uintmax_t;
#else
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uintmax_t.h" 3 4
typedef long long unsigned int uintmax_t;
#endif /* __LP64__ */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uintmax_t.h" 3 4
#endif /* __UINTMAX_TYPE__ */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uintmax_t.h" 3 4
#endif /* _UINTMAX_T */
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_uintmax_t.h" 3 4
# 60 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 2 3 4

/* 7.18.2 Limits of specified-width integer types:
 *   These #defines specify the minimum and maximum limits
 *   of each of the types declared above.
 *
 *   They must have "the same type as would an expression that is an
 *   object of the corresponding type converted according to the integer
 *   promotion".
 */


/* 7.18.2.1 Limits of exact-width integer types */
#define INT8_MAX         127
#define INT16_MAX        32767
#define INT32_MAX        2147483647
#define INT64_MAX        9223372036854775807LL

#define INT8_MIN          -128
#define INT16_MIN         -32768
   /*
      Note:  the literal "most negative int" cannot be written in C --
      the rules in the standard (section 6.4.4.1 in C99) will give it
      an unsigned type, so INT32_MIN (and the most negative member of
      any larger signed type) must be written via a constant expression.
   */
#define INT32_MIN        (-INT32_MAX-1)
#define INT64_MIN        (-INT64_MAX-1)

#define UINT8_MAX         255
#define UINT16_MAX        65535
#define UINT32_MAX        4294967295U
#define UINT64_MAX        18446744073709551615ULL

/* 7.18.2.2 Limits of minimum-width integer types */
#define INT_LEAST8_MIN    INT8_MIN
#define INT_LEAST16_MIN   INT16_MIN
#define INT_LEAST32_MIN   INT32_MIN
#define INT_LEAST64_MIN   INT64_MIN

#define INT_LEAST8_MAX    INT8_MAX
#define INT_LEAST16_MAX   INT16_MAX
#define INT_LEAST32_MAX   INT32_MAX
#define INT_LEAST64_MAX   INT64_MAX

#define UINT_LEAST8_MAX   UINT8_MAX
#define UINT_LEAST16_MAX  UINT16_MAX
#define UINT_LEAST32_MAX  UINT32_MAX
#define UINT_LEAST64_MAX  UINT64_MAX

/* 7.18.2.3 Limits of fastest minimum-width integer types */
#define INT_FAST8_MIN     INT8_MIN
#define INT_FAST16_MIN    INT16_MIN
#define INT_FAST32_MIN    INT32_MIN
#define INT_FAST64_MIN    INT64_MIN

#define INT_FAST8_MAX     INT8_MAX
#define INT_FAST16_MAX    INT16_MAX
#define INT_FAST32_MAX    INT32_MAX
#define INT_FAST64_MAX    INT64_MAX

#define UINT_FAST8_MAX    UINT8_MAX
#define UINT_FAST16_MAX   UINT16_MAX
#define UINT_FAST32_MAX   UINT32_MAX
#define UINT_FAST64_MAX   UINT64_MAX

/* 7.18.2.4 Limits of integer types capable of holding object pointers */

#if 0 /* disabled by -frewrite-includes */
#if __WORDSIZE == 64
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define INTPTR_MAX        9223372036854775807L
#else
# 130 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define INTPTR_MAX        2147483647L
#endif
# 132 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define INTPTR_MIN        (-INTPTR_MAX-1)

#if 0 /* disabled by -frewrite-includes */
#if __WORDSIZE == 64
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define UINTPTR_MAX       18446744073709551615UL
#else
# 137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define UINTPTR_MAX       4294967295UL
#endif
# 139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4

/* 7.18.2.5 Limits of greatest-width integer types */
#define INTMAX_MIN        INT64_MIN
#define INTMAX_MAX        INT64_MAX

#define UINTMAX_MAX       UINT64_MAX

/* 7.18.3 "Other" */
#if 0 /* disabled by -frewrite-includes */
#if __WORDSIZE == 64
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define PTRDIFF_MIN	  INT64_MIN
#define PTRDIFF_MAX	  INT64_MAX
#else
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define PTRDIFF_MIN       INT32_MIN
#define PTRDIFF_MAX       INT32_MAX
#endif
# 154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4

#define SIZE_MAX          UINTPTR_MAX

#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_WANT_LIB_EXT1__) && __STDC_WANT_LIB_EXT1__ >= 1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define RSIZE_MAX         (SIZE_MAX >> 1)
#endif
# 160 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4

#ifndef WCHAR_MAX
#  ifdef __WCHAR_MAX__
#    define WCHAR_MAX     __WCHAR_MAX__
#  else
# 165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#    define WCHAR_MAX     0x7fffffff
#  endif
# 167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#endif
# 168 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4

/* WCHAR_MIN should be 0 if wchar_t is an unsigned type and
   (-WCHAR_MAX-1) if wchar_t is a signed type.  Unfortunately,
   it turns out that -fshort-wchar changes the signedness of
   the type. */
#ifndef WCHAR_MIN
#if 0 /* disabled by -frewrite-includes */
#  if WCHAR_MAX == 0xffff
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#    define WCHAR_MIN       0
#  else
# 177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#    define WCHAR_MIN       (-WCHAR_MAX-1)
#  endif
# 179 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#endif
# 180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4

#define WINT_MIN	  INT32_MIN
#define WINT_MAX	  INT32_MAX

#define SIG_ATOMIC_MIN	  INT32_MIN
#define SIG_ATOMIC_MAX	  INT32_MAX

/* 7.18.4 Macros for integer constants */
#define INT8_C(v)    (v)
#define INT16_C(v)   (v)
#define INT32_C(v)   (v)
#define INT64_C(v)   (v ## LL)

#define UINT8_C(v)   (v)
#define UINT16_C(v)  (v)
#define UINT32_C(v)  (v ## U)
#define UINT64_C(v)  (v ## ULL)

#ifdef __LP64__
#define INTMAX_C(v)  (v ## L)
#define UINTMAX_C(v) (v ## UL)
#else
# 202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
#define INTMAX_C(v)  (v ## LL)
#define UINTMAX_C(v) (v ## ULL)
#endif
# 205 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4

#endif /* _STDINT_H_ */
# 207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdint.h" 3 4
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 2 3

# ifdef __STDC_LIMIT_MACROS_DEFINED_BY_CLANG
#  undef __STDC_LIMIT_MACROS
#  undef __STDC_LIMIT_MACROS_DEFINED_BY_CLANG
# endif
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
# ifdef __STDC_CONSTANT_MACROS_DEFINED_BY_CLANG
#  undef __STDC_CONSTANT_MACROS
#  undef __STDC_CONSTANT_MACROS_DEFINED_BY_CLANG
# endif
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#else
# 64 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

/* C99 7.18.1.1 Exact-width integer types.
 * C99 7.18.1.2 Minimum-width integer types.
 * C99 7.18.1.3 Fastest minimum-width integer types.
 *
 * The standard requires that exact-width type be defined for 8-, 16-, 32-, and
 * 64-bit types if they are implemented. Other exact width types are optional.
 * This implementation defines an exact-width types for every integer width
 * that is represented in the standard integer types.
 *
 * The standard also requires minimum-width types be defined for 8-, 16-, 32-,
 * and 64-bit widths regardless of whether there are corresponding exact-width
 * types.
 *
 * To accommodate targets that are missing types that are exactly 8, 16, 32, or
 * 64 bits wide, this implementation takes an approach of cascading
 * redefinitions, redefining __int_leastN_t to successively smaller exact-width
 * types. It is therefore important that the types are defined in order of
 * descending widths.
 *
 * We currently assume that the minimum-width types and the fastest
 * minimum-width types are the same. This is allowed by the standard, but is
 * suboptimal.
 *
 * In violation of the standard, some targets do not implement a type that is
 * wide enough to represent all of the required widths (8-, 16-, 32-, 64-bit).
 * To accommodate these targets, a required minimum-width type is only
 * defined if there exists an exact-width type of equal or greater width.
 */

#ifdef __INT64_TYPE__
# ifndef __int8_t_defined /* glibc sys/types.h also defines int64_t*/
typedef __INT64_TYPE__ int64_t;
# endif /* __int8_t_defined */
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
typedef __UINT64_TYPE__ uint64_t;
# define __int_least64_t int64_t
# define __uint_least64_t uint64_t
# define __int_least32_t int64_t
# define __uint_least32_t uint64_t
# define __int_least16_t int64_t
# define __uint_least16_t uint64_t
# define __int_least8_t int64_t
# define __uint_least8_t uint64_t
#endif /* __INT64_TYPE__ */
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __int_least64_t
typedef __int_least64_t int_least64_t;
typedef __uint_least64_t uint_least64_t;
typedef __int_least64_t int_fast64_t;
typedef __uint_least64_t uint_fast64_t;
#endif /* __int_least64_t */
# 115 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __INT56_TYPE__
typedef __INT56_TYPE__ int56_t;
typedef __UINT56_TYPE__ uint56_t;
typedef int56_t int_least56_t;
typedef uint56_t uint_least56_t;
typedef int56_t int_fast56_t;
typedef uint56_t uint_fast56_t;
# define __int_least32_t int56_t
# define __uint_least32_t uint56_t
# define __int_least16_t int56_t
# define __uint_least16_t uint56_t
# define __int_least8_t int56_t
# define __uint_least8_t uint56_t
#endif /* __INT56_TYPE__ */
# 130 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT48_TYPE__
typedef __INT48_TYPE__ int48_t;
typedef __UINT48_TYPE__ uint48_t;
typedef int48_t int_least48_t;
typedef uint48_t uint_least48_t;
typedef int48_t int_fast48_t;
typedef uint48_t uint_fast48_t;
# define __int_least32_t int48_t
# define __uint_least32_t uint48_t
# define __int_least16_t int48_t
# define __uint_least16_t uint48_t
# define __int_least8_t int48_t
# define __uint_least8_t uint48_t
#endif /* __INT48_TYPE__ */
# 146 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT40_TYPE__
typedef __INT40_TYPE__ int40_t;
typedef __UINT40_TYPE__ uint40_t;
typedef int40_t int_least40_t;
typedef uint40_t uint_least40_t;
typedef int40_t int_fast40_t;
typedef uint40_t uint_fast40_t;
# define __int_least32_t int40_t
# define __uint_least32_t uint40_t
# define __int_least16_t int40_t
# define __uint_least16_t uint40_t
# define __int_least8_t int40_t
# define __uint_least8_t uint40_t
#endif /* __INT40_TYPE__ */
# 162 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT32_TYPE__

# ifndef __int8_t_defined /* glibc sys/types.h also defines int32_t*/
typedef __INT32_TYPE__ int32_t;
# endif /* __int8_t_defined */
# 169 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

# ifndef __uint32_t_defined  /* more glibc compatibility */
# define __uint32_t_defined
typedef __UINT32_TYPE__ uint32_t;
# endif /* __uint32_t_defined */
# 174 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

# define __int_least32_t int32_t
# define __uint_least32_t uint32_t
# define __int_least16_t int32_t
# define __uint_least16_t uint32_t
# define __int_least8_t int32_t
# define __uint_least8_t uint32_t
#endif /* __INT32_TYPE__ */
# 182 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __int_least32_t
typedef __int_least32_t int_least32_t;
typedef __uint_least32_t uint_least32_t;
typedef __int_least32_t int_fast32_t;
typedef __uint_least32_t uint_fast32_t;
#endif /* __int_least32_t */
# 189 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __INT24_TYPE__
typedef __INT24_TYPE__ int24_t;
typedef __UINT24_TYPE__ uint24_t;
typedef int24_t int_least24_t;
typedef uint24_t uint_least24_t;
typedef int24_t int_fast24_t;
typedef uint24_t uint_fast24_t;
# define __int_least16_t int24_t
# define __uint_least16_t uint24_t
# define __int_least8_t int24_t
# define __uint_least8_t uint24_t
#endif /* __INT24_TYPE__ */
# 202 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __INT16_TYPE__
#ifndef __int8_t_defined /* glibc sys/types.h also defines int16_t*/
typedef __INT16_TYPE__ int16_t;
#endif /* __int8_t_defined */
# 207 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
typedef __UINT16_TYPE__ uint16_t;
# define __int_least16_t int16_t
# define __uint_least16_t uint16_t
# define __int_least8_t int16_t
# define __uint_least8_t uint16_t
#endif /* __INT16_TYPE__ */
# 213 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __int_least16_t
typedef __int_least16_t int_least16_t;
typedef __uint_least16_t uint_least16_t;
typedef __int_least16_t int_fast16_t;
typedef __uint_least16_t uint_fast16_t;
#endif /* __int_least16_t */
# 220 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT8_TYPE__
#ifndef __int8_t_defined  /* glibc sys/types.h also defines int8_t*/
typedef __INT8_TYPE__ int8_t;
#endif /* __int8_t_defined */
# 226 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
typedef __UINT8_TYPE__ uint8_t;
# define __int_least8_t int8_t
# define __uint_least8_t uint8_t
#endif /* __INT8_TYPE__ */
# 230 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __int_least8_t
typedef __int_least8_t int_least8_t;
typedef __uint_least8_t uint_least8_t;
typedef __int_least8_t int_fast8_t;
typedef __uint_least8_t uint_fast8_t;
#endif /* __int_least8_t */
# 237 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

/* prevent glibc sys/types.h from defining conflicting types */
#ifndef __int8_t_defined
# define __int8_t_defined
#endif /* __int8_t_defined */
# 242 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

/* C99 7.18.1.4 Integer types capable of holding object pointers.
 */
#define __stdint_join3(a,b,c) a ## b ## c

#ifndef _INTPTR_T
#ifndef __intptr_t_defined
typedef __INTPTR_TYPE__ intptr_t;
#define __intptr_t_defined
#define _INTPTR_T
#endif
# 253 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif
# 254 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifndef _UINTPTR_T
typedef __UINTPTR_TYPE__ uintptr_t;
#define _UINTPTR_T
#endif
# 259 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

/* C99 7.18.1.5 Greatest-width integer types.
 */
typedef __INTMAX_TYPE__  intmax_t;
typedef __UINTMAX_TYPE__ uintmax_t;

/* C99 7.18.4 Macros for minimum-width integer constants.
 *
 * The standard requires that integer constant macros be defined for all the
 * minimum-width types defined above. As 8-, 16-, 32-, and 64-bit minimum-width
 * types are required, the corresponding integer constant macros are defined
 * here. This implementation also defines minimum-width types for every other
 * integer width that the target implements, so corresponding macros are
 * defined below, too.
 *
 * These macros are defined using the same successive-shrinking approach as
 * the type definitions above. It is likewise important that macros are defined
 * in order of decending width.
 *
 * Note that C++ should not check __STDC_CONSTANT_MACROS here, contrary to the
 * claims of the C standard (see C++ 18.3.1p2, [cstdint.syn]).
 */

#define __int_c_join(a, b) a ## b
#define __int_c(v, suffix) __int_c_join(v, suffix)
#define __uint_c(v, suffix) __int_c_join(v##U, suffix)


#ifdef __INT64_TYPE__
# ifdef __INT64_C_SUFFIX__
#  define __int64_c_suffix __INT64_C_SUFFIX__
#  define __int32_c_suffix __INT64_C_SUFFIX__
#  define __int16_c_suffix __INT64_C_SUFFIX__
#  define  __int8_c_suffix __INT64_C_SUFFIX__
# else
# 294 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  undef __int64_c_suffix
#  undef __int32_c_suffix
#  undef __int16_c_suffix
#  undef  __int8_c_suffix
# endif /* __INT64_C_SUFFIX__ */
# 299 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __INT64_TYPE__ */
# 300 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __int_least64_t
# ifdef __int64_c_suffix
#  define INT64_C(v) __int_c(v, __int64_c_suffix)
#  define UINT64_C(v) __uint_c(v, __int64_c_suffix)
# else
# 306 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define INT64_C(v) v
#  define UINT64_C(v) v ## U
# endif /* __int64_c_suffix */
# 309 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __int_least64_t */
# 310 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT56_TYPE__
# ifdef __INT56_C_SUFFIX__
#  define INT56_C(v) __int_c(v, __INT56_C_SUFFIX__)
#  define UINT56_C(v) __uint_c(v, __INT56_C_SUFFIX__)
#  define __int32_c_suffix __INT56_C_SUFFIX__
#  define __int16_c_suffix __INT56_C_SUFFIX__
#  define __int8_c_suffix  __INT56_C_SUFFIX__
# else
# 320 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define INT56_C(v) v
#  define UINT56_C(v) v ## U
#  undef __int32_c_suffix
#  undef __int16_c_suffix
#  undef  __int8_c_suffix
# endif /* __INT56_C_SUFFIX__ */
# 326 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __INT56_TYPE__ */
# 327 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT48_TYPE__
# ifdef __INT48_C_SUFFIX__
#  define INT48_C(v) __int_c(v, __INT48_C_SUFFIX__)
#  define UINT48_C(v) __uint_c(v, __INT48_C_SUFFIX__)
#  define __int32_c_suffix __INT48_C_SUFFIX__
#  define __int16_c_suffix __INT48_C_SUFFIX__
#  define __int8_c_suffix  __INT48_C_SUFFIX__
# else
# 337 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define INT48_C(v) v
#  define UINT48_C(v) v ## U
#  undef __int32_c_suffix
#  undef __int16_c_suffix
#  undef  __int8_c_suffix
# endif /* __INT48_C_SUFFIX__ */
# 343 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __INT48_TYPE__ */
# 344 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT40_TYPE__
# ifdef __INT40_C_SUFFIX__
#  define INT40_C(v) __int_c(v, __INT40_C_SUFFIX__)
#  define UINT40_C(v) __uint_c(v, __INT40_C_SUFFIX__)
#  define __int32_c_suffix __INT40_C_SUFFIX__
#  define __int16_c_suffix __INT40_C_SUFFIX__
#  define __int8_c_suffix  __INT40_C_SUFFIX__
# else
# 354 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define INT40_C(v) v
#  define UINT40_C(v) v ## U
#  undef __int32_c_suffix
#  undef __int16_c_suffix
#  undef  __int8_c_suffix
# endif /* __INT40_C_SUFFIX__ */
# 360 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __INT40_TYPE__ */
# 361 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT32_TYPE__
# ifdef __INT32_C_SUFFIX__
#  define __int32_c_suffix __INT32_C_SUFFIX__
#  define __int16_c_suffix __INT32_C_SUFFIX__
#  define __int8_c_suffix  __INT32_C_SUFFIX__
#else
# 369 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  undef __int32_c_suffix
#  undef __int16_c_suffix
#  undef  __int8_c_suffix
# endif /* __INT32_C_SUFFIX__ */
# 373 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __INT32_TYPE__ */
# 374 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __int_least32_t
# ifdef __int32_c_suffix
#  define INT32_C(v) __int_c(v, __int32_c_suffix)
#  define UINT32_C(v) __uint_c(v, __int32_c_suffix)
# else
# 380 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define INT32_C(v) v
#  define UINT32_C(v) v ## U
# endif /* __int32_c_suffix */
# 383 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __int_least32_t */
# 384 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT24_TYPE__
# ifdef __INT24_C_SUFFIX__
#  define INT24_C(v) __int_c(v, __INT24_C_SUFFIX__)
#  define UINT24_C(v) __uint_c(v, __INT24_C_SUFFIX__)
#  define __int16_c_suffix __INT24_C_SUFFIX__
#  define __int8_c_suffix  __INT24_C_SUFFIX__
# else
# 393 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define INT24_C(v) v
#  define UINT24_C(v) v ## U
#  undef __int16_c_suffix
#  undef  __int8_c_suffix
# endif /* __INT24_C_SUFFIX__ */
# 398 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __INT24_TYPE__ */
# 399 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT16_TYPE__
# ifdef __INT16_C_SUFFIX__
#  define __int16_c_suffix __INT16_C_SUFFIX__
#  define __int8_c_suffix  __INT16_C_SUFFIX__
#else
# 406 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  undef __int16_c_suffix
#  undef  __int8_c_suffix
# endif /* __INT16_C_SUFFIX__ */
# 409 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __INT16_TYPE__ */
# 410 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __int_least16_t
# ifdef __int16_c_suffix
#  define INT16_C(v) __int_c(v, __int16_c_suffix)
#  define UINT16_C(v) __uint_c(v, __int16_c_suffix)
# else
# 416 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define INT16_C(v) v
#  define UINT16_C(v) v ## U
# endif /* __int16_c_suffix */
# 419 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __int_least16_t */
# 420 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT8_TYPE__
# ifdef __INT8_C_SUFFIX__
#  define __int8_c_suffix __INT8_C_SUFFIX__
#else
# 426 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  undef  __int8_c_suffix
# endif /* __INT8_C_SUFFIX__ */
# 428 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __INT8_TYPE__ */
# 429 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __int_least8_t
# ifdef __int8_c_suffix
#  define INT8_C(v) __int_c(v, __int8_c_suffix)
#  define UINT8_C(v) __uint_c(v, __int8_c_suffix)
# else
# 435 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define INT8_C(v) v
#  define UINT8_C(v) v ## U
# endif /* __int8_c_suffix */
# 438 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __int_least8_t */
# 439 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


/* C99 7.18.2.1 Limits of exact-width integer types.
 * C99 7.18.2.2 Limits of minimum-width integer types.
 * C99 7.18.2.3 Limits of fastest minimum-width integer types.
 *
 * The presence of limit macros are completely optional in C99.  This
 * implementation defines limits for all of the types (exact- and
 * minimum-width) that it defines above, using the limits of the minimum-width
 * type for any types that do not have exact-width representations.
 *
 * As in the type definitions, this section takes an approach of
 * successive-shrinking to determine which limits to use for the standard (8,
 * 16, 32, 64) bit widths when they don't have exact representations. It is
 * therefore important that the definitions be kept in order of decending
 * widths.
 *
 * Note that C++ should not check __STDC_LIMIT_MACROS here, contrary to the
 * claims of the C standard (see C++ 18.3.1p2, [cstdint.syn]).
 */

#ifdef __INT64_TYPE__
# define INT64_MAX           INT64_C( 9223372036854775807)
# define INT64_MIN         (-INT64_C( 9223372036854775807)-1)
# define UINT64_MAX         UINT64_C(18446744073709551615)
# define __INT_LEAST64_MIN   INT64_MIN
# define __INT_LEAST64_MAX   INT64_MAX
# define __UINT_LEAST64_MAX UINT64_MAX
# define __INT_LEAST32_MIN   INT64_MIN
# define __INT_LEAST32_MAX   INT64_MAX
# define __UINT_LEAST32_MAX UINT64_MAX
# define __INT_LEAST16_MIN   INT64_MIN
# define __INT_LEAST16_MAX   INT64_MAX
# define __UINT_LEAST16_MAX UINT64_MAX
# define __INT_LEAST8_MIN    INT64_MIN
# define __INT_LEAST8_MAX    INT64_MAX
# define __UINT_LEAST8_MAX  UINT64_MAX
#endif /* __INT64_TYPE__ */
# 477 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __INT_LEAST64_MIN
# define INT_LEAST64_MIN   __INT_LEAST64_MIN
# define INT_LEAST64_MAX   __INT_LEAST64_MAX
# define UINT_LEAST64_MAX __UINT_LEAST64_MAX
# define INT_FAST64_MIN    __INT_LEAST64_MIN
# define INT_FAST64_MAX    __INT_LEAST64_MAX
# define UINT_FAST64_MAX  __UINT_LEAST64_MAX
#endif /* __INT_LEAST64_MIN */
# 486 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT56_TYPE__
# define INT56_MAX           INT56_C(36028797018963967)
# define INT56_MIN         (-INT56_C(36028797018963967)-1)
# define UINT56_MAX         UINT56_C(72057594037927935)
# define INT_LEAST56_MIN     INT56_MIN
# define INT_LEAST56_MAX     INT56_MAX
# define UINT_LEAST56_MAX   UINT56_MAX
# define INT_FAST56_MIN      INT56_MIN
# define INT_FAST56_MAX      INT56_MAX
# define UINT_FAST56_MAX    UINT56_MAX
# define __INT_LEAST32_MIN   INT56_MIN
# define __INT_LEAST32_MAX   INT56_MAX
# define __UINT_LEAST32_MAX UINT56_MAX
# define __INT_LEAST16_MIN   INT56_MIN
# define __INT_LEAST16_MAX   INT56_MAX
# define __UINT_LEAST16_MAX UINT56_MAX
# define __INT_LEAST8_MIN    INT56_MIN
# define __INT_LEAST8_MAX    INT56_MAX
# define __UINT_LEAST8_MAX  UINT56_MAX
#endif /* __INT56_TYPE__ */
# 508 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT48_TYPE__
# define INT48_MAX           INT48_C(140737488355327)
# define INT48_MIN         (-INT48_C(140737488355327)-1)
# define UINT48_MAX         UINT48_C(281474976710655)
# define INT_LEAST48_MIN     INT48_MIN
# define INT_LEAST48_MAX     INT48_MAX
# define UINT_LEAST48_MAX   UINT48_MAX
# define INT_FAST48_MIN      INT48_MIN
# define INT_FAST48_MAX      INT48_MAX
# define UINT_FAST48_MAX    UINT48_MAX
# define __INT_LEAST32_MIN   INT48_MIN
# define __INT_LEAST32_MAX   INT48_MAX
# define __UINT_LEAST32_MAX UINT48_MAX
# define __INT_LEAST16_MIN   INT48_MIN
# define __INT_LEAST16_MAX   INT48_MAX
# define __UINT_LEAST16_MAX UINT48_MAX
# define __INT_LEAST8_MIN    INT48_MIN
# define __INT_LEAST8_MAX    INT48_MAX
# define __UINT_LEAST8_MAX  UINT48_MAX
#endif /* __INT48_TYPE__ */
# 530 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT40_TYPE__
# define INT40_MAX           INT40_C(549755813887)
# define INT40_MIN         (-INT40_C(549755813887)-1)
# define UINT40_MAX         UINT40_C(1099511627775)
# define INT_LEAST40_MIN     INT40_MIN
# define INT_LEAST40_MAX     INT40_MAX
# define UINT_LEAST40_MAX   UINT40_MAX
# define INT_FAST40_MIN      INT40_MIN
# define INT_FAST40_MAX      INT40_MAX
# define UINT_FAST40_MAX    UINT40_MAX
# define __INT_LEAST32_MIN   INT40_MIN
# define __INT_LEAST32_MAX   INT40_MAX
# define __UINT_LEAST32_MAX UINT40_MAX
# define __INT_LEAST16_MIN   INT40_MIN
# define __INT_LEAST16_MAX   INT40_MAX
# define __UINT_LEAST16_MAX UINT40_MAX
# define __INT_LEAST8_MIN    INT40_MIN
# define __INT_LEAST8_MAX    INT40_MAX
# define __UINT_LEAST8_MAX  UINT40_MAX
#endif /* __INT40_TYPE__ */
# 552 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT32_TYPE__
# define INT32_MAX           INT32_C(2147483647)
# define INT32_MIN         (-INT32_C(2147483647)-1)
# define UINT32_MAX         UINT32_C(4294967295)
# define __INT_LEAST32_MIN   INT32_MIN
# define __INT_LEAST32_MAX   INT32_MAX
# define __UINT_LEAST32_MAX UINT32_MAX
# define __INT_LEAST16_MIN   INT32_MIN
# define __INT_LEAST16_MAX   INT32_MAX
# define __UINT_LEAST16_MAX UINT32_MAX
# define __INT_LEAST8_MIN    INT32_MIN
# define __INT_LEAST8_MAX    INT32_MAX
# define __UINT_LEAST8_MAX  UINT32_MAX
#endif /* __INT32_TYPE__ */
# 568 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __INT_LEAST32_MIN
# define INT_LEAST32_MIN   __INT_LEAST32_MIN
# define INT_LEAST32_MAX   __INT_LEAST32_MAX
# define UINT_LEAST32_MAX __UINT_LEAST32_MAX
# define INT_FAST32_MIN    __INT_LEAST32_MIN
# define INT_FAST32_MAX    __INT_LEAST32_MAX
# define UINT_FAST32_MAX  __UINT_LEAST32_MAX
#endif /* __INT_LEAST32_MIN */
# 577 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT24_TYPE__
# define INT24_MAX           INT24_C(8388607)
# define INT24_MIN         (-INT24_C(8388607)-1)
# define UINT24_MAX         UINT24_C(16777215)
# define INT_LEAST24_MIN     INT24_MIN
# define INT_LEAST24_MAX     INT24_MAX
# define UINT_LEAST24_MAX   UINT24_MAX
# define INT_FAST24_MIN      INT24_MIN
# define INT_FAST24_MAX      INT24_MAX
# define UINT_FAST24_MAX    UINT24_MAX
# define __INT_LEAST16_MIN   INT24_MIN
# define __INT_LEAST16_MAX   INT24_MAX
# define __UINT_LEAST16_MAX UINT24_MAX
# define __INT_LEAST8_MIN    INT24_MIN
# define __INT_LEAST8_MAX    INT24_MAX
# define __UINT_LEAST8_MAX  UINT24_MAX
#endif /* __INT24_TYPE__ */
# 596 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT16_TYPE__
#define INT16_MAX            INT16_C(32767)
#define INT16_MIN          (-INT16_C(32767)-1)
#define UINT16_MAX          UINT16_C(65535)
# define __INT_LEAST16_MIN   INT16_MIN
# define __INT_LEAST16_MAX   INT16_MAX
# define __UINT_LEAST16_MAX UINT16_MAX
# define __INT_LEAST8_MIN    INT16_MIN
# define __INT_LEAST8_MAX    INT16_MAX
# define __UINT_LEAST8_MAX  UINT16_MAX
#endif /* __INT16_TYPE__ */
# 609 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __INT_LEAST16_MIN
# define INT_LEAST16_MIN   __INT_LEAST16_MIN
# define INT_LEAST16_MAX   __INT_LEAST16_MAX
# define UINT_LEAST16_MAX __UINT_LEAST16_MAX
# define INT_FAST16_MIN    __INT_LEAST16_MIN
# define INT_FAST16_MAX    __INT_LEAST16_MAX
# define UINT_FAST16_MAX  __UINT_LEAST16_MAX
#endif /* __INT_LEAST16_MIN */
# 618 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3


#ifdef __INT8_TYPE__
# define INT8_MAX            INT8_C(127)
# define INT8_MIN          (-INT8_C(127)-1)
# define UINT8_MAX          UINT8_C(255)
# define __INT_LEAST8_MIN    INT8_MIN
# define __INT_LEAST8_MAX    INT8_MAX
# define __UINT_LEAST8_MAX  UINT8_MAX
#endif /* __INT8_TYPE__ */
# 628 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifdef __INT_LEAST8_MIN
# define INT_LEAST8_MIN   __INT_LEAST8_MIN
# define INT_LEAST8_MAX   __INT_LEAST8_MAX
# define UINT_LEAST8_MAX __UINT_LEAST8_MAX
# define INT_FAST8_MIN    __INT_LEAST8_MIN
# define INT_FAST8_MAX    __INT_LEAST8_MAX
# define UINT_FAST8_MAX  __UINT_LEAST8_MAX
#endif /* __INT_LEAST8_MIN */
# 637 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

/* Some utility macros */
#define  __INTN_MIN(n)  __stdint_join3( INT, n, _MIN)
#define  __INTN_MAX(n)  __stdint_join3( INT, n, _MAX)
#define __UINTN_MAX(n)  __stdint_join3(UINT, n, _MAX)
#define  __INTN_C(n, v) __stdint_join3( INT, n, _C(v))
#define __UINTN_C(n, v) __stdint_join3(UINT, n, _C(v))

/* C99 7.18.2.4 Limits of integer types capable of holding object pointers. */
/* C99 7.18.3 Limits of other integer types. */

#define  INTPTR_MIN  (-__INTPTR_MAX__-1)
#define  INTPTR_MAX    __INTPTR_MAX__
#define UINTPTR_MAX   __UINTPTR_MAX__
#define PTRDIFF_MIN (-__PTRDIFF_MAX__-1)
#define PTRDIFF_MAX   __PTRDIFF_MAX__
#define    SIZE_MAX      __SIZE_MAX__

/* ISO9899:2011 7.20 (C11 Annex K): Define RSIZE_MAX if __STDC_WANT_LIB_EXT1__
 * is enabled. */
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_WANT_LIB_EXT1__) && __STDC_WANT_LIB_EXT1__ >= 1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 658 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#define   RSIZE_MAX            (SIZE_MAX >> 1)
#endif
# 660 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

/* C99 7.18.2.5 Limits of greatest-width integer types. */
#define  INTMAX_MIN (-__INTMAX_MAX__-1)
#define  INTMAX_MAX   __INTMAX_MAX__
#define UINTMAX_MAX  __UINTMAX_MAX__

/* C99 7.18.3 Limits of other integer types. */
#define SIG_ATOMIC_MIN __INTN_MIN(__SIG_ATOMIC_WIDTH__)
#define SIG_ATOMIC_MAX __INTN_MAX(__SIG_ATOMIC_WIDTH__)
#ifdef __WINT_UNSIGNED__
# define WINT_MIN       __UINTN_C(__WINT_WIDTH__, 0)
# define WINT_MAX       __UINTN_MAX(__WINT_WIDTH__)
#else
# 673 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
# define WINT_MIN       __INTN_MIN(__WINT_WIDTH__)
# define WINT_MAX       __INTN_MAX(__WINT_WIDTH__)
#endif
# 676 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

#ifndef WCHAR_MAX
# define WCHAR_MAX __WCHAR_MAX__
#endif
# 680 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#ifndef WCHAR_MIN
#if 0 /* disabled by -frewrite-includes */
# if __WCHAR_MAX__ == __INTN_MAX(__WCHAR_WIDTH__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 682 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define WCHAR_MIN __INTN_MIN(__WCHAR_WIDTH__)
# else
# 684 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#  define WCHAR_MIN __UINTN_C(__WCHAR_WIDTH__, 0)
# endif
# 686 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif
# 687 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3

/* 7.18.4.2 Macros for greatest-width integer constants. */
#define  INTMAX_C(v) __int_c(v,  __INTMAX_C_SUFFIX__)
#define UINTMAX_C(v) __int_c(v, __UINTMAX_C_SUFFIX__)

#endif /* __STDC_HOSTED__ */
# 693 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
#endif /* __CLANG_STDINT_H */
# 694 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdint.h" 3
# 124 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 2 3

#endif  // _LIBCPP_STDINT_H
# 126 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdint.h" 3
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 2 3 4
#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4

/* [XSI] The timeval structure shall be defined as described in
 * <sys/time.h>
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_timeval.h>
#endif /* expanded by -frewrite-includes */
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timeval.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _STRUCT_TIMEVAL
#define _STRUCT_TIMEVAL         struct timeval

#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_time_t */
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timeval.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timeval.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_suseconds_t */
#endif /* expanded by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timeval.h" 3 4
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timeval.h" 3 4

_STRUCT_TIMEVAL
{
	__darwin_time_t         tv_sec;         /* seconds */
	__darwin_suseconds_t    tv_usec;        /* and microseconds */
};
#endif /* _STRUCT_TIMEVAL */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timeval.h" 3 4
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 2 3 4

/* The id_t type shall be defined as described in <sys/types.h> */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_id_t.h>
#endif /* expanded by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4


/*
 * Resource limit type (low 63 bits, excluding the sign bit)
 */
typedef __uint64_t      rlim_t;


/*****
 * PRIORITY
 */

/*
 * Possible values of the first parameter to getpriority()/setpriority(),
 * used to indicate the type of the second parameter.
 */
#define PRIO_PROCESS    0               /* Second argument is a PID */
#define PRIO_PGRP       1               /* Second argument is a GID */
#define PRIO_USER       2               /* Second argument is a UID */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
#define PRIO_DARWIN_THREAD      3               /* Second argument is always 0 (current thread) */
#define PRIO_DARWIN_PROCESS     4               /* Second argument is a PID */


/*
 * Range limitations for the value of the third parameter to setpriority().
 */
#define PRIO_MIN        -20
#define PRIO_MAX        20

/*
 * use PRIO_DARWIN_BG to set the current thread into "background" state
 * which lowers CPU, disk IO, and networking priorites until thread terminates
 * or "background" state is revoked
 */
#define PRIO_DARWIN_BG 0x1000

/*
 * use PRIO_DARWIN_NONUI to restrict a process's ability to make calls to
 * the GPU. (deprecated)
 */
#define PRIO_DARWIN_NONUI 0x1001

#endif  /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4



/*****
 * RESOURCE USAGE
 */

/*
 * Possible values of the first parameter to getrusage(), used to indicate
 * the scope of the information to be returned.
 */
#define RUSAGE_SELF     0               /* Current process information */
#define RUSAGE_CHILDREN -1              /* Current process' children */

/*
 * A structure representing an accounting of resource utilization.  The
 * address of an instance of this structure is the second parameter to
 * getrusage().
 *
 * Note: All values other than ru_utime and ru_stime are implementaiton
 *       defined and subject to change in a future release.  Their use
 *       is discouraged for standards compliant programs.
 */
struct  rusage {
	struct timeval ru_utime;        /* user time used (PL) */
	struct timeval ru_stime;        /* system time used (PL) */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL < __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
	long    ru_opaque[14];          /* implementation defined */
#else
# 158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
	/*
	 * Informational aliases for source compatibility with programs
	 * that need more information than that provided by standards,
	 * and which do not mind being OS-dependent.
	 */
	long    ru_maxrss;              /* max resident set size (PL) */
#define ru_first        ru_ixrss        /* internal: ruadd() range start */
	long    ru_ixrss;               /* integral shared memory size (NU) */
	long    ru_idrss;               /* integral unshared data (NU)  */
	long    ru_isrss;               /* integral unshared stack (NU) */
	long    ru_minflt;              /* page reclaims (NU) */
	long    ru_majflt;              /* page faults (NU) */
	long    ru_nswap;               /* swaps (NU) */
	long    ru_inblock;             /* block input operations (atomic) */
	long    ru_oublock;             /* block output operations (atomic) */
	long    ru_msgsnd;              /* messages sent (atomic) */
	long    ru_msgrcv;              /* messages received (atomic) */
	long    ru_nsignals;            /* signals received (atomic) */
	long    ru_nvcsw;               /* voluntary context switches (atomic) */
	long    ru_nivcsw;              /* involuntary " */
#define ru_last         ru_nivcsw       /* internal: ruadd() range end */
#endif  /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
};

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 183 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
/*
 * Flavors for proc_pid_rusage().
 */
#define RUSAGE_INFO_V0  0
#define RUSAGE_INFO_V1  1
#define RUSAGE_INFO_V2  2
#define RUSAGE_INFO_V3  3
#define RUSAGE_INFO_V4  4
#define RUSAGE_INFO_CURRENT     RUSAGE_INFO_V4

typedef void *rusage_info_t;

struct rusage_info_v0 {
	uint8_t  ri_uuid[16];
	uint64_t ri_user_time;
	uint64_t ri_system_time;
	uint64_t ri_pkg_idle_wkups;
	uint64_t ri_interrupt_wkups;
	uint64_t ri_pageins;
	uint64_t ri_wired_size;
	uint64_t ri_resident_size;
	uint64_t ri_phys_footprint;
	uint64_t ri_proc_start_abstime;
	uint64_t ri_proc_exit_abstime;
};

struct rusage_info_v1 {
	uint8_t  ri_uuid[16];
	uint64_t ri_user_time;
	uint64_t ri_system_time;
	uint64_t ri_pkg_idle_wkups;
	uint64_t ri_interrupt_wkups;
	uint64_t ri_pageins;
	uint64_t ri_wired_size;
	uint64_t ri_resident_size;
	uint64_t ri_phys_footprint;
	uint64_t ri_proc_start_abstime;
	uint64_t ri_proc_exit_abstime;
	uint64_t ri_child_user_time;
	uint64_t ri_child_system_time;
	uint64_t ri_child_pkg_idle_wkups;
	uint64_t ri_child_interrupt_wkups;
	uint64_t ri_child_pageins;
	uint64_t ri_child_elapsed_abstime;
};

struct rusage_info_v2 {
	uint8_t  ri_uuid[16];
	uint64_t ri_user_time;
	uint64_t ri_system_time;
	uint64_t ri_pkg_idle_wkups;
	uint64_t ri_interrupt_wkups;
	uint64_t ri_pageins;
	uint64_t ri_wired_size;
	uint64_t ri_resident_size;
	uint64_t ri_phys_footprint;
	uint64_t ri_proc_start_abstime;
	uint64_t ri_proc_exit_abstime;
	uint64_t ri_child_user_time;
	uint64_t ri_child_system_time;
	uint64_t ri_child_pkg_idle_wkups;
	uint64_t ri_child_interrupt_wkups;
	uint64_t ri_child_pageins;
	uint64_t ri_child_elapsed_abstime;
	uint64_t ri_diskio_bytesread;
	uint64_t ri_diskio_byteswritten;
};

struct rusage_info_v3 {
	uint8_t  ri_uuid[16];
	uint64_t ri_user_time;
	uint64_t ri_system_time;
	uint64_t ri_pkg_idle_wkups;
	uint64_t ri_interrupt_wkups;
	uint64_t ri_pageins;
	uint64_t ri_wired_size;
	uint64_t ri_resident_size;
	uint64_t ri_phys_footprint;
	uint64_t ri_proc_start_abstime;
	uint64_t ri_proc_exit_abstime;
	uint64_t ri_child_user_time;
	uint64_t ri_child_system_time;
	uint64_t ri_child_pkg_idle_wkups;
	uint64_t ri_child_interrupt_wkups;
	uint64_t ri_child_pageins;
	uint64_t ri_child_elapsed_abstime;
	uint64_t ri_diskio_bytesread;
	uint64_t ri_diskio_byteswritten;
	uint64_t ri_cpu_time_qos_default;
	uint64_t ri_cpu_time_qos_maintenance;
	uint64_t ri_cpu_time_qos_background;
	uint64_t ri_cpu_time_qos_utility;
	uint64_t ri_cpu_time_qos_legacy;
	uint64_t ri_cpu_time_qos_user_initiated;
	uint64_t ri_cpu_time_qos_user_interactive;
	uint64_t ri_billed_system_time;
	uint64_t ri_serviced_system_time;
};

struct rusage_info_v4 {
	uint8_t  ri_uuid[16];
	uint64_t ri_user_time;
	uint64_t ri_system_time;
	uint64_t ri_pkg_idle_wkups;
	uint64_t ri_interrupt_wkups;
	uint64_t ri_pageins;
	uint64_t ri_wired_size;
	uint64_t ri_resident_size;
	uint64_t ri_phys_footprint;
	uint64_t ri_proc_start_abstime;
	uint64_t ri_proc_exit_abstime;
	uint64_t ri_child_user_time;
	uint64_t ri_child_system_time;
	uint64_t ri_child_pkg_idle_wkups;
	uint64_t ri_child_interrupt_wkups;
	uint64_t ri_child_pageins;
	uint64_t ri_child_elapsed_abstime;
	uint64_t ri_diskio_bytesread;
	uint64_t ri_diskio_byteswritten;
	uint64_t ri_cpu_time_qos_default;
	uint64_t ri_cpu_time_qos_maintenance;
	uint64_t ri_cpu_time_qos_background;
	uint64_t ri_cpu_time_qos_utility;
	uint64_t ri_cpu_time_qos_legacy;
	uint64_t ri_cpu_time_qos_user_initiated;
	uint64_t ri_cpu_time_qos_user_interactive;
	uint64_t ri_billed_system_time;
	uint64_t ri_serviced_system_time;
	uint64_t ri_logical_writes;
	uint64_t ri_lifetime_max_phys_footprint;
	uint64_t ri_instructions;
	uint64_t ri_cycles;
	uint64_t ri_billed_energy;
	uint64_t ri_serviced_energy;
	uint64_t ri_interval_max_phys_footprint;
	// 1 reserve counter(s) remaining for future extension
	uint64_t ri_unused[1];
};

typedef struct rusage_info_v4 rusage_info_current;

#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4



/*****
 * RESOURCE LIMITS
 */

/*
 * Symbolic constants for resource limits; since all limits are representable
 * as a type rlim_t, we are permitted to define RLIM_SAVED_* in terms of
 * RLIM_INFINITY.
 */
#define RLIM_INFINITY   (((__uint64_t)1 << 63) - 1)     /* no limit */
#define RLIM_SAVED_MAX  RLIM_INFINITY   /* Unrepresentable hard limit */
#define RLIM_SAVED_CUR  RLIM_INFINITY   /* Unrepresentable soft limit */

/*
 * Possible values of the first parameter to getrlimit()/setrlimit(), to
 * indicate for which resource the operation is being performed.
 */
#define RLIMIT_CPU      0               /* cpu time per process */
#define RLIMIT_FSIZE    1               /* file size */
#define RLIMIT_DATA     2               /* data segment size */
#define RLIMIT_STACK    3               /* stack size */
#define RLIMIT_CORE     4               /* core file size */
#define RLIMIT_AS       5               /* address space (resident set size) */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
#define RLIMIT_RSS      RLIMIT_AS       /* source compatibility alias */
#define RLIMIT_MEMLOCK  6               /* locked-in-memory address space */
#define RLIMIT_NPROC    7               /* number of processes */
#endif  /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 356 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
#define RLIMIT_NOFILE   8               /* number of open files */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 358 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
#define RLIM_NLIMITS    9               /* total number of resource limits */
#endif  /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 360 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
#define _RLIMIT_POSIX_FLAG      0x1000  /* Set bit for strict POSIX */

/*
 * A structure representing a resource limit.  The address of an instance
 * of this structure is the second parameter to getrlimit()/setrlimit().
 */
struct rlimit {
	rlim_t  rlim_cur;               /* current (soft) limit */
	rlim_t  rlim_max;               /* maximum value for rlim_cur */
};

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 372 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
/*
 * proc_rlimit_control()
 *
 * Resource limit flavors
 */
#define RLIMIT_WAKEUPS_MONITOR          0x1 /* Configure the wakeups monitor. */
#define RLIMIT_CPU_USAGE_MONITOR        0x2 /* Configure the CPU usage monitor. */
#define RLIMIT_THREAD_CPULIMITS         0x3 /* Configure a blocking, per-thread, CPU limits. */
#define RLIMIT_FOOTPRINT_INTERVAL       0x4 /* Configure memory footprint interval tracking */

/*
 * Flags for wakeups monitor control.
 */
#define WAKEMON_ENABLE                  0x01
#define WAKEMON_DISABLE                 0x02
#define WAKEMON_GET_PARAMS              0x04
#define WAKEMON_SET_DEFAULTS            0x08
#define WAKEMON_MAKE_FATAL              0x10 /* Configure the task so that violations are fatal. */

/*
 * Flags for CPU usage monitor control.
 */
#define CPUMON_MAKE_FATAL               0x1000

/*
 * Flags for memory footprint interval tracking.
 */
#define FOOTPRINT_INTERVAL_RESET        0x1 /* Reset the footprint interval counter to zero */

struct proc_rlimit_control_wakeupmon {
	uint32_t wm_flags;
	int32_t wm_rate;
};



/* I/O type */
#define IOPOL_TYPE_DISK 0
#define IOPOL_TYPE_VFS_ATIME_UPDATES 2

/* scope */
#define IOPOL_SCOPE_PROCESS   0
#define IOPOL_SCOPE_THREAD    1
#define IOPOL_SCOPE_DARWIN_BG 2

/* I/O Priority */
#define IOPOL_DEFAULT           0
#define IOPOL_IMPORTANT         1
#define IOPOL_PASSIVE           2
#define IOPOL_THROTTLE          3
#define IOPOL_UTILITY           4
#define IOPOL_STANDARD          5

/* compatibility with older names */
#define IOPOL_APPLICATION       IOPOL_STANDARD
#define IOPOL_NORMAL            IOPOL_IMPORTANT


#define IOPOL_ATIME_UPDATES_DEFAULT     0
#define IOPOL_ATIME_UPDATES_OFF         1

#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 434 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4


__BEGIN_DECLS
int     getpriority(int, id_t);
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 439 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
int     getiopolicy_np(int, int) __OSX_AVAILABLE_STARTING(__MAC_10_5, __IPHONE_2_0);
#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 441 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
int     getrlimit(int, struct rlimit *) __DARWIN_ALIAS(getrlimit);
int     getrusage(int, struct rusage *);
int     setpriority(int, id_t, int);
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 445 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
int     setiopolicy_np(int, int, int) __OSX_AVAILABLE_STARTING(__MAC_10_5, __IPHONE_2_0);
#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 447 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
int     setrlimit(int, const struct rlimit *) __DARWIN_ALIAS(setrlimit);
__END_DECLS

#endif  /* !_SYS_RESOURCE_H_ */
# 451 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/resource.h" 3 4
# 111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 2 3 4

/*
 * Option bits for the third argument of wait4.  WNOHANG causes the
 * wait to not hang if there are no stopped or terminated processes, rather
 * returning an error indication in this case (pid==0).  WUNTRACED
 * indicates that the caller should receive status about untraced children
 * which stop due to signals.  If children are stopped and a wait without
 * this option is done, it is as though they were still running... nothing
 * about them is returned.
 */
#define WNOHANG         0x00000001  /* [XSI] no hang in wait/no child to reap */
#define WUNTRACED       0x00000002  /* [XSI] notify on stop, untraced child */

/*
 * Macros to test the exit status returned by wait
 * and extract the relevant values.
 */
#if 0 /* disabled by -frewrite-includes */
#if defined(_POSIX_C_SOURCE) && !defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#define _W_INT(i)       (i)
#else
# 131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#define _W_INT(w)       (*(int *)&(w))  /* convert union wait to int */
#define WCOREFLAG       0200
#endif /* (_POSIX_C_SOURCE && !_DARWIN_C_SOURCE) */
# 134 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4

/* These macros are permited, as they are in the implementation namespace */
#define _WSTATUS(x)     (_W_INT(x) & 0177)
#define _WSTOPPED       0177            /* _WSTATUS if process is stopped */

/*
 * [XSI] The <sys/wait.h> header shall define the following macros for
 * analysis of process status values
 */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 144 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#define WEXITSTATUS(x)  ((_W_INT(x) >> 8) & 0x000000ff)
#else /* !__DARWIN_UNIX03 */
# 146 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#define WEXITSTATUS(x)  (_W_INT(x) >> 8)
#endif /* !__DARWIN_UNIX03 */
# 148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
/* 0x13 == SIGCONT */
#define WSTOPSIG(x)     (_W_INT(x) >> 8)
#define WIFCONTINUED(x) (_WSTATUS(x) == _WSTOPPED && WSTOPSIG(x) == 0x13)
#define WIFSTOPPED(x)   (_WSTATUS(x) == _WSTOPPED && WSTOPSIG(x) != 0x13)
#define WIFEXITED(x)    (_WSTATUS(x) == 0)
#define WIFSIGNALED(x)  (_WSTATUS(x) != _WSTOPPED && _WSTATUS(x) != 0)
#define WTERMSIG(x)     (_WSTATUS(x))
#if 0 /* disabled by -frewrite-includes */
#if (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#define WCOREDUMP(x)    (_W_INT(x) & WCOREFLAG)

#define W_EXITCODE(ret, sig)    ((ret) << 8 | (sig))
#define W_STOPCODE(sig)         ((sig) << 8 | _WSTOPPED)
#endif /* (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)) */
# 161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4

/*
 * [XSI] The following symbolic constants shall be defined as possible
 * values for the fourth argument to waitid().
 */
/* WNOHANG already defined for wait4() */
/* WUNTRACED defined for wait4() but not for waitid() */
#define WEXITED         0x00000004  /* [XSI] Processes which have exitted */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 170 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
/* waitid() parameter */
#define WSTOPPED        0x00000008  /* [XSI] Any child stopped by signal */
#endif
# 173 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#define WCONTINUED      0x00000010  /* [XSI] Any child stopped then continued */
#define WNOWAIT         0x00000020  /* [XSI] Leave process returned waitable */


#if 0 /* disabled by -frewrite-includes */
#if (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 178 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
/* POSIX extensions and 4.2/4.3 compatability: */

/*
 * Tokens for special values of the "pid" parameter to wait4.
 */
#define WAIT_ANY        (-1)    /* any process */
#define WAIT_MYPGRP     0       /* any process in my process group */

#if 0 /* expanded by -frewrite-includes */
#include <machine/endian.h>
#endif /* expanded by -frewrite-includes */
# 186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/endian.h" 1 3 4
/*
 * Copyright (c) 2000-2007 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*
 * Copyright 1995 NeXT Computer, Inc. All rights reserved.
 */
#ifndef _BSD_MACHINE_ENDIAN_H_
#define _BSD_MACHINE_ENDIAN_H_

#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/endian.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include "i386/endian.h"
#endif /* expanded by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/endian.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/endian.h" 1 3 4
/*
 * Copyright (c) 2000-2002 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*
 * Copyright 1995 NeXT Computer, Inc. All rights reserved.
 */
/*
 * Copyright (c) 1987, 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)endian.h	8.1 (Berkeley) 6/11/93
 */

#ifndef _I386__ENDIAN_H_
#define _I386__ENDIAN_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/endian.h" 3 4
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/endian.h" 3 4
/*
 * Define _NOQUAD if the compiler does NOT support 64-bit integers.
 */
/* #define _NOQUAD */

/*
 * Define the order of 32-bit words in 64-bit words.
 */
#define _QUAD_HIGHWORD 1
#define _QUAD_LOWWORD 0

/*
 * Definitions for byte order, according to byte significance from low
 * address to high.
 */
#define __DARWIN_LITTLE_ENDIAN  1234    /* LSB first: i386, vax */
#define __DARWIN_BIG_ENDIAN     4321    /* MSB first: 68000, ibm, net */
#define __DARWIN_PDP_ENDIAN     3412    /* LSB first in word, MSW first in long */

#define __DARWIN_BYTE_ORDER     __DARWIN_LITTLE_ENDIAN

#if 0 /* disabled by -frewrite-includes */
#if     defined(KERNEL) || (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/endian.h" 3 4

#define LITTLE_ENDIAN   __DARWIN_LITTLE_ENDIAN
#define BIG_ENDIAN      __DARWIN_BIG_ENDIAN
#define PDP_ENDIAN      __DARWIN_PDP_ENDIAN

#define BYTE_ORDER      __DARWIN_BYTE_ORDER

#if 0 /* expanded by -frewrite-includes */
#include <sys/_endian.h>
#endif /* expanded by -frewrite-includes */
# 99 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/endian.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 1 3 4
/*
 * Copyright (c) 2004, 2006 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

/*
 * Copyright (c) 1995 NeXT Computer, Inc. All rights reserved.
 * Copyright (c) 2000-2002 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 1987, 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _SYS__ENDIAN_H_
#define _SYS__ENDIAN_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4
# 94 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4

/*
 * Macros for network/external number representation conversion.
 */

#if 0 /* disabled by -frewrite-includes */
#if defined(lint)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4

__BEGIN_DECLS
__uint16_t      ntohs(__uint16_t);
__uint16_t      htons(__uint16_t);
__uint32_t      ntohl(__uint32_t);
__uint32_t      htonl(__uint32_t);
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __DARWIN_BYTE_ORDER == __DARWIN_BIG_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4

#define ntohl(x)        ((__uint32_t)(x))
#define ntohs(x)        ((__uint16_t)(x))
#define htonl(x)        ((__uint32_t)(x))
#define htons(x)        ((__uint16_t)(x))

#if 0 /* disabled by -frewrite-includes */
#if     defined(KERNEL) || (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4

#define ntohll(x)       ((__uint64_t)(x))
#define htonll(x)       ((__uint64_t)(x))

#define NTOHL(x)        (x)
#define NTOHS(x)        (x)
#define NTOHLL(x)       (x)
#define HTONL(x)        (x)
#define HTONS(x)        (x)
#define HTONLL(x)       (x)
#endif /* defined(KERNEL) || (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)) */
# 127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4

#else   /* __DARWIN_BYTE_ORDER == __DARWIN_LITTLE_ENDIAN */
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <libkern/_OSByteOrder.h>
#endif /* expanded by -frewrite-includes */
# 130 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 1 3 4
/*
 * Copyright (c) 2006 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _OS__OSBYTEORDER_H
#define _OS__OSBYTEORDER_H

/*
 * This header is normally included from <libkern/OSByteOrder.h>.  However,
 * <sys/_endian.h> also includes this in the case of little-endian
 * architectures, so that we can map OSByteOrder routines to the hton* and ntoh*
 * macros.  This results in the asymmetry below; we only include
 * <libkern/arch/_OSByteOrder.h> for little-endian architectures.
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4

/* Macros for swapping constant values in the preprocessing stage. */
#define __DARWIN_OSSwapConstInt16(x) \
    ((__uint16_t)((((__uint16_t)(x) & 0xff00) >> 8) | \
	        (((__uint16_t)(x) & 0x00ff) << 8)))

#define __DARWIN_OSSwapConstInt32(x) \
    ((__uint32_t)((((__uint32_t)(x) & 0xff000000) >> 24) | \
	        (((__uint32_t)(x) & 0x00ff0000) >>  8) | \
	        (((__uint32_t)(x) & 0x0000ff00) <<  8) | \
	        (((__uint32_t)(x) & 0x000000ff) << 24)))

#define __DARWIN_OSSwapConstInt64(x) \
    ((__uint64_t)((((__uint64_t)(x) & 0xff00000000000000ULL) >> 56) | \
	        (((__uint64_t)(x) & 0x00ff000000000000ULL) >> 40) | \
	        (((__uint64_t)(x) & 0x0000ff0000000000ULL) >> 24) | \
	        (((__uint64_t)(x) & 0x000000ff00000000ULL) >>  8) | \
	        (((__uint64_t)(x) & 0x00000000ff000000ULL) <<  8) | \
	        (((__uint64_t)(x) & 0x0000000000ff0000ULL) << 24) | \
	        (((__uint64_t)(x) & 0x000000000000ff00ULL) << 40) | \
	        (((__uint64_t)(x) & 0x00000000000000ffULL) << 56)))

#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <libkern/i386/_OSByteOrder.h>
#endif /* expanded by -frewrite-includes */
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 1 3 4
/*
 * Copyright (c) 2006-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _OS__OSBYTEORDERI386_H
#define _OS__OSBYTEORDERI386_H

#if 0 /* disabled by -frewrite-includes */
#if !defined(__DARWIN_OS_INLINE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
#if 0 /* disabled by -frewrite-includes */
# if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
#        define __DARWIN_OS_INLINE static inline
#if 0 /* disabled by -frewrite-includes */
#if 0
# elif defined(__MWERKS__) || defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
#        define __DARWIN_OS_INLINE static inline
# else
# 38 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
#        define __DARWIN_OS_INLINE static __inline__
# endif
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
#endif
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4

/* Generic byte swapping functions. */

__DARWIN_OS_INLINE
__uint16_t
_OSSwapInt16(
	__uint16_t        _data
	)
{
	return (__uint16_t)((_data << 8) | (_data >> 8));
}

__DARWIN_OS_INLINE
__uint32_t
_OSSwapInt32(
	__uint32_t        _data
	)
{
#if 0 /* disabled by -frewrite-includes */
#if defined(__llvm__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 60 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
	return __builtin_bswap32(_data);
#else
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
	__asm__ ("bswap   %0" : "+r" (_data));
	return _data;
#endif
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
}

#if 0 /* disabled by -frewrite-includes */
#if defined(__llvm__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
__DARWIN_OS_INLINE
__uint64_t
_OSSwapInt64(
	__uint64_t        _data
	)
{
	return __builtin_bswap64(_data);
}

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__i386__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
__DARWIN_OS_INLINE
__uint64_t
_OSSwapInt64(
	__uint64_t        _data
	)
{
	__asm__ ("bswap   %%eax\n\t"
                 "bswap   %%edx\n\t"
                 "xchgl   %%eax, %%edx"
                 : "+A" (_data));
	return _data;
}
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
__DARWIN_OS_INLINE
__uint64_t
_OSSwapInt64(
	__uint64_t        _data
	)
{
	__asm__ ("bswap   %0" : "+r" (_data));
	return _data;
}
#else
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
#error Unknown architecture
#endif
# 103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4

#endif /* ! _OS__OSBYTEORDERI386_H */
# 105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/i386/_OSByteOrder.h" 3 4
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 2 3 4
#endif
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4



#define __DARWIN_OSSwapInt16(x) \
    ((__uint16_t)(__builtin_constant_p(x) ? __DARWIN_OSSwapConstInt16(x) : _OSSwapInt16(x)))

#define __DARWIN_OSSwapInt32(x) \
    (__builtin_constant_p(x) ? __DARWIN_OSSwapConstInt32(x) : _OSSwapInt32(x))

#define __DARWIN_OSSwapInt64(x) \
    (__builtin_constant_p(x) ? __DARWIN_OSSwapConstInt64(x) : _OSSwapInt64(x))

#else /* ! __GNUC__ */
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(__DARWIN_OS_INLINE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 85 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
#if 0 /* disabled by -frewrite-includes */
# if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
#        define __DARWIN_OS_INLINE static inline
#if 0 /* disabled by -frewrite-includes */
#if 0
# elif defined(__MWERKS__) || defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 88 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
#        define __DARWIN_OS_INLINE static inline
# else
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
#        define __DARWIN_OS_INLINE static __inline__
# endif
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
#endif
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4

__DARWIN_OS_INLINE
uint16_t
_OSSwapInt16(
	uint16_t                    data
	)
{
	return __DARWIN_OSSwapConstInt16(data);
}

__DARWIN_OS_INLINE
uint32_t
_OSSwapInt32(
	uint32_t                    data
	)
{
	return __DARWIN_OSSwapConstInt32(data);
}

__DARWIN_OS_INLINE
uint64_t
_OSSwapInt64(
	uint64_t                    data
	)
{
	return __DARWIN_OSSwapConstInt64(data);
}
#endif
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4

#define __DARWIN_OSSwapInt16(x) _OSSwapInt16(x)

#define __DARWIN_OSSwapInt32(x) _OSSwapInt32(x)

#define __DARWIN_OSSwapInt64(x) _OSSwapInt64(x)

#endif /* __GNUC__ */
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4

#endif /* ! _OS__OSBYTEORDER_H */
# 131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/libkern/_OSByteOrder.h" 3 4
# 131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 2 3 4

#define ntohs(x)        __DARWIN_OSSwapInt16(x)
#define htons(x)        __DARWIN_OSSwapInt16(x)

#define ntohl(x)        __DARWIN_OSSwapInt32(x)
#define htonl(x)        __DARWIN_OSSwapInt32(x)

#if 0 /* disabled by -frewrite-includes */
#if     defined(KERNEL) || (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4

#define ntohll(x)       __DARWIN_OSSwapInt64(x)
#define htonll(x)       __DARWIN_OSSwapInt64(x)

#define NTOHL(x)        (x) = ntohl((__uint32_t)x)
#define NTOHS(x)        (x) = ntohs((__uint16_t)x)
#define NTOHLL(x)       (x) = ntohll((__uint64_t)x)
#define HTONL(x)        (x) = htonl((__uint32_t)x)
#define HTONS(x)        (x) = htons((__uint16_t)x)
#define HTONLL(x)       (x) = htonll((__uint64_t)x)
#endif /* defined(KERNEL) || (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)) */
# 150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4
#endif /* __DARWIN_BYTE_ORDER */
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4
#endif /* !_SYS__ENDIAN_H_ */
# 152 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_endian.h" 3 4
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/endian.h" 2 3 4

#endif /* defined(KERNEL) || (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)) */
# 102 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/endian.h" 3 4
#endif /* !_I386__ENDIAN_H_ */
# 103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/endian.h" 3 4
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/endian.h" 2 3 4
#else
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/endian.h" 3 4
#error architecture not supported
#endif
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/endian.h" 3 4

#endif /* _BSD_MACHINE_ENDIAN_H_ */
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/endian.h" 3 4
# 187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 2 3 4

/*
 * Deprecated:
 * Structure of the information in the status word returned by wait4.
 * If w_stopval==_WSTOPPED, then the second structure describes
 * the information returned, else the first.
 */
union wait {
	int     w_status;               /* used in syscall */
	/*
	 * Terminated process status.
	 */
	struct {
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_BYTE_ORDER == __DARWIN_LITTLE_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
		unsigned int    w_Termsig:7,    /* termination signal */
		    w_Coredump:1,               /* core dump indicator */
		    w_Retcode:8,                /* exit code if w_termsig==0 */
		    w_Filler:16;                /* upper bits filler */
#endif
# 206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_BYTE_ORDER == __DARWIN_BIG_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
		unsigned int    w_Filler:16,    /* upper bits filler */
		    w_Retcode:8,                /* exit code if w_termsig==0 */
		    w_Coredump:1,               /* core dump indicator */
		    w_Termsig:7;                /* termination signal */
#endif
# 212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
	} w_T;
	/*
	 * Stopped process status.  Returned
	 * only for traced children unless requested
	 * with the WUNTRACED option bit.
	 */
	struct {
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_BYTE_ORDER == __DARWIN_LITTLE_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
		unsigned int    w_Stopval:8,    /* == W_STOPPED if stopped */
		    w_Stopsig:8,                /* signal that stopped us */
		    w_Filler:16;                /* upper bits filler */
#endif
# 224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_BYTE_ORDER == __DARWIN_BIG_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
		unsigned int    w_Filler:16,    /* upper bits filler */
		    w_Stopsig:8,                /* signal that stopped us */
		    w_Stopval:8;                /* == W_STOPPED if stopped */
#endif
# 229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
	} w_S;
};
#define w_termsig       w_T.w_Termsig
#define w_coredump      w_T.w_Coredump
#define w_retcode       w_T.w_Retcode
#define w_stopval       w_S.w_Stopval
#define w_stopsig       w_S.w_Stopsig

#endif /* (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)) */
# 238 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !(__DARWIN_UNIX03 - 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 240 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
/*
 * Stopped state value; cannot use waitid() parameter of the same name
 * in the same scope
 */
#define WSTOPPED        _WSTOPPED
#endif /* !__DARWIN_UNIX03 */
# 246 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4

__BEGIN_DECLS
pid_t   wait(int *) __DARWIN_ALIAS_C(wait);
pid_t   waitpid(pid_t, int *, int) __DARWIN_ALIAS_C(waitpid);
#ifndef _ANSI_SOURCE
int     waitid(idtype_t, id_t, siginfo_t *, int) __DARWIN_ALIAS_C(waitid);
#endif /* !_ANSI_SOURCE */
# 253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#if  (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 254 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
pid_t   wait3(int *, int, struct rusage *);
pid_t   wait4(pid_t, int *, int, struct rusage *);
#endif /* (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)) */
# 257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
__END_DECLS
#endif /* !_SYS_WAIT_H_ */
# 259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/wait.h" 3 4
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4
#if 0 /* disabled by -frewrite-includes */
#if (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <alloca.h>
#endif /* expanded by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 1 3 4
/*
 * Copyright (c) 2003 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

#ifndef _ALLOCA_H_
#define _ALLOCA_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 27 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 3 4
# 28 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 28 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 3 4
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 2 3 4

__BEGIN_DECLS
void	*alloca(size_t);		/* built-in for gcc */
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__) && __GNUC__ >= 3
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 3 4
/* built-in for gcc 3 */
#undef	alloca
#undef	__alloca
#define	alloca(size)	__alloca(size)
#define	__alloca(size)	__builtin_alloca(size)
#endif
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 3 4

#endif /* _ALLOCA_H_ */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/alloca.h" 3 4
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4
#endif /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#endif /* !_ANSI_SOURCE */
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

/* DO NOT REMOVE THIS COMMENT: fixincludes needs to see:
 * _GCC_SIZE_T */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ct_rune_t.h>
#endif /* expanded by -frewrite-includes */
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ct_rune_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _CT_RUNE_T
#define _CT_RUNE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_ct_rune_t */
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ct_rune_t.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ct_rune_t.h" 3 4
typedef __darwin_ct_rune_t ct_rune_t;
#endif /* _CT_RUNE_T */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ct_rune_t.h" 3 4
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_rune_t.h>
#endif /* expanded by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_rune_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _RUNE_T
#define _RUNE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_rune_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_rune_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_rune_t.h" 3 4
typedef __darwin_rune_t rune_t;
#endif /* _RUNE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_rune_t.h" 3 4
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4
#endif	/* !_ANSI_SOURCE && (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_wchar_t.h>
#endif /* expanded by -frewrite-includes */
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

/* wchar_t is a built-in type in C++ */
#ifndef __cplusplus
#ifndef _WCHAR_T
#define _WCHAR_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_wchar_t */
#endif /* expanded by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
typedef __darwin_wchar_t wchar_t;
#endif /* _WCHAR_T */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
#endif /* __cplusplus */
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
# 82 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4

typedef struct {
	int quot;		/* quotient */
	int rem;		/* remainder */
} div_t;

typedef struct {
	long quot;		/* quotient */
	long rem;		/* remainder */
} ldiv_t;

#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_NO_LONG_LONG
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 94 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
typedef struct {
	long long quot;
	long long rem;
} lldiv_t;
#endif /* !__DARWIN_NO_LONG_LONG */
# 99 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_null.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef NULL
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __DARWIN_NULL */
#endif /* expanded by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
#define NULL  __DARWIN_NULL
#endif  /* NULL */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4

#define	EXIT_FAILURE	1
#define	EXIT_SUCCESS	0

#define	RAND_MAX	0x7fffffff

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <_xlocale.h>
#endif /* expanded by -frewrite-includes */
# 108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#ifndef MB_CUR_MAX
#ifdef _USE_EXTENDED_LOCALES_
#define	MB_CUR_MAX	(___mb_cur_max())
#ifndef MB_CUR_MAX_L
#define	MB_CUR_MAX_L(x)	(___mb_cur_max_l(x))
#endif /* !MB_CUR_MAX_L */
# 117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#else /* !_USE_EXTENDED_LOCALES_ */
# 118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
extern int __mb_cur_max;
#define	MB_CUR_MAX	__mb_cur_max
#endif /* _USE_EXTENDED_LOCALES_ */
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#endif /* MB_CUR_MAX */
# 122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)) \
    && defined(_USE_EXTENDED_LOCALES_) && !defined(MB_CUR_MAX_L)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 125 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#define	MB_CUR_MAX_L(x)	(___mb_cur_max_l(x))
#endif
# 127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <malloc/_malloc.h>
#endif /* expanded by -frewrite-includes */
# 128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 1 3 4
/*
 * Copyright (c) 2018 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */

#ifndef _MALLOC_UNDERSCORE_MALLOC_H_
#define _MALLOC_UNDERSCORE_MALLOC_H_

/*
 * This header is included from <stdlib.h>, so the contents of this file have
 * broad source compatibility and POSIX conformance implications.
 * Be cautious about what is included and declared here.
 */

#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 2 3 4

__BEGIN_DECLS

void	*malloc(size_t __size) __result_use_check __alloc_size(1);
void	*calloc(size_t __count, size_t __size) __result_use_check __alloc_size(1,2);
void	 free(void *);
void	*realloc(void *__ptr, size_t __size) __result_use_check __alloc_size(2);
#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
void	*valloc(size_t) __alloc_size(1);
#endif // !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
# 47 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
int 	 posix_memalign(void **__memptr, size_t __alignment, size_t __size) __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_0);

__END_DECLS

#endif /* _MALLOC_UNDERSCORE_MALLOC_H_ */
# 52 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/malloc/_malloc.h" 3 4
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4

__BEGIN_DECLS
void	 abort(void) __dead2;
int	 abs(int) __pure2;
int	 atexit(void (* _Nonnull)(void));
double	 atof(const char *);
int	 atoi(const char *);
long	 atol(const char *);
#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_NO_LONG_LONG
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 138 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
long long
	 atoll(const char *);
#endif /* !__DARWIN_NO_LONG_LONG */
# 141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
void	*bsearch(const void *__key, const void *__base, size_t __nel,
	    size_t __width, int (* _Nonnull __compar)(const void *, const void *));
/* calloc is now declared in _malloc.h */
div_t	 div(int, int) __pure2;
void	 exit(int) __dead2;
/* free is now declared in _malloc.h */
char	*getenv(const char *);
long	 labs(long) __pure2;
ldiv_t	 ldiv(long, long) __pure2;
#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_NO_LONG_LONG
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
long long
	 llabs(long long);
lldiv_t	 lldiv(long long, long long);
#endif /* !__DARWIN_NO_LONG_LONG */
# 155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
/* malloc is now declared in _malloc.h */
int	 mblen(const char *__s, size_t __n);
size_t	 mbstowcs(wchar_t * __restrict , const char * __restrict, size_t);
int	 mbtowc(wchar_t * __restrict, const char * __restrict, size_t);
/* posix_memalign is now declared in _malloc.h */
void	 qsort(void *__base, size_t __nel, size_t __width,
	    int (* _Nonnull __compar)(const void *, const void *));
int	 rand(void) __swift_unavailable("Use arc4random instead.");
/* realloc is now declared in _malloc.h */
void	 srand(unsigned) __swift_unavailable("Use arc4random instead.");
double	 strtod(const char *, char **) __DARWIN_ALIAS(strtod);
float	 strtof(const char *, char **) __DARWIN_ALIAS(strtof);
long	 strtol(const char *__str, char **__endptr, int __base);
long double
	 strtold(const char *, char **);
#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_NO_LONG_LONG
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 171 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
long long 
	 strtoll(const char *__str, char **__endptr, int __base);
#endif /* !__DARWIN_NO_LONG_LONG */
# 174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
unsigned long
	 strtoul(const char *__str, char **__endptr, int __base);
#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_NO_LONG_LONG
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
unsigned long long
	 strtoull(const char *__str, char **__endptr, int __base);
#endif /* !__DARWIN_NO_LONG_LONG */
# 180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if TARGET_OS_EMBEDDED
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 182 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#define __swift_unavailable_on(osx_msg, ios_msg) __swift_unavailable(ios_msg)
#else
# 184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#define __swift_unavailable_on(osx_msg, ios_msg) __swift_unavailable(osx_msg)
#endif
# 186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

__swift_unavailable_on("Use posix_spawn APIs or NSTask instead.", "Process spawning is unavailable")
__API_AVAILABLE(macos(10.0)) __IOS_PROHIBITED
__WATCHOS_PROHIBITED __TVOS_PROHIBITED
int	 system(const char *) __DARWIN_ALIAS_C(system);

#undef __swift_unavailable_on

size_t	 wcstombs(char * __restrict, const wchar_t * __restrict, size_t);
int	 wctomb(char *, wchar_t);

#ifndef _ANSI_SOURCE
void	_Exit(int) __dead2;
long	 a64l(const char *);
double	 drand48(void);
char	*ecvt(double, int, int *__restrict, int *__restrict); /* LEGACY */
double	 erand48(unsigned short[3]);
char	*fcvt(double, int, int *__restrict, int *__restrict); /* LEGACY */
char	*gcvt(double, int, char *); /* LEGACY */
int	 getsubopt(char **, char * const *, char **);
int	 grantpt(int);
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
char	*initstate(unsigned, char *, size_t); /* no  __DARWIN_ALIAS needed */
#else /* !__DARWIN_UNIX03 */
# 210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
char	*initstate(unsigned long, char *, long);
#endif /* __DARWIN_UNIX03 */
# 212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
long	 jrand48(unsigned short[3]) __swift_unavailable("Use arc4random instead.");
char	*l64a(long);
void	 lcong48(unsigned short[7]);
long	 lrand48(void) __swift_unavailable("Use arc4random instead.");
char	*mktemp(char *);
int	 mkstemp(char *);
long	 mrand48(void) __swift_unavailable("Use arc4random instead.");
long	 nrand48(unsigned short[3]) __swift_unavailable("Use arc4random instead.");
int	 posix_openpt(int);
char	*ptsname(int);

#if 0 /* disabled by -frewrite-includes */
#if (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
int ptsname_r(int fildes, char *buffer, size_t buflen) __API_AVAILABLE(macos(10.13.4), ios(11.3), tvos(11.3), watchos(4.3));
#endif
# 226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

int	 putenv(char *) __DARWIN_ALIAS(putenv);
long	 random(void) __swift_unavailable("Use arc4random instead.");
int	 rand_r(unsigned *) __swift_unavailable("Use arc4random instead.");
#if 0 /* disabled by -frewrite-includes */
#if (__DARWIN_UNIX03 && !defined(_POSIX_C_SOURCE)) || defined(_DARWIN_C_SOURCE) || defined(_DARWIN_BETTER_REALPATH)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 231 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
char	*realpath(const char * __restrict, char * __restrict) __DARWIN_EXTSN(realpath);
#else /* (!__DARWIN_UNIX03 || _POSIX_C_SOURCE) && !_DARWIN_C_SOURCE && !_DARWIN_BETTER_REALPATH */
# 233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
char	*realpath(const char * __restrict, char * __restrict) __DARWIN_ALIAS(realpath);
#endif /* (__DARWIN_UNIX03 && _POSIX_C_SOURCE) || _DARWIN_C_SOURCE || _DARWIN_BETTER_REALPATH */
# 235 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
unsigned short
	*seed48(unsigned short[3]);
int	 setenv(const char * __name, const char * __value, int __overwrite) __DARWIN_ALIAS(setenv);
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 239 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
void	 setkey(const char *) __DARWIN_ALIAS(setkey);
#else /* !__DARWIN_UNIX03 */
# 241 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
int	 setkey(const char *);
#endif /* __DARWIN_UNIX03 */
# 243 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
char	*setstate(const char *);
void	 srand48(long);
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 246 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
void	 srandom(unsigned);
#else /* !__DARWIN_UNIX03 */
# 248 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
void	 srandom(unsigned long);
#endif /* __DARWIN_UNIX03 */
# 250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
int	 unlockpt(int);
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 252 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
int	 unsetenv(const char *) __DARWIN_ALIAS(unsetenv);
#else /* !__DARWIN_UNIX03 */
# 254 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
void	 unsetenv(const char *);
#endif /* __DARWIN_UNIX03 */
# 256 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#endif	/* !_ANSI_SOURCE */
# 257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h>
#endif /* expanded by -frewrite-includes */
# 259 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_dev_t.h>
#endif /* expanded by -frewrite-includes */
# 261 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_dev_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _DEV_T
#define _DEV_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_dev_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_dev_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_dev_t.h" 3 4
typedef __darwin_dev_t        dev_t;    /* device number */
#endif  /* _DEV_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_dev_t.h" 3 4
# 262 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_mode_t.h>
#endif /* expanded by -frewrite-includes */
# 262 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_mode_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _MODE_T
#define _MODE_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_mode_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_mode_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_mode_t.h" 3 4
typedef __darwin_mode_t         mode_t;
#endif  /* _MODE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_mode_t.h" 3 4
# 263 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types/_uint32_t.h>
#endif /* expanded by -frewrite-includes */
# 263 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 264 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

uint32_t arc4random(void);
void	 arc4random_addrandom(unsigned char * /*dat*/, int /*datlen*/)
    __OSX_DEPRECATED(10.0, 10.12, "use arc4random_stir")
    __IOS_DEPRECATED(2.0, 10.0, "use arc4random_stir")
    __TVOS_DEPRECATED(2.0, 10.0, "use arc4random_stir")
    __WATCHOS_DEPRECATED(1.0, 3.0, "use arc4random_stir");
void	 arc4random_buf(void * __buf, size_t __nbytes) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
void	 arc4random_stir(void);
uint32_t
	 arc4random_uniform(uint32_t __upper_bound) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
#ifdef __BLOCKS__
int	 atexit_b(void (^ _Nonnull)(void)) __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2);
void	*bsearch_b(const void *__key, const void *__base, size_t __nel,
	    size_t __width, int (^ _Nonnull __compar)(const void *, const void *)) __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2);
#endif /* __BLOCKS__ */
# 280 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

	 /* getcap(3) functions */
char	*cgetcap(char *, const char *, int);
int	 cgetclose(void);
int	 cgetent(char **, char **, const char *);
int	 cgetfirst(char **, char **);
int	 cgetmatch(const char *, const char *);
int	 cgetnext(char **, char **);
int	 cgetnum(char *, const char *, long *);
int	 cgetset(const char *);
int	 cgetstr(char *, const char *, char **);
int	 cgetustr(char *, const char *, char **);

int	 daemon(int, int) __DARWIN_1050(daemon) __OSX_AVAILABLE_BUT_DEPRECATED_MSG(__MAC_10_0, __MAC_10_5, __IPHONE_2_0, __IPHONE_2_0, "Use posix_spawn APIs instead.") __WATCHOS_PROHIBITED __TVOS_PROHIBITED;
char	*devname(dev_t, mode_t);
char	*devname_r(dev_t, mode_t, char *buf, int len);
char	*getbsize(int *, long *);
int	 getloadavg(double [], int);
const char
	*getprogname(void);

int	 heapsort(void *__base, size_t __nel, size_t __width,
	    int (* _Nonnull __compar)(const void *, const void *));
#ifdef __BLOCKS__
int	 heapsort_b(void *__base, size_t __nel, size_t __width,
	    int (^ _Nonnull __compar)(const void *, const void *)) __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2);
#endif /* __BLOCKS__ */
# 307 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
int	 mergesort(void *__base, size_t __nel, size_t __width,
	    int (* _Nonnull __compar)(const void *, const void *));
#ifdef __BLOCKS__
int	 mergesort_b(void *__base, size_t __nel, size_t __width,
	    int (^ _Nonnull __compar)(const void *, const void *)) __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2);
#endif /* __BLOCKS__ */
# 313 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
void	 psort(void *__base, size_t __nel, size_t __width,
	    int (* _Nonnull __compar)(const void *, const void *)) __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2);
#ifdef __BLOCKS__
void	 psort_b(void *__base, size_t __nel, size_t __width,
	    int (^ _Nonnull __compar)(const void *, const void *)) __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2);
#endif /* __BLOCKS__ */
# 319 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
void	 psort_r(void *__base, size_t __nel, size_t __width, void *,
	    int (* _Nonnull __compar)(void *, const void *, const void *))  __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2);
#ifdef __BLOCKS__
void	 qsort_b(void *__base, size_t __nel, size_t __width,
	    int (^ _Nonnull __compar)(const void *, const void *)) __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2);
#endif /* __BLOCKS__ */
# 325 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
void	 qsort_r(void *__base, size_t __nel, size_t __width, void *,
	    int (* _Nonnull __compar)(void *, const void *, const void *));
int	 radixsort(const unsigned char **__base, int __nel, const unsigned char *__table,
	    unsigned __endbyte);
void	 setprogname(const char *);
int	 sradixsort(const unsigned char **__base, int __nel, const unsigned char *__table,
	    unsigned __endbyte);
void	 sranddev(void);
void	 srandomdev(void);
void	*reallocf(void *__ptr, size_t __size) __alloc_size(2);
#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_NO_LONG_LONG
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 336 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
long long
	 strtoq(const char *__str, char **__endptr, int __base);
unsigned long long
	 strtouq(const char *__str, char **__endptr, int __base);
#endif /* !__DARWIN_NO_LONG_LONG */
# 341 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
extern char *suboptarg;		/* getsubopt(3) external variable */
/* valloc is now declared in _malloc.h */
#endif	/* !_ANSI_SOURCE && !_POSIX_SOURCE */
# 344 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

/* Poison the following routines if -fshort-wchar is set */
#if 0 /* disabled by -frewrite-includes */
#if !defined(__cplusplus) && defined(__WCHAR_MAX__) && __WCHAR_MAX__ <= 0xffffU
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 347 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#pragma GCC poison mbstowcs mbtowc wcstombs wctomb
#endif
# 349 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
__END_DECLS

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_stdlib.h>
#endif /* expanded by -frewrite-includes */
# 352 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 354 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4

#endif /* _STDLIB_H_ */
# 356 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 2 3

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 1 3
// -*- C++ -*-
//===---------------------------- math.h ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_MATH_H
#define _LIBCPP_MATH_H

/*
    math.h synopsis

Macros:

    HUGE_VAL
    HUGE_VALF               // C99
    HUGE_VALL               // C99
    INFINITY                // C99
    NAN                     // C99
    FP_INFINITE             // C99
    FP_NAN                  // C99
    FP_NORMAL               // C99
    FP_SUBNORMAL            // C99
    FP_ZERO                 // C99
    FP_FAST_FMA             // C99
    FP_FAST_FMAF            // C99
    FP_FAST_FMAL            // C99
    FP_ILOGB0               // C99
    FP_ILOGBNAN             // C99
    MATH_ERRNO              // C99
    MATH_ERREXCEPT          // C99
    math_errhandling        // C99

Types:

    float_t                 // C99
    double_t                // C99

// C90

floating_point abs(floating_point x);

floating_point acos (arithmetic x);
float          acosf(float x);
long double    acosl(long double x);

floating_point asin (arithmetic x);
float          asinf(float x);
long double    asinl(long double x);

floating_point atan (arithmetic x);
float          atanf(float x);
long double    atanl(long double x);

floating_point atan2 (arithmetic y, arithmetic x);
float          atan2f(float y, float x);
long double    atan2l(long double y, long double x);

floating_point ceil (arithmetic x);
float          ceilf(float x);
long double    ceill(long double x);

floating_point cos (arithmetic x);
float          cosf(float x);
long double    cosl(long double x);

floating_point cosh (arithmetic x);
float          coshf(float x);
long double    coshl(long double x);

floating_point exp (arithmetic x);
float          expf(float x);
long double    expl(long double x);

floating_point fabs (arithmetic x);
float          fabsf(float x);
long double    fabsl(long double x);

floating_point floor (arithmetic x);
float          floorf(float x);
long double    floorl(long double x);

floating_point fmod (arithmetic x, arithmetic y);
float          fmodf(float x, float y);
long double    fmodl(long double x, long double y);

floating_point frexp (arithmetic value, int* exp);
float          frexpf(float value, int* exp);
long double    frexpl(long double value, int* exp);

floating_point ldexp (arithmetic value, int exp);
float          ldexpf(float value, int exp);
long double    ldexpl(long double value, int exp);

floating_point log (arithmetic x);
float          logf(float x);
long double    logl(long double x);

floating_point log10 (arithmetic x);
float          log10f(float x);
long double    log10l(long double x);

floating_point modf (floating_point value, floating_point* iptr);
float          modff(float value, float* iptr);
long double    modfl(long double value, long double* iptr);

floating_point pow (arithmetic x, arithmetic y);
float          powf(float x, float y);
long double    powl(long double x, long double y);

floating_point sin (arithmetic x);
float          sinf(float x);
long double    sinl(long double x);

floating_point sinh (arithmetic x);
float          sinhf(float x);
long double    sinhl(long double x);

floating_point sqrt (arithmetic x);
float          sqrtf(float x);
long double    sqrtl(long double x);

floating_point tan (arithmetic x);
float          tanf(float x);
long double    tanl(long double x);

floating_point tanh (arithmetic x);
float          tanhf(float x);
long double    tanhl(long double x);

//  C99

bool signbit(arithmetic x);

int fpclassify(arithmetic x);

bool isfinite(arithmetic x);
bool isinf(arithmetic x);
bool isnan(arithmetic x);
bool isnormal(arithmetic x);

bool isgreater(arithmetic x, arithmetic y);
bool isgreaterequal(arithmetic x, arithmetic y);
bool isless(arithmetic x, arithmetic y);
bool islessequal(arithmetic x, arithmetic y);
bool islessgreater(arithmetic x, arithmetic y);
bool isunordered(arithmetic x, arithmetic y);

floating_point acosh (arithmetic x);
float          acoshf(float x);
long double    acoshl(long double x);

floating_point asinh (arithmetic x);
float          asinhf(float x);
long double    asinhl(long double x);

floating_point atanh (arithmetic x);
float          atanhf(float x);
long double    atanhl(long double x);

floating_point cbrt (arithmetic x);
float          cbrtf(float x);
long double    cbrtl(long double x);

floating_point copysign (arithmetic x, arithmetic y);
float          copysignf(float x, float y);
long double    copysignl(long double x, long double y);

floating_point erf (arithmetic x);
float          erff(float x);
long double    erfl(long double x);

floating_point erfc (arithmetic x);
float          erfcf(float x);
long double    erfcl(long double x);

floating_point exp2 (arithmetic x);
float          exp2f(float x);
long double    exp2l(long double x);

floating_point expm1 (arithmetic x);
float          expm1f(float x);
long double    expm1l(long double x);

floating_point fdim (arithmetic x, arithmetic y);
float          fdimf(float x, float y);
long double    fdiml(long double x, long double y);

floating_point fma (arithmetic x, arithmetic y, arithmetic z);
float          fmaf(float x, float y, float z);
long double    fmal(long double x, long double y, long double z);

floating_point fmax (arithmetic x, arithmetic y);
float          fmaxf(float x, float y);
long double    fmaxl(long double x, long double y);

floating_point fmin (arithmetic x, arithmetic y);
float          fminf(float x, float y);
long double    fminl(long double x, long double y);

floating_point hypot (arithmetic x, arithmetic y);
float          hypotf(float x, float y);
long double    hypotl(long double x, long double y);

int ilogb (arithmetic x);
int ilogbf(float x);
int ilogbl(long double x);

floating_point lgamma (arithmetic x);
float          lgammaf(float x);
long double    lgammal(long double x);

long long llrint (arithmetic x);
long long llrintf(float x);
long long llrintl(long double x);

long long llround (arithmetic x);
long long llroundf(float x);
long long llroundl(long double x);

floating_point log1p (arithmetic x);
float          log1pf(float x);
long double    log1pl(long double x);

floating_point log2 (arithmetic x);
float          log2f(float x);
long double    log2l(long double x);

floating_point logb (arithmetic x);
float          logbf(float x);
long double    logbl(long double x);

long lrint (arithmetic x);
long lrintf(float x);
long lrintl(long double x);

long lround (arithmetic x);
long lroundf(float x);
long lroundl(long double x);

double      nan (const char* str);
float       nanf(const char* str);
long double nanl(const char* str);

floating_point nearbyint (arithmetic x);
float          nearbyintf(float x);
long double    nearbyintl(long double x);

floating_point nextafter (arithmetic x, arithmetic y);
float          nextafterf(float x, float y);
long double    nextafterl(long double x, long double y);

floating_point nexttoward (arithmetic x, long double y);
float          nexttowardf(float x, long double y);
long double    nexttowardl(long double x, long double y);

floating_point remainder (arithmetic x, arithmetic y);
float          remainderf(float x, float y);
long double    remainderl(long double x, long double y);

floating_point remquo (arithmetic x, arithmetic y, int* pquo);
float          remquof(float x, float y, int* pquo);
long double    remquol(long double x, long double y, int* pquo);

floating_point rint (arithmetic x);
float          rintf(float x);
long double    rintl(long double x);

floating_point round (arithmetic x);
float          roundf(float x);
long double    roundl(long double x);

floating_point scalbln (arithmetic x, long ex);
float          scalblnf(float x, long ex);
long double    scalblnl(long double x, long ex);

floating_point scalbn (arithmetic x, int ex);
float          scalbnf(float x, int ex);
long double    scalbnl(long double x, int ex);

floating_point tgamma (arithmetic x);
float          tgammaf(float x);
long double    tgammal(long double x);

floating_point trunc (arithmetic x);
float          truncf(float x);
long double    truncl(long double x);

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 294 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 298 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#endif
# 299 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#define _LIBCPP_STDLIB_INCLUDE_NEXT
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 301 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 302 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 2 3

#if 0 /* expanded by -frewrite-includes */
#include_next <math.h>
#endif /* expanded by -frewrite-includes */
# 303 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 1 3 4
/*
 * Copyright (c) 2002-2017 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 * 
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

#ifndef __MATH_H__
#define __MATH_H__

#ifndef __MATH__
#define __MATH__
#endif
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

__BEGIN_DECLS

/******************************************************************************
 * Floating point data types                                                  *
 ******************************************************************************/

/*  Define float_t and double_t per C standard, ISO/IEC 9899:2011 7.12 2,
    taking advantage of GCC's __FLT_EVAL_METHOD__ (which a compiler may
    define anytime and GCC does) that shadows FLT_EVAL_METHOD (which a
    compiler must define only in float.h).                                    */
#if 0 /* disabled by -frewrite-includes */
#if __FLT_EVAL_METHOD__ == 0
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
    typedef float float_t;
    typedef double double_t;
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __FLT_EVAL_METHOD__ == 1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 47 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
    typedef double float_t;
    typedef double double_t;
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __FLT_EVAL_METHOD__ == 2 || __FLT_EVAL_METHOD__ == -1
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 50 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
    typedef long double float_t;
    typedef long double double_t;
#else /* __FLT_EVAL_METHOD__ */
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
#   error "Unsupported value of __FLT_EVAL_METHOD__."
#endif /* __FLT_EVAL_METHOD__ */
# 55 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 57 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
#   define    HUGE_VAL     __builtin_huge_val()
#   define    HUGE_VALF    __builtin_huge_valf()
#   define    HUGE_VALL    __builtin_huge_vall()
#   define    NAN          __builtin_nanf("0x7fc00000")
#else
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
#   define    HUGE_VAL     1e500
#   define    HUGE_VALF    1e50f
#   define    HUGE_VALL    1e5000L
#   define    NAN          __nan()
#endif
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

#define INFINITY    HUGE_VALF

/******************************************************************************
 *      Taxonomy of floating point data types                                 *
 ******************************************************************************/

#define FP_NAN          1
#define FP_INFINITE     2
#define FP_ZERO         3
#define FP_NORMAL       4
#define FP_SUBNORMAL    5
#define FP_SUPERNORMAL  6 /* legacy PowerPC support; this is otherwise unused */

#if 0 /* disabled by -frewrite-includes */
#if defined __arm64__ || defined __ARM_VFPV4__
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 82 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
/*  On these architectures, fma(), fmaf( ), and fmal( ) are generally about as
    fast as (or faster than) separate multiply and add of the same operands.  */
#   define FP_FAST_FMA     1
#   define FP_FAST_FMAF    1
#   define FP_FAST_FMAL    1
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif (defined __i386__ || defined __x86_64__) && (defined __FMA__ || defined __AVX512F__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 88 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
/*  When targeting the FMA ISA extension, fma() and fmaf( ) are generally
    about as fast as (or faster than) separate multiply and add of the same
    operands, but fmal( ) may be more costly.                                 */
#   define FP_FAST_FMA     1
#   define FP_FAST_FMAF    1
#   undef  FP_FAST_FMAL
#else
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
/*  On these architectures, fma( ), fmaf( ), and fmal( ) function calls are
    significantly more costly than separate multiply and add operations.      */
#   undef  FP_FAST_FMA
#   undef  FP_FAST_FMAF
#   undef  FP_FAST_FMAL
#endif
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

/* The values returned by `ilogb' for 0 and NaN respectively. */
#define FP_ILOGB0      (-2147483647 - 1)
#define FP_ILOGBNAN    (-2147483647 - 1)

/* Bitmasks for the math_errhandling macro.  */
#define MATH_ERRNO        1    /* errno set by math functions.  */
#define MATH_ERREXCEPT    2    /* Exceptions raised by math functions.  */

#define math_errhandling (__math_errhandling())
extern int __math_errhandling(void);

/******************************************************************************
 *                                                                            *
 *                              Inquiry macros                                *
 *                                                                            *
 *  fpclassify      Returns one of the FP_* values.                           *
 *  isnormal        Non-zero if and only if the argument x is normalized.     *
 *  isfinite        Non-zero if and only if the argument x is finite.         *
 *  isnan           Non-zero if and only if the argument x is a NaN.          *
 *  signbit         Non-zero if and only if the sign of the argument x is     *
 *                  negative.  This includes, NaNs, infinities and zeros.     *
 *                                                                            *
 ******************************************************************************/

#define fpclassify(x)                                                    \
    ( sizeof(x) == sizeof(float)  ? __fpclassifyf((float)(x))            \
    : sizeof(x) == sizeof(double) ? __fpclassifyd((double)(x))           \
                                  : __fpclassifyl((long double)(x)))

extern int __fpclassifyf(float);
extern int __fpclassifyd(double);
extern int __fpclassifyl(long double);

#if 0 /* disabled by -frewrite-includes */
#if (defined(__GNUC__) && 0 == __FINITE_MATH_ONLY__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 136 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
/*  These inline functions may fail to return expected results if unsafe
    math optimizations like those enabled by -ffast-math are turned on.
    Thus, (somewhat surprisingly) you only get the fast inline
    implementations if such compiler options are NOT enabled.  This is
    because the inline functions require the compiler to be adhering to
    the standard in order to work properly; -ffast-math, among other
    things, implies that NaNs don't happen, which allows the compiler to
    optimize away checks like x != x, which might lead to things like
    isnan(NaN) returning false.                                               
 
    Thus, if you compile with -ffast-math, actual function calls are
    generated for these utilities.                                            */
    
#define isnormal(x)                                                      \
    ( sizeof(x) == sizeof(float)  ? __inline_isnormalf((float)(x))       \
    : sizeof(x) == sizeof(double) ? __inline_isnormald((double)(x))      \
                                  : __inline_isnormall((long double)(x)))

#define isfinite(x)                                                      \
    ( sizeof(x) == sizeof(float)  ? __inline_isfinitef((float)(x))       \
    : sizeof(x) == sizeof(double) ? __inline_isfinited((double)(x))      \
                                  : __inline_isfinitel((long double)(x)))

#define isinf(x)                                                         \
    ( sizeof(x) == sizeof(float)  ? __inline_isinff((float)(x))          \
    : sizeof(x) == sizeof(double) ? __inline_isinfd((double)(x))         \
                                  : __inline_isinfl((long double)(x)))

#define isnan(x)                                                         \
    ( sizeof(x) == sizeof(float)  ? __inline_isnanf((float)(x))          \
    : sizeof(x) == sizeof(double) ? __inline_isnand((double)(x))         \
                                  : __inline_isnanl((long double)(x)))

#define signbit(x)                                                       \
    ( sizeof(x) == sizeof(float)  ? __inline_signbitf((float)(x))        \
    : sizeof(x) == sizeof(double) ? __inline_signbitd((double)(x))       \
                                  : __inline_signbitl((long double)(x)))

__header_always_inline int __inline_isfinitef(float);
__header_always_inline int __inline_isfinited(double);
__header_always_inline int __inline_isfinitel(long double);
__header_always_inline int __inline_isinff(float);
__header_always_inline int __inline_isinfd(double);
__header_always_inline int __inline_isinfl(long double);
__header_always_inline int __inline_isnanf(float);
__header_always_inline int __inline_isnand(double);
__header_always_inline int __inline_isnanl(long double);
__header_always_inline int __inline_isnormalf(float);
__header_always_inline int __inline_isnormald(double);
__header_always_inline int __inline_isnormall(long double);
__header_always_inline int __inline_signbitf(float);
__header_always_inline int __inline_signbitd(double);
__header_always_inline int __inline_signbitl(long double);
    
__header_always_inline int __inline_isfinitef(float __x) {
    return __x == __x && __builtin_fabsf(__x) != __builtin_inff();
}
__header_always_inline int __inline_isfinited(double __x) {
    return __x == __x && __builtin_fabs(__x) != __builtin_inf();
}
__header_always_inline int __inline_isfinitel(long double __x) {
    return __x == __x && __builtin_fabsl(__x) != __builtin_infl();
}
__header_always_inline int __inline_isinff(float __x) {
    return __builtin_fabsf(__x) == __builtin_inff();
}
__header_always_inline int __inline_isinfd(double __x) {
    return __builtin_fabs(__x) == __builtin_inf();
}
__header_always_inline int __inline_isinfl(long double __x) {
    return __builtin_fabsl(__x) == __builtin_infl();
}
__header_always_inline int __inline_isnanf(float __x) {
    return __x != __x;
}
__header_always_inline int __inline_isnand(double __x) {
    return __x != __x;
}
__header_always_inline int __inline_isnanl(long double __x) {
    return __x != __x;
}
__header_always_inline int __inline_signbitf(float __x) {
    union { float __f; unsigned int __u; } __u;
    __u.__f = __x;
    return (int)(__u.__u >> 31);
}
__header_always_inline int __inline_signbitd(double __x) {
    union { double __f; unsigned long long __u; } __u;
    __u.__f = __x;
    return (int)(__u.__u >> 63);
}
#if 0 /* disabled by -frewrite-includes */
#if defined __i386__ || defined __x86_64__
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
__header_always_inline int __inline_signbitl(long double __x) {
    union {
        long double __ld;
        struct{ unsigned long long __m; unsigned short __sexp; } __p;
    } __u;
    __u.__ld = __x;
    return (int)(__u.__p.__sexp >> 15);
}
#else
# 237 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
__header_always_inline int __inline_signbitl(long double __x) {
    union { long double __f; unsigned long long __u;} __u;
    __u.__f = __x;
    return (int)(__u.__u >> 63);
}
#endif
# 243 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
__header_always_inline int __inline_isnormalf(float __x) {
    return __inline_isfinitef(__x) && __builtin_fabsf(__x) >= __FLT_MIN__;
}
__header_always_inline int __inline_isnormald(double __x) {
    return __inline_isfinited(__x) && __builtin_fabs(__x) >= __DBL_MIN__;
}
__header_always_inline int __inline_isnormall(long double __x) {
    return __inline_isfinitel(__x) && __builtin_fabsl(__x) >= __LDBL_MIN__;
}
    
#else /* defined(__GNUC__) && 0 == __FINITE_MATH_ONLY__ */
# 254 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

/*  Implementations making function calls to fall back on when -ffast-math
    or similar is specified.  These are not available in iOS versions prior
    to 6.0.  If you need them, you must target that version or later.         */
    
#define isnormal(x)                                               \
    ( sizeof(x) == sizeof(float)  ? __isnormalf((float)(x))       \
    : sizeof(x) == sizeof(double) ? __isnormald((double)(x))      \
                                  : __isnormall((long double)(x)))
    
#define isfinite(x)                                               \
    ( sizeof(x) == sizeof(float)  ? __isfinitef((float)(x))       \
    : sizeof(x) == sizeof(double) ? __isfinited((double)(x))      \
                                  : __isfinitel((long double)(x)))
    
#define isinf(x)                                                  \
    ( sizeof(x) == sizeof(float)  ? __isinff((float)(x))          \
    : sizeof(x) == sizeof(double) ? __isinfd((double)(x))         \
                                  : __isinfl((long double)(x)))
    
#define isnan(x)                                                  \
    ( sizeof(x) == sizeof(float)  ? __isnanf((float)(x))          \
    : sizeof(x) == sizeof(double) ? __isnand((double)(x))         \
                                  : __isnanl((long double)(x)))
    
#define signbit(x)                                                \
    ( sizeof(x) == sizeof(float)  ? __signbitf((float)(x))        \
    : sizeof(x) == sizeof(double) ? __signbitd((double)(x))       \
                                  : __signbitl((long double)(x)))
    
extern int __isnormalf(float);
extern int __isnormald(double);
extern int __isnormall(long double);
extern int __isfinitef(float);
extern int __isfinited(double);
extern int __isfinitel(long double);
extern int __isinff(float);
extern int __isinfd(double);
extern int __isinfl(long double);
extern int __isnanf(float);
extern int __isnand(double);
extern int __isnanl(long double);
extern int __signbitf(float);
extern int __signbitd(double);
extern int __signbitl(long double);

#endif /* defined(__GNUC__) && 0 == __FINITE_MATH_ONLY__ */
# 301 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

/******************************************************************************
 *                                                                            *
 *                              Math Functions                                *
 *                                                                            *
 ******************************************************************************/
    
extern float acosf(float);
extern double acos(double);
extern long double acosl(long double);
    
extern float asinf(float);
extern double asin(double);
extern long double asinl(long double);
    
extern float atanf(float);
extern double atan(double);
extern long double atanl(long double);
    
extern float atan2f(float, float);
extern double atan2(double, double);
extern long double atan2l(long double, long double);
    
extern float cosf(float);
extern double cos(double);
extern long double cosl(long double);
    
extern float sinf(float);
extern double sin(double);
extern long double sinl(long double);
    
extern float tanf(float);
extern double tan(double);
extern long double tanl(long double);
    
extern float acoshf(float);
extern double acosh(double);
extern long double acoshl(long double);
    
extern float asinhf(float);
extern double asinh(double);
extern long double asinhl(long double);
    
extern float atanhf(float);
extern double atanh(double);
extern long double atanhl(long double);
    
extern float coshf(float);
extern double cosh(double);
extern long double coshl(long double);
    
extern float sinhf(float);
extern double sinh(double);
extern long double sinhl(long double);
    
extern float tanhf(float);
extern double tanh(double);
extern long double tanhl(long double);
    
extern float expf(float);
extern double exp(double);
extern long double expl(long double);

extern float exp2f(float);
extern double exp2(double); 
extern long double exp2l(long double); 

extern float expm1f(float);
extern double expm1(double); 
extern long double expm1l(long double); 

extern float logf(float);
extern double log(double);
extern long double logl(long double);

extern float log10f(float);
extern double log10(double);
extern long double log10l(long double);

extern float log2f(float);
extern double log2(double);
extern long double log2l(long double);

extern float log1pf(float);
extern double log1p(double);
extern long double log1pl(long double);

extern float logbf(float);
extern double logb(double);
extern long double logbl(long double);

extern float modff(float, float *);
extern double modf(double, double *);
extern long double modfl(long double, long double *);

extern float ldexpf(float, int);
extern double ldexp(double, int);
extern long double ldexpl(long double, int);

extern float frexpf(float, int *);
extern double frexp(double, int *);
extern long double frexpl(long double, int *);

extern int ilogbf(float);
extern int ilogb(double);
extern int ilogbl(long double);

extern float scalbnf(float, int);
extern double scalbn(double, int);
extern long double scalbnl(long double, int);

extern float scalblnf(float, long int);
extern double scalbln(double, long int);
extern long double scalblnl(long double, long int);

extern float fabsf(float);
extern double fabs(double);
extern long double fabsl(long double);

extern float cbrtf(float);
extern double cbrt(double);
extern long double cbrtl(long double);

extern float hypotf(float, float);
extern double hypot(double, double);
extern long double hypotl(long double, long double);

extern float powf(float, float);
extern double pow(double, double);
extern long double powl(long double, long double);

extern float sqrtf(float);
extern double sqrt(double);
extern long double sqrtl(long double);

extern float erff(float);
extern double erf(double);
extern long double erfl(long double);

extern float erfcf(float);
extern double erfc(double);
extern long double erfcl(long double);

/*	lgammaf, lgamma, and lgammal are not thread-safe. The thread-safe
    variants lgammaf_r, lgamma_r, and lgammal_r are made available if
    you define the _REENTRANT symbol before including <math.h>                */
extern float lgammaf(float);
extern double lgamma(double);
extern long double lgammal(long double);

extern float tgammaf(float);
extern double tgamma(double);
extern long double tgammal(long double);

extern float ceilf(float);
extern double ceil(double);
extern long double ceill(long double);

extern float floorf(float);
extern double floor(double);
extern long double floorl(long double);

extern float nearbyintf(float);
extern double nearbyint(double);
extern long double nearbyintl(long double);

extern float rintf(float);
extern double rint(double);
extern long double rintl(long double);

extern long int lrintf(float);
extern long int lrint(double);
extern long int lrintl(long double);

extern float roundf(float);
extern double round(double);
extern long double roundl(long double);

extern long int lroundf(float);
extern long int lround(double);
extern long int lroundl(long double);
    
/*  long long is not part of C90. Make sure you are passing -std=c99 or
    -std=gnu99 or higher if you need these functions returning long longs     */
#if 0 /* disabled by -frewrite-includes */
#if !(__DARWIN_NO_LONG_LONG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 486 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
extern long long int llrintf(float);
extern long long int llrint(double);
extern long long int llrintl(long double);

extern long long int llroundf(float);
extern long long int llround(double);
extern long long int llroundl(long double);
#endif /* !(__DARWIN_NO_LONG_LONG) */
# 494 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

extern float truncf(float);
extern double trunc(double);
extern long double truncl(long double);

extern float fmodf(float, float);
extern double fmod(double, double);
extern long double fmodl(long double, long double);

extern float remainderf(float, float);
extern double remainder(double, double);
extern long double remainderl(long double, long double);

extern float remquof(float, float, int *);
extern double remquo(double, double, int *);
extern long double remquol(long double, long double, int *);

extern float copysignf(float, float);
extern double copysign(double, double);
extern long double copysignl(long double, long double);

extern float nanf(const char *);
extern double nan(const char *);
extern long double nanl(const char *);

extern float nextafterf(float, float);
extern double nextafter(double, double);
extern long double nextafterl(long double, long double);

extern double nexttoward(double, long double);
extern float nexttowardf(float, long double);
extern long double nexttowardl(long double, long double);

extern float fdimf(float, float);
extern double fdim(double, double);
extern long double fdiml(long double, long double);

extern float fmaxf(float, float);
extern double fmax(double, double);
extern long double fmaxl(long double, long double);

extern float fminf(float, float);
extern double fmin(double, double);
extern long double fminl(long double, long double);

extern float fmaf(float, float, float);
extern double fma(double, double, double);
extern long double fmal(long double, long double, long double);

#define isgreater(x, y) __builtin_isgreater((x),(y))
#define isgreaterequal(x, y) __builtin_isgreaterequal((x),(y))
#define isless(x, y) __builtin_isless((x),(y))
#define islessequal(x, y) __builtin_islessequal((x),(y))
#define islessgreater(x, y) __builtin_islessgreater((x),(y))
#define isunordered(x, y) __builtin_isunordered((x),(y))

/* Deprecated functions; use the INFINITY and NAN macros instead.             */
extern float __inff(void)
__API_DEPRECATED("use `(float)INFINITY` instead", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);
extern double __inf(void)
__API_DEPRECATED("use `INFINITY` instead", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);
extern long double __infl(void)
__API_DEPRECATED("use `(long double)INFINITY` instead", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);
extern float __nan(void)
__API_DEPRECATED("use `NAN` instead", macos(10.0, 10.14)) __API_UNAVAILABLE(ios, watchos, tvos);

/******************************************************************************
 *  Reentrant variants of lgamma[fl]                                          *
 ******************************************************************************/

#ifdef _REENTRANT
/*  Reentrant variants of the lgamma[fl] functions.                           */
extern float lgammaf_r(float, int *) __API_AVAILABLE(macos(10.6), ios(3.1));
extern double lgamma_r(double, int *) __API_AVAILABLE(macos(10.6), ios(3.1));
extern long double lgammal_r(long double, int *) __API_AVAILABLE(macos(10.6), ios(3.1));
#endif /* _REENTRANT */
# 570 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

/******************************************************************************
 *  Apple extensions to the C standard                                        *
 ******************************************************************************/

/*  Because these functions are not specified by any relevant standard, they
    are prefixed with __, which places them in the implementor's namespace, so
    they should not conflict with any developer or third-party code.  If they
    are added to a relevant standard in the future, un-prefixed names may be
    added to the library and they may be moved out of this section of the
    header.                                                                   
 
    Because these functions are non-standard, they may not be available on non-
    Apple platforms.                                                          */

/*  __exp10(x) returns 10**x.  Edge cases match those of exp( ) and exp2( ).  */
extern float __exp10f(float) __API_AVAILABLE(macos(10.9), ios(7.0));
extern double __exp10(double) __API_AVAILABLE(macos(10.9), ios(7.0));

/*  __sincos(x,sinp,cosp) computes the sine and cosine of x with a single
    function call, storing the sine in the memory pointed to by sinp, and
    the cosine in the memory pointed to by cosp. Edge cases match those of
    separate calls to sin( ) and cos( ).                                      */
__header_always_inline void __sincosf(float __x, float *__sinp, float *__cosp);
__header_always_inline void __sincos(double __x, double *__sinp, double *__cosp);

/*  __sinpi(x) returns the sine of pi times x; __cospi(x) and __tanpi(x) return
    the cosine and tangent, respectively.  These functions can produce a more
    accurate answer than expressions of the form sin(M_PI * x) because they
    avoid any loss of precision that results from rounding the result of the
    multiplication M_PI * x.  They may also be significantly more efficient in
    some cases because the argument reduction for these functions is easier
    to compute.  Consult the man pages for edge case details.                 */
extern float __cospif(float) __API_AVAILABLE(macos(10.9), ios(7.0));
extern double __cospi(double) __API_AVAILABLE(macos(10.9), ios(7.0));
extern float __sinpif(float) __API_AVAILABLE(macos(10.9), ios(7.0));
extern double __sinpi(double) __API_AVAILABLE(macos(10.9), ios(7.0));
extern float __tanpif(float) __API_AVAILABLE(macos(10.9), ios(7.0));
extern double __tanpi(double) __API_AVAILABLE(macos(10.9), ios(7.0));

#if 0 /* disabled by -frewrite-includes */
#if (defined __MAC_OS_X_VERSION_MIN_REQUIRED && __MAC_OS_X_VERSION_MIN_REQUIRED < 1090) || \
    (defined __IPHONE_OS_VERSION_MIN_REQUIRED && __IPHONE_OS_VERSION_MIN_REQUIRED < 70000)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 612 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
/*  __sincos and __sincosf were introduced in OSX 10.9 and iOS 7.0.  When
    targeting an older system, we simply split them up into discrete calls
    to sin( ) and cos( ).                                                     */
__header_always_inline void __sincosf(float __x, float *__sinp, float *__cosp) {
  *__sinp = sinf(__x);
  *__cosp = cosf(__x);
}

__header_always_inline void __sincos(double __x, double *__sinp, double *__cosp) {
  *__sinp = sin(__x);
  *__cosp = cos(__x);
}
#else
# 625 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
/*  __sincospi(x,sinp,cosp) computes the sine and cosine of pi times x with a
    single function call, storing the sine in the memory pointed to by sinp,
    and the cosine in the memory pointed to by cosp.  Edge cases match those
    of separate calls to __sinpi( ) and __cospi( ), and are documented in the
    man pages.
 
    These functions were introduced in OSX 10.9 and iOS 7.0.  Because they are
    implemented as header inlines, weak-linking does not function as normal,
    and they are simply hidden when targeting earlier OS versions.            */
__header_always_inline void __sincospif(float __x, float *__sinp, float *__cosp);
__header_always_inline void __sincospi(double __x, double *__sinp, double *__cosp);

/*  Implementation details of __sincos and __sincospi allowing them to return
    two results while allowing the compiler to optimize away unnecessary load-
    store traffic.  Although these interfaces are exposed in the math.h header
    to allow compilers to generate better code, users should call __sincos[f]
    and __sincospi[f] instead and allow the compiler to emit these calls.     */
struct __float2 { float __sinval; float __cosval; };
struct __double2 { double __sinval; double __cosval; };

extern struct __float2 __sincosf_stret(float);
extern struct __double2 __sincos_stret(double);
extern struct __float2 __sincospif_stret(float);
extern struct __double2 __sincospi_stret(double);

__header_always_inline void __sincosf(float __x, float *__sinp, float *__cosp) {
    const struct __float2 __stret = __sincosf_stret(__x);
    *__sinp = __stret.__sinval; *__cosp = __stret.__cosval;
}

__header_always_inline void __sincos(double __x, double *__sinp, double *__cosp) {
    const struct __double2 __stret = __sincos_stret(__x);
    *__sinp = __stret.__sinval; *__cosp = __stret.__cosval;
}

__header_always_inline void __sincospif(float __x, float *__sinp, float *__cosp) {
    const struct __float2 __stret = __sincospif_stret(__x);
    *__sinp = __stret.__sinval; *__cosp = __stret.__cosval;
}

__header_always_inline void __sincospi(double __x, double *__sinp, double *__cosp) {
    const struct __double2 __stret = __sincospi_stret(__x);
    *__sinp = __stret.__sinval; *__cosp = __stret.__cosval;
}
#endif
# 670 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

/******************************************************************************
 *  POSIX/UNIX extensions to the C standard                                   *
 ******************************************************************************/

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 199506L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 676 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
extern double j0(double) __API_AVAILABLE(macos(10.0), ios(3.2));
extern double j1(double) __API_AVAILABLE(macos(10.0), ios(3.2));
extern double jn(int, double) __API_AVAILABLE(macos(10.0), ios(3.2));
extern double y0(double) __API_AVAILABLE(macos(10.0), ios(3.2));
extern double y1(double) __API_AVAILABLE(macos(10.0), ios(3.2));
extern double yn(int, double) __API_AVAILABLE(macos(10.0), ios(3.2));
extern double scalb(double, double); 
extern int signgam;

/*  Even though these might be more useful as long doubles, POSIX requires
    that they be double-precision literals.                                   */
#define M_E         2.71828182845904523536028747135266250   /* e              */
#define M_LOG2E     1.44269504088896340735992468100189214   /* log2(e)        */
#define M_LOG10E    0.434294481903251827651128918916605082  /* log10(e)       */
#define M_LN2       0.693147180559945309417232121458176568  /* loge(2)        */
#define M_LN10      2.30258509299404568401799145468436421   /* loge(10)       */
#define M_PI        3.14159265358979323846264338327950288   /* pi             */
#define M_PI_2      1.57079632679489661923132169163975144   /* pi/2           */
#define M_PI_4      0.785398163397448309615660845819875721  /* pi/4           */
#define M_1_PI      0.318309886183790671537767526745028724  /* 1/pi           */
#define M_2_PI      0.636619772367581343075535053490057448  /* 2/pi           */
#define M_2_SQRTPI  1.12837916709551257389615890312154517   /* 2/sqrt(pi)     */
#define M_SQRT2     1.41421356237309504880168872420969808   /* sqrt(2)        */
#define M_SQRT1_2   0.707106781186547524400844362104849039  /* 1/sqrt(2)      */

#define MAXFLOAT    0x1.fffffep+127f
#endif /* __DARWIN_C_LEVEL >= 199506L */
# 703 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

/*  Long-double versions of M_E, etc for convenience on Intel where long-
    double is not the same as double.  Define __MATH_LONG_DOUBLE_CONSTANTS
    to make these constants available.                                        */
#if 0 /* disabled by -frewrite-includes */
#if defined __MATH_LONG_DOUBLE_CONSTANTS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 708 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
#define M_El        0xa.df85458a2bb4a9bp-2L
#define M_LOG2El    0xb.8aa3b295c17f0bcp-3L
#define M_LOG10El   0xd.e5bd8a937287195p-5L
#define M_LN2l      0xb.17217f7d1cf79acp-4L
#define M_LN10l     0x9.35d8dddaaa8ac17p-2L
#define M_PIl       0xc.90fdaa22168c235p-2L
#define M_PI_2l     0xc.90fdaa22168c235p-3L
#define M_PI_4l     0xc.90fdaa22168c235p-4L
#define M_1_PIl     0xa.2f9836e4e44152ap-5L
#define M_2_PIl     0xa.2f9836e4e44152ap-4L
#define M_2_SQRTPIl 0x9.06eba8214db688dp-3L
#define M_SQRT2l    0xb.504f333f9de6484p-3L
#define M_SQRT1_2l  0xb.504f333f9de6484p-4L
#endif /* defined __MATH_LONG_DOUBLE_CONSTANTS */
# 722 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

/******************************************************************************
 *  Legacy BSD extensions to the C standard                                   *
 ******************************************************************************/

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 728 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
#define FP_SNAN		FP_NAN
#define FP_QNAN		FP_NAN
#define	HUGE		MAXFLOAT
#define X_TLOSS		1.41484755040568800000e+16 
#define	DOMAIN		1
#define	SING		2
#define	OVERFLOW	3
#define	UNDERFLOW	4
#define	TLOSS		5
#define	PLOSS		6

/* Legacy BSD API; use the C99 `lrint( )` function instead.                   */
extern long int rinttol(double)
__API_DEPRECATED_WITH_REPLACEMENT("lrint", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);
/* Legacy BSD API; use the C99 `lround( )` function instead.                  */
extern long int roundtol(double)
__API_DEPRECATED_WITH_REPLACEMENT("lround", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);
/* Legacy BSD API; use the C99 `remainder( )` function instead.               */
extern double drem(double, double)
__API_DEPRECATED_WITH_REPLACEMENT("remainder", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);
/* Legacy BSD API; use the C99 `isfinite( )` macro instead.                   */
extern int finite(double)
__API_DEPRECATED("Use `isfinite((double)x)` instead.", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);
/* Legacy BSD API; use the C99 `tgamma( )` function instead.                  */
extern double gamma(double)
__API_DEPRECATED_WITH_REPLACEMENT("tgamma", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);
/* Legacy BSD API; use `2*frexp( )` or `scalbn(x, -ilogb(x))` instead.        */
extern double significand(double)
__API_DEPRECATED("Use `2*frexp( )` or `scalbn(x, -ilogb(x))` instead.", macos(10.0, 10.9)) __API_UNAVAILABLE(ios, watchos, tvos);

#if 0 /* disabled by -frewrite-includes */
#if !defined __cplusplus
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 759 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
struct exception {
    int type;
    char *name;
    double arg1;
    double arg2;
    double retval;
};

#endif /* !defined __cplusplus */
# 768 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 769 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4

__END_DECLS
#endif /* __MATH_H__ */
# 772 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/math.h" 3 4
# 304 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 2 3

#ifdef __cplusplus

// We support including .h headers inside 'extern "C"' contexts, so switch
// back to C++ linkage before including these C++ headers.
extern "C++" {

#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 311 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 1 3
// -*- C++ -*-
//===------------------------ type_traits ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_TYPE_TRAITS
#define _LIBCPP_TYPE_TRAITS

/*
    type_traits synopsis

namespace std
{

    // helper class:
    template <class T, T v> struct integral_constant;
    typedef integral_constant<bool, true>  true_type;   // C++11
    typedef integral_constant<bool, false> false_type;  // C++11

    template <bool B>                                   // C++14
    using bool_constant = integral_constant<bool, B>;   // C++14
    typedef bool_constant<true> true_type;              // C++14
    typedef bool_constant<false> false_type;            // C++14

    // helper traits
    template <bool, class T = void> struct enable_if;
    template <bool, class T, class F> struct conditional;

    // Primary classification traits:
    template <class T> struct is_void;
    template <class T> struct is_null_pointer;  // C++14
    template <class T> struct is_integral;
    template <class T> struct is_floating_point;
    template <class T> struct is_array;
    template <class T> struct is_pointer;
    template <class T> struct is_lvalue_reference;
    template <class T> struct is_rvalue_reference;
    template <class T> struct is_member_object_pointer;
    template <class T> struct is_member_function_pointer;
    template <class T> struct is_enum;
    template <class T> struct is_union;
    template <class T> struct is_class;
    template <class T> struct is_function;

    // Secondary classification traits:
    template <class T> struct is_reference;
    template <class T> struct is_arithmetic;
    template <class T> struct is_fundamental;
    template <class T> struct is_member_pointer;
    template <class T> struct is_scalar;
    template <class T> struct is_object;
    template <class T> struct is_compound;

    // Const-volatile properties and transformations:
    template <class T> struct is_const;
    template <class T> struct is_volatile;
    template <class T> struct remove_const;
    template <class T> struct remove_volatile;
    template <class T> struct remove_cv;
    template <class T> struct add_const;
    template <class T> struct add_volatile;
    template <class T> struct add_cv;

    // Reference transformations:
    template <class T> struct remove_reference;
    template <class T> struct add_lvalue_reference;
    template <class T> struct add_rvalue_reference;

    // Pointer transformations:
    template <class T> struct remove_pointer;
    template <class T> struct add_pointer;

    template<class T> struct type_identity;                     // C++20
    template<class T>
      using type_identity_t = typename type_identity<T>::type;  // C++20

    // Integral properties:
    template <class T> struct is_signed;
    template <class T> struct is_unsigned;
    template <class T> struct make_signed;
    template <class T> struct make_unsigned;

    // Array properties and transformations:
    template <class T> struct rank;
    template <class T, unsigned I = 0> struct extent;
    template <class T> struct remove_extent;
    template <class T> struct remove_all_extents;

    template <class T> struct is_bounded_array;                 // C++20
    template <class T> struct is_unbounded_array;               // C++20

    // Member introspection:
    template <class T> struct is_pod;
    template <class T> struct is_trivial;
    template <class T> struct is_trivially_copyable;
    template <class T> struct is_standard_layout;
    template <class T> struct is_literal_type;
    template <class T> struct is_empty;
    template <class T> struct is_polymorphic;
    template <class T> struct is_abstract;
    template <class T> struct is_final; // C++14
    template <class T> struct is_aggregate; // C++17

    template <class T, class... Args> struct is_constructible;
    template <class T>                struct is_default_constructible;
    template <class T>                struct is_copy_constructible;
    template <class T>                struct is_move_constructible;
    template <class T, class U>       struct is_assignable;
    template <class T>                struct is_copy_assignable;
    template <class T>                struct is_move_assignable;
    template <class T, class U>       struct is_swappable_with;       // C++17
    template <class T>                struct is_swappable;            // C++17
    template <class T>                struct is_destructible;

    template <class T, class... Args> struct is_trivially_constructible;
    template <class T>                struct is_trivially_default_constructible;
    template <class T>                struct is_trivially_copy_constructible;
    template <class T>                struct is_trivially_move_constructible;
    template <class T, class U>       struct is_trivially_assignable;
    template <class T>                struct is_trivially_copy_assignable;
    template <class T>                struct is_trivially_move_assignable;
    template <class T>                struct is_trivially_destructible;

    template <class T, class... Args> struct is_nothrow_constructible;
    template <class T>                struct is_nothrow_default_constructible;
    template <class T>                struct is_nothrow_copy_constructible;
    template <class T>                struct is_nothrow_move_constructible;
    template <class T, class U>       struct is_nothrow_assignable;
    template <class T>                struct is_nothrow_copy_assignable;
    template <class T>                struct is_nothrow_move_assignable;
    template <class T, class U>       struct is_nothrow_swappable_with; // C++17
    template <class T>                struct is_nothrow_swappable;      // C++17
    template <class T>                struct is_nothrow_destructible;

    template <class T> struct has_virtual_destructor;

    template<class T> struct has_unique_object_representations;         // C++17

    // Relationships between types:
    template <class T, class U> struct is_same;
    template <class Base, class Derived> struct is_base_of;

    template <class From, class To> struct is_convertible;
    template <typename From, typename To> struct is_nothrow_convertible;                  // C++20
    template <typename From, typename To> inline constexpr bool is_nothrow_convertible_v; // C++20

    template <class Fn, class... ArgTypes> struct is_invocable;
    template <class R, class Fn, class... ArgTypes> struct is_invocable_r;

    template <class Fn, class... ArgTypes> struct is_nothrow_invocable;
    template <class R, class Fn, class... ArgTypes> struct is_nothrow_invocable_r;

    // Alignment properties and transformations:
    template <class T> struct alignment_of;
    template <size_t Len, size_t Align = most_stringent_alignment_requirement>
        struct aligned_storage;
    template <size_t Len, class... Types> struct aligned_union;
    template <class T> struct remove_cvref; // C++20

    template <class T> struct decay;
    template <class... T> struct common_type;
    template <class T> struct underlying_type;
    template <class> class result_of; // undefined
    template <class Fn, class... ArgTypes> class result_of<Fn(ArgTypes...)>;
    template <class Fn, class... ArgTypes> struct invoke_result;  // C++17

    // const-volatile modifications:
    template <class T>
      using remove_const_t    = typename remove_const<T>::type;  // C++14
    template <class T>
      using remove_volatile_t = typename remove_volatile<T>::type;  // C++14
    template <class T>
      using remove_cv_t       = typename remove_cv<T>::type;  // C++14
    template <class T>
      using add_const_t       = typename add_const<T>::type;  // C++14
    template <class T>
      using add_volatile_t    = typename add_volatile<T>::type;  // C++14
    template <class T>
      using add_cv_t          = typename add_cv<T>::type;  // C++14

    // reference modifications:
    template <class T>
      using remove_reference_t     = typename remove_reference<T>::type;  // C++14
    template <class T>
      using add_lvalue_reference_t = typename add_lvalue_reference<T>::type;  // C++14
    template <class T>
      using add_rvalue_reference_t = typename add_rvalue_reference<T>::type;  // C++14

    // sign modifications:
    template <class T>
      using make_signed_t   = typename make_signed<T>::type;  // C++14
    template <class T>
      using make_unsigned_t = typename make_unsigned<T>::type;  // C++14

    // array modifications:
    template <class T>
      using remove_extent_t      = typename remove_extent<T>::type;  // C++14
    template <class T>
      using remove_all_extents_t = typename remove_all_extents<T>::type;  // C++14

    template <class T>
      inline constexpr bool is_bounded_array_v
        = is_bounded_array<T>::value;                                     // C++20
      inline constexpr bool is_unbounded_array_v
        = is_unbounded_array<T>::value;                                   // C++20

    // pointer modifications:
    template <class T>
      using remove_pointer_t = typename remove_pointer<T>::type;  // C++14
    template <class T>
      using add_pointer_t    = typename add_pointer<T>::type;  // C++14

    // other transformations:
    template <size_t Len, std::size_t Align=default-alignment>
      using aligned_storage_t = typename aligned_storage<Len,Align>::type;  // C++14
    template <std::size_t Len, class... Types>
      using aligned_union_t   = typename aligned_union<Len,Types...>::type;  // C++14
    template <class T>
      using remove_cvref_t    = typename remove_cvref<T>::type;  // C++20
    template <class T>
      using decay_t           = typename decay<T>::type;  // C++14
    template <bool b, class T=void>
      using enable_if_t       = typename enable_if<b,T>::type;  // C++14
    template <bool b, class T, class F>
      using conditional_t     = typename conditional<b,T,F>::type;  // C++14
    template <class... T>
      using common_type_t     = typename common_type<T...>::type;  // C++14
    template <class T>
      using underlying_type_t = typename underlying_type<T>::type;  // C++14
    template <class T>
      using result_of_t       = typename result_of<T>::type;  // C++14
    template <class Fn, class... ArgTypes>
      using invoke_result_t   = typename invoke_result<Fn, ArgTypes...>::type;  // C++17

    template <class...>
      using void_t = void;   // C++17

      // See C++14 20.10.4.1, primary type categories
      template <class T> inline constexpr bool is_void_v
        = is_void<T>::value;                                             // C++17
      template <class T> inline constexpr bool is_null_pointer_v
        = is_null_pointer<T>::value;                                     // C++17
      template <class T> inline constexpr bool is_integral_v
        = is_integral<T>::value;                                         // C++17
      template <class T> inline constexpr bool is_floating_point_v
        = is_floating_point<T>::value;                                   // C++17
      template <class T> inline constexpr bool is_array_v
        = is_array<T>::value;                                            // C++17
      template <class T> inline constexpr bool is_pointer_v
        = is_pointer<T>::value;                                          // C++17
      template <class T> inline constexpr bool is_lvalue_reference_v
        = is_lvalue_reference<T>::value;                                 // C++17
      template <class T> inline constexpr bool is_rvalue_reference_v
        = is_rvalue_reference<T>::value;                                 // C++17
      template <class T> inline constexpr bool is_member_object_pointer_v
        = is_member_object_pointer<T>::value;                            // C++17
      template <class T> inline constexpr bool is_member_function_pointer_v
        = is_member_function_pointer<T>::value;                          // C++17
      template <class T> inline constexpr bool is_enum_v
        = is_enum<T>::value;                                             // C++17
      template <class T> inline constexpr bool is_union_v
        = is_union<T>::value;                                            // C++17
      template <class T> inline constexpr bool is_class_v
        = is_class<T>::value;                                            // C++17
      template <class T> inline constexpr bool is_function_v
        = is_function<T>::value;                                         // C++17

      // See C++14 20.10.4.2, composite type categories
      template <class T> inline constexpr bool is_reference_v
        = is_reference<T>::value;                                        // C++17
      template <class T> inline constexpr bool is_arithmetic_v
        = is_arithmetic<T>::value;                                       // C++17
      template <class T> inline constexpr bool is_fundamental_v
        = is_fundamental<T>::value;                                      // C++17
      template <class T> inline constexpr bool is_object_v
        = is_object<T>::value;                                           // C++17
      template <class T> inline constexpr bool is_scalar_v
        = is_scalar<T>::value;                                           // C++17
      template <class T> inline constexpr bool is_compound_v
        = is_compound<T>::value;                                         // C++17
      template <class T> inline constexpr bool is_member_pointer_v
        = is_member_pointer<T>::value;                                   // C++17

      // See C++14 20.10.4.3, type properties
      template <class T> inline constexpr bool is_const_v
        = is_const<T>::value;                                            // C++17
      template <class T> inline constexpr bool is_volatile_v
        = is_volatile<T>::value;                                         // C++17
      template <class T> inline constexpr bool is_trivial_v
        = is_trivial<T>::value;                                          // C++17
      template <class T> inline constexpr bool is_trivially_copyable_v
        = is_trivially_copyable<T>::value;                               // C++17
      template <class T> inline constexpr bool is_standard_layout_v
        = is_standard_layout<T>::value;                                  // C++17
      template <class T> inline constexpr bool is_pod_v
        = is_pod<T>::value;                                              // C++17
      template <class T> inline constexpr bool is_literal_type_v
        = is_literal_type<T>::value;                                     // C++17
      template <class T> inline constexpr bool is_empty_v
        = is_empty<T>::value;                                            // C++17
      template <class T> inline constexpr bool is_polymorphic_v
        = is_polymorphic<T>::value;                                      // C++17
      template <class T> inline constexpr bool is_abstract_v
        = is_abstract<T>::value;                                         // C++17
      template <class T> inline constexpr bool is_final_v
        = is_final<T>::value;                                            // C++17
      template <class T> inline constexpr bool is_aggregate_v
        = is_aggregate<T>::value;                                        // C++17
      template <class T> inline constexpr bool is_signed_v
        = is_signed<T>::value;                                           // C++17
      template <class T> inline constexpr bool is_unsigned_v
        = is_unsigned<T>::value;                                         // C++17
      template <class T, class... Args> inline constexpr bool is_constructible_v
        = is_constructible<T, Args...>::value;                           // C++17
      template <class T> inline constexpr bool is_default_constructible_v
        = is_default_constructible<T>::value;                            // C++17
      template <class T> inline constexpr bool is_copy_constructible_v
        = is_copy_constructible<T>::value;                               // C++17
      template <class T> inline constexpr bool is_move_constructible_v
        = is_move_constructible<T>::value;                               // C++17
      template <class T, class U> inline constexpr bool is_assignable_v
        = is_assignable<T, U>::value;                                    // C++17
      template <class T> inline constexpr bool is_copy_assignable_v
        = is_copy_assignable<T>::value;                                  // C++17
      template <class T> inline constexpr bool is_move_assignable_v
        = is_move_assignable<T>::value;                                  // C++17
      template <class T, class U> inline constexpr bool is_swappable_with_v
        = is_swappable_with<T, U>::value;                                // C++17
      template <class T> inline constexpr bool is_swappable_v
        = is_swappable<T>::value;                                        // C++17
      template <class T> inline constexpr bool is_destructible_v
        = is_destructible<T>::value;                                     // C++17
      template <class T, class... Args> inline constexpr bool is_trivially_constructible_v
        = is_trivially_constructible<T, Args...>::value;                 // C++17
      template <class T> inline constexpr bool is_trivially_default_constructible_v
        = is_trivially_default_constructible<T>::value;                  // C++17
      template <class T> inline constexpr bool is_trivially_copy_constructible_v
        = is_trivially_copy_constructible<T>::value;                     // C++17
      template <class T> inline constexpr bool is_trivially_move_constructible_v
        = is_trivially_move_constructible<T>::value;                     // C++17
      template <class T, class U> inline constexpr bool is_trivially_assignable_v
        = is_trivially_assignable<T, U>::value;                          // C++17
      template <class T> inline constexpr bool is_trivially_copy_assignable_v
        = is_trivially_copy_assignable<T>::value;                        // C++17
      template <class T> inline constexpr bool is_trivially_move_assignable_v
        = is_trivially_move_assignable<T>::value;                        // C++17
      template <class T> inline constexpr bool is_trivially_destructible_v
        = is_trivially_destructible<T>::value;                           // C++17
      template <class T, class... Args> inline constexpr bool is_nothrow_constructible_v
        = is_nothrow_constructible<T, Args...>::value;                   // C++17
      template <class T> inline constexpr bool is_nothrow_default_constructible_v
        = is_nothrow_default_constructible<T>::value;                    // C++17
      template <class T> inline constexpr bool is_nothrow_copy_constructible_v
        = is_nothrow_copy_constructible<T>::value;                       // C++17
      template <class T> inline constexpr bool is_nothrow_move_constructible_v
        = is_nothrow_move_constructible<T>::value;                       // C++17
      template <class T, class U> inline constexpr bool is_nothrow_assignable_v
        = is_nothrow_assignable<T, U>::value;                            // C++17
      template <class T> inline constexpr bool is_nothrow_copy_assignable_v
        = is_nothrow_copy_assignable<T>::value;                          // C++17
      template <class T> inline constexpr bool is_nothrow_move_assignable_v
        = is_nothrow_move_assignable<T>::value;                          // C++17
      template <class T, class U> inline constexpr bool is_nothrow_swappable_with_v
        = is_nothrow_swappable_with<T, U>::value;                       // C++17
      template <class T> inline constexpr bool is_nothrow_swappable_v
        = is_nothrow_swappable<T>::value;                               // C++17
      template <class T> inline constexpr bool is_nothrow_destructible_v
        = is_nothrow_destructible<T>::value;                             // C++17
      template <class T> inline constexpr bool has_virtual_destructor_v
        = has_virtual_destructor<T>::value;                              // C++17
      template<class T> inline constexpr bool has_unique_object_representations_v // C++17
        = has_unique_object_representations<T>::value;

      // See C++14 20.10.5, type property queries
      template <class T> inline constexpr size_t alignment_of_v
        = alignment_of<T>::value;                                        // C++17
      template <class T> inline constexpr size_t rank_v
        = rank<T>::value;                                                // C++17
      template <class T, unsigned I = 0> inline constexpr size_t extent_v
        = extent<T, I>::value;                                           // C++17

      // See C++14 20.10.6, type relations
      template <class T, class U> inline constexpr bool is_same_v
        = is_same<T, U>::value;                                          // C++17
      template <class Base, class Derived> inline constexpr bool is_base_of_v
        = is_base_of<Base, Derived>::value;                              // C++17
      template <class From, class To> inline constexpr bool is_convertible_v
        = is_convertible<From, To>::value;                               // C++17
      template <class Fn, class... ArgTypes> inline constexpr bool is_invocable_v
        = is_invocable<Fn, ArgTypes...>::value;                          // C++17
      template <class R, class Fn, class... ArgTypes> inline constexpr bool is_invocable_r_v
        = is_invocable_r<R, Fn, ArgTypes...>::value;                     // C++17
      template <class Fn, class... ArgTypes> inline constexpr bool is_nothrow_invocable_v
        = is_nothrow_invocable<Fn, ArgTypes...>::value;                  // C++17
      template <class R, class Fn, class... ArgTypes> inline constexpr bool is_nothrow_invocable_r_v
        = is_nothrow_invocable_r<R, Fn, ArgTypes...>::value;             // C++17

      // [meta.logical], logical operator traits:
      template<class... B> struct conjunction;                           // C++17
      template<class... B>
        inline constexpr bool conjunction_v = conjunction<B...>::value;  // C++17
      template<class... B> struct disjunction;                           // C++17
      template<class... B>
        inline constexpr bool disjunction_v = disjunction<B...>::value;  // C++17
      template<class B> struct negation;                                 // C++17
      template<class B>
        inline constexpr bool negation_v = negation<B>::value;           // C++17

}

*/
#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 416 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
# 417 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 417 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
# 418 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 418 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
# 419 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 421 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 422 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
#endif
# 423 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _T1, class _T2> struct _LIBCPP_TEMPLATE_VIS pair;
template <class _Tp> class _LIBCPP_TEMPLATE_VIS reference_wrapper;
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS hash;

template <class _Tp, _Tp __v>
struct _LIBCPP_TEMPLATE_VIS integral_constant
{
  static _LIBCPP_CONSTEXPR const _Tp      value = __v;
  typedef _Tp               value_type;
  typedef integral_constant type;
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_CONSTEXPR operator value_type() const _NOEXCEPT {return value;}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 439 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
  _LIBCPP_INLINE_VISIBILITY
  constexpr value_type operator ()() const _NOEXCEPT {return value;}
#endif
# 442 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
};

template <class _Tp, _Tp __v>
_LIBCPP_CONSTEXPR const _Tp integral_constant<_Tp, __v>::value;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 448 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <bool __b>
using bool_constant = integral_constant<bool, __b>;
#define _LIBCPP_BOOL_CONSTANT(__b) bool_constant<(__b)>
#else
# 452 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
#define _LIBCPP_BOOL_CONSTANT(__b) integral_constant<bool,(__b)>
#endif
# 454 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

typedef _LIBCPP_BOOL_CONSTANT(true)  true_type;
typedef _LIBCPP_BOOL_CONSTANT(false) false_type;

template <bool _Val>
using _BoolConstant _LIBCPP_NODEBUG_TYPE = integral_constant<bool, _Val>;

template <bool> struct _MetaBase;
template <>
struct _MetaBase<true> {
  template <class _Tp, class _Up>
  using _SelectImpl _LIBCPP_NODEBUG_TYPE = _Tp;
  template <template <class...> class _FirstFn, template <class...> class, class ..._Args>
  using _SelectApplyImpl _LIBCPP_NODEBUG_TYPE = _FirstFn<_Args...>;
  template <class _First, class...>
  using _FirstImpl _LIBCPP_NODEBUG_TYPE = _First;
  template <class, class _Second, class...>
  using _SecondImpl _LIBCPP_NODEBUG_TYPE = _Second;
  template <class _Tp = void>
  using _EnableIfImpl _LIBCPP_NODEBUG_TYPE = _Tp;
  template <class _Result, class _First, class ..._Rest>
  using _OrImpl _LIBCPP_NODEBUG_TYPE = typename _MetaBase<_First::value != true && sizeof...(_Rest) != 0>::template _OrImpl<_First, _Rest...>;
  template <class _Result, class _First, class ..._Rest>
  using _AndImpl _LIBCPP_NODEBUG_TYPE = typename _MetaBase<_First::value == true && sizeof...(_Rest) != 0>::template _AndImpl<_First, _Rest...>;
};

template <>
struct _MetaBase<false> {
  template <class _Tp, class _Up>
  using _SelectImpl _LIBCPP_NODEBUG_TYPE = _Up;
  template <template <class...> class, template <class...> class _SecondFn, class ..._Args>
  using _SelectApplyImpl _LIBCPP_NODEBUG_TYPE = _SecondFn<_Args...>;
  template <class _Result, class ...>
  using _OrImpl _LIBCPP_NODEBUG_TYPE = _Result;
  template <class _Result, class ...>
  using _AndImpl _LIBCPP_NODEBUG_TYPE = _Result;
};
template <bool _Cond, class _Ret = void>
using _EnableIf _LIBCPP_NODEBUG_TYPE = typename _MetaBase<_Cond>::template _EnableIfImpl<_Ret>;
template <bool _Cond, class _IfRes, class _ElseRes>
using _If _LIBCPP_NODEBUG_TYPE = typename _MetaBase<_Cond>::template _SelectImpl<_IfRes, _ElseRes>;
template <class ..._Rest>
using _Or _LIBCPP_NODEBUG_TYPE = typename _MetaBase< sizeof...(_Rest) != 0 >::template _OrImpl<false_type, _Rest...>;
template <class ..._Rest>
using _And _LIBCPP_NODEBUG_TYPE = typename _MetaBase< sizeof...(_Rest) != 0 >::template _AndImpl<true_type, _Rest...>;
template <class _Pred>
struct _Not : _BoolConstant<!_Pred::value> {};
template <class ..._Args>
using _FirstType _LIBCPP_NODEBUG_TYPE = typename _MetaBase<(sizeof...(_Args) >= 1)>::template _FirstImpl<_Args...>;
template <class ..._Args>
using _SecondType _LIBCPP_NODEBUG_TYPE = typename _MetaBase<(sizeof...(_Args) >= 2)>::template _SecondImpl<_Args...>;

template <template <class...> class _Func, class ..._Args>
struct _Lazy : _Func<_Args...> {};

// Member detector base

template <template <class...> class _Templ, class ..._Args, class = _Templ<_Args...> >
true_type __sfinae_test_impl(int);
template <template <class...> class, class ...>
false_type __sfinae_test_impl(...);

template <template <class ...> class _Templ, class ..._Args>
using _IsValidExpansion _LIBCPP_NODEBUG_TYPE = decltype(std::__sfinae_test_impl<_Templ, _Args...>(0));

template <class>
struct __void_t { typedef void type; };

template <class _Tp>
struct __identity { typedef _Tp type; };

template <class _Tp, bool>
struct _LIBCPP_TEMPLATE_VIS __dependent_type : public _Tp {};


template <bool _Bp, class _If, class _Then>
    struct _LIBCPP_TEMPLATE_VIS conditional {typedef _If type;};
template <class _If, class _Then>
    struct _LIBCPP_TEMPLATE_VIS conditional<false, _If, _Then> {typedef _Then type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 535 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <bool _Bp, class _If, class _Then> using conditional_t = typename conditional<_Bp, _If, _Then>::type;
#endif
# 537 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <bool, class _Tp = void> struct _LIBCPP_TEMPLATE_VIS enable_if {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS enable_if<true, _Tp> {typedef _Tp type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 542 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <bool _Bp, class _Tp = void> using enable_if_t = typename enable_if<_Bp, _Tp>::type;
#endif
# 544 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_same

template <class _Tp, class _Up> struct _LIBCPP_TEMPLATE_VIS is_same           : public false_type {};
template <class _Tp>            struct _LIBCPP_TEMPLATE_VIS is_same<_Tp, _Tp> : public true_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 551 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class _Up>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_same_v
    = is_same<_Tp, _Up>::value;
#endif
# 555 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class _Up>
using _IsSame = _BoolConstant<
#ifdef __clang__
    __is_same(_Tp, _Up)
#else
# 561 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    _VSTD::is_same<_Tp, _Up>::value
#endif
# 563 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
>;

template <class _Tp, class _Up>
using _IsNotSame = _BoolConstant<
#ifdef __clang__
    !__is_same(_Tp, _Up)
#else
# 570 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    !_VSTD::is_same<_Tp, _Up>::value
#endif
# 572 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
>;


template <class _Tp>
using __test_for_primary_template = _EnableIf<
    _IsSame<_Tp, typename _Tp::__primary_template>::value
  >;
template <class _Tp>
using __is_primary_template = _IsValidExpansion<
    __test_for_primary_template, _Tp
  >;

// addressof
#ifndef _LIBCPP_HAS_NO_BUILTIN_ADDRESSOF

template <class _Tp>
inline _LIBCPP_CONSTEXPR_AFTER_CXX14
_LIBCPP_NO_CFI _LIBCPP_INLINE_VISIBILITY
_Tp*
addressof(_Tp& __x) _NOEXCEPT
{
    return __builtin_addressof(__x);
}

#else
# 597 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
inline _LIBCPP_NO_CFI _LIBCPP_INLINE_VISIBILITY
_Tp*
addressof(_Tp& __x) _NOEXCEPT
{
  return reinterpret_cast<_Tp *>(
      const_cast<char *>(&reinterpret_cast<const volatile char &>(__x)));
}

#endif // _LIBCPP_HAS_NO_BUILTIN_ADDRESSOF
# 608 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_OBJC_ARC) && !defined(_LIBCPP_PREDEFINED_OBJC_ARC_ADDRESSOF)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 610 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
// Objective-C++ Automatic Reference Counting uses qualified pointers
// that require special addressof() signatures. When
// _LIBCPP_PREDEFINED_OBJC_ARC_ADDRESSOF is defined, the compiler
// itself is providing these definitions. Otherwise, we provide them.
template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__strong _Tp*
addressof(__strong _Tp& __x) _NOEXCEPT
{
  return &__x;
}

#ifdef _LIBCPP_HAS_OBJC_ARC_WEAK
template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__weak _Tp*
addressof(__weak _Tp& __x) _NOEXCEPT
{
  return &__x;
}
#endif
# 631 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__autoreleasing _Tp*
addressof(__autoreleasing _Tp& __x) _NOEXCEPT
{
  return &__x;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__unsafe_unretained _Tp*
addressof(__unsafe_unretained _Tp& __x) _NOEXCEPT
{
  return &__x;
}
#endif
# 648 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 650 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> _Tp* addressof(const _Tp&&) noexcept = delete;
#endif
# 652 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

struct __two {char __lx[2];};

// helper class:

// is_const

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_const            : public false_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_const<_Tp const> : public true_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 663 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_const_v
    = is_const<_Tp>::value;
#endif
# 667 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_volatile

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_volatile               : public false_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_volatile<_Tp volatile> : public true_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 674 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_volatile_v
    = is_volatile<_Tp>::value;
#endif
# 678 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// remove_const

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_const            {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_const<const _Tp> {typedef _Tp type;};
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 684 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using remove_const_t = typename remove_const<_Tp>::type;
#endif
# 686 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// remove_volatile

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_volatile               {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_volatile<volatile _Tp> {typedef _Tp type;};
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 692 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using remove_volatile_t = typename remove_volatile<_Tp>::type;
#endif
# 694 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// remove_cv

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_cv
{typedef typename remove_volatile<typename remove_const<_Tp>::type>::type type;};
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 700 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using remove_cv_t = typename remove_cv<_Tp>::type;
#endif
# 702 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_void

template <class _Tp> struct __libcpp_is_void       : public false_type {};
template <>          struct __libcpp_is_void<void> : public true_type {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_void
    : public __libcpp_is_void<typename remove_cv<_Tp>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 712 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_void_v
    = is_void<_Tp>::value;
#endif
# 716 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// __is_nullptr_t

template <class _Tp> struct __is_nullptr_t_impl       : public false_type {};
template <>          struct __is_nullptr_t_impl<nullptr_t> : public true_type {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS __is_nullptr_t
    : public __is_nullptr_t_impl<typename remove_cv<_Tp>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 726 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_null_pointer
    : public __is_nullptr_t_impl<typename remove_cv<_Tp>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 730 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_null_pointer_v
    = is_null_pointer<_Tp>::value;
#endif
# 734 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
#endif // _LIBCPP_STD_VER > 11
# 735 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_integral

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_integral
    : public _BoolConstant<__libcpp_is_integral<typename remove_cv<_Tp>::type>::value> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 742 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_integral_v
    = is_integral<_Tp>::value;
#endif
# 746 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_floating_point

template <class _Tp> struct __libcpp_is_floating_point              : public false_type {};
template <>          struct __libcpp_is_floating_point<float>       : public true_type {};
template <>          struct __libcpp_is_floating_point<double>      : public true_type {};
template <>          struct __libcpp_is_floating_point<long double> : public true_type {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_floating_point
    : public __libcpp_is_floating_point<typename remove_cv<_Tp>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 758 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_floating_point_v
    = is_floating_point<_Tp>::value;
#endif
# 762 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_array

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_array
    : public false_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_array<_Tp[]>
    : public true_type {};
template <class _Tp, size_t _Np> struct _LIBCPP_TEMPLATE_VIS is_array<_Tp[_Np]>
    : public true_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 773 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_array_v
    = is_array<_Tp>::value;
#endif
# 777 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_pointer

template <class _Tp> struct __libcpp_is_pointer       : public false_type {};
template <class _Tp> struct __libcpp_is_pointer<_Tp*> : public true_type {};

template <class _Tp> struct __libcpp_remove_objc_qualifiers { typedef _Tp type; };
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_OBJC_ARC)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 785 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> struct __libcpp_remove_objc_qualifiers<_Tp __strong> { typedef _Tp type; };
template <class _Tp> struct __libcpp_remove_objc_qualifiers<_Tp __weak> { typedef _Tp type; };
template <class _Tp> struct __libcpp_remove_objc_qualifiers<_Tp __autoreleasing> { typedef _Tp type; };
template <class _Tp> struct __libcpp_remove_objc_qualifiers<_Tp __unsafe_unretained> { typedef _Tp type; };
#endif
# 790 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_pointer
    : public __libcpp_is_pointer<typename __libcpp_remove_objc_qualifiers<typename remove_cv<_Tp>::type>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 795 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_pointer_v
    = is_pointer<_Tp>::value;
#endif
# 799 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_reference

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_lvalue_reference       : public false_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_lvalue_reference<_Tp&> : public true_type {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_rvalue_reference        : public false_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_rvalue_reference<_Tp&&> : public true_type {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_reference        : public false_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_reference<_Tp&>  : public true_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_reference<_Tp&&> : public true_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 813 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_reference_v
    = is_reference<_Tp>::value;

template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_lvalue_reference_v
    = is_lvalue_reference<_Tp>::value;

template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_rvalue_reference_v
    = is_rvalue_reference<_Tp>::value;
#endif
# 825 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
// is_union

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_union) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 828 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_union
    : public integral_constant<bool, __is_union(_Tp)> {};

#else
# 833 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct __libcpp_union : public false_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_union
    : public __libcpp_union<typename remove_cv<_Tp>::type> {};

#endif
# 839 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 841 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_union_v
    = is_union<_Tp>::value;
#endif
# 845 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_class

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_class) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 849 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_class
    : public integral_constant<bool, __is_class(_Tp)> {};

#else
# 854 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

namespace __is_class_imp
{
template <class _Tp> char  __test(int _Tp::*);
template <class _Tp> __two __test(...);
}

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_class
    : public integral_constant<bool, sizeof(__is_class_imp::__test<_Tp>(0)) == 1 && !is_union<_Tp>::value> {};

#endif
# 865 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 867 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_class_v
    = is_class<_Tp>::value;
#endif
# 871 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_function

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_function
    : public _BoolConstant<
#ifdef __clang__
    __is_function(_Tp)
#else
# 879 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
 !(is_reference<_Tp>::value || is_const<const _Tp>::value)
#endif
# 881 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    > {};


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 885 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_function_v
    = is_function<_Tp>::value;
#endif
# 889 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct __libcpp_is_member_pointer {
  enum {
    __is_member = false,
    __is_func = false,
    __is_obj = false
  };
};
template <class _Tp, class _Up> struct __libcpp_is_member_pointer<_Tp _Up::*> {
  enum {
    __is_member = true,
    __is_func = is_function<_Tp>::value,
    __is_obj = !__is_func,
  };
};


template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_member_function_pointer
    : public _BoolConstant< __libcpp_is_member_pointer<typename remove_cv<_Tp>::type>::__is_func > {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 910 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_member_function_pointer_v
    = is_member_function_pointer<_Tp>::value;
#endif
# 914 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_member_pointer

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_member_pointer
 : public _BoolConstant< __libcpp_is_member_pointer<typename remove_cv<_Tp>::type>::__is_member > {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 921 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_member_pointer_v
    = is_member_pointer<_Tp>::value;
#endif
# 925 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_member_object_pointer

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_member_object_pointer
    : public _BoolConstant< __libcpp_is_member_pointer<typename remove_cv<_Tp>::type>::__is_obj >  {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 932 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_member_object_pointer_v
    = is_member_object_pointer<_Tp>::value;
#endif
# 936 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_enum

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_enum) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 940 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_enum
    : public integral_constant<bool, __is_enum(_Tp)> {};

#else
# 945 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_enum
    : public integral_constant<bool, !is_void<_Tp>::value             &&
                                     !is_integral<_Tp>::value         &&
                                     !is_floating_point<_Tp>::value   &&
                                     !is_array<_Tp>::value            &&
                                     !is_pointer<_Tp>::value          &&
                                     !is_reference<_Tp>::value        &&
                                     !is_member_pointer<_Tp>::value   &&
                                     !is_union<_Tp>::value            &&
                                     !is_class<_Tp>::value            &&
                                     !is_function<_Tp>::value         > {};

#endif
# 959 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 961 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_enum_v
    = is_enum<_Tp>::value;
#endif
# 965 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_arithmetic

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_arithmetic
    : public integral_constant<bool, is_integral<_Tp>::value      ||
                                     is_floating_point<_Tp>::value> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 973 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_arithmetic_v
    = is_arithmetic<_Tp>::value;
#endif
# 977 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_fundamental

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_fundamental
    : public integral_constant<bool, is_void<_Tp>::value        ||
                                     __is_nullptr_t<_Tp>::value ||
                                     is_arithmetic<_Tp>::value> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 986 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_fundamental_v
    = is_fundamental<_Tp>::value;
#endif
# 990 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_scalar

template <class _Tp> struct __is_block : false_type {};
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_EXTENSION_BLOCKS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 995 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Rp, class ..._Args> struct __is_block<_Rp (^)(_Args...)> : true_type {};
#endif
# 997 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_scalar
    : public integral_constant<bool, is_arithmetic<_Tp>::value     ||
                                     is_member_pointer<_Tp>::value ||
                                     is_pointer<_Tp>::value        ||
                                     __is_nullptr_t<_Tp>::value    ||
                                     __is_block<_Tp>::value        ||
                                     is_enum<_Tp>::value           > {};

template <> struct _LIBCPP_TEMPLATE_VIS is_scalar<nullptr_t> : public true_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1009 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_scalar_v
    = is_scalar<_Tp>::value;
#endif
# 1013 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_object

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_object
    : public integral_constant<bool, is_scalar<_Tp>::value ||
                                     is_array<_Tp>::value  ||
                                     is_union<_Tp>::value  ||
                                     is_class<_Tp>::value  > {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1023 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_object_v
    = is_object<_Tp>::value;
#endif
# 1027 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_compound

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_compound
    : public integral_constant<bool, !is_fundamental<_Tp>::value> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1034 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_compound_v
    = is_compound<_Tp>::value;
#endif
# 1038 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3


// __is_referenceable  [defns.referenceable]

struct __is_referenceable_impl {
    template <class _Tp> static _Tp& __test(int);
    template <class _Tp> static __two __test(...);
};

template <class _Tp>
struct __is_referenceable : integral_constant<bool,
    _IsNotSame<decltype(__is_referenceable_impl::__test<_Tp>(0)), __two>::value> {};


// add_const

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS add_const {
  typedef _LIBCPP_NODEBUG_TYPE const _Tp type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1059 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using add_const_t = typename add_const<_Tp>::type;
#endif
# 1061 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// add_volatile

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS add_volatile {
  typedef _LIBCPP_NODEBUG_TYPE volatile _Tp type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1069 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using add_volatile_t = typename add_volatile<_Tp>::type;
#endif
# 1071 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// add_cv
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS add_cv {
  typedef _LIBCPP_NODEBUG_TYPE const volatile _Tp type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1078 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using add_cv_t = typename add_cv<_Tp>::type;
#endif
# 1080 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// remove_reference

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_reference        {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_reference<_Tp&>  {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_reference<_Tp&&> {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1088 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using remove_reference_t = typename remove_reference<_Tp>::type;
#endif
# 1090 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// add_lvalue_reference

template <class _Tp, bool = __is_referenceable<_Tp>::value> struct __add_lvalue_reference_impl            { typedef _LIBCPP_NODEBUG_TYPE _Tp  type; };
template <class _Tp                                       > struct __add_lvalue_reference_impl<_Tp, true> { typedef _LIBCPP_NODEBUG_TYPE _Tp& type; };

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS add_lvalue_reference
{typedef _LIBCPP_NODEBUG_TYPE typename  __add_lvalue_reference_impl<_Tp>::type type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using add_lvalue_reference_t = typename add_lvalue_reference<_Tp>::type;
#endif
# 1102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, bool = __is_referenceable<_Tp>::value> struct __add_rvalue_reference_impl            { typedef _LIBCPP_NODEBUG_TYPE  _Tp   type; };
template <class _Tp                                       > struct __add_rvalue_reference_impl<_Tp, true> { typedef _LIBCPP_NODEBUG_TYPE  _Tp&& type; };

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS add_rvalue_reference
{typedef _LIBCPP_NODEBUG_TYPE  typename __add_rvalue_reference_impl<_Tp>::type type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using add_rvalue_reference_t = typename add_rvalue_reference<_Tp>::type;
#endif
# 1112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// Suppress deprecation notice for volatile-qualified return type resulting
// from volatile-qualified types _Tp.
_LIBCPP_SUPPRESS_DEPRECATED_PUSH
template <class _Tp> _Tp&& __declval(int);
template <class _Tp> _Tp   __declval(long);
_LIBCPP_SUPPRESS_DEPRECATED_POP

template <class _Tp>
decltype(_VSTD::__declval<_Tp>(0))
declval() _NOEXCEPT;

// __uncvref

template <class _Tp>
struct __uncvref  {
    typedef _LIBCPP_NODEBUG_TYPE typename remove_cv<typename remove_reference<_Tp>::type>::type type;
};

template <class _Tp>
struct __unconstref {
    typedef _LIBCPP_NODEBUG_TYPE typename remove_const<typename remove_reference<_Tp>::type>::type type;
};

#ifndef _LIBCPP_CXX03_LANG
template <class _Tp>
using __uncvref_t _LIBCPP_NODEBUG_TYPE = typename __uncvref<_Tp>::type;
#endif
# 1140 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// __is_same_uncvref

template <class _Tp, class _Up>
struct __is_same_uncvref : _IsSame<typename __uncvref<_Tp>::type,
                                   typename __uncvref<_Up>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
// remove_cvref - same as __uncvref
template <class _Tp>
struct remove_cvref : public __uncvref<_Tp> {};

template <class _Tp> using remove_cvref_t = typename remove_cvref<_Tp>::type;
#endif
# 1154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3


struct __any
{
    __any(...);
};

// remove_pointer

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_pointer                      {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_pointer<_Tp*>                {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_pointer<_Tp* const>          {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_pointer<_Tp* volatile>       {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_pointer<_Tp* const volatile> {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1170 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using remove_pointer_t = typename remove_pointer<_Tp>::type;
#endif
# 1172 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// add_pointer

template <class _Tp,
        bool = __is_referenceable<_Tp>::value ||
                _IsSame<typename remove_cv<_Tp>::type, void>::value>
struct __add_pointer_impl
    {typedef _LIBCPP_NODEBUG_TYPE typename remove_reference<_Tp>::type* type;};
template <class _Tp> struct __add_pointer_impl<_Tp, false>
    {typedef _LIBCPP_NODEBUG_TYPE _Tp type;};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS add_pointer
    {typedef _LIBCPP_NODEBUG_TYPE typename __add_pointer_impl<_Tp>::type type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1187 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using add_pointer_t = typename add_pointer<_Tp>::type;
#endif
# 1189 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// type_identity
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1192 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template<class _Tp> struct type_identity { typedef _Tp type; };
template<class _Tp> using type_identity_t = typename type_identity<_Tp>::type;
#endif
# 1195 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_signed

template <class _Tp, bool = is_integral<_Tp>::value>
struct __libcpp_is_signed_impl : public _LIBCPP_BOOL_CONSTANT(_Tp(-1) < _Tp(0)) {};

template <class _Tp>
struct __libcpp_is_signed_impl<_Tp, false> : public true_type {};  // floating point

template <class _Tp, bool = is_arithmetic<_Tp>::value>
struct __libcpp_is_signed : public __libcpp_is_signed_impl<_Tp> {};

template <class _Tp> struct __libcpp_is_signed<_Tp, false> : public false_type {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_signed : public __libcpp_is_signed<_Tp> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1212 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_signed_v
    = is_signed<_Tp>::value;
#endif
# 1216 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_unsigned

template <class _Tp, bool = is_integral<_Tp>::value>
struct __libcpp_is_unsigned_impl : public _LIBCPP_BOOL_CONSTANT(_Tp(0) < _Tp(-1)) {};

template <class _Tp>
struct __libcpp_is_unsigned_impl<_Tp, false> : public false_type {};  // floating point

template <class _Tp, bool = is_arithmetic<_Tp>::value>
struct __libcpp_is_unsigned : public __libcpp_is_unsigned_impl<_Tp> {};

template <class _Tp> struct __libcpp_is_unsigned<_Tp, false> : public false_type {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_unsigned : public __libcpp_is_unsigned<_Tp> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1233 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_unsigned_v
    = is_unsigned<_Tp>::value;
#endif
# 1237 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// rank

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS rank
    : public integral_constant<size_t, 0> {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS rank<_Tp[]>
    : public integral_constant<size_t, rank<_Tp>::value + 1> {};
template <class _Tp, size_t _Np> struct _LIBCPP_TEMPLATE_VIS rank<_Tp[_Np]>
    : public integral_constant<size_t, rank<_Tp>::value + 1> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1248 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR size_t rank_v
    = rank<_Tp>::value;
#endif
# 1252 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// extent

template <class _Tp, unsigned _Ip = 0> struct _LIBCPP_TEMPLATE_VIS extent
    : public integral_constant<size_t, 0> {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS extent<_Tp[], 0>
    : public integral_constant<size_t, 0> {};
template <class _Tp, unsigned _Ip> struct _LIBCPP_TEMPLATE_VIS extent<_Tp[], _Ip>
    : public integral_constant<size_t, extent<_Tp, _Ip-1>::value> {};
template <class _Tp, size_t _Np> struct _LIBCPP_TEMPLATE_VIS extent<_Tp[_Np], 0>
    : public integral_constant<size_t, _Np> {};
template <class _Tp, size_t _Np, unsigned _Ip> struct _LIBCPP_TEMPLATE_VIS extent<_Tp[_Np], _Ip>
    : public integral_constant<size_t, extent<_Tp, _Ip-1>::value> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1267 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, unsigned _Ip = 0>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR size_t extent_v
    = extent<_Tp, _Ip>::value;
#endif
# 1271 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// remove_extent

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_extent
    {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_extent<_Tp[]>
    {typedef _Tp type;};
template <class _Tp, size_t _Np> struct _LIBCPP_TEMPLATE_VIS remove_extent<_Tp[_Np]>
    {typedef _Tp type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1282 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using remove_extent_t = typename remove_extent<_Tp>::type;
#endif
# 1284 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// remove_all_extents

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_all_extents
    {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS remove_all_extents<_Tp[]>
    {typedef typename remove_all_extents<_Tp>::type type;};
template <class _Tp, size_t _Np> struct _LIBCPP_TEMPLATE_VIS remove_all_extents<_Tp[_Np]>
    {typedef typename remove_all_extents<_Tp>::type type;};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using remove_all_extents_t = typename remove_all_extents<_Tp>::type;
#endif
# 1297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1299 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
// is_bounded_array

template <class>                 struct _LIBCPP_TEMPLATE_VIS is_bounded_array           : false_type {};
template <class _Tp, size_t _Np> struct _LIBCPP_TEMPLATE_VIS is_bounded_array<_Tp[_Np]> : true_type {};

template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR
bool is_bounded_array_v  = is_bounded_array<_Tp>::value;

// is_unbounded_array

template <class>     struct _LIBCPP_TEMPLATE_VIS is_unbounded_array        : false_type {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_unbounded_array<_Tp[]> : true_type {};

template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR
bool is_unbounded_array_v  = is_unbounded_array<_Tp>::value;
#endif
# 1317 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// decay

template <class _Up, bool>
struct __decay {
    typedef _LIBCPP_NODEBUG_TYPE typename remove_cv<_Up>::type type;
};

template <class _Up>
struct __decay<_Up, true> {
public:
    typedef _LIBCPP_NODEBUG_TYPE typename conditional
                     <
                         is_array<_Up>::value,
                         typename remove_extent<_Up>::type*,
                         typename conditional
                         <
                              is_function<_Up>::value,
                              typename add_pointer<_Up>::type,
                              typename remove_cv<_Up>::type
                         >::type
                     >::type type;
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS decay
{
private:
    typedef _LIBCPP_NODEBUG_TYPE typename remove_reference<_Tp>::type _Up;
public:
    typedef _LIBCPP_NODEBUG_TYPE typename __decay<_Up, __is_referenceable<_Up>::value>::type type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1351 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using decay_t = typename decay<_Tp>::type;
#endif
# 1353 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_abstract

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_abstract
    : public integral_constant<bool, __is_abstract(_Tp)> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1360 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_abstract_v
    = is_abstract<_Tp>::value;
#endif
# 1364 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_final

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS
__libcpp_is_final : public integral_constant<bool, __is_final(_Tp)> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1371 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS
is_final : public integral_constant<bool, __is_final(_Tp)> {};
#endif
# 1374 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1376 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_final_v
    = is_final<_Tp>::value;
#endif
# 1380 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_aggregate
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_IS_AGGREGATE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1383 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS
is_aggregate : public integral_constant<bool, __is_aggregate(_Tp)> {};

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1388 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR constexpr bool is_aggregate_v
    = is_aggregate<_Tp>::value;
#endif
# 1392 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#endif // _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_IS_AGGREGATE)
# 1394 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_base_of

template <class _Bp, class _Dp>
struct _LIBCPP_TEMPLATE_VIS is_base_of
    : public integral_constant<bool, __is_base_of(_Bp, _Dp)> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1402 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Bp, class _Dp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_base_of_v
    = is_base_of<_Bp, _Dp>::value;
#endif
# 1406 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_convertible

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_convertible_to) && !defined(_LIBCPP_USE_IS_CONVERTIBLE_FALLBACK)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1410 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _T1, class _T2> struct _LIBCPP_TEMPLATE_VIS is_convertible
    : public integral_constant<bool, __is_convertible_to(_T1, _T2)> {};

#else  // __has_feature(is_convertible_to)
# 1415 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

namespace __is_convertible_imp
{
template <class _Tp> void  __test_convert(_Tp);

template <class _From, class _To, class = void>
struct __is_convertible_test : public false_type {};

template <class _From, class _To>
struct __is_convertible_test<_From, _To,
    decltype(_VSTD::__is_convertible_imp::__test_convert<_To>(_VSTD::declval<_From>()))> : public true_type
{};

template <class _Tp, bool _IsArray =    is_array<_Tp>::value,
                     bool _IsFunction = is_function<_Tp>::value,
                     bool _IsVoid =     is_void<_Tp>::value>
                     struct __is_array_function_or_void                          {enum {value = 0};};
template <class _Tp> struct __is_array_function_or_void<_Tp, true, false, false> {enum {value = 1};};
template <class _Tp> struct __is_array_function_or_void<_Tp, false, true, false> {enum {value = 2};};
template <class _Tp> struct __is_array_function_or_void<_Tp, false, false, true> {enum {value = 3};};
}

template <class _Tp,
    unsigned = __is_convertible_imp::__is_array_function_or_void<typename remove_reference<_Tp>::type>::value>
struct __is_convertible_check
{
    static const size_t __v = 0;
};

template <class _Tp>
struct __is_convertible_check<_Tp, 0>
{
    static const size_t __v = sizeof(_Tp);
};

template <class _T1, class _T2,
    unsigned _T1_is_array_function_or_void = __is_convertible_imp::__is_array_function_or_void<_T1>::value,
    unsigned _T2_is_array_function_or_void = __is_convertible_imp::__is_array_function_or_void<_T2>::value>
struct __is_convertible
    : public integral_constant<bool,
        __is_convertible_imp::__is_convertible_test<_T1, _T2>::value
    >
{};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 0, 1> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 1, 1> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 2, 1> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 3, 1> : public false_type {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 0, 2> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 1, 2> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 2, 2> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 3, 2> : public false_type {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 0, 3> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 1, 3> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 2, 3> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 3, 3> : public true_type {};

template <class _T1, class _T2> struct _LIBCPP_TEMPLATE_VIS is_convertible
    : public __is_convertible<_T1, _T2>
{
    static const size_t __complete_check1 = __is_convertible_check<_T1>::__v;
    static const size_t __complete_check2 = __is_convertible_check<_T2>::__v;
};

#endif  // __has_feature(is_convertible_to)
# 1482 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1484 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _From, class _To>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_convertible_v
    = is_convertible<_From, _To>::value;
#endif
# 1488 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_convertible

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1492 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <typename _Tp>
static void __test_noexcept(_Tp) noexcept;

template<typename _Fm, typename _To>
static bool_constant<noexcept(__test_noexcept<_To>(declval<_Fm>()))>
__is_nothrow_convertible_test();

template <typename _Fm, typename _To>
struct __is_nothrow_convertible_helper: decltype(__is_nothrow_convertible_test<_Fm, _To>())
{ };

template <typename _Fm, typename _To>
struct is_nothrow_convertible : _Or<
    _And<is_void<_To>, is_void<_Fm>>,
    _Lazy<_And, is_convertible<_Fm, _To>, __is_nothrow_convertible_helper<_Fm, _To>>
>::type { };

template <typename _Fm, typename _To>
inline constexpr bool is_nothrow_convertible_v = is_nothrow_convertible<_Fm, _To>::value;

#endif // _LIBCPP_STD_VER > 17
# 1514 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_empty

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_empty) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1518 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_empty
    : public integral_constant<bool, __is_empty(_Tp)> {};

#else  // __has_feature(is_empty)
# 1524 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
struct __is_empty1
    : public _Tp
{
    double __lx;
};

struct __is_empty2
{
    double __lx;
};

template <class _Tp, bool = is_class<_Tp>::value>
struct __libcpp_empty : public integral_constant<bool, sizeof(__is_empty1<_Tp>) == sizeof(__is_empty2)> {};

template <class _Tp> struct __libcpp_empty<_Tp, false> : public false_type {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_empty : public __libcpp_empty<_Tp> {};

#endif  // __has_feature(is_empty)
# 1545 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1547 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_empty_v
    = is_empty<_Tp>::value;
#endif
# 1551 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_polymorphic

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_polymorphic) || defined(_LIBCPP_COMPILER_MSVC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1555 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_polymorphic
    : public integral_constant<bool, __is_polymorphic(_Tp)> {};

#else
# 1561 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template<typename _Tp> char &__is_polymorphic_impl(
    typename enable_if<sizeof((_Tp*)dynamic_cast<const volatile void*>(declval<_Tp*>())) != 0,
                       int>::type);
template<typename _Tp> __two &__is_polymorphic_impl(...);

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_polymorphic
    : public integral_constant<bool, sizeof(__is_polymorphic_impl<_Tp>(0)) == 1> {};

#endif // __has_feature(is_polymorphic)
# 1571 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1573 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_polymorphic_v
    = is_polymorphic<_Tp>::value;
#endif
# 1577 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// has_virtual_destructor

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(has_virtual_destructor) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1581 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS has_virtual_destructor
    : public integral_constant<bool, __has_virtual_destructor(_Tp)> {};

#else
# 1586 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS has_virtual_destructor
    : public false_type {};

#endif
# 1591 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1593 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool has_virtual_destructor_v
    = has_virtual_destructor<_Tp>::value;
#endif
# 1597 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// has_unique_object_representations

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && defined(_LIBCPP_HAS_UNIQUE_OBJECT_REPRESENTATIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1601 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS has_unique_object_representations
    : public integral_constant<bool,
       __has_unique_object_representations(remove_cv_t<remove_all_extents_t<_Tp>>)> {};

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1607 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool has_unique_object_representations_v
    = has_unique_object_representations<_Tp>::value;
#endif
# 1611 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#endif
# 1613 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// alignment_of

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS alignment_of
    : public integral_constant<size_t, _LIBCPP_ALIGNOF(_Tp)> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1620 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR size_t alignment_of_v
    = alignment_of<_Tp>::value;
#endif
# 1624 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// aligned_storage

template <class _Hp, class _Tp>
struct __type_list
{
    typedef _Hp _Head;
    typedef _Tp _Tail;
};

struct __nat
{
#ifndef _LIBCPP_CXX03_LANG
    __nat() = delete;
    __nat(const __nat&) = delete;
    __nat& operator=(const __nat&) = delete;
    ~__nat() = delete;
#endif
# 1642 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
};

template <class _Tp>
struct __align_type
{
    static const size_t value = _LIBCPP_PREFERRED_ALIGNOF(_Tp);
    typedef _Tp type;
};

struct __struct_double {long double __lx;};
struct __struct_double4 {double __lx[4];};

typedef
    __type_list<__align_type<unsigned char>,
    __type_list<__align_type<unsigned short>,
    __type_list<__align_type<unsigned int>,
    __type_list<__align_type<unsigned long>,
    __type_list<__align_type<unsigned long long>,
    __type_list<__align_type<double>,
    __type_list<__align_type<long double>,
    __type_list<__align_type<__struct_double>,
    __type_list<__align_type<__struct_double4>,
    __type_list<__align_type<int*>,
    __nat
    > > > > > > > > > > __all_types;

template <size_t _Align>
struct _ALIGNAS(_Align) __fallback_overaligned {};

template <class _TL, size_t _Align> struct __find_pod;

template <class _Hp, size_t _Align>
struct __find_pod<__type_list<_Hp, __nat>, _Align>
{
    typedef typename conditional<
                             _Align == _Hp::value,
                             typename _Hp::type,
                             __fallback_overaligned<_Align>
                         >::type type;
};

template <class _Hp, class _Tp, size_t _Align>
struct __find_pod<__type_list<_Hp, _Tp>, _Align>
{
    typedef typename conditional<
                             _Align == _Hp::value,
                             typename _Hp::type,
                             typename __find_pod<_Tp, _Align>::type
                         >::type type;
};

template <class _TL, size_t _Len> struct __find_max_align;

template <class _Hp, size_t _Len>
struct __find_max_align<__type_list<_Hp, __nat>, _Len> : public integral_constant<size_t, _Hp::value> {};

template <size_t _Len, size_t _A1, size_t _A2>
struct __select_align
{
private:
    static const size_t __min = _A2 < _A1 ? _A2 : _A1;
    static const size_t __max = _A1 < _A2 ? _A2 : _A1;
public:
    static const size_t value = _Len < __max ? __min : __max;
};

template <class _Hp, class _Tp, size_t _Len>
struct __find_max_align<__type_list<_Hp, _Tp>, _Len>
    : public integral_constant<size_t, __select_align<_Len, _Hp::value, __find_max_align<_Tp, _Len>::value>::value> {};

template <size_t _Len, size_t _Align = __find_max_align<__all_types, _Len>::value>
struct _LIBCPP_TEMPLATE_VIS aligned_storage
{
    typedef typename __find_pod<__all_types, _Align>::type _Aligner;
    union type
    {
        _Aligner __align;
        unsigned char __data[(_Len + _Align - 1)/_Align * _Align];
    };
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1724 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <size_t _Len, size_t _Align = __find_max_align<__all_types, _Len>::value>
    using aligned_storage_t = typename aligned_storage<_Len, _Align>::type;
#endif
# 1727 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#define _CREATE_ALIGNED_STORAGE_SPECIALIZATION(n) \
template <size_t _Len>\
struct _LIBCPP_TEMPLATE_VIS aligned_storage<_Len, n>\
{\
    struct _ALIGNAS(n) type\
    {\
        unsigned char __lx[(_Len + n - 1)/n * n];\
    };\
}

_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x1);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x2);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x4);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x8);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x10);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x20);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x40);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x80);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x100);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x200);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x400);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x800);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x1000);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x2000);
// PE/COFF does not support alignment beyond 8192 (=0x2000)
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_OBJECT_FORMAT_COFF)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1754 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x4000);
#endif // !defined(_LIBCPP_OBJECT_FORMAT_COFF)
# 1756 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#undef _CREATE_ALIGNED_STORAGE_SPECIALIZATION


// aligned_union

template <size_t _I0, size_t ..._In>
struct __static_max;

template <size_t _I0>
struct __static_max<_I0>
{
    static const size_t value = _I0;
};

template <size_t _I0, size_t _I1, size_t ..._In>
struct __static_max<_I0, _I1, _In...>
{
    static const size_t value = _I0 >= _I1 ? __static_max<_I0, _In...>::value :
                                             __static_max<_I1, _In...>::value;
};

template <size_t _Len, class _Type0, class ..._Types>
struct aligned_union
{
    static const size_t alignment_value = __static_max<_LIBCPP_PREFERRED_ALIGNOF(_Type0),
                                                       _LIBCPP_PREFERRED_ALIGNOF(_Types)...>::value;
    static const size_t __len = __static_max<_Len, sizeof(_Type0),
                                             sizeof(_Types)...>::value;
    typedef typename aligned_storage<__len, alignment_value>::type type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1789 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <size_t _Len, class ..._Types> using aligned_union_t = typename aligned_union<_Len, _Types...>::type;
#endif
# 1791 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
struct __numeric_type
{
   static void __test(...);
   static float __test(float);
   static double __test(char);
   static double __test(int);
   static double __test(unsigned);
   static double __test(long);
   static double __test(unsigned long);
   static double __test(long long);
   static double __test(unsigned long long);
   static double __test(double);
   static long double __test(long double);

   typedef decltype(__test(declval<_Tp>())) type;
   static const bool value = _IsNotSame<type, void>::value;
};

template <>
struct __numeric_type<void>
{
   static const bool value = true;
};

// __promote

template <class _A1, class _A2 = void, class _A3 = void,
          bool = __numeric_type<_A1>::value &&
                 __numeric_type<_A2>::value &&
                 __numeric_type<_A3>::value>
class __promote_imp
{
public:
    static const bool value = false;
};

template <class _A1, class _A2, class _A3>
class __promote_imp<_A1, _A2, _A3, true>
{
private:
    typedef typename __promote_imp<_A1>::type __type1;
    typedef typename __promote_imp<_A2>::type __type2;
    typedef typename __promote_imp<_A3>::type __type3;
public:
    typedef decltype(__type1() + __type2() + __type3()) type;
    static const bool value = true;
};

template <class _A1, class _A2>
class __promote_imp<_A1, _A2, void, true>
{
private:
    typedef typename __promote_imp<_A1>::type __type1;
    typedef typename __promote_imp<_A2>::type __type2;
public:
    typedef decltype(__type1() + __type2()) type;
    static const bool value = true;
};

template <class _A1>
class __promote_imp<_A1, void, void, true>
{
public:
    typedef typename __numeric_type<_A1>::type type;
    static const bool value = true;
};

template <class _A1, class _A2 = void, class _A3 = void>
class __promote : public __promote_imp<_A1, _A2, _A3> {};

// make_signed / make_unsigned

typedef
    __type_list<signed char,
    __type_list<signed short,
    __type_list<signed int,
    __type_list<signed long,
    __type_list<signed long long,
#ifndef _LIBCPP_HAS_NO_INT128
    __type_list<__int128_t,
#endif
# 1874 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    __nat
#ifndef _LIBCPP_HAS_NO_INT128
    >
#endif
# 1878 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    > > > > > __signed_types;

typedef
    __type_list<unsigned char,
    __type_list<unsigned short,
    __type_list<unsigned int,
    __type_list<unsigned long,
    __type_list<unsigned long long,
#ifndef _LIBCPP_HAS_NO_INT128
    __type_list<__uint128_t,
#endif
# 1889 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    __nat
#ifndef _LIBCPP_HAS_NO_INT128
    >
#endif
# 1893 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    > > > > > __unsigned_types;

template <class _TypeList, size_t _Size, bool = _Size <= sizeof(typename _TypeList::_Head)> struct __find_first;

template <class _Hp, class _Tp, size_t _Size>
struct __find_first<__type_list<_Hp, _Tp>, _Size, true>
{
    typedef _LIBCPP_NODEBUG_TYPE _Hp type;
};

template <class _Hp, class _Tp, size_t _Size>
struct __find_first<__type_list<_Hp, _Tp>, _Size, false>
{
    typedef _LIBCPP_NODEBUG_TYPE typename __find_first<_Tp, _Size>::type type;
};

template <class _Tp, class _Up, bool = is_const<typename remove_reference<_Tp>::type>::value,
                             bool = is_volatile<typename remove_reference<_Tp>::type>::value>
struct __apply_cv
{
    typedef _LIBCPP_NODEBUG_TYPE _Up type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp, _Up, true, false>
{
    typedef _LIBCPP_NODEBUG_TYPE const _Up type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp, _Up, false, true>
{
    typedef volatile _Up type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp, _Up, true, true>
{
    typedef const volatile _Up type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp&, _Up, false, false>
{
    typedef _Up& type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp&, _Up, true, false>
{
    typedef const _Up& type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp&, _Up, false, true>
{
    typedef volatile _Up& type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp&, _Up, true, true>
{
    typedef const volatile _Up& type;
};

template <class _Tp, bool = is_integral<_Tp>::value || is_enum<_Tp>::value>
struct __make_signed {};

template <class _Tp>
struct __make_signed<_Tp, true>
{
    typedef typename __find_first<__signed_types, sizeof(_Tp)>::type type;
};

template <> struct __make_signed<bool,               true> {};
template <> struct __make_signed<  signed short,     true> {typedef short     type;};
template <> struct __make_signed<unsigned short,     true> {typedef short     type;};
template <> struct __make_signed<  signed int,       true> {typedef int       type;};
template <> struct __make_signed<unsigned int,       true> {typedef int       type;};
template <> struct __make_signed<  signed long,      true> {typedef long      type;};
template <> struct __make_signed<unsigned long,      true> {typedef long      type;};
template <> struct __make_signed<  signed long long, true> {typedef long long type;};
template <> struct __make_signed<unsigned long long, true> {typedef long long type;};
#ifndef _LIBCPP_HAS_NO_INT128
template <> struct __make_signed<__int128_t,         true> {typedef __int128_t type;};
template <> struct __make_signed<__uint128_t,        true> {typedef __int128_t type;};
#endif
# 1980 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS make_signed
{
    typedef typename __apply_cv<_Tp, typename __make_signed<typename remove_cv<_Tp>::type>::type>::type type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1988 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using make_signed_t = typename make_signed<_Tp>::type;
#endif
# 1990 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, bool = is_integral<_Tp>::value || is_enum<_Tp>::value>
struct __make_unsigned {};

template <class _Tp>
struct __make_unsigned<_Tp, true>
{
    typedef typename __find_first<__unsigned_types, sizeof(_Tp)>::type type;
};

template <> struct __make_unsigned<bool,               true> {};
template <> struct __make_unsigned<  signed short,     true> {typedef unsigned short     type;};
template <> struct __make_unsigned<unsigned short,     true> {typedef unsigned short     type;};
template <> struct __make_unsigned<  signed int,       true> {typedef unsigned int       type;};
template <> struct __make_unsigned<unsigned int,       true> {typedef unsigned int       type;};
template <> struct __make_unsigned<  signed long,      true> {typedef unsigned long      type;};
template <> struct __make_unsigned<unsigned long,      true> {typedef unsigned long      type;};
template <> struct __make_unsigned<  signed long long, true> {typedef unsigned long long type;};
template <> struct __make_unsigned<unsigned long long, true> {typedef unsigned long long type;};
#ifndef _LIBCPP_HAS_NO_INT128
template <> struct __make_unsigned<__int128_t,         true> {typedef __uint128_t        type;};
template <> struct __make_unsigned<__uint128_t,        true> {typedef __uint128_t        type;};
#endif
# 2013 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS make_unsigned
{
    typedef typename __apply_cv<_Tp, typename __make_unsigned<typename remove_cv<_Tp>::type>::type>::type type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2021 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using make_unsigned_t = typename make_unsigned<_Tp>::type;
#endif
# 2023 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class _Up, class = void>
struct __common_type2_imp {};

template <class _Tp, class _Up>
struct __common_type2_imp<_Tp, _Up,
                          typename __void_t<decltype(
                                            true ? _VSTD::declval<_Tp>() : _VSTD::declval<_Up>()
                                            )>::type>
{
  typedef _LIBCPP_NODEBUG_TYPE typename decay<decltype(
                         true ? _VSTD::declval<_Tp>() : _VSTD::declval<_Up>()
                         )>::type type;
};

template <class, class = void>
struct __common_type_impl {};

// Clang provides variadic templates in C++03 as an extension.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG) || defined(__clang__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2043 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
# define _LIBCPP_OPTIONAL_PACK(...) , __VA_ARGS__
template <class... Tp>
struct __common_types;
template <class... _Tp>
struct _LIBCPP_TEMPLATE_VIS common_type;
#else
# 2049 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
# define _LIBCPP_OPTIONAL_PACK(...)
struct __no_arg;
template <class _Tp, class _Up, class = __no_arg>
struct __common_types;
template <class _Tp = __no_arg, class _Up = __no_arg, class _Vp = __no_arg,
          class _Unused = __no_arg>
struct common_type {
  static_assert(sizeof(_Unused) == 0,
                "common_type accepts at most 3 arguments in C++03");
};
#endif // _LIBCPP_CXX03_LANG
# 2060 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class _Up>
struct __common_type_impl<
    __common_types<_Tp, _Up>,
    typename __void_t<typename common_type<_Tp, _Up>::type>::type>
{
  typedef typename common_type<_Tp, _Up>::type type;
};

template <class _Tp, class _Up, class _Vp _LIBCPP_OPTIONAL_PACK(class... _Rest)>
struct __common_type_impl<
    __common_types<_Tp, _Up, _Vp _LIBCPP_OPTIONAL_PACK(_Rest...)>,
    typename __void_t<typename common_type<_Tp, _Up>::type>::type>
    : __common_type_impl<__common_types<typename common_type<_Tp, _Up>::type,
                                        _Vp _LIBCPP_OPTIONAL_PACK(_Rest...)> > {
};

// bullet 1 - sizeof...(Tp) == 0

template <>
struct _LIBCPP_TEMPLATE_VIS common_type<> {};

// bullet 2 - sizeof...(Tp) == 1

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS common_type<_Tp>
    : public common_type<_Tp, _Tp> {};

// bullet 3 - sizeof...(Tp) == 2

template <class _Tp, class _Up>
struct _LIBCPP_TEMPLATE_VIS common_type<_Tp, _Up>
    : conditional<
        _IsSame<_Tp, typename decay<_Tp>::type>::value && _IsSame<_Up, typename decay<_Up>::type>::value,
        __common_type2_imp<_Tp, _Up>,
        common_type<typename decay<_Tp>::type, typename decay<_Up>::type>
    >::type
{};

// bullet 4 - sizeof...(Tp) > 2

template <class _Tp, class _Up, class _Vp _LIBCPP_OPTIONAL_PACK(class... _Rest)>
struct _LIBCPP_TEMPLATE_VIS
    common_type<_Tp, _Up, _Vp _LIBCPP_OPTIONAL_PACK(_Rest...)>
    : __common_type_impl<
          __common_types<_Tp, _Up, _Vp _LIBCPP_OPTIONAL_PACK(_Rest...)> > {};

#undef _LIBCPP_OPTIONAL_PACK

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class ..._Tp> using common_type_t = typename common_type<_Tp...>::type;
#endif
# 2112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_assignable

template<typename, typename _Tp> struct __select_2nd { typedef _LIBCPP_NODEBUG_TYPE _Tp type; };

template <class _Tp, class _Arg>
typename __select_2nd<decltype((_VSTD::declval<_Tp>() = _VSTD::declval<_Arg>())), true_type>::type
__is_assignable_test(int);

template <class, class>
false_type __is_assignable_test(...);


template <class _Tp, class _Arg, bool = is_void<_Tp>::value || is_void<_Arg>::value>
struct __is_assignable_imp
    : public decltype((_VSTD::__is_assignable_test<_Tp, _Arg>(0))) {};

template <class _Tp, class _Arg>
struct __is_assignable_imp<_Tp, _Arg, true>
    : public false_type
{
};

template <class _Tp, class _Arg>
struct is_assignable
    : public __is_assignable_imp<_Tp, _Arg> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2140 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class _Arg>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_assignable_v
    = is_assignable<_Tp, _Arg>::value;
#endif
# 2144 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_copy_assignable

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_copy_assignable
    : public is_assignable<typename add_lvalue_reference<_Tp>::type,
                  typename add_lvalue_reference<typename add_const<_Tp>::type>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_copy_assignable_v
    = is_copy_assignable<_Tp>::value;
#endif
# 2156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_move_assignable

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_move_assignable
    : public is_assignable<typename add_lvalue_reference<_Tp>::type,
                           typename add_rvalue_reference<_Tp>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_move_assignable_v
    = is_move_assignable<_Tp>::value;
#endif
# 2168 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_destructible

//  if it's a reference, return true
//  if it's a function, return false
//  if it's   void,     return false
//  if it's an array of unknown bound, return false
//  Otherwise, return "std::declval<_Up&>().~_Up()" is well-formed
//    where _Up is remove_all_extents<_Tp>::type

template <class>
struct __is_destructible_apply { typedef int type; };

template <typename _Tp>
struct __is_destructor_wellformed {
    template <typename _Tp1>
    static char  __test (
        typename __is_destructible_apply<decltype(_VSTD::declval<_Tp1&>().~_Tp1())>::type
    );

    template <typename _Tp1>
    static __two __test (...);

    static const bool value = sizeof(__test<_Tp>(12)) == sizeof(char);
};

template <class _Tp, bool>
struct __destructible_imp;

template <class _Tp>
struct __destructible_imp<_Tp, false>
   : public _VSTD::integral_constant<bool,
        __is_destructor_wellformed<typename _VSTD::remove_all_extents<_Tp>::type>::value> {};

template <class _Tp>
struct __destructible_imp<_Tp, true>
    : public _VSTD::true_type {};

template <class _Tp, bool>
struct __destructible_false;

template <class _Tp>
struct __destructible_false<_Tp, false> : public __destructible_imp<_Tp, _VSTD::is_reference<_Tp>::value> {};

template <class _Tp>
struct __destructible_false<_Tp, true> : public _VSTD::false_type {};

template <class _Tp>
struct is_destructible
    : public __destructible_false<_Tp, _VSTD::is_function<_Tp>::value> {};

template <class _Tp>
struct is_destructible<_Tp[]>
    : public _VSTD::false_type {};

template <>
struct is_destructible<void>
    : public _VSTD::false_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2228 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_destructible_v
    = is_destructible<_Tp>::value;
#endif
# 2232 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// move

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename remove_reference<_Tp>::type&&
move(_Tp&& __t) _NOEXCEPT
{
    typedef _LIBCPP_NODEBUG_TYPE typename remove_reference<_Tp>::type _Up;
    return static_cast<_Up&&>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
_Tp&&
forward(typename remove_reference<_Tp>::type& __t) _NOEXCEPT
{
    return static_cast<_Tp&&>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
_Tp&&
forward(typename remove_reference<_Tp>::type&& __t) _NOEXCEPT
{
    static_assert(!is_lvalue_reference<_Tp>::value,
                  "can not forward an rvalue as an lvalue");
    return static_cast<_Tp&&>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename decay<_Tp>::type
__decay_copy(_Tp&& __t)
{
    return _VSTD::forward<_Tp>(__t);
}

template <class _MP, bool _IsMemberFunctionPtr, bool _IsMemberObjectPtr>
struct __member_pointer_traits_imp
{
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...), true, false>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...), true, false>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const, true, false>
{
    typedef _Class const _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) const, true, false>
{
    typedef _Class const _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) volatile, true, false>
{
    typedef _Class volatile _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) volatile, true, false>
{
    typedef _Class volatile _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const volatile, true, false>
{
    typedef _Class const volatile _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) const volatile, true, false>
{
    typedef _Class const volatile _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_reference_qualified_functions) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2340 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) &, true, false>
{
    typedef _Class& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) &, true, false>
{
    typedef _Class& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const&, true, false>
{
    typedef _Class const& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) const&, true, false>
{
    typedef _Class const& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) volatile&, true, false>
{
    typedef _Class volatile& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) volatile&, true, false>
{
    typedef _Class volatile& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const volatile&, true, false>
{
    typedef _Class const volatile& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) const volatile&, true, false>
{
    typedef _Class const volatile& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) &&, true, false>
{
    typedef _Class&& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) &&, true, false>
{
    typedef _Class&& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const&&, true, false>
{
    typedef _Class const&& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) const&&, true, false>
{
    typedef _Class const&& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) volatile&&, true, false>
{
    typedef _Class volatile&& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) volatile&&, true, false>
{
    typedef _Class volatile&& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const volatile&&, true, false>
{
    typedef _Class const volatile&& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param...);
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param..., ...) const volatile&&, true, false>
{
    typedef _Class const volatile&& _ClassType;
    typedef _Rp _ReturnType;
    typedef _Rp (_FnType) (_Param..., ...);
};

#endif  // __has_feature(cxx_reference_qualified_functions) || defined(_LIBCPP_COMPILER_GCC)
# 2470 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3


template <class _Rp, class _Class>
struct __member_pointer_traits_imp<_Rp _Class::*, false, true>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
};

template <class _MP>
struct __member_pointer_traits
    : public __member_pointer_traits_imp<typename remove_cv<_MP>::type,
                    is_member_function_pointer<_MP>::value,
                    is_member_object_pointer<_MP>::value>
{
//     typedef ... _ClassType;
//     typedef ... _ReturnType;
//     typedef ... _FnType;
};


template <class _DecayedFp>
struct __member_pointer_class_type {};

template <class _Ret, class _ClassType>
struct __member_pointer_class_type<_Ret _ClassType::*> {
  typedef _ClassType type;
};

// result_of

template <class _Callable> class result_of;

#ifdef _LIBCPP_HAS_NO_VARIADICS

template <class _Fn, bool, bool>
class __result_of
{
};

template <class _Fn>
class __result_of<_Fn(), true, false>
{
public:
    typedef decltype(declval<_Fn>()()) type;
};

template <class _Fn, class _A0>
class __result_of<_Fn(_A0), true, false>
{
public:
    typedef decltype(declval<_Fn>()(declval<_A0>())) type;
};

template <class _Fn, class _A0, class _A1>
class __result_of<_Fn(_A0, _A1), true, false>
{
public:
    typedef decltype(declval<_Fn>()(declval<_A0>(), declval<_A1>())) type;
};

template <class _Fn, class _A0, class _A1, class _A2>
class __result_of<_Fn(_A0, _A1, _A2), true, false>
{
public:
    typedef decltype(declval<_Fn>()(declval<_A0>(), declval<_A1>(), declval<_A2>())) type;
};

template <class _MP, class _Tp, bool _IsMemberFunctionPtr>
struct __result_of_mp;

// member function pointer

template <class _MP, class _Tp>
struct __result_of_mp<_MP, _Tp, true>
    : public __identity<typename __member_pointer_traits<_MP>::_ReturnType>
{
};

// member data pointer

template <class _MP, class _Tp, bool>
struct __result_of_mdp;

template <class _Rp, class _Class, class _Tp>
struct __result_of_mdp<_Rp _Class::*, _Tp, false>
{
    typedef typename __apply_cv<decltype(*_VSTD::declval<_Tp>()), _Rp>::type& type;
};

template <class _Rp, class _Class, class _Tp>
struct __result_of_mdp<_Rp _Class::*, _Tp, true>
{
    typedef typename __apply_cv<_Tp, _Rp>::type& type;
};

template <class _Rp, class _Class, class _Tp>
struct __result_of_mp<_Rp _Class::*, _Tp, false>
    : public __result_of_mdp<_Rp _Class::*, _Tp,
            is_base_of<_Class, typename remove_reference<_Tp>::type>::value>
{
};



template <class _Fn, class _Tp>
class __result_of<_Fn(_Tp), false, true>  // _Fn must be member pointer
    : public __result_of_mp<typename remove_reference<_Fn>::type,
                            _Tp,
                            is_member_function_pointer<typename remove_reference<_Fn>::type>::value>
{
};

template <class _Fn, class _Tp, class _A0>
class __result_of<_Fn(_Tp, _A0), false, true>  // _Fn must be member pointer
    : public __result_of_mp<typename remove_reference<_Fn>::type,
                            _Tp,
                            is_member_function_pointer<typename remove_reference<_Fn>::type>::value>
{
};

template <class _Fn, class _Tp, class _A0, class _A1>
class __result_of<_Fn(_Tp, _A0, _A1), false, true>  // _Fn must be member pointer
    : public __result_of_mp<typename remove_reference<_Fn>::type,
                            _Tp,
                            is_member_function_pointer<typename remove_reference<_Fn>::type>::value>
{
};

template <class _Fn, class _Tp, class _A0, class _A1, class _A2>
class __result_of<_Fn(_Tp, _A0, _A1, _A2), false, true>  // _Fn must be member pointer
    : public __result_of_mp<typename remove_reference<_Fn>::type,
                            _Tp,
                            is_member_function_pointer<typename remove_reference<_Fn>::type>::value>
{
};

// result_of

template <class _Fn>
class _LIBCPP_TEMPLATE_VIS result_of<_Fn()>
    : public __result_of<_Fn(),
                         is_class<typename remove_reference<_Fn>::type>::value ||
                         is_function<typename remove_pointer<typename remove_reference<_Fn>::type>::type>::value,
                         is_member_pointer<typename remove_reference<_Fn>::type>::value
                        >
{
};

template <class _Fn, class _A0>
class _LIBCPP_TEMPLATE_VIS result_of<_Fn(_A0)>
    : public __result_of<_Fn(_A0),
                         is_class<typename remove_reference<_Fn>::type>::value ||
                         is_function<typename remove_pointer<typename remove_reference<_Fn>::type>::type>::value,
                         is_member_pointer<typename remove_reference<_Fn>::type>::value
                        >
{
};

template <class _Fn, class _A0, class _A1>
class _LIBCPP_TEMPLATE_VIS result_of<_Fn(_A0, _A1)>
    : public __result_of<_Fn(_A0, _A1),
                         is_class<typename remove_reference<_Fn>::type>::value ||
                         is_function<typename remove_pointer<typename remove_reference<_Fn>::type>::type>::value,
                         is_member_pointer<typename remove_reference<_Fn>::type>::value
                        >
{
};

template <class _Fn, class _A0, class _A1, class _A2>
class _LIBCPP_TEMPLATE_VIS result_of<_Fn(_A0, _A1, _A2)>
    : public __result_of<_Fn(_A0, _A1, _A2),
                         is_class<typename remove_reference<_Fn>::type>::value ||
                         is_function<typename remove_pointer<typename remove_reference<_Fn>::type>::type>::value,
                         is_member_pointer<typename remove_reference<_Fn>::type>::value
                        >
{
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2650 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// template <class T, class... Args> struct is_constructible;

namespace __is_construct
{
struct __nat {};
}

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG) && (!__has_feature(is_constructible) || \
    defined(_LIBCPP_TESTING_FALLBACK_IS_CONSTRUCTIBLE))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2660 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class... _Args>
struct __libcpp_is_constructible;

template <class _To, class _From>
struct __is_invalid_base_to_derived_cast {
  static_assert(is_reference<_To>::value, "Wrong specialization");
  using _RawFrom = __uncvref_t<_From>;
  using _RawTo = __uncvref_t<_To>;
  static const bool value = _And<
        _IsNotSame<_RawFrom, _RawTo>,
        is_base_of<_RawFrom, _RawTo>,
        _Not<__libcpp_is_constructible<_RawTo, _From>>
  >::value;
};

template <class _To, class _From>
struct __is_invalid_lvalue_to_rvalue_cast : false_type {
  static_assert(is_reference<_To>::value, "Wrong specialization");
};

template <class _ToRef, class _FromRef>
struct __is_invalid_lvalue_to_rvalue_cast<_ToRef&&, _FromRef&> {
  using _RawFrom = __uncvref_t<_FromRef>;
  using _RawTo = __uncvref_t<_ToRef>;
  static const bool value = _And<
      _Not<is_function<_RawTo>>,
      _Or<
        _IsSame<_RawFrom, _RawTo>,
        is_base_of<_RawTo, _RawFrom>>
    >::value;
};

struct __is_constructible_helper
{
    template <class _To>
    static void __eat(_To);

    // This overload is needed to work around a Clang bug that disallows
    // static_cast<T&&>(e) for non-reference-compatible types.
    // Example: static_cast<int&&>(declval<double>());
    // NOTE: The static_cast implementation below is required to support
    //  classes with explicit conversion operators.
    template <class _To, class _From,
              class = decltype(__eat<_To>(_VSTD::declval<_From>()))>
    static true_type __test_cast(int);

    template <class _To, class _From,
              class = decltype(static_cast<_To>(_VSTD::declval<_From>()))>
    static integral_constant<bool,
        !__is_invalid_base_to_derived_cast<_To, _From>::value &&
        !__is_invalid_lvalue_to_rvalue_cast<_To, _From>::value
    > __test_cast(long);

    template <class, class>
    static false_type __test_cast(...);

    template <class _Tp, class ..._Args,
        class = decltype(_Tp(_VSTD::declval<_Args>()...))>
    static true_type __test_nary(int);
    template <class _Tp, class...>
    static false_type __test_nary(...);

    template <class _Tp, class _A0, class = decltype(::new _Tp(_VSTD::declval<_A0>()))>
    static is_destructible<_Tp> __test_unary(int);
    template <class, class>
    static false_type __test_unary(...);
};

template <class _Tp, bool = is_void<_Tp>::value>
struct __is_default_constructible
    : decltype(__is_constructible_helper::__test_nary<_Tp>(0))
{};

template <class _Tp>
struct __is_default_constructible<_Tp, true> : false_type {};

template <class _Tp>
struct __is_default_constructible<_Tp[], false> : false_type {};

template <class _Tp, size_t _Nx>
struct __is_default_constructible<_Tp[_Nx], false>
    : __is_default_constructible<typename remove_all_extents<_Tp>::type>  {};

template <class _Tp, class... _Args>
struct __libcpp_is_constructible
{
  static_assert(sizeof...(_Args) > 1, "Wrong specialization");
  typedef decltype(__is_constructible_helper::__test_nary<_Tp, _Args...>(0))
      type;
};

template <class _Tp>
struct __libcpp_is_constructible<_Tp> : __is_default_constructible<_Tp> {};

template <class _Tp, class _A0>
struct __libcpp_is_constructible<_Tp, _A0>
    : public decltype(__is_constructible_helper::__test_unary<_Tp, _A0>(0))
{};

template <class _Tp, class _A0>
struct __libcpp_is_constructible<_Tp&, _A0>
    : public decltype(__is_constructible_helper::
    __test_cast<_Tp&, _A0>(0))
{};

template <class _Tp, class _A0>
struct __libcpp_is_constructible<_Tp&&, _A0>
    : public decltype(__is_constructible_helper::
    __test_cast<_Tp&&, _A0>(0))
{};

#endif
# 2773 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_constructible)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2775 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class ..._Args>
struct _LIBCPP_TEMPLATE_VIS is_constructible
    : public integral_constant<bool, __is_constructible(_Tp, _Args...)>
    {};
#else
# 2780 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class... _Args>
struct _LIBCPP_TEMPLATE_VIS is_constructible
    : public __libcpp_is_constructible<_Tp, _Args...>::type {};
#endif
# 2784 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2786 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class ..._Args>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_constructible_v
    = is_constructible<_Tp, _Args...>::value;
#endif
# 2790 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_default_constructible

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_default_constructible
    : public is_constructible<_Tp>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2799 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_default_constructible_v
    = is_default_constructible<_Tp>::value;
#endif
# 2803 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#ifndef _LIBCPP_CXX03_LANG
// First of all, we can't implement this check in C++03 mode because the {}
// default initialization syntax isn't valid.
// Second, we implement the trait in a funny manner with two defaulted template
// arguments to workaround Clang's PR43454.
template <class _Tp>
void __test_implicit_default_constructible(_Tp);

template <class _Tp, class = void, bool = is_default_constructible<_Tp>::value>
struct __is_implicitly_default_constructible
    : false_type
{ };

template <class _Tp>
struct __is_implicitly_default_constructible<_Tp, decltype(__test_implicit_default_constructible<_Tp const&>({})), true>
    : true_type
{ };

template <class _Tp>
struct __is_implicitly_default_constructible<_Tp, decltype(__test_implicit_default_constructible<_Tp const&>({})), false>
    : false_type
{ };
#endif // !C++03
# 2827 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_copy_constructible

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_copy_constructible
    : public is_constructible<_Tp,
                  typename add_lvalue_reference<typename add_const<_Tp>::type>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2836 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_copy_constructible_v
    = is_copy_constructible<_Tp>::value;
#endif
# 2840 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_move_constructible

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_move_constructible
    : public is_constructible<_Tp, typename add_rvalue_reference<_Tp>::type>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2849 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_move_constructible_v
    = is_move_constructible<_Tp>::value;
#endif
# 2853 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_constructible

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_trivially_constructible) || _GNUC_VER >= 501
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2857 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class... _Args>
struct _LIBCPP_TEMPLATE_VIS is_trivially_constructible
    : integral_constant<bool, __is_trivially_constructible(_Tp, _Args...)>
{
};

#else  // !__has_feature(is_trivially_constructible)
# 2865 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class... _Args>
struct _LIBCPP_TEMPLATE_VIS is_trivially_constructible
    : false_type
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_trivially_constructible<_Tp>
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(has_trivial_constructor) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2875 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : integral_constant<bool, __has_trivial_constructor(_Tp)>
#else
# 2877 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2879 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_trivially_constructible<_Tp, _Tp&&>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_trivially_constructible<_Tp, const _Tp&>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_trivially_constructible<_Tp, _Tp&>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

#endif  // !__has_feature(is_trivially_constructible)
# 2901 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2904 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class... _Args>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_constructible_v
    = is_trivially_constructible<_Tp, _Args...>::value;
#endif
# 2908 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_default_constructible

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_default_constructible
    : public is_trivially_constructible<_Tp>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2916 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_default_constructible_v
    = is_trivially_default_constructible<_Tp>::value;
#endif
# 2920 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_copy_constructible

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_copy_constructible
    : public is_trivially_constructible<_Tp, typename add_lvalue_reference<const _Tp>::type>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2928 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_copy_constructible_v
    = is_trivially_copy_constructible<_Tp>::value;
#endif
# 2932 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_move_constructible

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_move_constructible
    : public is_trivially_constructible<_Tp, typename add_rvalue_reference<_Tp>::type>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2940 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_move_constructible_v
    = is_trivially_move_constructible<_Tp>::value;
#endif
# 2944 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_assignable

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_trivially_assignable) || _GNUC_VER >= 501
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2948 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class _Arg>
struct is_trivially_assignable
    : integral_constant<bool, __is_trivially_assignable(_Tp, _Arg)>
{
};

#else  // !__has_feature(is_trivially_assignable)
# 2956 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class _Arg>
struct is_trivially_assignable
    : public false_type {};

template <class _Tp>
struct is_trivially_assignable<_Tp&, _Tp>
    : integral_constant<bool, is_scalar<_Tp>::value> {};

template <class _Tp>
struct is_trivially_assignable<_Tp&, _Tp&>
    : integral_constant<bool, is_scalar<_Tp>::value> {};

template <class _Tp>
struct is_trivially_assignable<_Tp&, const _Tp&>
    : integral_constant<bool, is_scalar<_Tp>::value> {};

template <class _Tp>
struct is_trivially_assignable<_Tp&, _Tp&&>
    : integral_constant<bool, is_scalar<_Tp>::value> {};

#endif  // !__has_feature(is_trivially_assignable)
# 2978 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2980 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class _Arg>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_assignable_v
    = is_trivially_assignable<_Tp, _Arg>::value;
#endif
# 2984 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_copy_assignable

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_copy_assignable
    : public is_trivially_assignable<typename add_lvalue_reference<_Tp>::type,
                  typename add_lvalue_reference<typename add_const<_Tp>::type>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2992 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_copy_assignable_v
    = is_trivially_copy_assignable<_Tp>::value;
#endif
# 2996 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_move_assignable

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_move_assignable
    : public is_trivially_assignable<typename add_lvalue_reference<_Tp>::type,
                                     typename add_rvalue_reference<_Tp>::type>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3005 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_move_assignable_v
    = is_trivially_move_assignable<_Tp>::value;
#endif
# 3009 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_destructible

#if 0 /* disabled by -frewrite-includes */
#if __has_keyword(__is_trivially_destructible)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3013 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_destructible
    : public integral_constant<bool, __is_trivially_destructible(_Tp)> {};

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __has_feature(has_trivial_destructor) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 3018 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_destructible
    : public integral_constant<bool, is_destructible<_Tp>::value && __has_trivial_destructor(_Tp)> {};

#else
# 3023 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct __libcpp_trivial_destructor
    : public integral_constant<bool, is_scalar<_Tp>::value ||
                                     is_reference<_Tp>::value> {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_destructible
    : public __libcpp_trivial_destructor<typename remove_all_extents<_Tp>::type> {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_destructible<_Tp[]>
    : public false_type {};

#endif
# 3035 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3037 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_destructible_v
    = is_trivially_destructible<_Tp>::value;
#endif
# 3041 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_constructible

#if 0 /* disabled by -frewrite-includes */
#if __has_keyword(__is_nothrow_constructible)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3045 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class... _Args>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_constructible
    : public integral_constant<bool, __is_nothrow_constructible(_Tp, _Args...)> {};

#else
# 3051 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <bool, bool, class _Tp, class... _Args> struct __libcpp_is_nothrow_constructible;

template <class _Tp, class... _Args>
struct __libcpp_is_nothrow_constructible</*is constructible*/true, /*is reference*/false, _Tp, _Args...>
    : public integral_constant<bool, noexcept(_Tp(declval<_Args>()...))>
{
};

template <class _Tp>
void __implicit_conversion_to(_Tp) noexcept { }

template <class _Tp, class _Arg>
struct __libcpp_is_nothrow_constructible</*is constructible*/true, /*is reference*/true, _Tp, _Arg>
    : public integral_constant<bool, noexcept(__implicit_conversion_to<_Tp>(declval<_Arg>()))>
{
};

template <class _Tp, bool _IsReference, class... _Args>
struct __libcpp_is_nothrow_constructible</*is constructible*/false, _IsReference, _Tp, _Args...>
    : public false_type
{
};

template <class _Tp, class... _Args>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_constructible
    : __libcpp_is_nothrow_constructible<is_constructible<_Tp, _Args...>::value, is_reference<_Tp>::value, _Tp, _Args...>
{
};

template <class _Tp, size_t _Ns>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_constructible<_Tp[_Ns]>
    : __libcpp_is_nothrow_constructible<is_constructible<_Tp>::value, is_reference<_Tp>::value, _Tp>
{
};

#endif  // _LIBCPP_HAS_NO_NOEXCEPT
# 3088 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3091 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class ..._Args>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_nothrow_constructible_v
    = is_nothrow_constructible<_Tp, _Args...>::value;
#endif
# 3095 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_default_constructible

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_nothrow_default_constructible
    : public is_nothrow_constructible<_Tp>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3103 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_nothrow_default_constructible_v
    = is_nothrow_default_constructible<_Tp>::value;
#endif
# 3107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_copy_constructible

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_nothrow_copy_constructible
    : public is_nothrow_constructible<_Tp,
                  typename add_lvalue_reference<typename add_const<_Tp>::type>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3115 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_nothrow_copy_constructible_v
    = is_nothrow_copy_constructible<_Tp>::value;
#endif
# 3119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_move_constructible

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_nothrow_move_constructible
    : public is_nothrow_constructible<_Tp, typename add_rvalue_reference<_Tp>::type>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3127 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_nothrow_move_constructible_v
    = is_nothrow_move_constructible<_Tp>::value;
#endif
# 3131 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_assignable

#if 0 /* disabled by -frewrite-includes */
#if __has_keyword(__is_nothrow_assignable)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3135 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class _Arg>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_assignable
    : public integral_constant<bool, __is_nothrow_assignable(_Tp, _Arg)> {};

#else
# 3141 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <bool, class _Tp, class _Arg> struct __libcpp_is_nothrow_assignable;

template <class _Tp, class _Arg>
struct __libcpp_is_nothrow_assignable<false, _Tp, _Arg>
    : public false_type
{
};

template <class _Tp, class _Arg>
struct __libcpp_is_nothrow_assignable<true, _Tp, _Arg>
    : public integral_constant<bool, noexcept(_VSTD::declval<_Tp>() = _VSTD::declval<_Arg>()) >
{
};

template <class _Tp, class _Arg>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_assignable
    : public __libcpp_is_nothrow_assignable<is_assignable<_Tp, _Arg>::value, _Tp, _Arg>
{
};

#endif  // _LIBCPP_HAS_NO_NOEXCEPT
# 3163 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3165 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp, class _Arg>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_nothrow_assignable_v
    = is_nothrow_assignable<_Tp, _Arg>::value;
#endif
# 3169 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_copy_assignable

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_nothrow_copy_assignable
    : public is_nothrow_assignable<typename add_lvalue_reference<_Tp>::type,
                  typename add_lvalue_reference<typename add_const<_Tp>::type>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3177 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_nothrow_copy_assignable_v
    = is_nothrow_copy_assignable<_Tp>::value;
#endif
# 3181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_move_assignable

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_nothrow_move_assignable
    : public is_nothrow_assignable<typename add_lvalue_reference<_Tp>::type,
                                     typename add_rvalue_reference<_Tp>::type>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3190 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_nothrow_move_assignable_v
    = is_nothrow_move_assignable<_Tp>::value;
#endif
# 3194 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_nothrow_destructible

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3198 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <bool, class _Tp> struct __libcpp_is_nothrow_destructible;

template <class _Tp>
struct __libcpp_is_nothrow_destructible<false, _Tp>
    : public false_type
{
};

template <class _Tp>
struct __libcpp_is_nothrow_destructible<true, _Tp>
    : public integral_constant<bool, noexcept(_VSTD::declval<_Tp>().~_Tp()) >
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_destructible
    : public __libcpp_is_nothrow_destructible<is_destructible<_Tp>::value, _Tp>
{
};

template <class _Tp, size_t _Ns>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_destructible<_Tp[_Ns]>
    : public is_nothrow_destructible<_Tp>
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_destructible<_Tp&>
    : public true_type
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_destructible<_Tp&&>
    : public true_type
{
};

#else
# 3238 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct __libcpp_nothrow_destructor
    : public integral_constant<bool, is_scalar<_Tp>::value ||
                                     is_reference<_Tp>::value> {};

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_nothrow_destructible
    : public __libcpp_nothrow_destructor<typename remove_all_extents<_Tp>::type> {};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_destructible<_Tp[]>
    : public false_type {};

#endif
# 3251 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3253 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_nothrow_destructible_v
    = is_nothrow_destructible<_Tp>::value;
#endif
# 3257 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_pod

#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_pod) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3261 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_pod
    : public integral_constant<bool, __is_pod(_Tp)> {};

#else
# 3266 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_pod
    : public integral_constant<bool, is_trivially_default_constructible<_Tp>::value   &&
                                     is_trivially_copy_constructible<_Tp>::value      &&
                                     is_trivially_copy_assignable<_Tp>::value    &&
                                     is_trivially_destructible<_Tp>::value> {};

#endif
# 3274 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3276 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_pod_v
    = is_pod<_Tp>::value;
#endif
# 3280 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_literal_type;

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_literal_type
    : public integral_constant<bool, __is_literal_type(_Tp)>
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3288 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_literal_type_v
    = is_literal_type<_Tp>::value;
#endif
# 3292 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_standard_layout;

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_standard_layout
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_standard_layout) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : public integral_constant<bool, __is_standard_layout(_Tp)>
#else
# 3299 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<typename remove_all_extents<_Tp>::type>::value>
#endif
# 3301 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3304 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_standard_layout_v
    = is_standard_layout<_Tp>::value;
#endif
# 3308 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivially_copyable;

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivially_copyable
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_trivially_copyable)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3313 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : public integral_constant<bool, __is_trivially_copyable(_Tp)>
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _GNUC_VER >= 501
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 3315 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : public integral_constant<bool, !is_volatile<_Tp>::value && __is_trivially_copyable(_Tp)>
#else
# 3317 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<typename remove_all_extents<_Tp>::type>::value>
#endif
# 3319 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3322 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivially_copyable_v
    = is_trivially_copyable<_Tp>::value;
#endif
# 3326 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// is_trivial;

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS is_trivial
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(is_trivial) || defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3331 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : public integral_constant<bool, __is_trivial(_Tp)>
#else
# 3333 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    : integral_constant<bool, is_trivially_copyable<_Tp>::value &&
                                 is_trivially_default_constructible<_Tp>::value>
#endif
# 3336 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
    {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3339 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool is_trivial_v
    = is_trivial<_Tp>::value;
#endif
# 3343 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct __is_reference_wrapper_impl : public false_type {};
template <class _Tp> struct __is_reference_wrapper_impl<reference_wrapper<_Tp> > : public true_type {};
template <class _Tp> struct __is_reference_wrapper
    : public __is_reference_wrapper_impl<typename remove_cv<_Tp>::type> {};

#ifndef _LIBCPP_CXX03_LANG

template <class _Fp, class _A0,
         class _DecayFp = typename decay<_Fp>::type,
         class _DecayA0 = typename decay<_A0>::type,
         class _ClassT = typename __member_pointer_class_type<_DecayFp>::type>
using __enable_if_bullet1 = typename enable_if
    <
        is_member_function_pointer<_DecayFp>::value
        && is_base_of<_ClassT, _DecayA0>::value
    >::type;

template <class _Fp, class _A0,
         class _DecayFp = typename decay<_Fp>::type,
         class _DecayA0 = typename decay<_A0>::type>
using __enable_if_bullet2 = typename enable_if
    <
        is_member_function_pointer<_DecayFp>::value
        && __is_reference_wrapper<_DecayA0>::value
    >::type;

template <class _Fp, class _A0,
         class _DecayFp = typename decay<_Fp>::type,
         class _DecayA0 = typename decay<_A0>::type,
         class _ClassT = typename __member_pointer_class_type<_DecayFp>::type>
using __enable_if_bullet3 = typename enable_if
    <
        is_member_function_pointer<_DecayFp>::value
        && !is_base_of<_ClassT, _DecayA0>::value
        && !__is_reference_wrapper<_DecayA0>::value
    >::type;

template <class _Fp, class _A0,
         class _DecayFp = typename decay<_Fp>::type,
         class _DecayA0 = typename decay<_A0>::type,
         class _ClassT = typename __member_pointer_class_type<_DecayFp>::type>
using __enable_if_bullet4 = typename enable_if
    <
        is_member_object_pointer<_DecayFp>::value
        && is_base_of<_ClassT, _DecayA0>::value
    >::type;

template <class _Fp, class _A0,
         class _DecayFp = typename decay<_Fp>::type,
         class _DecayA0 = typename decay<_A0>::type>
using __enable_if_bullet5 = typename enable_if
    <
        is_member_object_pointer<_DecayFp>::value
        && __is_reference_wrapper<_DecayA0>::value
    >::type;

template <class _Fp, class _A0,
         class _DecayFp = typename decay<_Fp>::type,
         class _DecayA0 = typename decay<_A0>::type,
         class _ClassT = typename __member_pointer_class_type<_DecayFp>::type>
using __enable_if_bullet6 = typename enable_if
    <
        is_member_object_pointer<_DecayFp>::value
        && !is_base_of<_ClassT, _DecayA0>::value
        && !__is_reference_wrapper<_DecayA0>::value
    >::type;

// __invoke forward declarations

// fall back - none of the bullets

#define _LIBCPP_INVOKE_RETURN(...) \
    noexcept(noexcept(__VA_ARGS__)) -> decltype(__VA_ARGS__) \
    { return __VA_ARGS__; }

template <class ..._Args>
auto __invoke(__any, _Args&& ...__args) -> __nat;

template <class ..._Args>
auto __invoke_constexpr(__any, _Args&& ...__args) -> __nat;

// bullets 1, 2 and 3

template <class _Fp, class _A0, class ..._Args,
          class = __enable_if_bullet1<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
_LIBCPP_INVOKE_RETURN((_VSTD::forward<_A0>(__a0).*__f)(_VSTD::forward<_Args>(__args)...))

template <class _Fp, class _A0, class ..._Args,
          class = __enable_if_bullet1<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR auto
__invoke_constexpr(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
_LIBCPP_INVOKE_RETURN((_VSTD::forward<_A0>(__a0).*__f)(_VSTD::forward<_Args>(__args)...))

template <class _Fp, class _A0, class ..._Args,
          class = __enable_if_bullet2<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
_LIBCPP_INVOKE_RETURN((__a0.get().*__f)(_VSTD::forward<_Args>(__args)...))

template <class _Fp, class _A0, class ..._Args,
          class = __enable_if_bullet2<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR auto
__invoke_constexpr(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
_LIBCPP_INVOKE_RETURN((__a0.get().*__f)(_VSTD::forward<_Args>(__args)...))

template <class _Fp, class _A0, class ..._Args,
          class = __enable_if_bullet3<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
_LIBCPP_INVOKE_RETURN(((*_VSTD::forward<_A0>(__a0)).*__f)(_VSTD::forward<_Args>(__args)...))

template <class _Fp, class _A0, class ..._Args,
          class = __enable_if_bullet3<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR auto
__invoke_constexpr(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
_LIBCPP_INVOKE_RETURN(((*_VSTD::forward<_A0>(__a0)).*__f)(_VSTD::forward<_Args>(__args)...))

// bullets 4, 5 and 6

template <class _Fp, class _A0,
          class = __enable_if_bullet4<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0)
_LIBCPP_INVOKE_RETURN(_VSTD::forward<_A0>(__a0).*__f)

template <class _Fp, class _A0,
          class = __enable_if_bullet4<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR auto
__invoke_constexpr(_Fp&& __f, _A0&& __a0)
_LIBCPP_INVOKE_RETURN(_VSTD::forward<_A0>(__a0).*__f)

template <class _Fp, class _A0,
          class = __enable_if_bullet5<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0)
_LIBCPP_INVOKE_RETURN(__a0.get().*__f)

template <class _Fp, class _A0,
          class = __enable_if_bullet5<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR auto
__invoke_constexpr(_Fp&& __f, _A0&& __a0)
_LIBCPP_INVOKE_RETURN(__a0.get().*__f)

template <class _Fp, class _A0,
          class = __enable_if_bullet6<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0)
_LIBCPP_INVOKE_RETURN((*_VSTD::forward<_A0>(__a0)).*__f)

template <class _Fp, class _A0,
          class = __enable_if_bullet6<_Fp, _A0>>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR auto
__invoke_constexpr(_Fp&& __f, _A0&& __a0)
_LIBCPP_INVOKE_RETURN((*_VSTD::forward<_A0>(__a0)).*__f)

// bullet 7

template <class _Fp, class ..._Args>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _Args&& ...__args)
_LIBCPP_INVOKE_RETURN(_VSTD::forward<_Fp>(__f)(_VSTD::forward<_Args>(__args)...))

template <class _Fp, class ..._Args>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR auto
__invoke_constexpr(_Fp&& __f, _Args&& ...__args)
_LIBCPP_INVOKE_RETURN(_VSTD::forward<_Fp>(__f)(_VSTD::forward<_Args>(__args)...))

#undef _LIBCPP_INVOKE_RETURN

// __invokable
template <class _Ret, class _Fp, class ..._Args>
struct __invokable_r
{
  template <class _XFp, class ..._XArgs>
  static auto __try_call(int) -> decltype(
    _VSTD::__invoke(_VSTD::declval<_XFp>(), _VSTD::declval<_XArgs>()...));
  template <class _XFp, class ..._XArgs>
  static __nat __try_call(...);

  // FIXME: Check that _Ret, _Fp, and _Args... are all complete types, cv void,
  // or incomplete array types as required by the standard.
  using _Result = decltype(__try_call<_Fp, _Args...>(0));

  using type =
  typename conditional<
      _IsNotSame<_Result, __nat>::value,
      typename conditional<
          is_void<_Ret>::value,
          true_type,
          is_convertible<_Result, _Ret>
      >::type,
      false_type
  >::type;
  static const bool value = type::value;
};
template <class _Fp, class ..._Args>
using __invokable = __invokable_r<void, _Fp, _Args...>;

template <bool _IsInvokable, bool _IsCVVoid, class _Ret, class _Fp, class ..._Args>
struct __nothrow_invokable_r_imp {
  static const bool value = false;
};

template <class _Ret, class _Fp, class ..._Args>
struct __nothrow_invokable_r_imp<true, false, _Ret, _Fp, _Args...>
{
    typedef __nothrow_invokable_r_imp _ThisT;

    template <class _Tp>
    static void __test_noexcept(_Tp) noexcept;

    static const bool value = noexcept(_ThisT::__test_noexcept<_Ret>(
        _VSTD::__invoke(_VSTD::declval<_Fp>(), _VSTD::declval<_Args>()...)));
};

template <class _Ret, class _Fp, class ..._Args>
struct __nothrow_invokable_r_imp<true, true, _Ret, _Fp, _Args...>
{
    static const bool value = noexcept(
        _VSTD::__invoke(_VSTD::declval<_Fp>(), _VSTD::declval<_Args>()...));
};

template <class _Ret, class _Fp, class ..._Args>
using __nothrow_invokable_r =
    __nothrow_invokable_r_imp<
            __invokable_r<_Ret, _Fp, _Args...>::value,
            is_void<_Ret>::value,
            _Ret, _Fp, _Args...
    >;

template <class _Fp, class ..._Args>
using __nothrow_invokable =
    __nothrow_invokable_r_imp<
            __invokable<_Fp, _Args...>::value,
            true, void, _Fp, _Args...
    >;

template <class _Fp, class ..._Args>
struct __invoke_of
    : public enable_if<
        __invokable<_Fp, _Args...>::value,
        typename __invokable_r<void, _Fp, _Args...>::_Result>
{
};

// result_of

template <class _Fp, class ..._Args>
class _LIBCPP_TEMPLATE_VIS result_of<_Fp(_Args...)>
    : public __invoke_of<_Fp, _Args...>
{
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3614 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using result_of_t = typename result_of<_Tp>::type;
#endif
# 3616 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3618 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// invoke_result

template <class _Fn, class... _Args>
struct _LIBCPP_TEMPLATE_VIS invoke_result
    : __invoke_of<_Fn, _Args...>
{
};

template <class _Fn, class... _Args>
using invoke_result_t = typename invoke_result<_Fn, _Args...>::type;

// is_invocable

template <class _Fn, class ..._Args>
struct _LIBCPP_TEMPLATE_VIS is_invocable
    : integral_constant<bool, __invokable<_Fn, _Args...>::value> {};

template <class _Ret, class _Fn, class ..._Args>
struct _LIBCPP_TEMPLATE_VIS is_invocable_r
    : integral_constant<bool, __invokable_r<_Ret, _Fn, _Args...>::value> {};

template <class _Fn, class ..._Args>
_LIBCPP_INLINE_VAR constexpr bool is_invocable_v
    = is_invocable<_Fn, _Args...>::value;

template <class _Ret, class _Fn, class ..._Args>
_LIBCPP_INLINE_VAR constexpr bool is_invocable_r_v
    = is_invocable_r<_Ret, _Fn, _Args...>::value;

// is_nothrow_invocable

template <class _Fn, class ..._Args>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_invocable
    : integral_constant<bool, __nothrow_invokable<_Fn, _Args...>::value> {};

template <class _Ret, class _Fn, class ..._Args>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_invocable_r
    : integral_constant<bool, __nothrow_invokable_r<_Ret, _Fn, _Args...>::value> {};

template <class _Fn, class ..._Args>
_LIBCPP_INLINE_VAR constexpr bool is_nothrow_invocable_v
    = is_nothrow_invocable<_Fn, _Args...>::value;

template <class _Ret, class _Fn, class ..._Args>
_LIBCPP_INLINE_VAR constexpr bool is_nothrow_invocable_r_v
    = is_nothrow_invocable_r<_Ret, _Fn, _Args...>::value;

#endif // _LIBCPP_STD_VER > 14
# 3667 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#endif  // !defined(_LIBCPP_CXX03_LANG)
# 3669 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp> struct __is_swappable;
template <class _Tp> struct __is_nothrow_swappable;

// swap, swap_ranges

template <class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator2
swap_ranges(_ForwardIterator1 __first1, _ForwardIterator1 __last1, _ForwardIterator2 __first2);

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
#ifndef _LIBCPP_CXX03_LANG
typename enable_if
<
    is_move_constructible<_Tp>::value &&
    is_move_assignable<_Tp>::value
>::type
#else
# 3689 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
void
#endif
# 3691 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
_LIBCPP_CONSTEXPR_AFTER_CXX17
swap(_Tp& __x, _Tp& __y) _NOEXCEPT_(is_nothrow_move_constructible<_Tp>::value &&
                                    is_nothrow_move_assignable<_Tp>::value)
{
    _Tp __t(_VSTD::move(__x));
    __x = _VSTD::move(__y);
    __y = _VSTD::move(__t);
}

template<class _Tp, size_t _Np>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
typename enable_if<
    __is_swappable<_Tp>::value
>::type
swap(_Tp (&__a)[_Np], _Tp (&__b)[_Np]) _NOEXCEPT_(__is_nothrow_swappable<_Tp>::value)
{
    _VSTD::swap_ranges(__a, __a + _Np, __b);
}

template <class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator2
swap_ranges(_ForwardIterator1 __first1, _ForwardIterator1 __last1, _ForwardIterator2 __first2)
{
    for(; __first1 != __last1; ++__first1, (void) ++__first2)
        swap(*__first1, *__first2);
    return __first2;
}

// iter_swap

template <class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
void
iter_swap(_ForwardIterator1 __a, _ForwardIterator2 __b)
    //                                  _NOEXCEPT_(_NOEXCEPT_(swap(*__a, *__b)))
               _NOEXCEPT_(_NOEXCEPT_(swap(*_VSTD::declval<_ForwardIterator1>(),
                                          *_VSTD::declval<_ForwardIterator2>())))
{
    swap(*__a, *__b);
}

// __swappable

namespace __detail
{
// ALL generic swap overloads MUST already have a declaration available at this point.

template <class _Tp, class _Up = _Tp,
          bool _NotVoid = !is_void<_Tp>::value && !is_void<_Up>::value>
struct __swappable_with
{
    template <class _LHS, class _RHS>
    static decltype(swap(_VSTD::declval<_LHS>(), _VSTD::declval<_RHS>()))
    __test_swap(int);
    template <class, class>
    static __nat __test_swap(long);

    // Extra parens are needed for the C++03 definition of decltype.
    typedef decltype((__test_swap<_Tp, _Up>(0))) __swap1;
    typedef decltype((__test_swap<_Up, _Tp>(0))) __swap2;

    static const bool value = _IsNotSame<__swap1, __nat>::value
                           && _IsNotSame<__swap2, __nat>::value;
};

template <class _Tp, class _Up>
struct __swappable_with<_Tp, _Up,  false> : false_type {};

template <class _Tp, class _Up = _Tp, bool _Swappable = __swappable_with<_Tp, _Up>::value>
struct __nothrow_swappable_with {
  static const bool value =
#ifndef _LIBCPP_HAS_NO_NOEXCEPT
      noexcept(swap(_VSTD::declval<_Tp>(), _VSTD::declval<_Up>()))
  &&  noexcept(swap(_VSTD::declval<_Up>(), _VSTD::declval<_Tp>()));
#else
# 3767 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
      false;
#endif
# 3769 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
};

template <class _Tp, class _Up>
struct __nothrow_swappable_with<_Tp, _Up, false> : false_type {};

}  // __detail

template <class _Tp>
struct __is_swappable
    : public integral_constant<bool, __detail::__swappable_with<_Tp&>::value>
{
};

template <class _Tp>
struct __is_nothrow_swappable
    : public integral_constant<bool, __detail::__nothrow_swappable_with<_Tp&>::value>
{
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3789 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, class _Up>
struct _LIBCPP_TEMPLATE_VIS is_swappable_with
    : public integral_constant<bool, __detail::__swappable_with<_Tp, _Up>::value>
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_swappable
    : public conditional<
        __is_referenceable<_Tp>::value,
        is_swappable_with<
            typename add_lvalue_reference<_Tp>::type,
            typename add_lvalue_reference<_Tp>::type>,
        false_type
    >::type
{
};

template <class _Tp, class _Up>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_swappable_with
    : public integral_constant<bool, __detail::__nothrow_swappable_with<_Tp, _Up>::value>
{
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_nothrow_swappable
    : public conditional<
        __is_referenceable<_Tp>::value,
        is_nothrow_swappable_with<
            typename add_lvalue_reference<_Tp>::type,
            typename add_lvalue_reference<_Tp>::type>,
        false_type
    >::type
{
};

template <class _Tp, class _Up>
_LIBCPP_INLINE_VAR constexpr bool is_swappable_with_v
    = is_swappable_with<_Tp, _Up>::value;

template <class _Tp>
_LIBCPP_INLINE_VAR constexpr bool is_swappable_v
    = is_swappable<_Tp>::value;

template <class _Tp, class _Up>
_LIBCPP_INLINE_VAR constexpr bool is_nothrow_swappable_with_v
    = is_nothrow_swappable_with<_Tp, _Up>::value;

template <class _Tp>
_LIBCPP_INLINE_VAR constexpr bool is_nothrow_swappable_v
    = is_nothrow_swappable<_Tp>::value;

#endif // _LIBCPP_STD_VER > 14
# 3843 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp, bool = is_enum<_Tp>::value> struct __underlying_type_impl;

template <class _Tp>
struct __underlying_type_impl<_Tp, false> {};

template <class _Tp>
struct __underlying_type_impl<_Tp, true>
{
    typedef __underlying_type(_Tp) type;
};

template <class _Tp>
struct underlying_type : __underlying_type_impl<_Tp, is_enum<_Tp>::value> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3859 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
template <class _Tp> using underlying_type_t = typename underlying_type<_Tp>::type;
#endif
# 3861 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3


template <class _Tp, bool = is_enum<_Tp>::value>
struct __sfinae_underlying_type
{
    typedef typename underlying_type<_Tp>::type type;
    typedef decltype(((type)1) + 0) __promoted_type;
};

template <class _Tp>
struct __sfinae_underlying_type<_Tp, false> {};

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __convert_to_integral(int __val) { return __val; }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
unsigned __convert_to_integral(unsigned __val) { return __val; }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
long __convert_to_integral(long __val) { return __val; }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
unsigned long __convert_to_integral(unsigned long __val) { return __val; }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
long long __convert_to_integral(long long __val) { return __val; }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
unsigned long long __convert_to_integral(unsigned long long __val) {return __val; }

template<typename _Fp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if<is_floating_point<_Fp>::value, long long>::type
 __convert_to_integral(_Fp __val) { return __val; }

#ifndef _LIBCPP_HAS_NO_INT128
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
__int128_t __convert_to_integral(__int128_t __val) { return __val; }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
__uint128_t __convert_to_integral(__uint128_t __val) { return __val; }
#endif
# 3903 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename __sfinae_underlying_type<_Tp>::__promoted_type
__convert_to_integral(_Tp __val) { return __val; }

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp>
struct __has_operator_addressof_member_imp
{
    template <class _Up>
        static auto __test(int)
            -> typename __select_2nd<decltype(_VSTD::declval<_Up>().operator&()), true_type>::type;
    template <class>
        static auto __test(long) -> false_type;

    static const bool value = decltype(__test<_Tp>(0))::value;
};

template <class _Tp>
struct __has_operator_addressof_free_imp
{
    template <class _Up>
        static auto __test(int)
            -> typename __select_2nd<decltype(operator&(_VSTD::declval<_Up>())), true_type>::type;
    template <class>
        static auto __test(long) -> false_type;

    static const bool value = decltype(__test<_Tp>(0))::value;
};

template <class _Tp>
struct __has_operator_addressof
    : public integral_constant<bool, __has_operator_addressof_member_imp<_Tp>::value
                                  || __has_operator_addressof_free_imp<_Tp>::value>
{};

#endif  // _LIBCPP_CXX03_LANG
# 3942 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3944 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class...> using void_t = void;

template <class... _Args>
struct conjunction : _And<_Args...> {};
template<class... _Args>
_LIBCPP_INLINE_VAR constexpr bool conjunction_v
    = conjunction<_Args...>::value;

template <class... _Args>
struct disjunction : _Or<_Args...> {};
template<class... _Args>
_LIBCPP_INLINE_VAR constexpr bool disjunction_v
    = disjunction<_Args...>::value;

template <class _Tp>
struct negation : _Not<_Tp> {};
template<class _Tp>
_LIBCPP_INLINE_VAR constexpr bool negation_v
    = negation<_Tp>::value;
#endif  // _LIBCPP_STD_VER > 14
# 3965 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

// These traits are used in __tree and __hash_table
#ifndef _LIBCPP_CXX03_LANG
struct __extract_key_fail_tag {};
struct __extract_key_self_tag {};
struct __extract_key_first_tag {};

template <class _ValTy, class _Key,
          class _RawValTy = typename __unconstref<_ValTy>::type>
struct __can_extract_key
    : conditional<_IsSame<_RawValTy, _Key>::value, __extract_key_self_tag,
                  __extract_key_fail_tag>::type {};

template <class _Pair, class _Key, class _First, class _Second>
struct __can_extract_key<_Pair, _Key, pair<_First, _Second>>
    : conditional<_IsSame<typename remove_const<_First>::type, _Key>::value,
                  __extract_key_first_tag, __extract_key_fail_tag>::type {};

// __can_extract_map_key uses true_type/false_type instead of the tags.
// It returns true if _Key != _ContainerValueTy (the container is a map not a set)
// and _ValTy == _Key.
template <class _ValTy, class _Key, class _ContainerValueTy,
          class _RawValTy = typename __unconstref<_ValTy>::type>
struct __can_extract_map_key
    : integral_constant<bool, _IsSame<_RawValTy, _Key>::value> {};

// This specialization returns __extract_key_fail_tag for non-map containers
// because _Key == _ContainerValueTy
template <class _ValTy, class _Key, class _RawValTy>
struct __can_extract_map_key<_ValTy, _Key, _Key, _RawValTy>
    : false_type {};

#endif
# 3998 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#ifndef _LIBCPP_HAS_NO_BUILTIN_IS_CONSTANT_EVALUATED
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4001 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
_LIBCPP_INLINE_VISIBILITY
inline constexpr bool is_constant_evaluated() noexcept {
  return __builtin_is_constant_evaluated();
}
#endif
# 4006 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

inline _LIBCPP_CONSTEXPR
bool __libcpp_is_constant_evaluated() _NOEXCEPT { return __builtin_is_constant_evaluated(); }
#else
# 4010 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
inline _LIBCPP_CONSTEXPR
bool __libcpp_is_constant_evaluated() _NOEXCEPT { return false; }
#endif
# 4013 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

template <class _CharT>
using _IsCharLikeType = _And<is_standard_layout<_CharT>, is_trivial<_CharT> >;

_LIBCPP_END_NAMESPACE_STD

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4020 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
// std::byte
namespace std  // purposefully not versioned
{


}
#endif
# 4027 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3

#endif  // _LIBCPP_TYPE_TRAITS
# 4029 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/type_traits" 3
# 312 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 312 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 1 3
// -*- C++ -*-
//===---------------------------- limits ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_LIMITS
#define _LIBCPP_LIMITS

/*
    limits synopsis

namespace std
{

template<class T>
class numeric_limits
{
public:
    static constexpr bool is_specialized = false;
    static constexpr T min() noexcept;
    static constexpr T max() noexcept;
    static constexpr T lowest() noexcept;

    static constexpr int  digits = 0;
    static constexpr int  digits10 = 0;
    static constexpr int  max_digits10 = 0;
    static constexpr bool is_signed = false;
    static constexpr bool is_integer = false;
    static constexpr bool is_exact = false;
    static constexpr int  radix = 0;
    static constexpr T epsilon() noexcept;
    static constexpr T round_error() noexcept;

    static constexpr int  min_exponent = 0;
    static constexpr int  min_exponent10 = 0;
    static constexpr int  max_exponent = 0;
    static constexpr int  max_exponent10 = 0;

    static constexpr bool has_infinity = false;
    static constexpr bool has_quiet_NaN = false;
    static constexpr bool has_signaling_NaN = false;
    static constexpr float_denorm_style has_denorm = denorm_absent;
    static constexpr bool has_denorm_loss = false;
    static constexpr T infinity() noexcept;
    static constexpr T quiet_NaN() noexcept;
    static constexpr T signaling_NaN() noexcept;
    static constexpr T denorm_min() noexcept;

    static constexpr bool is_iec559 = false;
    static constexpr bool is_bounded = false;
    static constexpr bool is_modulo = false;

    static constexpr bool traps = false;
    static constexpr bool tinyness_before = false;
    static constexpr float_round_style round_style = round_toward_zero;
};

enum float_round_style
{
    round_indeterminate       = -1,
    round_toward_zero         =  0,
    round_to_nearest          =  1,
    round_toward_infinity     =  2,
    round_toward_neg_infinity =  3
};

enum float_denorm_style
{
    denorm_indeterminate = -1,
    denorm_absent = 0,
    denorm_present = 1
};

template<> class numeric_limits<cv bool>;

template<> class numeric_limits<cv char>;
template<> class numeric_limits<cv signed char>;
template<> class numeric_limits<cv unsigned char>;
template<> class numeric_limits<cv wchar_t>;
template<> class numeric_limits<cv char8_t>; // C++20
template<> class numeric_limits<cv char16_t>;
template<> class numeric_limits<cv char32_t>;

template<> class numeric_limits<cv short>;
template<> class numeric_limits<cv int>;
template<> class numeric_limits<cv long>;
template<> class numeric_limits<cv long long>;
template<> class numeric_limits<cv unsigned short>;
template<> class numeric_limits<cv unsigned int>;
template<> class numeric_limits<cv unsigned long>;
template<> class numeric_limits<cv unsigned long long>;

template<> class numeric_limits<cv float>;
template<> class numeric_limits<cv double>;
template<> class numeric_limits<cv long double>;

}  // std

*/
#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
# 106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_COMPILER_MSVC)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
#if 0 /* expanded by -frewrite-includes */
#include "support/win32/limits_msvc_win32.h"
#endif /* expanded by -frewrite-includes */
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
# 109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
#endif // _LIBCPP_MSVCRT
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__IBMCPP__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
#if 0 /* expanded by -frewrite-includes */
#include "support/ibm/limits.h"
#endif /* expanded by -frewrite-includes */
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
# 113 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
#endif // __IBMCPP__
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 116 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 117 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
#endif
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 121 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 121 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3


_LIBCPP_BEGIN_NAMESPACE_STD

enum float_round_style
{
    round_indeterminate       = -1,
    round_toward_zero         =  0,
    round_to_nearest          =  1,
    round_toward_infinity     =  2,
    round_toward_neg_infinity =  3
};

enum float_denorm_style
{
    denorm_indeterminate = -1,
    denorm_absent = 0,
    denorm_present = 1
};

template <class _Tp, bool = is_arithmetic<_Tp>::value>
class __libcpp_numeric_limits
{
protected:
    typedef _Tp type;

    static _LIBCPP_CONSTEXPR const  bool is_specialized = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return type();}

    static _LIBCPP_CONSTEXPR const int  digits = 0;
    static _LIBCPP_CONSTEXPR const int  digits10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 0;
    static _LIBCPP_CONSTEXPR const bool is_signed = false;
    static _LIBCPP_CONSTEXPR const bool is_integer = false;
    static _LIBCPP_CONSTEXPR const bool is_exact = false;
    static _LIBCPP_CONSTEXPR const int  radix = 0;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return type();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = 0;

    static _LIBCPP_CONSTEXPR const bool has_infinity = false;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = false;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = false;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_absent;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return type();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = false;
    static _LIBCPP_CONSTEXPR const bool is_bounded = false;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_toward_zero;
};

template <class _Tp, int __digits, bool _IsSigned>
struct __libcpp_compute_min
{
    static _LIBCPP_CONSTEXPR const _Tp value = _Tp(_Tp(1) << __digits);
};

template <class _Tp, int __digits>
struct __libcpp_compute_min<_Tp, __digits, false>
{
    static _LIBCPP_CONSTEXPR const _Tp value = _Tp(0);
};

template <class _Tp>
class __libcpp_numeric_limits<_Tp, true>
{
protected:
    typedef _Tp type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = type(-1) < type(0);
    static _LIBCPP_CONSTEXPR const int  digits = static_cast<int>(sizeof(type) * __CHAR_BIT__ - is_signed);
    static _LIBCPP_CONSTEXPR const int  digits10 = digits * 3 / 10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 0;
    static _LIBCPP_CONSTEXPR const type __min = __libcpp_compute_min<type, digits, is_signed>::value;
    static _LIBCPP_CONSTEXPR const type __max = is_signed ? type(type(~0) ^ __min) : type(~0);
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __min;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __max;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return min();}

    static _LIBCPP_CONSTEXPR const bool is_integer = true;
    static _LIBCPP_CONSTEXPR const bool is_exact = true;
    static _LIBCPP_CONSTEXPR const int  radix = 2;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return type(0);}

    static _LIBCPP_CONSTEXPR const int  min_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = 0;

    static _LIBCPP_CONSTEXPR const bool has_infinity = false;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = false;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = false;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_absent;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return type(0);}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = false;
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = !_VSTD::is_signed<_Tp>::value;

#if 0 /* disabled by -frewrite-includes */
#if defined(__i386__) || defined(__x86_64__) || defined(__pnacl__) || \
    defined(__wasm__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 244 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool traps = true;
#else
# 246 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool traps = false;
#endif
# 248 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_toward_zero;
};

template <>
class __libcpp_numeric_limits<bool, true>
{
protected:
    typedef bool type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = false;
    static _LIBCPP_CONSTEXPR const int  digits = 1;
    static _LIBCPP_CONSTEXPR const int  digits10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 0;
    static _LIBCPP_CONSTEXPR const type __min = false;
    static _LIBCPP_CONSTEXPR const type __max = true;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __min;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __max;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return min();}

    static _LIBCPP_CONSTEXPR const bool is_integer = true;
    static _LIBCPP_CONSTEXPR const bool is_exact = true;
    static _LIBCPP_CONSTEXPR const int  radix = 2;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return type(0);}

    static _LIBCPP_CONSTEXPR const int  min_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = 0;

    static _LIBCPP_CONSTEXPR const bool has_infinity = false;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = false;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = false;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_absent;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return type(0);}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = false;
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_toward_zero;
};

template <>
class __libcpp_numeric_limits<float, true>
{
protected:
    typedef float type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = true;
    static _LIBCPP_CONSTEXPR const int  digits = __FLT_MANT_DIG__;
    static _LIBCPP_CONSTEXPR const int  digits10 = __FLT_DIG__;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 2+(digits * 30103l)/100000l;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __FLT_MIN__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __FLT_MAX__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return -max();}

    static _LIBCPP_CONSTEXPR const bool is_integer = false;
    static _LIBCPP_CONSTEXPR const bool is_exact = false;
    static _LIBCPP_CONSTEXPR const int  radix = __FLT_RADIX__;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __FLT_EPSILON__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return 0.5F;}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __FLT_MIN_EXP__;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __FLT_MIN_10_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __FLT_MAX_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __FLT_MAX_10_EXP__;

    static _LIBCPP_CONSTEXPR const bool has_infinity = true;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = true;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = true;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_present;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __builtin_huge_valf();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __builtin_nanf("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __builtin_nansf("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __FLT_DENORM_MIN__;}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = true;
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_to_nearest;
};

template <>
class __libcpp_numeric_limits<double, true>
{
protected:
    typedef double type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = true;
    static _LIBCPP_CONSTEXPR const int  digits = __DBL_MANT_DIG__;
    static _LIBCPP_CONSTEXPR const int  digits10 = __DBL_DIG__;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 2+(digits * 30103l)/100000l;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __DBL_MIN__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __DBL_MAX__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return -max();}

    static _LIBCPP_CONSTEXPR const bool is_integer = false;
    static _LIBCPP_CONSTEXPR const bool is_exact = false;
    static _LIBCPP_CONSTEXPR const int  radix = __FLT_RADIX__;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __DBL_EPSILON__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return 0.5;}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __DBL_MIN_EXP__;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __DBL_MIN_10_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __DBL_MAX_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __DBL_MAX_10_EXP__;

    static _LIBCPP_CONSTEXPR const bool has_infinity = true;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = true;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = true;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_present;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __builtin_huge_val();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __builtin_nan("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __builtin_nans("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __DBL_DENORM_MIN__;}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = true;
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_to_nearest;
};

template <>
class __libcpp_numeric_limits<long double, true>
{
protected:
    typedef long double type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = true;
    static _LIBCPP_CONSTEXPR const int  digits = __LDBL_MANT_DIG__;
    static _LIBCPP_CONSTEXPR const int  digits10 = __LDBL_DIG__;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 2+(digits * 30103l)/100000l;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __LDBL_MIN__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __LDBL_MAX__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return -max();}

    static _LIBCPP_CONSTEXPR const bool is_integer = false;
    static _LIBCPP_CONSTEXPR const bool is_exact = false;
    static _LIBCPP_CONSTEXPR const int  radix = __FLT_RADIX__;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __LDBL_EPSILON__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return 0.5L;}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __LDBL_MIN_EXP__;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __LDBL_MIN_10_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __LDBL_MAX_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __LDBL_MAX_10_EXP__;

    static _LIBCPP_CONSTEXPR const bool has_infinity = true;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = true;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = true;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_present;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __builtin_huge_vall();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __builtin_nanl("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __builtin_nansl("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __LDBL_DENORM_MIN__;}

#if 0 /* disabled by -frewrite-includes */
#if (defined(__ppc__) || defined(__ppc64__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 430 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool is_iec559 = false;
#else
# 432 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool is_iec559 = true;
#endif
# 434 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_to_nearest;
};

template <class _Tp>
class _LIBCPP_TEMPLATE_VIS numeric_limits
    : private __libcpp_numeric_limits<typename remove_cv<_Tp>::type>
{
    typedef __libcpp_numeric_limits<typename remove_cv<_Tp>::type> __base;
    typedef typename __base::type type;
public:
    static _LIBCPP_CONSTEXPR const bool is_specialized = __base::is_specialized;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __base::min();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __base::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return __base::lowest();}

    static _LIBCPP_CONSTEXPR const int  digits = __base::digits;
    static _LIBCPP_CONSTEXPR const int  digits10 = __base::digits10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = __base::max_digits10;
    static _LIBCPP_CONSTEXPR const bool is_signed = __base::is_signed;
    static _LIBCPP_CONSTEXPR const bool is_integer = __base::is_integer;
    static _LIBCPP_CONSTEXPR const bool is_exact = __base::is_exact;
    static _LIBCPP_CONSTEXPR const int  radix = __base::radix;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __base::epsilon();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return __base::round_error();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __base::min_exponent;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __base::min_exponent10;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __base::max_exponent;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __base::max_exponent10;

    static _LIBCPP_CONSTEXPR const bool has_infinity = __base::has_infinity;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = __base::has_quiet_NaN;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = __base::has_signaling_NaN;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = __base::has_denorm;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = __base::has_denorm_loss;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __base::infinity();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __base::quiet_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __base::signaling_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __base::denorm_min();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = __base::is_iec559;
    static _LIBCPP_CONSTEXPR const bool is_bounded = __base::is_bounded;
    static _LIBCPP_CONSTEXPR const bool is_modulo = __base::is_modulo;

    static _LIBCPP_CONSTEXPR const bool traps = __base::traps;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = __base::tinyness_before;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = __base::round_style;
};

template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_specialized;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::digits;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::max_digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_signed;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_integer;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_exact;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::radix;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::min_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::min_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::max_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::max_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::has_infinity;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::has_quiet_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::has_signaling_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_denorm_style numeric_limits<_Tp>::has_denorm;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::has_denorm_loss;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_iec559;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_bounded;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_modulo;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::traps;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::tinyness_before;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_round_style numeric_limits<_Tp>::round_style;

template <class _Tp>
class _LIBCPP_TEMPLATE_VIS numeric_limits<const _Tp>
    : private numeric_limits<_Tp>
{
    typedef numeric_limits<_Tp> __base;
    typedef _Tp type;
public:
    static _LIBCPP_CONSTEXPR const bool is_specialized = __base::is_specialized;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __base::min();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __base::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return __base::lowest();}

    static _LIBCPP_CONSTEXPR const int  digits = __base::digits;
    static _LIBCPP_CONSTEXPR const int  digits10 = __base::digits10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = __base::max_digits10;
    static _LIBCPP_CONSTEXPR const bool is_signed = __base::is_signed;
    static _LIBCPP_CONSTEXPR const bool is_integer = __base::is_integer;
    static _LIBCPP_CONSTEXPR const bool is_exact = __base::is_exact;
    static _LIBCPP_CONSTEXPR const int  radix = __base::radix;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __base::epsilon();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return __base::round_error();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __base::min_exponent;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __base::min_exponent10;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __base::max_exponent;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __base::max_exponent10;

    static _LIBCPP_CONSTEXPR const bool has_infinity = __base::has_infinity;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = __base::has_quiet_NaN;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = __base::has_signaling_NaN;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = __base::has_denorm;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = __base::has_denorm_loss;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __base::infinity();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __base::quiet_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __base::signaling_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __base::denorm_min();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = __base::is_iec559;
    static _LIBCPP_CONSTEXPR const bool is_bounded = __base::is_bounded;
    static _LIBCPP_CONSTEXPR const bool is_modulo = __base::is_modulo;

    static _LIBCPP_CONSTEXPR const bool traps = __base::traps;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = __base::tinyness_before;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = __base::round_style;
};

template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_specialized;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::digits;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::max_digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_signed;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_integer;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_exact;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::radix;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::min_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::min_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::max_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::max_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::has_infinity;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::has_quiet_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::has_signaling_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_denorm_style numeric_limits<const _Tp>::has_denorm;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::has_denorm_loss;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_iec559;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_bounded;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_modulo;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::traps;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::tinyness_before;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_round_style numeric_limits<const _Tp>::round_style;

template <class _Tp>
class _LIBCPP_TEMPLATE_VIS numeric_limits<volatile _Tp>
    : private numeric_limits<_Tp>
{
    typedef numeric_limits<_Tp> __base;
    typedef _Tp type;
public:
    static _LIBCPP_CONSTEXPR const bool is_specialized = __base::is_specialized;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __base::min();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __base::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return __base::lowest();}

    static _LIBCPP_CONSTEXPR const int  digits = __base::digits;
    static _LIBCPP_CONSTEXPR const int  digits10 = __base::digits10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = __base::max_digits10;
    static _LIBCPP_CONSTEXPR const bool is_signed = __base::is_signed;
    static _LIBCPP_CONSTEXPR const bool is_integer = __base::is_integer;
    static _LIBCPP_CONSTEXPR const bool is_exact = __base::is_exact;
    static _LIBCPP_CONSTEXPR const int  radix = __base::radix;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __base::epsilon();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return __base::round_error();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __base::min_exponent;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __base::min_exponent10;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __base::max_exponent;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __base::max_exponent10;

    static _LIBCPP_CONSTEXPR const bool has_infinity = __base::has_infinity;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = __base::has_quiet_NaN;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = __base::has_signaling_NaN;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = __base::has_denorm;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = __base::has_denorm_loss;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __base::infinity();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __base::quiet_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __base::signaling_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __base::denorm_min();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = __base::is_iec559;
    static _LIBCPP_CONSTEXPR const bool is_bounded = __base::is_bounded;
    static _LIBCPP_CONSTEXPR const bool is_modulo = __base::is_modulo;

    static _LIBCPP_CONSTEXPR const bool traps = __base::traps;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = __base::tinyness_before;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = __base::round_style;
};

template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_specialized;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::digits;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::max_digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_signed;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_integer;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_exact;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::radix;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::min_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::min_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::max_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::max_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::has_infinity;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::has_quiet_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::has_signaling_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_denorm_style numeric_limits<volatile _Tp>::has_denorm;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::has_denorm_loss;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_iec559;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_bounded;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_modulo;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::traps;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::tinyness_before;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_round_style numeric_limits<volatile _Tp>::round_style;

template <class _Tp>
class _LIBCPP_TEMPLATE_VIS numeric_limits<const volatile _Tp>
    : private numeric_limits<_Tp>
{
    typedef numeric_limits<_Tp> __base;
    typedef _Tp type;
public:
    static _LIBCPP_CONSTEXPR const bool is_specialized = __base::is_specialized;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __base::min();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __base::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return __base::lowest();}

    static _LIBCPP_CONSTEXPR const int  digits = __base::digits;
    static _LIBCPP_CONSTEXPR const int  digits10 = __base::digits10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = __base::max_digits10;
    static _LIBCPP_CONSTEXPR const bool is_signed = __base::is_signed;
    static _LIBCPP_CONSTEXPR const bool is_integer = __base::is_integer;
    static _LIBCPP_CONSTEXPR const bool is_exact = __base::is_exact;
    static _LIBCPP_CONSTEXPR const int  radix = __base::radix;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __base::epsilon();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return __base::round_error();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __base::min_exponent;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __base::min_exponent10;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __base::max_exponent;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __base::max_exponent10;

    static _LIBCPP_CONSTEXPR const bool has_infinity = __base::has_infinity;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = __base::has_quiet_NaN;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = __base::has_signaling_NaN;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = __base::has_denorm;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = __base::has_denorm_loss;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __base::infinity();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __base::quiet_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __base::signaling_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __base::denorm_min();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = __base::is_iec559;
    static _LIBCPP_CONSTEXPR const bool is_bounded = __base::is_bounded;
    static _LIBCPP_CONSTEXPR const bool is_modulo = __base::is_modulo;

    static _LIBCPP_CONSTEXPR const bool traps = __base::traps;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = __base::tinyness_before;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = __base::round_style;
};

template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_specialized;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::digits;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::max_digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_signed;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_integer;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_exact;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::radix;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::min_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::min_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::max_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::max_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::has_infinity;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::has_quiet_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::has_signaling_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_denorm_style numeric_limits<const volatile _Tp>::has_denorm;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::has_denorm_loss;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_iec559;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_bounded;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_modulo;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::traps;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::tinyness_before;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_round_style numeric_limits<const volatile _Tp>::round_style;

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_LIMITS
# 819 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits" 3
# 313 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 2 3

// signbit

#ifdef signbit

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_signbit(_A1 __lcpp_x) _NOEXCEPT
{
    return signbit(__lcpp_x);
}

#undef signbit

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
signbit(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_signbit((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_integral<_A1>::value && std::is_signed<_A1>::value, bool>::type
signbit(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x < 0; }

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_integral<_A1>::value && !std::is_signed<_A1>::value, bool>::type
signbit(_A1) _NOEXCEPT
{ return false; }

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_MSVCRT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 351 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <typename _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
signbit(_A1 __lcpp_x) _NOEXCEPT
{
  return ::signbit(static_cast<typename std::__promote<_A1>::type>(__lcpp_x));
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_integral<_A1>::value && std::is_signed<_A1>::value, bool>::type
signbit(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x < 0; }

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_integral<_A1>::value && !std::is_signed<_A1>::value, bool>::type
signbit(_A1) _NOEXCEPT
{ return false; }

#endif  // signbit
# 375 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// fpclassify

#ifdef fpclassify

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
int
__libcpp_fpclassify(_A1 __lcpp_x) _NOEXCEPT
{
    return fpclassify(__lcpp_x);
}

#undef fpclassify

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, int>::type
fpclassify(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_fpclassify((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, int>::type
fpclassify(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x == 0 ? FP_ZERO : FP_NORMAL; }

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_MSVCRT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 405 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <typename _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
fpclassify(_A1 __lcpp_x) _NOEXCEPT
{
  return ::fpclassify(static_cast<typename std::__promote<_A1>::type>(__lcpp_x));
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, int>::type
fpclassify(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x == 0 ? FP_ZERO : FP_NORMAL; }

#endif  // fpclassify
# 421 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isfinite

#ifdef isfinite

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isfinite(_A1 __lcpp_x) _NOEXCEPT
{
    return isfinite(__lcpp_x);
}

#undef isfinite

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_arithmetic<_A1>::value && std::numeric_limits<_A1>::has_infinity,
    bool>::type
isfinite(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_isfinite((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_arithmetic<_A1>::value && !std::numeric_limits<_A1>::has_infinity,
    bool>::type
isfinite(_A1) _NOEXCEPT
{ return true; }

#endif  // isfinite
# 455 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isinf

#ifdef isinf

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isinf(_A1 __lcpp_x) _NOEXCEPT
{
    return isinf(__lcpp_x);
}

#undef isinf

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_arithmetic<_A1>::value && std::numeric_limits<_A1>::has_infinity,
    bool>::type
isinf(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_isinf((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_arithmetic<_A1>::value && !std::numeric_limits<_A1>::has_infinity,
    bool>::type
isinf(_A1) _NOEXCEPT
{ return false; }

#ifdef _LIBCPP_PREFERRED_OVERLOAD
inline _LIBCPP_INLINE_VISIBILITY
bool
isinf(float __lcpp_x) _NOEXCEPT { return __libcpp_isinf(__lcpp_x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
bool
isinf(double __lcpp_x) _NOEXCEPT { return __libcpp_isinf(__lcpp_x); }

inline _LIBCPP_INLINE_VISIBILITY
bool
isinf(long double __lcpp_x) _NOEXCEPT { return __libcpp_isinf(__lcpp_x); }
#endif
# 501 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#endif  // isinf
# 503 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isnan

#ifdef isnan

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isnan(_A1 __lcpp_x) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_isnan)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 514 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
    return __builtin_isnan(__lcpp_x);
#else
# 516 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
    return isnan(__lcpp_x);
#endif
# 518 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
}

#undef isnan

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
isnan(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_isnan((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, bool>::type
isnan(_A1) _NOEXCEPT
{ return false; }

#ifdef _LIBCPP_PREFERRED_OVERLOAD
inline _LIBCPP_INLINE_VISIBILITY
bool
isnan(float __lcpp_x) _NOEXCEPT { return __libcpp_isnan(__lcpp_x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
bool
isnan(double __lcpp_x) _NOEXCEPT { return __libcpp_isnan(__lcpp_x); }

inline _LIBCPP_INLINE_VISIBILITY
bool
isnan(long double __lcpp_x) _NOEXCEPT { return __libcpp_isnan(__lcpp_x); }
#endif
# 549 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#endif  // isnan
# 551 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isnormal

#ifdef isnormal

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isnormal(_A1 __lcpp_x) _NOEXCEPT
{
    return isnormal(__lcpp_x);
}

#undef isnormal

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
isnormal(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_isnormal((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, bool>::type
isnormal(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x != 0; }

#endif  // isnormal
# 581 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isgreater

#ifdef isgreater

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isgreater(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return isgreater(__lcpp_x, __lcpp_y);
}

#undef isgreater

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isgreater(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isgreater((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // isgreater
# 611 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isgreaterequal

#ifdef isgreaterequal

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isgreaterequal(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return isgreaterequal(__lcpp_x, __lcpp_y);
}

#undef isgreaterequal

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isgreaterequal(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isgreaterequal((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // isgreaterequal
# 641 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isless

#ifdef isless

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isless(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return isless(__lcpp_x, __lcpp_y);
}

#undef isless

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isless(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isless((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // isless
# 671 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// islessequal

#ifdef islessequal

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_islessequal(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return islessequal(__lcpp_x, __lcpp_y);
}

#undef islessequal

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
islessequal(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_islessequal((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // islessequal
# 701 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// islessgreater

#ifdef islessgreater

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_islessgreater(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return islessgreater(__lcpp_x, __lcpp_y);
}

#undef islessgreater

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
islessgreater(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_islessgreater((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // islessgreater
# 731 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isunordered

#ifdef isunordered

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isunordered(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return isunordered(__lcpp_x, __lcpp_y);
}

#undef isunordered

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isunordered(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isunordered((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // isunordered
# 761 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// abs

#undef abs
#undef labs
#ifndef _LIBCPP_HAS_NO_LONG_LONG
#undef llabs
#endif
# 769 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// MSVCRT already has the correct prototype in <stdlib.h> if __cplusplus is defined
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_MSVCRT) && !defined(__sun__) && !defined(_AIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 772 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY long abs(long __x) _NOEXCEPT {
  return ::labs(__x);
}
#ifndef _LIBCPP_HAS_NO_LONG_LONG
inline _LIBCPP_INLINE_VISIBILITY long long abs(long long __x) _NOEXCEPT {
  return ::llabs(__x);
}
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 780 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#endif // !defined(_LIBCPP_MSVCRT) && !defined(__sun__) && !defined(_AIX)
# 781 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3


#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 784 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float abs(float __lcpp_x) _NOEXCEPT {
  return ::fabsf(__lcpp_x);
}

inline _LIBCPP_INLINE_VISIBILITY double abs(double __lcpp_x) _NOEXCEPT {
  return ::fabs(__lcpp_x);
}

inline _LIBCPP_INLINE_VISIBILITY long double
abs(long double __lcpp_x) _NOEXCEPT {
  return ::fabsl(__lcpp_x);
}
#endif // !(defined(_AIX) || defined(__sun__))
# 797 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// div

#undef div
#undef ldiv
#ifndef _LIBCPP_HAS_NO_LONG_LONG
#undef lldiv
#endif
# 805 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// MSVCRT already has the correct prototype in <stdlib.h> if __cplusplus is defined
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_MSVCRT) && !defined(__sun__) && !defined(_AIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 808 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY ldiv_t div(long __x, long __y) _NOEXCEPT {
  return ::ldiv(__x, __y);
}
#ifndef _LIBCPP_HAS_NO_LONG_LONG
inline _LIBCPP_INLINE_VISIBILITY lldiv_t div(long long __x,
                                             long long __y) _NOEXCEPT {
  return ::lldiv(__x, __y);
}
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 817 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#endif // _LIBCPP_MSVCRT / __sun__ / _AIX
# 818 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// acos

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 822 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       acos(float __lcpp_x) _NOEXCEPT       {return ::acosf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double acos(long double __lcpp_x) _NOEXCEPT {return ::acosl(__lcpp_x);}
#endif
# 825 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
acos(_A1 __lcpp_x) _NOEXCEPT {return ::acos((double)__lcpp_x);}

// asin

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 834 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       asin(float __lcpp_x) _NOEXCEPT       {return ::asinf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double asin(long double __lcpp_x) _NOEXCEPT {return ::asinl(__lcpp_x);}
#endif
# 837 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
asin(_A1 __lcpp_x) _NOEXCEPT {return ::asin((double)__lcpp_x);}

// atan

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 846 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       atan(float __lcpp_x) _NOEXCEPT       {return ::atanf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double atan(long double __lcpp_x) _NOEXCEPT {return ::atanl(__lcpp_x);}
#endif
# 849 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
atan(_A1 __lcpp_x) _NOEXCEPT {return ::atan((double)__lcpp_x);}

// atan2

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 858 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       atan2(float __lcpp_y, float __lcpp_x) _NOEXCEPT             {return ::atan2f(__lcpp_y, __lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double atan2(long double __lcpp_y, long double __lcpp_x) _NOEXCEPT {return ::atan2l(__lcpp_y, __lcpp_x);}
#endif
# 861 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
atan2(_A1 __lcpp_y, _A2 __lcpp_x) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::atan2((__result_type)__lcpp_y, (__result_type)__lcpp_x);
}

// ceil

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 881 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       ceil(float __lcpp_x) _NOEXCEPT       {return ::ceilf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double ceil(long double __lcpp_x) _NOEXCEPT {return ::ceill(__lcpp_x);}
#endif
# 884 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
ceil(_A1 __lcpp_x) _NOEXCEPT {return ::ceil((double)__lcpp_x);}

// cos

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 893 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       cos(float __lcpp_x) _NOEXCEPT       {return ::cosf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double cos(long double __lcpp_x) _NOEXCEPT {return ::cosl(__lcpp_x);}
#endif
# 896 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
cos(_A1 __lcpp_x) _NOEXCEPT {return ::cos((double)__lcpp_x);}

// cosh

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 905 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       cosh(float __lcpp_x) _NOEXCEPT       {return ::coshf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double cosh(long double __lcpp_x) _NOEXCEPT {return ::coshl(__lcpp_x);}
#endif
# 908 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
cosh(_A1 __lcpp_x) _NOEXCEPT {return ::cosh((double)__lcpp_x);}

// exp

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 917 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       exp(float __lcpp_x) _NOEXCEPT       {return ::expf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double exp(long double __lcpp_x) _NOEXCEPT {return ::expl(__lcpp_x);}
#endif
# 920 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
exp(_A1 __lcpp_x) _NOEXCEPT {return ::exp((double)__lcpp_x);}

// fabs

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 929 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       fabs(float __lcpp_x) _NOEXCEPT       {return ::fabsf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double fabs(long double __lcpp_x) _NOEXCEPT {return ::fabsl(__lcpp_x);}
#endif
# 932 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
fabs(_A1 __lcpp_x) _NOEXCEPT {return ::fabs((double)__lcpp_x);}

// floor

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 941 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       floor(float __lcpp_x) _NOEXCEPT       {return ::floorf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double floor(long double __lcpp_x) _NOEXCEPT {return ::floorl(__lcpp_x);}
#endif
# 944 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
floor(_A1 __lcpp_x) _NOEXCEPT {return ::floor((double)__lcpp_x);}

// fmod

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 953 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       fmod(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::fmodf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmod(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::fmodl(__lcpp_x, __lcpp_y);}
#endif
# 956 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
fmod(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::fmod((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// frexp

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 976 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       frexp(float __lcpp_x, int* __lcpp_e) _NOEXCEPT       {return ::frexpf(__lcpp_x, __lcpp_e);}
inline _LIBCPP_INLINE_VISIBILITY long double frexp(long double __lcpp_x, int* __lcpp_e) _NOEXCEPT {return ::frexpl(__lcpp_x, __lcpp_e);}
#endif
# 979 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
frexp(_A1 __lcpp_x, int* __lcpp_e) _NOEXCEPT {return ::frexp((double)__lcpp_x, __lcpp_e);}

// ldexp

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 988 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       ldexp(float __lcpp_x, int __lcpp_e) _NOEXCEPT       {return ::ldexpf(__lcpp_x, __lcpp_e);}
inline _LIBCPP_INLINE_VISIBILITY long double ldexp(long double __lcpp_x, int __lcpp_e) _NOEXCEPT {return ::ldexpl(__lcpp_x, __lcpp_e);}
#endif
# 991 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
ldexp(_A1 __lcpp_x, int __lcpp_e) _NOEXCEPT {return ::ldexp((double)__lcpp_x, __lcpp_e);}

// log

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1000 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       log(float __lcpp_x) _NOEXCEPT       {return ::logf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double log(long double __lcpp_x) _NOEXCEPT {return ::logl(__lcpp_x);}
#endif
# 1003 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
log(_A1 __lcpp_x) _NOEXCEPT {return ::log((double)__lcpp_x);}

// log10

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1012 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       log10(float __lcpp_x) _NOEXCEPT       {return ::log10f(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double log10(long double __lcpp_x) _NOEXCEPT {return ::log10l(__lcpp_x);}
#endif
# 1015 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
log10(_A1 __lcpp_x) _NOEXCEPT {return ::log10((double)__lcpp_x);}

// modf

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1024 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       modf(float __lcpp_x, float* __lcpp_y) _NOEXCEPT             {return ::modff(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double modf(long double __lcpp_x, long double* __lcpp_y) _NOEXCEPT {return ::modfl(__lcpp_x, __lcpp_y);}
#endif
# 1027 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// pow

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1031 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       pow(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::powf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double pow(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::powl(__lcpp_x, __lcpp_y);}
#endif
# 1034 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
pow(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::pow((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// sin

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1054 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       sin(float __lcpp_x) _NOEXCEPT       {return ::sinf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double sin(long double __lcpp_x) _NOEXCEPT {return ::sinl(__lcpp_x);}
#endif
# 1057 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
sin(_A1 __lcpp_x) _NOEXCEPT {return ::sin((double)__lcpp_x);}

// sinh

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1066 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       sinh(float __lcpp_x) _NOEXCEPT       {return ::sinhf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double sinh(long double __lcpp_x) _NOEXCEPT {return ::sinhl(__lcpp_x);}
#endif
# 1069 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
sinh(_A1 __lcpp_x) _NOEXCEPT {return ::sinh((double)__lcpp_x);}

// sqrt

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1078 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       sqrt(float __lcpp_x) _NOEXCEPT       {return ::sqrtf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double sqrt(long double __lcpp_x) _NOEXCEPT {return ::sqrtl(__lcpp_x);}
#endif
# 1081 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
sqrt(_A1 __lcpp_x) _NOEXCEPT {return ::sqrt((double)__lcpp_x);}

// tan

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1090 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       tan(float __lcpp_x) _NOEXCEPT       {return ::tanf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double tan(long double __lcpp_x) _NOEXCEPT {return ::tanl(__lcpp_x);}
#endif
# 1093 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
tan(_A1 __lcpp_x) _NOEXCEPT {return ::tan((double)__lcpp_x);}

// tanh

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       tanh(float __lcpp_x) _NOEXCEPT       {return ::tanhf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double tanh(long double __lcpp_x) _NOEXCEPT {return ::tanhl(__lcpp_x);}
#endif
# 1105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
tanh(_A1 __lcpp_x) _NOEXCEPT {return ::tanh((double)__lcpp_x);}

// acosh

inline _LIBCPP_INLINE_VISIBILITY float       acosh(float __lcpp_x) _NOEXCEPT       {return ::acoshf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double acosh(long double __lcpp_x) _NOEXCEPT {return ::acoshl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
acosh(_A1 __lcpp_x) _NOEXCEPT {return ::acosh((double)__lcpp_x);}

// asinh

inline _LIBCPP_INLINE_VISIBILITY float       asinh(float __lcpp_x) _NOEXCEPT       {return ::asinhf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double asinh(long double __lcpp_x) _NOEXCEPT {return ::asinhl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
asinh(_A1 __lcpp_x) _NOEXCEPT {return ::asinh((double)__lcpp_x);}

// atanh

inline _LIBCPP_INLINE_VISIBILITY float       atanh(float __lcpp_x) _NOEXCEPT       {return ::atanhf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double atanh(long double __lcpp_x) _NOEXCEPT {return ::atanhl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
atanh(_A1 __lcpp_x) _NOEXCEPT {return ::atanh((double)__lcpp_x);}

// cbrt

inline _LIBCPP_INLINE_VISIBILITY float       cbrt(float __lcpp_x) _NOEXCEPT       {return ::cbrtf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double cbrt(long double __lcpp_x) _NOEXCEPT {return ::cbrtl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
cbrt(_A1 __lcpp_x) _NOEXCEPT {return ::cbrt((double)__lcpp_x);}

// copysign

inline _LIBCPP_INLINE_VISIBILITY float copysign(float __lcpp_x,
                                                float __lcpp_y) _NOEXCEPT {
  return ::copysignf(__lcpp_x, __lcpp_y);
}
inline _LIBCPP_INLINE_VISIBILITY long double
copysign(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {
  return ::copysignl(__lcpp_x, __lcpp_y);
}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
copysign(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::copysign((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// erf

inline _LIBCPP_INLINE_VISIBILITY float       erf(float __lcpp_x) _NOEXCEPT       {return ::erff(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double erf(long double __lcpp_x) _NOEXCEPT {return ::erfl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
erf(_A1 __lcpp_x) _NOEXCEPT {return ::erf((double)__lcpp_x);}

// erfc

inline _LIBCPP_INLINE_VISIBILITY float       erfc(float __lcpp_x) _NOEXCEPT       {return ::erfcf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double erfc(long double __lcpp_x) _NOEXCEPT {return ::erfcl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
erfc(_A1 __lcpp_x) _NOEXCEPT {return ::erfc((double)__lcpp_x);}

// exp2

inline _LIBCPP_INLINE_VISIBILITY float       exp2(float __lcpp_x) _NOEXCEPT       {return ::exp2f(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double exp2(long double __lcpp_x) _NOEXCEPT {return ::exp2l(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
exp2(_A1 __lcpp_x) _NOEXCEPT {return ::exp2((double)__lcpp_x);}

// expm1

inline _LIBCPP_INLINE_VISIBILITY float       expm1(float __lcpp_x) _NOEXCEPT       {return ::expm1f(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double expm1(long double __lcpp_x) _NOEXCEPT {return ::expm1l(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
expm1(_A1 __lcpp_x) _NOEXCEPT {return ::expm1((double)__lcpp_x);}

// fdim

inline _LIBCPP_INLINE_VISIBILITY float       fdim(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::fdimf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double fdim(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::fdiml(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
fdim(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::fdim((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// fma

inline _LIBCPP_INLINE_VISIBILITY float       fma(float __lcpp_x, float __lcpp_y, float __lcpp_z) _NOEXCEPT                   {return ::fmaf(__lcpp_x, __lcpp_y, __lcpp_z);}
inline _LIBCPP_INLINE_VISIBILITY long double fma(long double __lcpp_x, long double __lcpp_y, long double __lcpp_z) _NOEXCEPT {return ::fmal(__lcpp_x, __lcpp_y, __lcpp_z);}

template <class _A1, class _A2, class _A3>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value &&
    std::is_arithmetic<_A3>::value,
    std::__promote<_A1, _A2, _A3>
>::type
fma(_A1 __lcpp_x, _A2 __lcpp_y, _A3 __lcpp_z) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2, _A3>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value &&
                     std::_IsSame<_A3, __result_type>::value)), "");
    return ::fma((__result_type)__lcpp_x, (__result_type)__lcpp_y, (__result_type)__lcpp_z);
}

// fmax

inline _LIBCPP_INLINE_VISIBILITY float       fmax(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::fmaxf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmax(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::fmaxl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
fmax(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::fmax((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// fmin

inline _LIBCPP_INLINE_VISIBILITY float       fmin(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::fminf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmin(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::fminl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
fmin(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::fmin((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// hypot

inline _LIBCPP_INLINE_VISIBILITY float       hypot(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::hypotf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double hypot(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::hypotl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
hypot(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::hypot((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// ilogb

inline _LIBCPP_INLINE_VISIBILITY int ilogb(float __lcpp_x) _NOEXCEPT       {return ::ilogbf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY int ilogb(long double __lcpp_x) _NOEXCEPT {return ::ilogbl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, int>::type
ilogb(_A1 __lcpp_x) _NOEXCEPT {return ::ilogb((double)__lcpp_x);}

// lgamma

inline _LIBCPP_INLINE_VISIBILITY float       lgamma(float __lcpp_x) _NOEXCEPT       {return ::lgammaf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double lgamma(long double __lcpp_x) _NOEXCEPT {return ::lgammal(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
lgamma(_A1 __lcpp_x) _NOEXCEPT {return ::lgamma((double)__lcpp_x);}

// llrint

inline _LIBCPP_INLINE_VISIBILITY long long llrint(float __lcpp_x) _NOEXCEPT       {return ::llrintf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long long llrint(long double __lcpp_x) _NOEXCEPT {return ::llrintl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, long long>::type
llrint(_A1 __lcpp_x) _NOEXCEPT {return ::llrint((double)__lcpp_x);}

// llround

inline _LIBCPP_INLINE_VISIBILITY long long llround(float __lcpp_x) _NOEXCEPT       {return ::llroundf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long long llround(long double __lcpp_x) _NOEXCEPT {return ::llroundl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, long long>::type
llround(_A1 __lcpp_x) _NOEXCEPT {return ::llround((double)__lcpp_x);}

// log1p

inline _LIBCPP_INLINE_VISIBILITY float       log1p(float __lcpp_x) _NOEXCEPT       {return ::log1pf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double log1p(long double __lcpp_x) _NOEXCEPT {return ::log1pl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
log1p(_A1 __lcpp_x) _NOEXCEPT {return ::log1p((double)__lcpp_x);}

// log2

inline _LIBCPP_INLINE_VISIBILITY float       log2(float __lcpp_x) _NOEXCEPT       {return ::log2f(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double log2(long double __lcpp_x) _NOEXCEPT {return ::log2l(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
log2(_A1 __lcpp_x) _NOEXCEPT {return ::log2((double)__lcpp_x);}

// logb

inline _LIBCPP_INLINE_VISIBILITY float       logb(float __lcpp_x) _NOEXCEPT       {return ::logbf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double logb(long double __lcpp_x) _NOEXCEPT {return ::logbl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
logb(_A1 __lcpp_x) _NOEXCEPT {return ::logb((double)__lcpp_x);}

// lrint

inline _LIBCPP_INLINE_VISIBILITY long lrint(float __lcpp_x) _NOEXCEPT       {return ::lrintf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long lrint(long double __lcpp_x) _NOEXCEPT {return ::lrintl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, long>::type
lrint(_A1 __lcpp_x) _NOEXCEPT {return ::lrint((double)__lcpp_x);}

// lround

inline _LIBCPP_INLINE_VISIBILITY long lround(float __lcpp_x) _NOEXCEPT       {return ::lroundf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long lround(long double __lcpp_x) _NOEXCEPT {return ::lroundl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, long>::type
lround(_A1 __lcpp_x) _NOEXCEPT {return ::lround((double)__lcpp_x);}

// nan

// nearbyint

inline _LIBCPP_INLINE_VISIBILITY float       nearbyint(float __lcpp_x) _NOEXCEPT       {return ::nearbyintf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double nearbyint(long double __lcpp_x) _NOEXCEPT {return ::nearbyintl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
nearbyint(_A1 __lcpp_x) _NOEXCEPT {return ::nearbyint((double)__lcpp_x);}

// nextafter

inline _LIBCPP_INLINE_VISIBILITY float       nextafter(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::nextafterf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double nextafter(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::nextafterl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
nextafter(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::nextafter((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// nexttoward

inline _LIBCPP_INLINE_VISIBILITY float       nexttoward(float __lcpp_x, long double __lcpp_y) _NOEXCEPT       {return ::nexttowardf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double nexttoward(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::nexttowardl(__lcpp_x, __lcpp_y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
nexttoward(_A1 __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::nexttoward((double)__lcpp_x, __lcpp_y);}

// remainder

inline _LIBCPP_INLINE_VISIBILITY float       remainder(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::remainderf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double remainder(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::remainderl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
remainder(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::remainder((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// remquo

inline _LIBCPP_INLINE_VISIBILITY float       remquo(float __lcpp_x, float __lcpp_y, int* __lcpp_z) _NOEXCEPT             {return ::remquof(__lcpp_x, __lcpp_y, __lcpp_z);}
inline _LIBCPP_INLINE_VISIBILITY long double remquo(long double __lcpp_x, long double __lcpp_y, int* __lcpp_z) _NOEXCEPT {return ::remquol(__lcpp_x, __lcpp_y, __lcpp_z);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
remquo(_A1 __lcpp_x, _A2 __lcpp_y, int* __lcpp_z) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::remquo((__result_type)__lcpp_x, (__result_type)__lcpp_y, __lcpp_z);
}

// rint

inline _LIBCPP_INLINE_VISIBILITY float       rint(float __lcpp_x) _NOEXCEPT       {return ::rintf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double rint(long double __lcpp_x) _NOEXCEPT {return ::rintl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
rint(_A1 __lcpp_x) _NOEXCEPT {return ::rint((double)__lcpp_x);}

// round

inline _LIBCPP_INLINE_VISIBILITY float       round(float __lcpp_x) _NOEXCEPT       {return ::roundf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double round(long double __lcpp_x) _NOEXCEPT {return ::roundl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
round(_A1 __lcpp_x) _NOEXCEPT {return ::round((double)__lcpp_x);}

// scalbln

inline _LIBCPP_INLINE_VISIBILITY float       scalbln(float __lcpp_x, long __lcpp_y) _NOEXCEPT       {return ::scalblnf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double scalbln(long double __lcpp_x, long __lcpp_y) _NOEXCEPT {return ::scalblnl(__lcpp_x, __lcpp_y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
scalbln(_A1 __lcpp_x, long __lcpp_y) _NOEXCEPT {return ::scalbln((double)__lcpp_x, __lcpp_y);}

// scalbn

inline _LIBCPP_INLINE_VISIBILITY float       scalbn(float __lcpp_x, int __lcpp_y) _NOEXCEPT       {return ::scalbnf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double scalbn(long double __lcpp_x, int __lcpp_y) _NOEXCEPT {return ::scalbnl(__lcpp_x, __lcpp_y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
scalbn(_A1 __lcpp_x, int __lcpp_y) _NOEXCEPT {return ::scalbn((double)__lcpp_x, __lcpp_y);}

// tgamma

inline _LIBCPP_INLINE_VISIBILITY float       tgamma(float __lcpp_x) _NOEXCEPT       {return ::tgammaf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double tgamma(long double __lcpp_x) _NOEXCEPT {return ::tgammal(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
tgamma(_A1 __lcpp_x) _NOEXCEPT {return ::tgamma((double)__lcpp_x);}

// trunc

inline _LIBCPP_INLINE_VISIBILITY float       trunc(float __lcpp_x) _NOEXCEPT       {return ::truncf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double trunc(long double __lcpp_x) _NOEXCEPT {return ::truncl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
trunc(_A1 __lcpp_x) _NOEXCEPT {return ::trunc((double)__lcpp_x);}

} // extern "C++"

#endif // __cplusplus
# 1563 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#else // _LIBCPP_MATH_H
# 1565 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// This include lives outside the header guard in order to support an MSVC
// extension which allows users to do:
//
// #define _USE_MATH_DEFINES
// #include <math.h>
//
// and receive the definitions of mathematical constants, even if <math.h>
// has previously been included.
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_MSVCRT) && defined(_USE_MATH_DEFINES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1575 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#if 0 /* expanded by -frewrite-includes */
#include_next <math.h>
#endif /* expanded by -frewrite-includes */
# 1575 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 1576 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#endif
# 1577 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#endif  // _LIBCPP_MATH_H
# 1579 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 2 3
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 86 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 88 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 89 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
#endif
# 90 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3

#ifdef __GNUC__
#define _LIBCPP_UNREACHABLE() __builtin_unreachable()
#else
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
#define _LIBCPP_UNREACHABLE() _VSTD::abort()
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::size_t;
using ::div_t;
using ::ldiv_t;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::lldiv_t;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::atof;
using ::atoi;
using ::atol;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::atoll;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::strtod;
using ::strtof;
using ::strtold;
using ::strtol;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::strtoll;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::strtoul;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::strtoull;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::rand;
using ::srand;
using ::calloc;
using ::free;
using ::malloc;
using ::realloc;
using ::abort;
using ::atexit;
using ::exit;
using ::_Exit;
#ifndef _LIBCPP_WINDOWS_STORE_APP
using ::getenv;
using ::system;
#endif
# 136 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::bsearch;
using ::qsort;
using ::abs;
using ::labs;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::llabs;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 143 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::div;
using ::ldiv;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::lldiv;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::mblen;
using ::mbtowc;
using ::wctomb;
using ::mbstowcs;
using ::wcstombs;
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG) && defined(_LIBCPP_HAS_QUICK_EXIT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::at_quick_exit;
using ::quick_exit;
#endif
# 157 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && defined(_LIBCPP_HAS_ALIGNED_ALLOC)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
using ::aligned_alloc;
#endif
# 160 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTDLIB
# 164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdlib" 3
# 82 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 82 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
# 83 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 83 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
# 84 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_VCRUNTIME)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 86 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
#if 0 /* expanded by -frewrite-includes */
#include <vcruntime_exception.h>
#endif /* expanded by -frewrite-includes */
# 86 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
# 87 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
#endif
# 88 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 90 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
#endif
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3

namespace std  // purposefully not using versioning namespace
{

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_ABI_VCRUNTIME)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
class _LIBCPP_EXCEPTION_ABI exception
{
public:
    _LIBCPP_INLINE_VISIBILITY exception() _NOEXCEPT {}
    virtual ~exception() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI bad_exception
    : public exception
{
public:
    _LIBCPP_INLINE_VISIBILITY bad_exception() _NOEXCEPT {}
    virtual ~bad_exception() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};
#endif // !_LIBCPP_ABI_VCRUNTIME
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 \
    || defined(_LIBCPP_ENABLE_CXX17_REMOVED_UNEXPECTED_FUNCTIONS) \
    || defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
typedef void (*unexpected_handler)();
_LIBCPP_FUNC_VIS unexpected_handler set_unexpected(unexpected_handler) _NOEXCEPT;
_LIBCPP_FUNC_VIS unexpected_handler get_unexpected() _NOEXCEPT;
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void unexpected();
#endif
# 123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3

typedef void (*terminate_handler)();
_LIBCPP_FUNC_VIS terminate_handler set_terminate(terminate_handler) _NOEXCEPT;
_LIBCPP_FUNC_VIS terminate_handler get_terminate() _NOEXCEPT;
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void terminate() _NOEXCEPT;

_LIBCPP_FUNC_VIS bool uncaught_exception() _NOEXCEPT;
_LIBCPP_FUNC_VIS _LIBCPP_AVAILABILITY_UNCAUGHT_EXCEPTIONS int uncaught_exceptions() _NOEXCEPT;

class _LIBCPP_TYPE_VIS exception_ptr;

_LIBCPP_FUNC_VIS exception_ptr current_exception() _NOEXCEPT;
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void rethrow_exception(exception_ptr);

#ifndef _LIBCPP_ABI_MICROSOFT

class _LIBCPP_TYPE_VIS exception_ptr
{
    void* __ptr_;
public:
    _LIBCPP_INLINE_VISIBILITY exception_ptr() _NOEXCEPT : __ptr_() {}
    _LIBCPP_INLINE_VISIBILITY exception_ptr(nullptr_t) _NOEXCEPT : __ptr_() {}

    exception_ptr(const exception_ptr&) _NOEXCEPT;
    exception_ptr& operator=(const exception_ptr&) _NOEXCEPT;
    ~exception_ptr() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT
    {return __ptr_ != nullptr;}

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator==(const exception_ptr& __x, const exception_ptr& __y) _NOEXCEPT
        {return __x.__ptr_ == __y.__ptr_;}

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const exception_ptr& __x, const exception_ptr& __y) _NOEXCEPT
        {return !(__x == __y);}

    friend _LIBCPP_FUNC_VIS exception_ptr current_exception() _NOEXCEPT;
    friend _LIBCPP_FUNC_VIS void rethrow_exception(exception_ptr);
};

template<class _Ep>
_LIBCPP_INLINE_VISIBILITY exception_ptr
make_exception_ptr(_Ep __e) _NOEXCEPT
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
        throw __e;
    }
    catch (...)
    {
        return current_exception();
    }
#else
# 179 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
    ((void)__e);
    _VSTD::abort();
#endif
# 182 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
}

#else // _LIBCPP_ABI_MICROSOFT
# 185 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3

class _LIBCPP_TYPE_VIS exception_ptr
{
#if 0 /* disabled by -frewrite-includes */
#if defined(__clang__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 189 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wunused-private-field"
#endif
# 192 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
    void* __ptr1_;
    void* __ptr2_;
#if 0 /* disabled by -frewrite-includes */
#if defined(__clang__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 195 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
#pragma clang diagnostic pop
#endif
# 197 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
public:
    exception_ptr() _NOEXCEPT;
    exception_ptr(nullptr_t) _NOEXCEPT;
    exception_ptr(const exception_ptr& __other) _NOEXCEPT;
    exception_ptr& operator=(const exception_ptr& __other) _NOEXCEPT;
    exception_ptr& operator=(nullptr_t) _NOEXCEPT;
    ~exception_ptr() _NOEXCEPT;
    _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT;
};

_LIBCPP_FUNC_VIS
bool operator==(const exception_ptr& __x, const exception_ptr& __y) _NOEXCEPT;

inline _LIBCPP_INLINE_VISIBILITY
bool operator!=(const exception_ptr& __x, const exception_ptr& __y) _NOEXCEPT
    {return !(__x == __y);}

_LIBCPP_FUNC_VIS void swap(exception_ptr&, exception_ptr&) _NOEXCEPT;

_LIBCPP_FUNC_VIS exception_ptr __copy_exception_ptr(void *__except, const void* __ptr);
_LIBCPP_FUNC_VIS exception_ptr current_exception() _NOEXCEPT;
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void rethrow_exception(exception_ptr p);

// This is a built-in template function which automagically extracts the required
// information.
template <class _E> void *__GetExceptionInfo(_E);

template<class _Ep>
_LIBCPP_INLINE_VISIBILITY exception_ptr
make_exception_ptr(_Ep __e) _NOEXCEPT
{
  return __copy_exception_ptr(_VSTD::addressof(__e), __GetExceptionInfo(__e));
}

#endif // _LIBCPP_ABI_MICROSOFT
# 232 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
// nested_exception

class _LIBCPP_EXCEPTION_ABI nested_exception
{
    exception_ptr __ptr_;
public:
    nested_exception() _NOEXCEPT;
//     nested_exception(const nested_exception&) noexcept = default;
//     nested_exception& operator=(const nested_exception&) noexcept = default;
    virtual ~nested_exception() _NOEXCEPT;

    // access functions
    _LIBCPP_NORETURN void rethrow_nested() const;
    _LIBCPP_INLINE_VISIBILITY exception_ptr nested_ptr() const _NOEXCEPT {return __ptr_;}
};

template <class _Tp>
struct __nested
    : public _Tp,
      public nested_exception
{
    _LIBCPP_INLINE_VISIBILITY explicit __nested(const _Tp& __t) : _Tp(__t) {}
};

#ifndef _LIBCPP_NO_EXCEPTIONS
template <class _Tp, class _Up, bool>
struct __throw_with_nested;

template <class _Tp, class _Up>
struct __throw_with_nested<_Tp, _Up, true> {
    _LIBCPP_NORETURN static inline _LIBCPP_INLINE_VISIBILITY void
    __do_throw(_Tp&& __t)
    {
        throw __nested<_Up>(_VSTD::forward<_Tp>(__t));
    }
};

template <class _Tp, class _Up>
struct __throw_with_nested<_Tp, _Up, false> {
    _LIBCPP_NORETURN static inline _LIBCPP_INLINE_VISIBILITY void
#ifndef _LIBCPP_CXX03_LANG
    __do_throw(_Tp&& __t)
#else
# 275 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
    __do_throw (_Tp& __t)
#endif  // _LIBCPP_CXX03_LANG
# 277 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
    {
        throw _VSTD::forward<_Tp>(__t);
    }
};
#endif
# 282 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3

template <class _Tp>
_LIBCPP_NORETURN
void
throw_with_nested(_Tp&& __t)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    typedef typename decay<_Tp>::type _Up;
    static_assert( is_copy_constructible<_Up>::value, "type thrown must be CopyConstructible");
    __throw_with_nested<_Tp, _Up,
        is_class<_Up>::value &&
        !is_base_of<nested_exception, _Up>::value &&
        !__libcpp_is_final<_Up>::value>::
            __do_throw(_VSTD::forward<_Tp>(__t));
#else
# 297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
    ((void)__t);
    // FIXME: Make this abort
#endif
# 300 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
}

template <class _From, class _To>
struct __can_dynamic_cast : public _LIBCPP_BOOL_CONSTANT(
              is_polymorphic<_From>::value &&
                 (!is_base_of<_To, _From>::value ||
                   is_convertible<const _From*, const _To*>::value)) {};

template <class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
void
rethrow_if_nested(const _Ep& __e,
                  typename enable_if< __can_dynamic_cast<_Ep, nested_exception>::value>::type* = 0)
{
    const nested_exception* __nep = dynamic_cast<const nested_exception*>(_VSTD::addressof(__e));
    if (__nep)
        __nep->rethrow_nested();
}

template <class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
void
rethrow_if_nested(const _Ep&,
                  typename enable_if<!__can_dynamic_cast<_Ep, nested_exception>::value>::type* = 0)
{
}

}  // std

#endif  // _LIBCPP_EXCEPTION
# 330 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/exception" 3
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# 93 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 93 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#ifdef _LIBCPP_NO_EXCEPTIONS
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#endif
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_VCRUNTIME)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 99 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#if 0 /* expanded by -frewrite-includes */
#include <new.h>
#endif /* expanded by -frewrite-includes */
# 99 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#endif
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 103 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#endif
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(__cpp_sized_deallocation) || __cpp_sized_deallocation  < 201309L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#define _LIBCPP_HAS_NO_LANGUAGE_SIZED_DEALLOCATION
#endif
# 109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_BUILDING_LIBRARY) && _LIBCPP_STD_VER < 14 && \
    defined(_LIBCPP_HAS_NO_LANGUAGE_SIZED_DEALLOCATION)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# define _LIBCPP_HAS_NO_LIBRARY_SIZED_DEALLOCATION
#endif
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_LIBRARY_SIZED_DEALLOCATION) || \
    defined(_LIBCPP_HAS_NO_LANGUAGE_SIZED_DEALLOCATION)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 117 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# define _LIBCPP_HAS_NO_SIZED_DEALLOCATION
#endif
# 119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#if 0 /* disabled by -frewrite-includes */
#if !__has_builtin(__builtin_operator_new) || \
   __has_builtin(__builtin_operator_new) < 201802L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#define _LIBCPP_HAS_NO_BUILTIN_OVERLOADED_OPERATOR_NEW_DELETE
#endif
# 124 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

namespace std  // purposefully not using versioning namespace
{

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_ABI_VCRUNTIME)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 129 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
struct _LIBCPP_TYPE_VIS nothrow_t { explicit nothrow_t() = default; };
extern _LIBCPP_FUNC_VIS const nothrow_t nothrow;

class _LIBCPP_EXCEPTION_ABI bad_alloc
    : public exception
{
public:
    bad_alloc() _NOEXCEPT;
    virtual ~bad_alloc() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI bad_array_new_length
    : public bad_alloc
{
public:
    bad_array_new_length() _NOEXCEPT;
    virtual ~bad_array_new_length() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

typedef void (*new_handler)();
_LIBCPP_FUNC_VIS new_handler set_new_handler(new_handler) _NOEXCEPT;
_LIBCPP_FUNC_VIS new_handler get_new_handler() _NOEXCEPT;

#endif // !_LIBCPP_ABI_VCRUNTIME
# 155 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void __throw_bad_alloc();  // not in C++ spec

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_LIBRARY_ALIGNED_ALLOCATION) && \
    !defined(_LIBCPP_ABI_VCRUNTIME)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 160 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#ifndef _LIBCPP_CXX03_LANG
enum class _LIBCPP_ENUM_VIS align_val_t : size_t { };
#else
# 163 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
enum align_val_t { __zero = 0, __max = (size_t)-1 };
#endif
# 165 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#endif
# 166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 168 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
// Enable the declaration even if the compiler doesn't support the language
// feature.
struct destroying_delete_t {
  explicit destroying_delete_t() = default;
};
_LIBCPP_INLINE_VAR constexpr destroying_delete_t destroying_delete{};
#endif // _LIBCPP_STD_VER > 17
# 175 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

}  // std

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 179 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#define _THROW_BAD_ALLOC throw(std::bad_alloc)
#else
# 181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#define _THROW_BAD_ALLOC
#endif
# 183 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_ABI_VCRUNTIME)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 185 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_OVERRIDABLE_FUNC_VIS void* operator new(std::size_t __sz) _THROW_BAD_ALLOC;
_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_OVERRIDABLE_FUNC_VIS void* operator new(std::size_t __sz, const std::nothrow_t&) _NOEXCEPT _LIBCPP_NOALIAS;
_LIBCPP_OVERRIDABLE_FUNC_VIS void  operator delete(void* __p) _NOEXCEPT;
_LIBCPP_OVERRIDABLE_FUNC_VIS void  operator delete(void* __p, const std::nothrow_t&) _NOEXCEPT;
#ifndef _LIBCPP_HAS_NO_LIBRARY_SIZED_DEALLOCATION
_LIBCPP_OVERRIDABLE_FUNC_VIS _LIBCPP_AVAILABILITY_SIZED_NEW_DELETE void  operator delete(void* __p, std::size_t __sz) _NOEXCEPT;
#endif
# 193 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_OVERRIDABLE_FUNC_VIS void* operator new[](std::size_t __sz) _THROW_BAD_ALLOC;
_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_OVERRIDABLE_FUNC_VIS void* operator new[](std::size_t __sz, const std::nothrow_t&) _NOEXCEPT _LIBCPP_NOALIAS;
_LIBCPP_OVERRIDABLE_FUNC_VIS void  operator delete[](void* __p) _NOEXCEPT;
_LIBCPP_OVERRIDABLE_FUNC_VIS void  operator delete[](void* __p, const std::nothrow_t&) _NOEXCEPT;
#ifndef _LIBCPP_HAS_NO_LIBRARY_SIZED_DEALLOCATION
_LIBCPP_OVERRIDABLE_FUNC_VIS _LIBCPP_AVAILABILITY_SIZED_NEW_DELETE void  operator delete[](void* __p, std::size_t __sz) _NOEXCEPT;
#endif
# 201 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

#ifndef _LIBCPP_HAS_NO_LIBRARY_ALIGNED_ALLOCATION
_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_OVERRIDABLE_FUNC_VIS void* operator new(std::size_t __sz, std::align_val_t) _THROW_BAD_ALLOC;
_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_OVERRIDABLE_FUNC_VIS void* operator new(std::size_t __sz, std::align_val_t, const std::nothrow_t&) _NOEXCEPT _LIBCPP_NOALIAS;
_LIBCPP_OVERRIDABLE_FUNC_VIS void  operator delete(void* __p, std::align_val_t) _NOEXCEPT;
_LIBCPP_OVERRIDABLE_FUNC_VIS void  operator delete(void* __p, std::align_val_t, const std::nothrow_t&) _NOEXCEPT;
#ifndef _LIBCPP_HAS_NO_LIBRARY_SIZED_DEALLOCATION
_LIBCPP_OVERRIDABLE_FUNC_VIS _LIBCPP_AVAILABILITY_SIZED_NEW_DELETE void  operator delete(void* __p, std::size_t __sz, std::align_val_t) _NOEXCEPT;
#endif
# 210 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_OVERRIDABLE_FUNC_VIS void* operator new[](std::size_t __sz, std::align_val_t) _THROW_BAD_ALLOC;
_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_OVERRIDABLE_FUNC_VIS void* operator new[](std::size_t __sz, std::align_val_t, const std::nothrow_t&) _NOEXCEPT _LIBCPP_NOALIAS;
_LIBCPP_OVERRIDABLE_FUNC_VIS void  operator delete[](void* __p, std::align_val_t) _NOEXCEPT;
_LIBCPP_OVERRIDABLE_FUNC_VIS void  operator delete[](void* __p, std::align_val_t, const std::nothrow_t&) _NOEXCEPT;
#ifndef _LIBCPP_HAS_NO_LIBRARY_SIZED_DEALLOCATION
_LIBCPP_OVERRIDABLE_FUNC_VIS _LIBCPP_AVAILABILITY_SIZED_NEW_DELETE void  operator delete[](void* __p, std::size_t __sz, std::align_val_t) _NOEXCEPT;
#endif
# 218 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#endif
# 219 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

_LIBCPP_NODISCARD_AFTER_CXX17 inline _LIBCPP_INLINE_VISIBILITY void* operator new  (std::size_t, void* __p) _NOEXCEPT {return __p;}
_LIBCPP_NODISCARD_AFTER_CXX17 inline _LIBCPP_INLINE_VISIBILITY void* operator new[](std::size_t, void* __p) _NOEXCEPT {return __p;}
inline _LIBCPP_INLINE_VISIBILITY void  operator delete  (void*, void*) _NOEXCEPT {}
inline _LIBCPP_INLINE_VISIBILITY void  operator delete[](void*, void*) _NOEXCEPT {}

#endif // !_LIBCPP_ABI_VCRUNTIME
# 226 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

_LIBCPP_BEGIN_NAMESPACE_STD

_LIBCPP_CONSTEXPR inline _LIBCPP_INLINE_VISIBILITY bool __is_overaligned_for_new(size_t __align) _NOEXCEPT {
#ifdef __STDCPP_DEFAULT_NEW_ALIGNMENT__
  return __align > __STDCPP_DEFAULT_NEW_ALIGNMENT__;
#else
# 233 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  return __align > alignment_of<max_align_t>::value;
#endif
# 235 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
}

inline _LIBCPP_INLINE_VISIBILITY void *__libcpp_allocate(size_t __size, size_t __align) {
#ifndef _LIBCPP_HAS_NO_ALIGNED_ALLOCATION
  if (__is_overaligned_for_new(__align)) {
    const align_val_t __align_val = static_cast<align_val_t>(__align);
# ifdef _LIBCPP_HAS_NO_BUILTIN_OVERLOADED_OPERATOR_NEW_DELETE
    return ::operator new(__size, __align_val);
# else
# 244 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return __builtin_operator_new(__size, __align_val);
# endif
# 246 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  }
#else
# 248 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  ((void)__align);
#endif
# 250 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
#ifdef _LIBCPP_HAS_NO_BUILTIN_OPERATOR_NEW_DELETE
  return ::operator new(__size);
#else
# 253 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  return __builtin_operator_new(__size);
#endif
# 255 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
}

struct _DeallocateCaller {
  static inline _LIBCPP_INLINE_VISIBILITY
  void __do_deallocate_handle_size_align(void *__ptr, size_t __size, size_t __align) {
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_ALIGNED_ALLOCATION)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 261 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    ((void)__align);
    return __do_deallocate_handle_size(__ptr, __size);
#else
# 264 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    if (__is_overaligned_for_new(__align)) {
      const align_val_t __align_val = static_cast<align_val_t>(__align);
      return __do_deallocate_handle_size(__ptr, __size, __align_val);
    } else {
      return __do_deallocate_handle_size(__ptr, __size);
    }
#endif
# 271 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  }

  static inline _LIBCPP_INLINE_VISIBILITY
  void __do_deallocate_handle_align(void *__ptr, size_t __align) {
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_ALIGNED_ALLOCATION)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 276 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    ((void)__align);
    return __do_call(__ptr);
#else
# 279 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    if (__is_overaligned_for_new(__align)) {
      const align_val_t __align_val = static_cast<align_val_t>(__align);
      return __do_call(__ptr, __align_val);
    } else {
      return __do_call(__ptr);
    }
#endif
# 286 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  }

 private:
  static inline void __do_deallocate_handle_size(void *__ptr, size_t __size) {
#ifdef _LIBCPP_HAS_NO_SIZED_DEALLOCATION
    ((void)__size);
    return __do_call(__ptr);
#else
# 294 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return __do_call(__ptr, __size);
#endif
# 296 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  }

#ifndef _LIBCPP_HAS_NO_ALIGNED_ALLOCATION
  static inline void __do_deallocate_handle_size(void *__ptr, size_t __size, align_val_t __align) {
#ifdef _LIBCPP_HAS_NO_SIZED_DEALLOCATION
    ((void)__size);
    return __do_call(__ptr, __align);
#else
# 304 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return __do_call(__ptr, __size, __align);
#endif
# 306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  }
#endif
# 308 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

private:
  template <class _A1, class _A2>
  static inline void __do_call(void *__ptr, _A1 __a1, _A2 __a2) {
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_BUILTIN_OPERATOR_NEW_DELETE) || \
    defined(_LIBCPP_HAS_NO_BUILTIN_OVERLOADED_OPERATOR_NEW_DELETE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 314 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return ::operator delete(__ptr, __a1, __a2);
#else
# 316 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return __builtin_operator_delete(__ptr, __a1, __a2);
#endif
# 318 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  }

  template <class _A1>
  static inline void __do_call(void *__ptr, _A1 __a1) {
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_BUILTIN_OPERATOR_NEW_DELETE) || \
    defined(_LIBCPP_HAS_NO_BUILTIN_OVERLOADED_OPERATOR_NEW_DELETE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 324 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return ::operator delete(__ptr, __a1);
#else
# 326 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return __builtin_operator_delete(__ptr, __a1);
#endif
# 328 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  }

  static inline void __do_call(void *__ptr) {
#ifdef _LIBCPP_HAS_NO_BUILTIN_OPERATOR_NEW_DELETE
    return ::operator delete(__ptr);
#else
# 334 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return __builtin_operator_delete(__ptr);
#endif
# 336 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
  }
};

inline _LIBCPP_INLINE_VISIBILITY void __libcpp_deallocate(void* __ptr, size_t __size, size_t __align) {
  _DeallocateCaller::__do_deallocate_handle_size_align(__ptr, __size, __align);
}

inline _LIBCPP_INLINE_VISIBILITY void __libcpp_deallocate_unsized(void* __ptr, size_t __align) {
  _DeallocateCaller::__do_deallocate_handle_align(__ptr, __align);
}

template <class _Tp>
_LIBCPP_NODISCARD_AFTER_CXX17 inline
_LIBCPP_CONSTEXPR _Tp* __launder(_Tp* __p) _NOEXCEPT
{
    static_assert (!(is_function<_Tp>::value), "can't launder functions" );
    static_assert (!(is_same<void, typename remove_cv<_Tp>::type>::value), "can't launder cv-void" );
#ifdef _LIBCPP_COMPILER_HAS_BUILTIN_LAUNDER
    return __builtin_launder(__p);
#else
# 356 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
    return __p;
#endif
# 358 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
}


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 362 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
template <class _Tp>
_LIBCPP_NODISCARD_AFTER_CXX17 inline _LIBCPP_INLINE_VISIBILITY
constexpr _Tp* launder(_Tp* __p) noexcept
{
    return _VSTD::__launder(__p);
}
#endif
# 369 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_NEW
# 373 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/new" 3
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h" 2
#endif
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#if 0 /* expanded by -frewrite-includes */
#include <stddef.h>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 1 3
// -*- C++ -*-
//===--------------------------- stddef.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_ptrdiff_t) || defined(__need_size_t) || \
    defined(__need_wchar_t) || defined(__need_NULL) || defined(__need_wint_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 12 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
#endif
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stddef.h>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDDEF_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
#define _LIBCPP_STDDEF_H

/*
    stddef.h synopsis

Macros:

    offsetof(type,member-designator)
    NULL

Types:

    ptrdiff_t
    size_t
    max_align_t
    nullptr_t

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 39 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
# 40 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 43 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
#endif
# 44 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stddef.h>
#endif /* expanded by -frewrite-includes */
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 1 3
/*===---- stddef.h - Basic type definitions --------------------------------===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#if 0 /* disabled by -frewrite-includes */
#if !defined(__STDDEF_H) || defined(__need_ptrdiff_t) ||                       \
    defined(__need_size_t) || defined(__need_wchar_t) ||                       \
    defined(__need_NULL) || defined(__need_wint_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(__need_ptrdiff_t) && !defined(__need_size_t) &&                   \
    !defined(__need_wchar_t) && !defined(__need_NULL) &&                       \
    !defined(__need_wint_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define miscellaneous pieces when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define __STDDEF_H
#endif
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define __need_ptrdiff_t
#define __need_size_t
#define __need_wchar_t
#define __need_NULL
#define __need_STDDEF_H_misc
/* __need_wint_t is intentionally not defined here. */
#endif
# 28 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_ptrdiff_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 30 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if !defined(_PTRDIFF_T) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define ptrdiff_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 33 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _PTRDIFF_T
#endif
# 35 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __PTRDIFF_TYPE__ ptrdiff_t;
#endif
# 37 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_ptrdiff_t
#endif /* defined(__need_ptrdiff_t) */
# 39 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_size_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 41 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if !defined(_SIZE_T) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 42 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define size_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _SIZE_T
#endif
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __SIZE_TYPE__ size_t;
#endif
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_size_t
#endif /*defined(__need_size_t) */
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_STDDEF_H_misc)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 52 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* ISO9899:2011 7.20 (C11 Annex K): Define rsize_t if __STDC_WANT_LIB_EXT1__ is
 * enabled. */
#if 0 /* disabled by -frewrite-includes */
#if (defined(__STDC_WANT_LIB_EXT1__) && __STDC_WANT_LIB_EXT1__ >= 1 && \
     !defined(_RSIZE_T)) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 56 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define rsize_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _RSIZE_T
#endif
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __SIZE_TYPE__ rsize_t;
#endif
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif /* defined(__need_STDDEF_H_misc) */
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_wchar_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#ifndef __cplusplus
/* Always define wchar_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_WCHAR_T) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 68 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _WCHAR_T
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_EXTENSIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 71 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _WCHAR_T_DEFINED
#endif
# 73 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif
# 74 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __WCHAR_TYPE__ wchar_t;
#endif
# 76 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif
# 77 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_wchar_t
#endif /* defined(__need_wchar_t) */
# 79 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_NULL)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 81 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef NULL
#ifdef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#  if !defined(__MINGW32__) && !defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 84 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#    define NULL __null
#  else
# 86 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#    define NULL 0
#  endif
# 88 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#else
# 89 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#  define NULL ((void*)0)
#endif
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#ifdef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_EXTENSIONS) && defined(_NATIVE_NULLPTR_SUPPORTED)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 93 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
namespace std { typedef decltype(nullptr) nullptr_t; }
using ::std::nullptr_t;
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_NULL
#endif /* defined(__need_NULL) */
# 99 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_STDDEF_H_misc)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if __STDC_VERSION__ >= 201112L || __cplusplus >= 201103L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* expanded by -frewrite-includes */
#include "__stddef_max_align_t.h"
#endif /* expanded by -frewrite-includes */
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
# 103 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#endif
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define offsetof(t, d) __builtin_offsetof(t, d)
#undef __need_STDDEF_H_misc
#endif  /* defined(__need_STDDEF_H_misc) */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

/* Some C libraries expect to see a wint_t here. Others (notably MinGW) will use
__WINT_TYPE__ directly; accommodate both by requiring __need_wint_t */
#if 0 /* disabled by -frewrite-includes */
#if defined(__need_wint_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
/* Always define wint_t when modules are available. */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_WINT_T) || __has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 113 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#if 0 /* disabled by -frewrite-includes */
#if !__has_feature(modules)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#define _WINT_T
#endif
# 116 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
typedef __WINT_TYPE__ wint_t;
#endif
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
#undef __need_wint_t
#endif /* __need_wint_t */
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3

#endif
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stddef.h" 3
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 2 3

#ifdef __cplusplus

extern "C++" {
#if 0 /* expanded by -frewrite-includes */
#include <__nullptr>
#endif /* expanded by -frewrite-includes */
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
# 51 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
using std::nullptr_t;
}

// Re-use the compiler's <stddef.h> max_align_t where possible.
#if 0 /* disabled by -frewrite-includes */
#if !defined(__CLANG_MAX_ALIGN_T_DEFINED) && !defined(_GCC_MAX_ALIGN_T) && \
    !defined(__DEFINED_max_align_t) && !defined(__NetBSD__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
typedef long double max_align_t;
#endif
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3

#endif
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3

#endif  // _LIBCPP_STDDEF_H
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stddef.h" 3
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h" 2

#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#if 0 /* expanded by -frewrite-includes */
#include <sal.h>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#endif
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#ifndef __has_feature
# define __has_feature(x) 0
#endif
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#ifndef __has_extension
# define __has_extension(x) 0
#endif
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#ifndef __has_attribute
# define __has_attribute(x) 0
#endif
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#ifndef __has_builtin
# define __has_builtin(x) 0
#endif
# 44 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

// Only use __has_cpp_attribute in C++ mode. GCC defines __has_cpp_attribute in
// C mode, but the :: in __has_cpp_attribute(scoped::attribute) is invalid.
#ifndef LLVM_HAS_CPP_ATTRIBUTE
#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && defined(__has_cpp_attribute)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 49 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_HAS_CPP_ATTRIBUTE(x) __has_cpp_attribute(x)
#else
# 51 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_HAS_CPP_ATTRIBUTE(x) 0
#endif
# 53 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#endif
# 54 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_GNUC_PREREQ
/// Extend the default __GNUC_PREREQ even if glibc's features.h isn't
/// available.
#ifndef LLVM_GNUC_PREREQ
#if 0 /* disabled by -frewrite-includes */
# if defined(__GNUC__) && defined(__GNUC_MINOR__) && defined(__GNUC_PATCHLEVEL__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 60 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#  define LLVM_GNUC_PREREQ(maj, min, patch) \
    ((__GNUC__ << 20) + (__GNUC_MINOR__ << 10) + __GNUC_PATCHLEVEL__ >= \
     ((maj) << 20) + ((min) << 10) + (patch))
#if 0 /* disabled by -frewrite-includes */
#if 0
# elif defined(__GNUC__) && defined(__GNUC_MINOR__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 64 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#  define LLVM_GNUC_PREREQ(maj, min, patch) \
    ((__GNUC__ << 20) + (__GNUC_MINOR__ << 10) >= ((maj) << 20) + ((min) << 10))
# else
# 67 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#  define LLVM_GNUC_PREREQ(maj, min, patch) 0
# endif
# 69 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#endif
# 70 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_MSC_PREREQ
/// Is the compiler MSVC of at least the specified version?
/// The common \param version values to check for are:
/// * 1910: VS2017, version 15.1 & 15.2
/// * 1911: VS2017, version 15.3 & 15.4
/// * 1912: VS2017, version 15.5
/// * 1913: VS2017, version 15.6
/// * 1914: VS2017, version 15.7
/// * 1915: VS2017, version 15.8
/// * 1916: VS2017, version 15.9
/// * 1920: VS2019, version 16.0
/// * 1921: VS2019, version 16.1
#ifdef _MSC_VER
#define LLVM_MSC_PREREQ(version) (_MSC_VER >= (version))

// We require at least MSVC 2017.
#if 0 /* disabled by -frewrite-includes */
#if !LLVM_MSC_PREREQ(1910)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 88 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#error LLVM requires at least MSVC 2017.
#endif
# 90 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#else
# 92 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_MSC_PREREQ(version) 0
#endif
# 94 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// Does the compiler support ref-qualifiers for *this?
///
/// Sadly, this is separate from just rvalue reference support because GCC
/// and MSVC implemented this later than everything else. This appears to be
/// corrected in MSVC 2019 but not MSVC 2017.
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_rvalue_references) || LLVM_GNUC_PREREQ(4, 8, 1)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 101 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_HAS_RVALUE_REFERENCE_THIS 1
#else
# 103 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_HAS_RVALUE_REFERENCE_THIS 0
#endif
# 105 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// Expands to '&' if ref-qualifiers for *this are supported.
///
/// This can be used to provide lvalue/rvalue overrides of member functions.
/// The rvalue override should be guarded by LLVM_HAS_RVALUE_REFERENCE_THIS
#if 0 /* disabled by -frewrite-includes */
#if LLVM_HAS_RVALUE_REFERENCE_THIS
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 111 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_LVALUE_FUNCTION &
#else
# 113 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_LVALUE_FUNCTION
#endif
# 115 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_LIBRARY_VISIBILITY - If a class marked with this attribute is linked
/// into a shared library, then the class should be private to the library and
/// not accessible from outside it.  Can also be used to mark variables and
/// functions, making them private to any shared library they are linked into.
/// On PE/COFF targets, library visibility is the default, so this isn't needed.
///
/// LLVM_EXTERNAL_VISIBILITY - classes, functions, and variables marked with
/// this attribute will be made public and visible outside of any shared library
/// they are linked in to.
#if 0 /* disabled by -frewrite-includes */
#if (__has_attribute(visibility) || LLVM_GNUC_PREREQ(4, 0, 0)) &&              \
    !defined(__MINGW32__) && !defined(__CYGWIN__) && !defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 127 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_LIBRARY_VISIBILITY __attribute__ ((visibility("hidden")))
#define LLVM_EXTERNAL_VISIBILITY __attribute__ ((visibility("default")))
#else
# 130 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_LIBRARY_VISIBILITY
#define LLVM_EXTERNAL_VISIBILITY
#endif
# 133 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 135 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_PREFETCH(addr, rw, locality) __builtin_prefetch(addr, rw, locality)
#else
# 137 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_PREFETCH(addr, rw, locality)
#endif
# 139 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(used) || LLVM_GNUC_PREREQ(3, 1, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 141 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_USED __attribute__((__used__))
#else
# 143 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_USED
#endif
# 145 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_NODISCARD - Warn if a type or return value is discarded.

// Use the 'nodiscard' attribute in C++17 or newer mode.
#if 0 /* disabled by -frewrite-includes */
#if __cplusplus > 201402L && LLVM_HAS_CPP_ATTRIBUTE(nodiscard)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 150 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_NODISCARD [[nodiscard]]
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif LLVM_HAS_CPP_ATTRIBUTE(clang::warn_unused_result)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 152 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_NODISCARD [[clang::warn_unused_result]]
// Clang in C++14 mode claims that it has the 'nodiscard' attribute, but also
// warns in the pedantic mode that 'nodiscard' is a C++17 extension (PR33518).
// Use the 'nodiscard' attribute in C++14 mode only with GCC.
// TODO: remove this workaround when PR33518 is resolved.
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__) && LLVM_HAS_CPP_ATTRIBUTE(nodiscard)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 158 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_NODISCARD [[nodiscard]]
#else
# 160 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_NODISCARD
#endif
# 162 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

// Indicate that a non-static, non-const C++ member function reinitializes
// the entire object to a known state, independent of the previous state of
// the object.
//
// The clang-tidy check bugprone-use-after-move recognizes this attribute as a
// marker that a moved-from object has left the indeterminate state and can be
// reused.
#if 0 /* disabled by -frewrite-includes */
#if LLVM_HAS_CPP_ATTRIBUTE(clang::reinitializes)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 171 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_REINITIALIZES [[clang::reinitializes]]
#else
# 173 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_REINITIALIZES
#endif
# 175 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

// Some compilers warn about unused functions. When a function is sometimes
// used or not depending on build settings (e.g. a function only called from
// within "assert"), this attribute can be used to suppress such warnings.
//
// However, it shouldn't be used for unused *variables*, as those have a much
// more portable solution:
//   (void)unused_var_name;
// Prefer cast-to-void wherever it is sufficient.
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(unused) || LLVM_GNUC_PREREQ(3, 1, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 185 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_UNUSED __attribute__((__unused__))
#else
# 187 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_UNUSED
#endif
# 189 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

// FIXME: Provide this for PE/COFF targets.
#if 0 /* disabled by -frewrite-includes */
#if (__has_attribute(weak) || LLVM_GNUC_PREREQ(4, 0, 0)) &&                    \
    (!defined(__MINGW32__) && !defined(__CYGWIN__) && !defined(_WIN32))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 193 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_WEAK __attribute__((__weak__))
#else
# 195 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_WEAK
#endif
# 197 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

// Prior to clang 3.2, clang did not accept any spelling of
// __has_attribute(const), so assume it is supported.
#if 0 /* disabled by -frewrite-includes */
#if defined(__clang__) || defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 201 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// aka 'CONST' but following LLVM Conventions.
#define LLVM_READNONE __attribute__((__const__))
#else
# 204 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_READNONE
#endif
# 206 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(pure) || defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 208 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// aka 'PURE' but following LLVM Conventions.
#define LLVM_READONLY __attribute__((__pure__))
#else
# 211 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_READONLY
#endif
# 213 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_expect) || LLVM_GNUC_PREREQ(4, 0, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 215 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_LIKELY(EXPR) __builtin_expect((bool)(EXPR), true)
#define LLVM_UNLIKELY(EXPR) __builtin_expect((bool)(EXPR), false)
#else
# 218 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_LIKELY(EXPR) (EXPR)
#define LLVM_UNLIKELY(EXPR) (EXPR)
#endif
# 221 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_ATTRIBUTE_NOINLINE - On compilers where we have a directive to do so,
/// mark a method "not for inlining".
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(noinline) || LLVM_GNUC_PREREQ(3, 4, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 225 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_NOINLINE __attribute__((noinline))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 227 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_NOINLINE __declspec(noinline)
#else
# 229 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_NOINLINE
#endif
# 231 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_ATTRIBUTE_ALWAYS_INLINE - On compilers where we have a directive to do
/// so, mark a method "always inline" because it is performance sensitive. GCC
/// 3.4 supported this but is buggy in various cases and produces unimplemented
/// errors, just use it in GCC 4.0 and later.
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(always_inline) || LLVM_GNUC_PREREQ(4, 0, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 237 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_ALWAYS_INLINE __attribute__((always_inline))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 239 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_ALWAYS_INLINE __forceinline
#else
# 241 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_ALWAYS_INLINE
#endif
# 243 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#ifdef __GNUC__
#define LLVM_ATTRIBUTE_NORETURN __attribute__((noreturn))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 247 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_NORETURN __declspec(noreturn)
#else
# 249 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_NORETURN
#endif
# 251 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(returns_nonnull) || LLVM_GNUC_PREREQ(4, 9, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 253 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_RETURNS_NONNULL __attribute__((returns_nonnull))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 255 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_RETURNS_NONNULL _Ret_notnull_
#else
# 257 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_RETURNS_NONNULL
#endif
# 259 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_ATTRIBUTE_RETURNS_NOALIAS Used to mark a function as returning a
/// pointer that does not alias any other valid pointer.
#ifdef __GNUC__
#define LLVM_ATTRIBUTE_RETURNS_NOALIAS __attribute__((__malloc__))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 265 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_RETURNS_NOALIAS __declspec(restrict)
#else
# 267 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ATTRIBUTE_RETURNS_NOALIAS
#endif
# 269 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_FALLTHROUGH - Mark fallthrough cases in switch statements.
#if 0 /* disabled by -frewrite-includes */
#if __cplusplus > 201402L && LLVM_HAS_CPP_ATTRIBUTE(fallthrough)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 272 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_FALLTHROUGH [[fallthrough]]
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif LLVM_HAS_CPP_ATTRIBUTE(gnu::fallthrough)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 274 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_FALLTHROUGH [[gnu::fallthrough]]
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __has_attribute(fallthrough)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 276 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_FALLTHROUGH __attribute__((fallthrough))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif LLVM_HAS_CPP_ATTRIBUTE(clang::fallthrough)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 278 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_FALLTHROUGH [[clang::fallthrough]]
#else
# 280 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_FALLTHROUGH
#endif
# 282 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_REQUIRE_CONSTANT_INITIALIZATION - Apply this to globals to ensure that
/// they are constant initialized.
#if 0 /* disabled by -frewrite-includes */
#if LLVM_HAS_CPP_ATTRIBUTE(clang::require_constant_initialization)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 286 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_REQUIRE_CONSTANT_INITIALIZATION                                   \
  [[clang::require_constant_initialization]]
#else
# 289 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_REQUIRE_CONSTANT_INITIALIZATION
#endif
# 291 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_EXTENSION - Support compilers where we have a keyword to suppress
/// pedantic diagnostics.
#ifdef __GNUC__
#define LLVM_EXTENSION __extension__
#else
# 297 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_EXTENSION
#endif
# 299 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

// LLVM_ATTRIBUTE_DEPRECATED(decl, "message")
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(attribute_deprecated_with_message)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 302 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_ATTRIBUTE_DEPRECATED(decl, message) \
  decl __attribute__((deprecated(message)))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 305 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_ATTRIBUTE_DEPRECATED(decl, message) \
  decl __attribute__((deprecated))
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 308 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_ATTRIBUTE_DEPRECATED(decl, message) \
  __declspec(deprecated(message)) decl
#else
# 311 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_ATTRIBUTE_DEPRECATED(decl, message) \
  decl
#endif
# 314 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_BUILTIN_UNREACHABLE - On compilers which support it, expands
/// to an expression which states that it is undefined behavior for the
/// compiler to reach this point.  Otherwise is not defined.
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_unreachable) || LLVM_GNUC_PREREQ(4, 5, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 319 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_BUILTIN_UNREACHABLE __builtin_unreachable()
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 321 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_BUILTIN_UNREACHABLE __assume(false)
#endif
# 323 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_BUILTIN_TRAP - On compilers which support it, expands to an expression
/// which causes the program to exit abnormally.
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_trap) || LLVM_GNUC_PREREQ(4, 3, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 327 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_BUILTIN_TRAP __builtin_trap()
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 329 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// The __debugbreak intrinsic is supported by MSVC, does not require forward
// declarations involving platform-specific typedefs (unlike RaiseException),
// results in a call to vectored exception handlers, and encodes to a short
// instruction that still causes the trapping behavior we want.
# define LLVM_BUILTIN_TRAP __debugbreak()
#else
# 335 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_BUILTIN_TRAP *(volatile int*)0x11 = 0
#endif
# 337 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// LLVM_BUILTIN_DEBUGTRAP - On compilers which support it, expands to
/// an expression which causes the program to break while running
/// under a debugger.
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_debugtrap)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 342 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_BUILTIN_DEBUGTRAP __builtin_debugtrap()
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 344 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// The __debugbreak intrinsic is supported by MSVC and breaks while
// running under the debugger, and also supports invoking a debugger
// when the OS is configured appropriately.
# define LLVM_BUILTIN_DEBUGTRAP __debugbreak()
#else
# 349 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// Just continue execution when built with compilers that have no
// support. This is a debugging aid and not intended to force the
// program to abort if encountered.
# define LLVM_BUILTIN_DEBUGTRAP
#endif
# 354 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_ASSUME_ALIGNED
/// Returns a pointer with an assumed alignment.
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_assume_aligned) || LLVM_GNUC_PREREQ(4, 7, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 358 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_ASSUME_ALIGNED(p, a) __builtin_assume_aligned(p, a)
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(LLVM_BUILTIN_UNREACHABLE)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 360 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// As of today, clang does not support __builtin_assume_aligned.
# define LLVM_ASSUME_ALIGNED(p, a) \
           (((uintptr_t(p) % (a)) == 0) ? (p) : (LLVM_BUILTIN_UNREACHABLE, (p)))
#else
# 364 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_ASSUME_ALIGNED(p, a) (p)
#endif
# 366 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_PACKED
/// Used to specify a packed structure.
/// LLVM_PACKED(
///    struct A {
///      int i;
///      int j;
///      int k;
///      long long l;
///   });
///
/// LLVM_PACKED_START
/// struct B {
///   int i;
///   int j;
///   int k;
///   long long l;
/// };
/// LLVM_PACKED_END
#ifdef _MSC_VER
# define LLVM_PACKED(d) __pragma(pack(push, 1)) d __pragma(pack(pop))
# define LLVM_PACKED_START __pragma(pack(push, 1))
# define LLVM_PACKED_END   __pragma(pack(pop))
#else
# 390 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_PACKED(d) d __attribute__((packed))
# define LLVM_PACKED_START _Pragma("pack(push, 1)")
# define LLVM_PACKED_END   _Pragma("pack(pop)")
#endif
# 394 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_PTR_SIZE
/// A constant integer equivalent to the value of sizeof(void*).
/// Generally used in combination with alignas or when doing computation in the
/// preprocessor.
#ifdef __SIZEOF_POINTER__
# define LLVM_PTR_SIZE __SIZEOF_POINTER__
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_WIN64)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 402 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_PTR_SIZE 8
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 404 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_PTR_SIZE 4
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 406 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# error "could not determine LLVM_PTR_SIZE as a constant int for MSVC"
#else
# 408 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_PTR_SIZE sizeof(void *)
#endif
# 410 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_MEMORY_SANITIZER_BUILD
/// Whether LLVM itself is built with MemorySanitizer instrumentation.
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(memory_sanitizer)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 414 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_MEMORY_SANITIZER_BUILD 1
#if 0 /* expanded by -frewrite-includes */
# include <sanitizer/msan_interface.h>
#endif /* expanded by -frewrite-includes */
# 415 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# 416 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_NO_SANITIZE_MEMORY_ATTRIBUTE __attribute__((no_sanitize_memory))
#else
# 418 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_MEMORY_SANITIZER_BUILD 0
# define __msan_allocated_memory(p, size)
# define __msan_unpoison(p, size)
# define LLVM_NO_SANITIZE_MEMORY_ATTRIBUTE
#endif
# 423 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_ADDRESS_SANITIZER_BUILD
/// Whether LLVM itself is built with AddressSanitizer instrumentation.
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(address_sanitizer) || defined(__SANITIZE_ADDRESS__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 427 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_ADDRESS_SANITIZER_BUILD 1
#if 0 /* expanded by -frewrite-includes */
# include <sanitizer/asan_interface.h>
#endif /* expanded by -frewrite-includes */
# 428 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# 429 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#else
# 430 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_ADDRESS_SANITIZER_BUILD 0
# define __asan_poison_memory_region(p, size)
# define __asan_unpoison_memory_region(p, size)
#endif
# 434 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_THREAD_SANITIZER_BUILD
/// Whether LLVM itself is built with ThreadSanitizer instrumentation.
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(thread_sanitizer) || defined(__SANITIZE_THREAD__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 438 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_THREAD_SANITIZER_BUILD 1
#else
# 440 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define LLVM_THREAD_SANITIZER_BUILD 0
#endif
# 442 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#if 0 /* disabled by -frewrite-includes */
#if LLVM_THREAD_SANITIZER_BUILD
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 444 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// Thread Sanitizer is a tool that finds races in code.
// See http://code.google.com/p/data-race-test/wiki/DynamicAnnotations .
// tsan detects these exact functions by name.
#ifdef __cplusplus
extern "C" {
#endif
# 450 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
void AnnotateHappensAfter(const char *file, int line, const volatile void *cv);
void AnnotateHappensBefore(const char *file, int line, const volatile void *cv);
void AnnotateIgnoreWritesBegin(const char *file, int line);
void AnnotateIgnoreWritesEnd(const char *file, int line);
#ifdef __cplusplus
}
#endif
# 457 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

// This marker is used to define a happens-before arc. The race detector will
// infer an arc from the begin to the end when they share the same pointer
// argument.
# define TsanHappensBefore(cv) AnnotateHappensBefore(__FILE__, __LINE__, cv)

// This marker defines the destination of a happens-before arc.
# define TsanHappensAfter(cv) AnnotateHappensAfter(__FILE__, __LINE__, cv)

// Ignore any races on writes between here and the next TsanIgnoreWritesEnd.
# define TsanIgnoreWritesBegin() AnnotateIgnoreWritesBegin(__FILE__, __LINE__)

// Resume checking for racy writes.
# define TsanIgnoreWritesEnd() AnnotateIgnoreWritesEnd(__FILE__, __LINE__)
#else
# 472 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# define TsanHappensBefore(cv)
# define TsanHappensAfter(cv)
# define TsanIgnoreWritesBegin()
# define TsanIgnoreWritesEnd()
#endif
# 477 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_NO_SANITIZE
/// Disable a particular sanitizer for a function.
#if 0 /* disabled by -frewrite-includes */
#if __has_attribute(no_sanitize)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 481 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_NO_SANITIZE(KIND) __attribute__((no_sanitize(KIND)))
#else
# 483 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_NO_SANITIZE(KIND)
#endif
# 485 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// Mark debug helper function definitions like dump() that should not be
/// stripped from debug builds.
/// Note that you should also surround dump() functions with
/// `#if !defined(NDEBUG) || defined(LLVM_ENABLE_DUMP)` so they do always
/// get stripped in release builds.
// FIXME: Move this to a private config.h as it's not usable in public headers.
#if 0 /* disabled by -frewrite-includes */
#if !defined(NDEBUG) || defined(LLVM_ENABLE_DUMP)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 493 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_DUMP_METHOD LLVM_ATTRIBUTE_NOINLINE LLVM_ATTRIBUTE_USED
#else
# 495 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_DUMP_METHOD LLVM_ATTRIBUTE_NOINLINE
#endif
# 497 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_PRETTY_FUNCTION
/// Gets a user-friendly looking function signature for the current scope
/// using the best available method on each platform.  The exact format of the
/// resulting string is implementation specific and non-portable, so this should
/// only be used, for example, for logging or diagnostics.
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 504 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_PRETTY_FUNCTION __FUNCSIG__
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__) || defined(__clang__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 506 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_PRETTY_FUNCTION __PRETTY_FUNCTION__
#else
# 508 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_PRETTY_FUNCTION __func__
#endif
# 510 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_THREAD_LOCAL
/// A thread-local storage specifier which can be used with globals,
/// extern globals, and static globals.
///
/// This is essentially an extremely restricted analog to C++11's thread_local
/// support. It uses thread_local if available, falling back on gcc __thread
/// if not. __thread doesn't support many of the C++11 thread_local's
/// features. You should only use this for PODs that you can statically
/// initialize to some constant value. In almost all circumstances this is most
/// appropriate for use with a pointer, integer, or small aggregation of
/// pointers and integers.
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_THREADS
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 523 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_thread_local) || defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 524 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_THREAD_LOCAL thread_local
#else
# 526 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// Clang, GCC, and other compatible compilers used __thread prior to C++11 and
// we only need the restricted functionality that provides.
#define LLVM_THREAD_LOCAL __thread
#endif
# 530 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#else // !LLVM_ENABLE_THREADS
# 531 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
// If threading is disabled entirely, this compiles to nothing and you get
// a normal global variable.
#define LLVM_THREAD_LOCAL
#endif
# 535 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

/// \macro LLVM_ENABLE_EXCEPTIONS
/// Whether LLVM is built with exception support.
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_exceptions)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 539 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ENABLE_EXCEPTIONS 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GNUC__) && defined(__EXCEPTIONS)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 541 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ENABLE_EXCEPTIONS 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER) && defined(_CPPUNWIND)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 543 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#define LLVM_ENABLE_EXCEPTIONS 1
#endif
# 545 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"

#ifdef __cplusplus
namespace llvm {

/// Allocate a buffer of memory with the given size and alignment.
///
/// When the compiler supports aligned operator new, this will use it to to
/// handle even over-aligned allocations.
///
/// However, this doesn't make any attempt to leverage the fancier techniques
/// like posix_memalign due to portability. It is mostly intended to allow
/// compatibility with platforms that, after aligned allocation was added, use
/// reduced default alignment.
inline void *allocate_buffer(size_t Size, size_t Alignment) {
  return ::operator new(Size
#ifdef __cpp_aligned_new
                        ,
                        std::align_val_t(Alignment)
#endif
# 564 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
  );
}

/// Deallocate a buffer of memory with the given size and alignment.
///
/// If supported, this will used the sized delete operator. Also if supported,
/// this will pass the alignment to the delete operator.
///
/// The pointer must have been allocated with the corresponding new operator,
/// most likely using the above helper.
inline void deallocate_buffer(void *Ptr, size_t Size, size_t Alignment) {
  ::operator delete(Ptr
#ifdef __cpp_sized_deallocation
                    ,
                    Size
#endif
# 580 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#ifdef __cpp_aligned_new
                    ,
                    std::align_val_t(Alignment)
#endif
# 584 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
  );
}

} // End namespace llvm

#endif // __cplusplus
# 590 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
#endif
# 591 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Compiler.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/type_traits.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h" 1
//===- llvm/Support/type_traits.h - Simplfied type traits -------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file provides useful additions to the standard type_traits library.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_TYPE_TRAITS_H
#define LLVM_SUPPORT_TYPE_TRAITS_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 1 3
// -*- C++ -*-
//===-------------------------- utility -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_UTILITY
#define _LIBCPP_UTILITY

/*
    utility synopsis

#include <initializer_list>

namespace std
{

template <class T>
    void
    swap(T& a, T& b);

namespace rel_ops
{
    template<class T> bool operator!=(const T&, const T&);
    template<class T> bool operator> (const T&, const T&);
    template<class T> bool operator<=(const T&, const T&);
    template<class T> bool operator>=(const T&, const T&);
}

template<class T>
void
swap(T& a, T& b) noexcept(is_nothrow_move_constructible<T>::value &&
                          is_nothrow_move_assignable<T>::value);

template <class T, size_t N>
void
swap(T (&a)[N], T (&b)[N]) noexcept(noexcept(swap(*a, *b)));

template <class T> T&& forward(typename remove_reference<T>::type& t) noexcept;  // constexpr in C++14
template <class T> T&& forward(typename remove_reference<T>::type&& t) noexcept; // constexpr in C++14

template <class T> typename remove_reference<T>::type&& move(T&&) noexcept;      // constexpr in C++14

template <class T>
    typename conditional
    <
        !is_nothrow_move_constructible<T>::value && is_copy_constructible<T>::value,
        const T&,
        T&&
    >::type
    move_if_noexcept(T& x) noexcept; // constexpr in C++14

template <class T> constexpr add_const_t<T>& as_const(T& t) noexcept;      // C++17
template <class T>                      void as_const(const T&&) = delete; // C++17

template <class T> typename add_rvalue_reference<T>::type declval() noexcept;

template <class T1, class T2>
struct pair
{
    typedef T1 first_type;
    typedef T2 second_type;

    T1 first;
    T2 second;

    pair(const pair&) = default;
    pair(pair&&) = default;
    explicit(see-below) constexpr pair();
    explicit(see-below) pair(const T1& x, const T2& y);                          // constexpr in C++14
    template <class U, class V> explicit(see-below) pair(U&& x, V&& y);          // constexpr in C++14
    template <class U, class V> explicit(see-below) pair(const pair<U, V>& p);   // constexpr in C++14
    template <class U, class V> explicit(see-below) pair(pair<U, V>&& p);        // constexpr in C++14
    template <class... Args1, class... Args2>
        pair(piecewise_construct_t, tuple<Args1...> first_args,
             tuple<Args2...> second_args);

    template <class U, class V> pair& operator=(const pair<U, V>& p);
    pair& operator=(pair&& p) noexcept(is_nothrow_move_assignable<T1>::value &&
                                       is_nothrow_move_assignable<T2>::value);
    template <class U, class V> pair& operator=(pair<U, V>&& p);

    void swap(pair& p) noexcept(is_nothrow_swappable_v<T1> &&
                                is_nothrow_swappable_v<T2>);
};

template <class T1, class T2> bool operator==(const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator!=(const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator< (const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator> (const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator>=(const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator<=(const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14

template <class T1, class T2> pair<V1, V2> make_pair(T1&&, T2&&);   // constexpr in C++14
template <class T1, class T2>
void
swap(pair<T1, T2>& x, pair<T1, T2>& y) noexcept(noexcept(x.swap(y)));

struct piecewise_construct_t { explicit piecewise_construct_t() = default; };
inline constexpr piecewise_construct_t piecewise_construct = piecewise_construct_t();

template <class T> struct tuple_size;
template <size_t I, class T> struct tuple_element;

template <class T1, class T2> struct tuple_size<pair<T1, T2> >;
template <class T1, class T2> struct tuple_element<0, pair<T1, T2> >;
template <class T1, class T2> struct tuple_element<1, pair<T1, T2> >;

template<size_t I, class T1, class T2>
    typename tuple_element<I, pair<T1, T2> >::type&
    get(pair<T1, T2>&) noexcept; // constexpr in C++14

template<size_t I, class T1, class T2>
    const typename tuple_element<I, pair<T1, T2> >::type&
    get(const pair<T1, T2>&) noexcept; // constexpr in C++14

template<size_t I, class T1, class T2>
    typename tuple_element<I, pair<T1, T2> >::type&&
    get(pair<T1, T2>&&) noexcept; // constexpr in C++14

template<size_t I, class T1, class T2>
    const typename tuple_element<I, pair<T1, T2> >::type&&
    get(const pair<T1, T2>&&) noexcept; // constexpr in C++14

template<class T1, class T2>
    constexpr T1& get(pair<T1, T2>&) noexcept; // C++14

template<class T1, class T2>
    constexpr const T1& get(const pair<T1, T2>&) noexcept; // C++14

template<class T1, class T2>
    constexpr T1&& get(pair<T1, T2>&&) noexcept; // C++14

template<class T1, class T2>
    constexpr const T1&& get(const pair<T1, T2>&&) noexcept; // C++14

template<class T1, class T2>
    constexpr T1& get(pair<T2, T1>&) noexcept; // C++14

template<class T1, class T2>
    constexpr const T1& get(const pair<T2, T1>&) noexcept; // C++14

template<class T1, class T2>
    constexpr T1&& get(pair<T2, T1>&&) noexcept; // C++14

template<class T1, class T2>
    constexpr const T1&& get(const pair<T2, T1>&&) noexcept; // C++14

// C++14

template<class T, T... I>
struct integer_sequence
{
    typedef T value_type;

    static constexpr size_t size() noexcept;
};

template<size_t... I>
  using index_sequence = integer_sequence<size_t, I...>;

template<class T, T N>
  using make_integer_sequence = integer_sequence<T, 0, 1, ..., N-1>;
template<size_t N>
  using make_index_sequence = make_integer_sequence<size_t, N>;

template<class... T>
  using index_sequence_for = make_index_sequence<sizeof...(T)>;

template<class T, class U=T>
    T exchange(T& obj, U&& new_value);

// 20.2.7, in-place construction // C++17
struct in_place_t {
  explicit in_place_t() = default;
};
inline constexpr in_place_t in_place{};
template <class T>
  struct in_place_type_t {
    explicit in_place_type_t() = default;
  };
template <class T>
  inline constexpr in_place_type_t<T> in_place_type{};
template <size_t I>
  struct in_place_index_t {
    explicit in_place_index_t() = default;
  };
template <size_t I>
  inline constexpr in_place_index_t<I> in_place_index{};

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 198 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 199 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
#if 0 /* expanded by -frewrite-includes */
#include <__tuple>
#endif /* expanded by -frewrite-includes */
# 199 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___TUPLE
#define _LIBCPP___TUPLE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3


_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Tp> struct _LIBCPP_TEMPLATE_VIS tuple_size;

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
template <class _Tp, class...>
using __enable_if_tuple_size_imp = _Tp;

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_size<__enable_if_tuple_size_imp<
    const _Tp,
    typename enable_if<!is_volatile<_Tp>::value>::type,
    integral_constant<size_t, sizeof(tuple_size<_Tp>)>>>
    : public integral_constant<size_t, tuple_size<_Tp>::value> {};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_size<__enable_if_tuple_size_imp<
    volatile _Tp,
    typename enable_if<!is_const<_Tp>::value>::type,
    integral_constant<size_t, sizeof(tuple_size<_Tp>)>>>
    : public integral_constant<size_t, tuple_size<_Tp>::value> {};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_size<__enable_if_tuple_size_imp<
    const volatile _Tp,
    integral_constant<size_t, sizeof(tuple_size<_Tp>)>>>
    : public integral_constant<size_t, tuple_size<_Tp>::value> {};

#else
# 51 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS tuple_size<const _Tp> : public tuple_size<_Tp> {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS tuple_size<volatile _Tp> : public tuple_size<_Tp> {};
template <class _Tp> struct _LIBCPP_TEMPLATE_VIS tuple_size<const volatile _Tp> : public tuple_size<_Tp> {};
#endif
# 55 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

template <size_t _Ip, class _Tp> struct _LIBCPP_TEMPLATE_VIS tuple_element;

template <size_t _Ip, class _Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_element<_Ip, const _Tp>
{
    typedef _LIBCPP_NODEBUG_TYPE typename add_const<typename tuple_element<_Ip, _Tp>::type>::type type;
};

template <size_t _Ip, class _Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_element<_Ip, volatile _Tp>
{
    typedef _LIBCPP_NODEBUG_TYPE typename add_volatile<typename tuple_element<_Ip, _Tp>::type>::type type;
};

template <size_t _Ip, class _Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_element<_Ip, const volatile _Tp>
{
    typedef _LIBCPP_NODEBUG_TYPE typename add_cv<typename tuple_element<_Ip, _Tp>::type>::type type;
};

template <class _Tp> struct __tuple_like : false_type {};

template <class _Tp> struct __tuple_like<const _Tp> : public __tuple_like<_Tp> {};
template <class _Tp> struct __tuple_like<volatile _Tp> : public __tuple_like<_Tp> {};
template <class _Tp> struct __tuple_like<const volatile _Tp> : public __tuple_like<_Tp> {};

// tuple specializations

#ifndef _LIBCPP_CXX03_LANG

template <size_t...> struct __tuple_indices {};

template <class _IdxType, _IdxType... _Values>
struct __integer_sequence {
  template <template <class _OIdxType, _OIdxType...> class _ToIndexSeq, class _ToIndexType>
  using __convert = _ToIndexSeq<_ToIndexType, _Values...>;

  template <size_t _Sp>
  using __to_tuple_indices = __tuple_indices<(_Values + _Sp)...>;
};

#if 0 /* disabled by -frewrite-includes */
#if !__has_builtin(__make_integer_seq) || defined(_LIBCPP_TESTING_FALLBACK_MAKE_INTEGER_SEQUENCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
namespace __detail {

template<typename _Tp, size_t ..._Extra> struct __repeat;
template<typename _Tp, _Tp ..._Np, size_t ..._Extra> struct __repeat<__integer_sequence<_Tp, _Np...>, _Extra...> {
  typedef _LIBCPP_NODEBUG_TYPE __integer_sequence<_Tp,
                           _Np...,
                           sizeof...(_Np) + _Np...,
                           2 * sizeof...(_Np) + _Np...,
                           3 * sizeof...(_Np) + _Np...,
                           4 * sizeof...(_Np) + _Np...,
                           5 * sizeof...(_Np) + _Np...,
                           6 * sizeof...(_Np) + _Np...,
                           7 * sizeof...(_Np) + _Np...,
                           _Extra...> type;
};

template<size_t _Np> struct __parity;
template<size_t _Np> struct __make : __parity<_Np % 8>::template __pmake<_Np> {};

template<> struct __make<0> { typedef __integer_sequence<size_t> type; };
template<> struct __make<1> { typedef __integer_sequence<size_t, 0> type; };
template<> struct __make<2> { typedef __integer_sequence<size_t, 0, 1> type; };
template<> struct __make<3> { typedef __integer_sequence<size_t, 0, 1, 2> type; };
template<> struct __make<4> { typedef __integer_sequence<size_t, 0, 1, 2, 3> type; };
template<> struct __make<5> { typedef __integer_sequence<size_t, 0, 1, 2, 3, 4> type; };
template<> struct __make<6> { typedef __integer_sequence<size_t, 0, 1, 2, 3, 4, 5> type; };
template<> struct __make<7> { typedef __integer_sequence<size_t, 0, 1, 2, 3, 4, 5, 6> type; };

template<> struct __parity<0> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type> {}; };
template<> struct __parity<1> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 1> {}; };
template<> struct __parity<2> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 2, _Np - 1> {}; };
template<> struct __parity<3> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 3, _Np - 2, _Np - 1> {}; };
template<> struct __parity<4> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 4, _Np - 3, _Np - 2, _Np - 1> {}; };
template<> struct __parity<5> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 5, _Np - 4, _Np - 3, _Np - 2, _Np - 1> {}; };
template<> struct __parity<6> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 6, _Np - 5, _Np - 4, _Np - 3, _Np - 2, _Np - 1> {}; };
template<> struct __parity<7> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 7, _Np - 6, _Np - 5, _Np - 4, _Np - 3, _Np - 2, _Np - 1> {}; };

} // namespace detail

#endif  // !__has_builtin(__make_integer_seq) || defined(_LIBCPP_TESTING_FALLBACK_MAKE_INTEGER_SEQUENCE)
# 138 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__make_integer_seq)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 140 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
template <size_t _Ep, size_t _Sp>
using __make_indices_imp =
    typename __make_integer_seq<__integer_sequence, size_t, _Ep - _Sp>::template
    __to_tuple_indices<_Sp>;
#else
# 145 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
template <size_t _Ep, size_t _Sp>
using __make_indices_imp =
    typename __detail::__make<_Ep - _Sp>::type::template __to_tuple_indices<_Sp>;

#endif
# 150 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

template <size_t _Ep, size_t _Sp = 0>
struct __make_tuple_indices
{
    static_assert(_Sp <= _Ep, "__make_tuple_indices input error");
    typedef __make_indices_imp<_Ep, _Sp> type;
};


template <class ..._Tp> class _LIBCPP_TEMPLATE_VIS tuple;

template <class... _Tp> struct __tuple_like<tuple<_Tp...> > : true_type {};

template <class ..._Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_size<tuple<_Tp...> >
    : public integral_constant<size_t, sizeof...(_Tp)>
{
};

template <size_t _Ip, class ..._Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, tuple<_Tp...> >::type&
get(tuple<_Tp...>&) _NOEXCEPT;

template <size_t _Ip, class ..._Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, tuple<_Tp...> >::type&
get(const tuple<_Tp...>&) _NOEXCEPT;

template <size_t _Ip, class ..._Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, tuple<_Tp...> >::type&&
get(tuple<_Tp...>&&) _NOEXCEPT;

template <size_t _Ip, class ..._Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, tuple<_Tp...> >::type&&
get(const tuple<_Tp...>&&) _NOEXCEPT;

#endif // !defined(_LIBCPP_CXX03_LANG)
# 190 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

// pair specializations

template <class _T1, class _T2> struct __tuple_like<pair<_T1, _T2> > : true_type {};

template <size_t _Ip, class _T1, class _T2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, pair<_T1, _T2> >::type&
get(pair<_T1, _T2>&) _NOEXCEPT;

template <size_t _Ip, class _T1, class _T2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, pair<_T1, _T2> >::type&
get(const pair<_T1, _T2>&) _NOEXCEPT;

#ifndef _LIBCPP_CXX03_LANG
template <size_t _Ip, class _T1, class _T2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, pair<_T1, _T2> >::type&&
get(pair<_T1, _T2>&&) _NOEXCEPT;

template <size_t _Ip, class _T1, class _T2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, pair<_T1, _T2> >::type&&
get(const pair<_T1, _T2>&&) _NOEXCEPT;
#endif
# 216 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

// array specializations

template <class _Tp, size_t _Size> struct _LIBCPP_TEMPLATE_VIS array;

template <class _Tp, size_t _Size> struct __tuple_like<array<_Tp, _Size> > : true_type {};

template <size_t _Ip, class _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp&
get(array<_Tp, _Size>&) _NOEXCEPT;

template <size_t _Ip, class _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&
get(const array<_Tp, _Size>&) _NOEXCEPT;

#ifndef _LIBCPP_CXX03_LANG
template <size_t _Ip, class _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp&&
get(array<_Tp, _Size>&&) _NOEXCEPT;

template <size_t _Ip, class _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&&
get(const array<_Tp, _Size>&&) _NOEXCEPT;
#endif
# 244 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

#ifndef _LIBCPP_CXX03_LANG

// __tuple_types

template <class ..._Tp> struct __tuple_types {};

#if 0 /* disabled by -frewrite-includes */
#if !__has_builtin(__type_pack_element)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 252 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

namespace __indexer_detail {

template <size_t _Idx, class _Tp>
struct __indexed { using type _LIBCPP_NODEBUG_TYPE = _Tp; };

template <class _Types, class _Indexes> struct __indexer;

template <class ..._Types, size_t ..._Idx>
struct __indexer<__tuple_types<_Types...>, __tuple_indices<_Idx...>>
    : __indexed<_Idx, _Types>...
{};

template <size_t _Idx, class _Tp>
__indexed<_Idx, _Tp> __at_index(__indexed<_Idx, _Tp> const&);

} // namespace __indexer_detail

template <size_t _Idx, class ..._Types>
using __type_pack_element _LIBCPP_NODEBUG_TYPE = typename decltype(
    __indexer_detail::__at_index<_Idx>(
        __indexer_detail::__indexer<
            __tuple_types<_Types...>,
            typename __make_tuple_indices<sizeof...(_Types)>::type
        >{})
  )::type;
#endif
# 279 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

template <size_t _Ip, class ..._Types>
struct _LIBCPP_TEMPLATE_VIS tuple_element<_Ip, __tuple_types<_Types...>>
{
    static_assert(_Ip < sizeof...(_Types), "tuple_element index out of range");
    typedef _LIBCPP_NODEBUG_TYPE __type_pack_element<_Ip, _Types...> type;
};


template <class ..._Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_size<__tuple_types<_Tp...> >
    : public integral_constant<size_t, sizeof...(_Tp)>
{
};

template <class... _Tp> struct __tuple_like<__tuple_types<_Tp...> > : true_type {};

template <bool _ApplyLV, bool _ApplyConst, bool _ApplyVolatile>
struct __apply_cv_mf;
template <>
struct __apply_cv_mf<false, false, false> {
  template <class _Tp> using __apply = _Tp;
};
template <>
struct __apply_cv_mf<false, true, false> {
  template <class _Tp> using __apply _LIBCPP_NODEBUG_TYPE  = const _Tp;
};
template <>
struct __apply_cv_mf<false, false, true> {
  template <class _Tp> using __apply _LIBCPP_NODEBUG_TYPE  = volatile _Tp;
};
template <>
struct __apply_cv_mf<false, true, true> {
  template <class _Tp> using __apply _LIBCPP_NODEBUG_TYPE  = const volatile _Tp;
};
template <>
struct __apply_cv_mf<true, false, false> {
  template <class _Tp> using __apply _LIBCPP_NODEBUG_TYPE  = _Tp&;
};
template <>
struct __apply_cv_mf<true, true, false> {
  template <class _Tp> using __apply _LIBCPP_NODEBUG_TYPE  = const _Tp&;
};
template <>
struct __apply_cv_mf<true, false, true> {
  template <class _Tp> using __apply _LIBCPP_NODEBUG_TYPE  = volatile _Tp&;
};
template <>
struct __apply_cv_mf<true, true, true> {
  template <class _Tp> using __apply _LIBCPP_NODEBUG_TYPE = const volatile _Tp&;
};
template <class _Tp, class _RawTp = typename remove_reference<_Tp>::type>
using __apply_cv_t _LIBCPP_NODEBUG_TYPE  = __apply_cv_mf<
    is_lvalue_reference<_Tp>::value,
    is_const<_RawTp>::value,
    is_volatile<_RawTp>::value>;

// __make_tuple_types

// __make_tuple_types<_Tuple<_Types...>, _Ep, _Sp>::type is a
// __tuple_types<_Types...> using only those _Types in the range [_Sp, _Ep).
// _Sp defaults to 0 and _Ep defaults to tuple_size<_Tuple>.  If _Tuple is a
// lvalue_reference type, then __tuple_types<_Types&...> is the result.

template <class _TupleTypes, class _TupleIndices>
struct __make_tuple_types_flat;

template <template <class...> class _Tuple, class ..._Types, size_t ..._Idx>
struct __make_tuple_types_flat<_Tuple<_Types...>, __tuple_indices<_Idx...>> {
  // Specialization for pair, tuple, and __tuple_types
  template <class _Tp, class _ApplyFn = __apply_cv_t<_Tp>>
  using __apply_quals _LIBCPP_NODEBUG_TYPE = __tuple_types<
      typename _ApplyFn::template __apply<__type_pack_element<_Idx, _Types...>>...
    >;
};

template <class _Vt, size_t _Np, size_t ..._Idx>
struct __make_tuple_types_flat<array<_Vt, _Np>, __tuple_indices<_Idx...>> {
  template <size_t>
  using __value_type = _Vt;
  template <class _Tp, class _ApplyFn = __apply_cv_t<_Tp>>
  using __apply_quals = __tuple_types<
      typename _ApplyFn::template __apply<__value_type<_Idx>>...
    >;
};

template <class _Tp, size_t _Ep = tuple_size<typename remove_reference<_Tp>::type>::value,
          size_t _Sp = 0,
          bool _SameSize = (_Ep == tuple_size<typename remove_reference<_Tp>::type>::value)>
struct __make_tuple_types
{
    static_assert(_Sp <= _Ep, "__make_tuple_types input error");
    using _RawTp = typename remove_cv<typename remove_reference<_Tp>::type>::type;
    using _Maker = __make_tuple_types_flat<_RawTp, typename __make_tuple_indices<_Ep, _Sp>::type>;
    using type = typename _Maker::template __apply_quals<_Tp>;
};

template <class ..._Types, size_t _Ep>
struct __make_tuple_types<tuple<_Types...>, _Ep, 0, true> {
  typedef _LIBCPP_NODEBUG_TYPE __tuple_types<_Types...> type;
};

template <class ..._Types, size_t _Ep>
struct __make_tuple_types<__tuple_types<_Types...>, _Ep, 0, true> {
  typedef _LIBCPP_NODEBUG_TYPE __tuple_types<_Types...> type;
};

template <bool ..._Preds>
struct __all_dummy;

template <bool ..._Pred>
using __all = _IsSame<__all_dummy<_Pred...>, __all_dummy<((void)_Pred, true)...>>;

struct __tuple_sfinae_base {
  template <template <class, class...> class _Trait,
            class ..._LArgs, class ..._RArgs>
  static auto __do_test(__tuple_types<_LArgs...>, __tuple_types<_RArgs...>)
    -> __all<typename enable_if<_Trait<_LArgs, _RArgs>::value, bool>::type{true}...>;
  template <template <class...> class>
  static auto __do_test(...) -> false_type;

  template <class _FromArgs, class _ToArgs>
  using __constructible = decltype(__do_test<is_constructible>(_ToArgs{}, _FromArgs{}));
  template <class _FromArgs, class _ToArgs>
  using __convertible = decltype(__do_test<is_convertible>(_FromArgs{}, _ToArgs{}));
  template <class _FromArgs, class _ToArgs>
  using __assignable = decltype(__do_test<is_assignable>(_ToArgs{}, _FromArgs{}));
};

// __tuple_convertible

template <class _Tp, class _Up, bool = __tuple_like<typename remove_reference<_Tp>::type>::value,
                                bool = __tuple_like<_Up>::value>
struct __tuple_convertible
    : public false_type {};

template <class _Tp, class _Up>
struct __tuple_convertible<_Tp, _Up, true, true>
    : public __tuple_sfinae_base::__convertible<
      typename __make_tuple_types<_Tp>::type
    , typename __make_tuple_types<_Up>::type
    >
{};

// __tuple_constructible

template <class _Tp, class _Up, bool = __tuple_like<typename remove_reference<_Tp>::type>::value,
                                bool = __tuple_like<_Up>::value>
struct __tuple_constructible
    : public false_type {};

template <class _Tp, class _Up>
struct __tuple_constructible<_Tp, _Up, true, true>
    : public __tuple_sfinae_base::__constructible<
      typename __make_tuple_types<_Tp>::type
    , typename __make_tuple_types<_Up>::type
    >
{};

// __tuple_assignable

template <class _Tp, class _Up, bool = __tuple_like<typename remove_reference<_Tp>::type>::value,
                                bool = __tuple_like<_Up>::value>
struct __tuple_assignable
    : public false_type {};

template <class _Tp, class _Up>
struct __tuple_assignable<_Tp, _Up, true, true>
    : public __tuple_sfinae_base::__assignable<
      typename __make_tuple_types<_Tp>::type
    , typename __make_tuple_types<_Up&>::type
    >
{};


template <size_t _Ip, class ..._Tp>
struct _LIBCPP_TEMPLATE_VIS tuple_element<_Ip, tuple<_Tp...> >
{
    typedef _LIBCPP_NODEBUG_TYPE typename tuple_element<_Ip, __tuple_types<_Tp...> >::type type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 461 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
template <size_t _Ip, class ..._Tp>
using tuple_element_t _LIBCPP_NODEBUG_TYPE  = typename tuple_element <_Ip, _Tp...>::type;
#endif
# 464 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

template <bool _IsTuple, class _SizeTrait, size_t _Expected>
struct __tuple_like_with_size_imp : false_type {};

template <class _SizeTrait, size_t _Expected>
struct __tuple_like_with_size_imp<true, _SizeTrait, _Expected>
    : integral_constant<bool, _SizeTrait::value == _Expected> {};

template <class _Tuple, size_t _ExpectedSize,
          class _RawTuple = typename __uncvref<_Tuple>::type>
using __tuple_like_with_size _LIBCPP_NODEBUG_TYPE = __tuple_like_with_size_imp<
                                   __tuple_like<_RawTuple>::value,
                                   tuple_size<_RawTuple>, _ExpectedSize
                              >;

struct _LIBCPP_TYPE_VIS __check_tuple_constructor_fail {

    static constexpr bool __enable_explicit_default() { return false; }
    static constexpr bool __enable_implicit_default() { return false; }
    template <class ...>
    static constexpr bool __enable_explicit() { return false; }
    template <class ...>
    static constexpr bool __enable_implicit() { return false; }
    template <class ...>
    static constexpr bool __enable_assign() { return false; }
};
#endif // !defined(_LIBCPP_CXX03_LANG)
# 491 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 493 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

template <bool _CanCopy, bool _CanMove>
struct __sfinae_ctor_base {};
template <>
struct __sfinae_ctor_base<false, false> {
  __sfinae_ctor_base() = default;
  __sfinae_ctor_base(__sfinae_ctor_base const&) = delete;
  __sfinae_ctor_base(__sfinae_ctor_base &&) = delete;
  __sfinae_ctor_base& operator=(__sfinae_ctor_base const&) = default;
  __sfinae_ctor_base& operator=(__sfinae_ctor_base&&) = default;
};
template <>
struct __sfinae_ctor_base<true, false> {
  __sfinae_ctor_base() = default;
  __sfinae_ctor_base(__sfinae_ctor_base const&) = default;
  __sfinae_ctor_base(__sfinae_ctor_base &&) = delete;
  __sfinae_ctor_base& operator=(__sfinae_ctor_base const&) = default;
  __sfinae_ctor_base& operator=(__sfinae_ctor_base&&) = default;
};
template <>
struct __sfinae_ctor_base<false, true> {
  __sfinae_ctor_base() = default;
  __sfinae_ctor_base(__sfinae_ctor_base const&) = delete;
  __sfinae_ctor_base(__sfinae_ctor_base &&) = default;
  __sfinae_ctor_base& operator=(__sfinae_ctor_base const&) = default;
  __sfinae_ctor_base& operator=(__sfinae_ctor_base&&) = default;
};

template <bool _CanCopy, bool _CanMove>
struct __sfinae_assign_base {};
template <>
struct __sfinae_assign_base<false, false> {
  __sfinae_assign_base() = default;
  __sfinae_assign_base(__sfinae_assign_base const&) = default;
  __sfinae_assign_base(__sfinae_assign_base &&) = default;
  __sfinae_assign_base& operator=(__sfinae_assign_base const&) = delete;
  __sfinae_assign_base& operator=(__sfinae_assign_base&&) = delete;
};
template <>
struct __sfinae_assign_base<true, false> {
  __sfinae_assign_base() = default;
  __sfinae_assign_base(__sfinae_assign_base const&) = default;
  __sfinae_assign_base(__sfinae_assign_base &&) = default;
  __sfinae_assign_base& operator=(__sfinae_assign_base const&) = default;
  __sfinae_assign_base& operator=(__sfinae_assign_base&&) = delete;
};
template <>
struct __sfinae_assign_base<false, true> {
  __sfinae_assign_base() = default;
  __sfinae_assign_base(__sfinae_assign_base const&) = default;
  __sfinae_assign_base(__sfinae_assign_base &&) = default;
  __sfinae_assign_base& operator=(__sfinae_assign_base const&) = delete;
  __sfinae_assign_base& operator=(__sfinae_assign_base&&) = default;
};
#endif // _LIBCPP_STD_VER > 14
# 548 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP___TUPLE
# 552 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tuple" 3
# 200 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 200 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 201 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 201 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 1 3
// -*- C++ -*-
//===----------------------- initializer_list -----------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_INITIALIZER_LIST
#define _LIBCPP_INITIALIZER_LIST

/*
    initializer_list synopsis

namespace std
{

template<class E>
class initializer_list
{
public:
    typedef E        value_type;
    typedef const E& reference;
    typedef const E& const_reference;
    typedef size_t   size_type;

    typedef const E* iterator;
    typedef const E* const_iterator;

    initializer_list() noexcept; // constexpr in C++14

    size_t   size()  const noexcept; // constexpr in C++14
    const E* begin() const noexcept; // constexpr in C++14
    const E* end()   const noexcept; // constexpr in C++14
};

template<class E> const E* begin(initializer_list<E> il) noexcept; // constexpr in C++14
template<class E> const E* end(initializer_list<E> il) noexcept; // constexpr in C++14

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3
# 47 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 49 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3
#endif
# 51 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3

namespace std  // purposefully not versioned
{

#ifndef _LIBCPP_CXX03_LANG

template<class _Ep>
class _LIBCPP_TEMPLATE_VIS initializer_list
{
    const _Ep* __begin_;
    size_t    __size_;

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    initializer_list(const _Ep* __b, size_t __s) _NOEXCEPT
        : __begin_(__b),
          __size_(__s)
        {}
public:
    typedef _Ep        value_type;
    typedef const _Ep& reference;
    typedef const _Ep& const_reference;
    typedef size_t    size_type;

    typedef const _Ep* iterator;
    typedef const _Ep* const_iterator;

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    initializer_list() _NOEXCEPT : __begin_(nullptr), __size_(0) {}

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    size_t    size()  const _NOEXCEPT {return __size_;}

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _Ep* begin() const _NOEXCEPT {return __begin_;}

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _Ep* end()   const _NOEXCEPT {return __begin_ + __size_;}
};

template<class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX11
const _Ep*
begin(initializer_list<_Ep> __il) _NOEXCEPT
{
    return __il.begin();
}

template<class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX11
const _Ep*
end(initializer_list<_Ep> __il) _NOEXCEPT
{
    return __il.end();
}

#endif  // !defined(_LIBCPP_CXX03_LANG)
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3

}  // std

#endif  // _LIBCPP_INITIALIZER_LIST
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/initializer_list" 3
# 202 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 202 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 203 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 203 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 1 3
// -*- C++ -*-
//===--------------------------- cstring ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTRING
#define _LIBCPP_CSTRING

/*
    cstring synopsis

Macros:

    NULL

namespace std
{

Types:

    size_t

void* memcpy(void* restrict s1, const void* restrict s2, size_t n);
void* memmove(void* s1, const void* s2, size_t n);
char* strcpy (char* restrict s1, const char* restrict s2);
char* strncpy(char* restrict s1, const char* restrict s2, size_t n);
char* strcat (char* restrict s1, const char* restrict s2);
char* strncat(char* restrict s1, const char* restrict s2, size_t n);
int memcmp(const void* s1, const void* s2, size_t n);
int strcmp (const char* s1, const char* s2);
int strncmp(const char* s1, const char* s2, size_t n);
int strcoll(const char* s1, const char* s2);
size_t strxfrm(char* restrict s1, const char* restrict s2, size_t n);
const void* memchr(const void* s, int c, size_t n);
      void* memchr(      void* s, int c, size_t n);
const char* strchr(const char* s, int c);
      char* strchr(      char* s, int c);
size_t strcspn(const char* s1, const char* s2);
const char* strpbrk(const char* s1, const char* s2);
      char* strpbrk(      char* s1, const char* s2);
const char* strrchr(const char* s, int c);
      char* strrchr(      char* s, int c);
size_t strspn(const char* s1, const char* s2);
const char* strstr(const char* s1, const char* s2);
      char* strstr(      char* s1, const char* s2);
char* strtok(char* restrict s1, const char* restrict s2);
void* memset(void* s, int c, size_t n);
char* strerror(int errnum);
size_t strlen(const char* s);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 3
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 3
#if 0 /* expanded by -frewrite-includes */
#include <string.h>
#endif /* expanded by -frewrite-includes */
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 1 3
// -*- C++ -*-
//===--------------------------- string.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STRING_H
#define _LIBCPP_STRING_H

/*
    string.h synopsis

Macros:

    NULL

Types:

    size_t

void* memcpy(void* restrict s1, const void* restrict s2, size_t n);
void* memmove(void* s1, const void* s2, size_t n);
char* strcpy (char* restrict s1, const char* restrict s2);
char* strncpy(char* restrict s1, const char* restrict s2, size_t n);
char* strcat (char* restrict s1, const char* restrict s2);
char* strncat(char* restrict s1, const char* restrict s2, size_t n);
int memcmp(const void* s1, const void* s2, size_t n);
int strcmp (const char* s1, const char* s2);
int strncmp(const char* s1, const char* s2, size_t n);
int strcoll(const char* s1, const char* s2);
size_t strxfrm(char* restrict s1, const char* restrict s2, size_t n);
const void* memchr(const void* s, int c, size_t n);
      void* memchr(      void* s, int c, size_t n);
const char* strchr(const char* s, int c);
      char* strchr(      char* s, int c);
size_t strcspn(const char* s1, const char* s2);
const char* strpbrk(const char* s1, const char* s2);
      char* strpbrk(      char* s1, const char* s2);
const char* strrchr(const char* s, int c);
      char* strrchr(      char* s, int c);
size_t strspn(const char* s1, const char* s2);
const char* strstr(const char* s1, const char* s2);
      char* strstr(      char* s1, const char* s2);
char* strtok(char* restrict s1, const char* restrict s2);
void* memset(void* s, int c, size_t n);
char* strerror(int errnum);
size_t strlen(const char* s);

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 54 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3
# 55 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3
#endif
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <string.h>
#endif /* expanded by -frewrite-includes */
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 1 3 4
/*
 * Copyright (c) 2000, 2007, 2010 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)string.h	8.1 (Berkeley) 6/2/93
 */

#ifndef _STRING_H_
#define	_STRING_H_

#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 61 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_null.h>
#endif /* expanded by -frewrite-includes */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef NULL
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __DARWIN_NULL */
#endif /* expanded by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
#define NULL  __DARWIN_NULL
#endif  /* NULL */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 2 3 4

/* ANSI-C */

__BEGIN_DECLS
void	*memchr(const void *__s, int __c, size_t __n);
int	 memcmp(const void *__s1, const void *__s2, size_t __n);
void	*memcpy(void *__dst, const void *__src, size_t __n);
void	*memmove(void *__dst, const void *__src, size_t __len);
void	*memset(void *__b, int __c, size_t __len);
char	*strcat(char *__s1, const char *__s2);
char	*strchr(const char *__s, int __c);
int	 strcmp(const char *__s1, const char *__s2);
int	 strcoll(const char *__s1, const char *__s2);
char	*strcpy(char *__dst, const char *__src);
size_t	 strcspn(const char *__s, const char *__charset);
char	*strerror(int __errnum) __DARWIN_ALIAS(strerror);
size_t	 strlen(const char *__s);
char	*strncat(char *__s1, const char *__s2, size_t __n);
int	 strncmp(const char *__s1, const char *__s2, size_t __n);
char	*strncpy(char *__dst, const char *__src, size_t __n);
char	*strpbrk(const char *__s, const char *__charset);
char	*strrchr(const char *__s, int __c);
size_t	 strspn(const char *__s, const char *__charset);
char	*strstr(const char *__big, const char *__little);
char	*strtok(char *__str, const char *__sep);
size_t	 strxfrm(char *__s1, const char *__s2, size_t __n);
__END_DECLS



/* Additional functionality provided by:
 * POSIX.1c-1995,
 * POSIX.1i-1995,
 * and the omnibus ISO/IEC 9945-1: 1996
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 199506L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
__BEGIN_DECLS
char	*strtok_r(char *__str, const char *__sep, char **__lasts);
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 199506L */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4



/* Additional functionality provided by:
 * POSIX.1-2001
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200112L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
__BEGIN_DECLS
int	 strerror_r(int __errnum, char *__strerrbuf, size_t __buflen);
char	*strdup(const char *__s1);
void	*memccpy(void *__dst, const void *__src, int __c, size_t __n);
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 200112L */
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4



/* Additional functionality provided by:
 * POSIX.1-2008
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200809L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
__BEGIN_DECLS
char	*stpcpy(char *__dst, const char *__src);
char    *stpncpy(char *__dst, const char *__src, size_t __n) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
char	*strndup(const char *__s1, size_t __n) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
size_t   strnlen(const char *__s1, size_t __n) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
char	*strsignal(int __sig);
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 200809L */
# 137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4

/* C11 Annex K */

#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_WANT_LIB_EXT1__) && __STDC_WANT_LIB_EXT1__ >= 1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_rsize_t.h>
#endif /* expanded by -frewrite-includes */
# 141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 142 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_errno_t.h>
#endif /* expanded by -frewrite-includes */
# 142 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4

__BEGIN_DECLS
errno_t	memset_s(void *__s, rsize_t __smax, int __c, rsize_t __n) __OSX_AVAILABLE_STARTING(__MAC_10_9, __IPHONE_7_0);
__END_DECLS
#endif
# 148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4

/* Darwin extensions */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 152 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ssize_t.h>
#endif /* expanded by -frewrite-includes */
# 152 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ssize_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SSIZE_T
#define _SSIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_ssize_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ssize_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ssize_t.h" 3 4
typedef __darwin_ssize_t        ssize_t;
#endif  /* _SSIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ssize_t.h" 3 4
# 153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 2 3 4

__BEGIN_DECLS
void	*memmem(const void *__big, size_t __big_len, const void *__little, size_t __little_len) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
void     memset_pattern4(void *__b, const void *__pattern4, size_t __len) __OSX_AVAILABLE_STARTING(__MAC_10_5, __IPHONE_3_0);
void     memset_pattern8(void *__b, const void *__pattern8, size_t __len) __OSX_AVAILABLE_STARTING(__MAC_10_5, __IPHONE_3_0);
void     memset_pattern16(void *__b, const void *__pattern16, size_t __len) __OSX_AVAILABLE_STARTING(__MAC_10_5, __IPHONE_3_0);

char	*strcasestr(const char *__big, const char *__little);
char	*strnstr(const char *__big, const char *__little, size_t __len);
size_t	 strlcat(char *__dst, const char *__source, size_t __size);
size_t	 strlcpy(char *__dst, const char *__source, size_t __size);
void	 strmode(int __mode, char *__bp);
char	*strsep(char **__stringp, const char *__delim);

/* SUS places swab() in unistd.h.  It is listed here for source compatibility */
void	 swab(const void * __restrict, void * __restrict, ssize_t);

__OSX_AVAILABLE(10.12.1) __IOS_AVAILABLE(10.1)
__TVOS_AVAILABLE(10.0.1) __WATCHOS_AVAILABLE(3.1)
int	timingsafe_bcmp(const void *__b1, const void *__b2, size_t __len);
__END_DECLS

/* Some functions historically defined in string.h were placed in strings.h
 * by SUS.  We are using "strings.h" instead of <strings.h> to avoid an issue
 * where /Developer/Headers/FlatCarbon/Strings.h could be included instead on
 * case-insensitive file systems.
 */
#if 0 /* expanded by -frewrite-includes */
#include "strings.h"
#endif /* expanded by -frewrite-includes */
# 180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 1 3 4
/*
 * Copyright (c) 2000, 2007, 2010 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)strings.h	8.1 (Berkeley) 6/2/93
 */

#ifndef _STRINGS_H_
#define _STRINGS_H_

#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 61 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 2 3 4

__BEGIN_DECLS
/* Removed in Issue 7 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || _POSIX_C_SOURCE < 200809L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
int	 bcmp(const void *, const void *, size_t) __POSIX_C_DEPRECATED(200112L);
void	 bcopy(const void *, void *, size_t) __POSIX_C_DEPRECATED(200112L);
void	 bzero(void *, size_t) __POSIX_C_DEPRECATED(200112L);
char	*index(const char *, int) __POSIX_C_DEPRECATED(200112L);
char	*rindex(const char *, int) __POSIX_C_DEPRECATED(200112L);
#endif
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4

int	 ffs(int);
int	 strcasecmp(const char *, const char *);
int	 strncasecmp(const char *, const char *, size_t);
__END_DECLS

/* Darwin extensions */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
__BEGIN_DECLS
int	 ffsl(long) __OSX_AVAILABLE_STARTING(__MAC_10_5, __IPHONE_2_0);
int	 ffsll(long long) __OSX_AVAILABLE_STARTING(__MAC_10_9, __IPHONE_7_0);
int	 fls(int) __OSX_AVAILABLE_STARTING(__MAC_10_5, __IPHONE_2_0);
int	 flsl(long) __OSX_AVAILABLE_STARTING(__MAC_10_5, __IPHONE_2_0);
int	 flsll(long long) __OSX_AVAILABLE_STARTING(__MAC_10_9, __IPHONE_7_0);
__END_DECLS

#if 0 /* expanded by -frewrite-includes */
#include <string.h>
#endif /* expanded by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 1 3 4
// -*- C++ -*-
//===--------------------------- string.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STRING_H
#define _LIBCPP_STRING_H

/*
    string.h synopsis

Macros:

    NULL

Types:

    size_t

void* memcpy(void* restrict s1, const void* restrict s2, size_t n);
void* memmove(void* s1, const void* s2, size_t n);
char* strcpy (char* restrict s1, const char* restrict s2);
char* strncpy(char* restrict s1, const char* restrict s2, size_t n);
char* strcat (char* restrict s1, const char* restrict s2);
char* strncat(char* restrict s1, const char* restrict s2, size_t n);
int memcmp(const void* s1, const void* s2, size_t n);
int strcmp (const char* s1, const char* s2);
int strncmp(const char* s1, const char* s2, size_t n);
int strcoll(const char* s1, const char* s2);
size_t strxfrm(char* restrict s1, const char* restrict s2, size_t n);
const void* memchr(const void* s, int c, size_t n);
      void* memchr(      void* s, int c, size_t n);
const char* strchr(const char* s, int c);
      char* strchr(      char* s, int c);
size_t strcspn(const char* s1, const char* s2);
const char* strpbrk(const char* s1, const char* s2);
      char* strpbrk(      char* s1, const char* s2);
const char* strrchr(const char* s, int c);
      char* strrchr(      char* s, int c);
size_t strspn(const char* s1, const char* s2);
const char* strstr(const char* s1, const char* s2);
      char* strstr(      char* s1, const char* s2);
char* strtok(char* restrict s1, const char* restrict s2);
void* memset(void* s, int c, size_t n);
char* strerror(int errnum);
size_t strlen(const char* s);

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 54 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4
# 55 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4
#endif
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <string.h>
#endif /* expanded by -frewrite-includes */
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4

// MSVCRT, GNU libc and its derivates may already have the correct prototype in
// <string.h>. This macro can be defined by users if their C library provides
// the right signature.
#if 0 /* disabled by -frewrite-includes */
#if defined(__CORRECT_ISO_CPP_STRING_H_PROTO) || defined(_LIBCPP_MSVCRT) || \
    defined(__sun__) || defined(_STRING_H_CPLUSPLUS_98_CONFORMANCE_)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 67 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4
#define _LIBCPP_STRING_H_HAS_CONST_OVERLOADS
#endif
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && !defined(_LIBCPP_STRING_H_HAS_CONST_OVERLOADS) && defined(_LIBCPP_PREFERRED_OVERLOAD)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 71 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4
extern "C++" {
inline _LIBCPP_INLINE_VISIBILITY
char* __libcpp_strchr(const char* __s, int __c) {return (char*)strchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const char* strchr(const char* __s, int __c) {return __libcpp_strchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      char* strchr(      char* __s, int __c) {return __libcpp_strchr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY
char* __libcpp_strpbrk(const char* __s1, const char* __s2) {return (char*)strpbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const char* strpbrk(const char* __s1, const char* __s2) {return __libcpp_strpbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      char* strpbrk(      char* __s1, const char* __s2) {return __libcpp_strpbrk(__s1, __s2);}

inline _LIBCPP_INLINE_VISIBILITY
char* __libcpp_strrchr(const char* __s, int __c) {return (char*)strrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const char* strrchr(const char* __s, int __c) {return __libcpp_strrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      char* strrchr(      char* __s, int __c) {return __libcpp_strrchr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY
void* __libcpp_memchr(const void* __s, int __c, size_t __n) {return (void*)memchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const void* memchr(const void* __s, int __c, size_t __n) {return __libcpp_memchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      void* memchr(      void* __s, int __c, size_t __n) {return __libcpp_memchr(__s, __c, __n);}

inline _LIBCPP_INLINE_VISIBILITY
char* __libcpp_strstr(const char* __s1, const char* __s2) {return (char*)strstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const char* strstr(const char* __s1, const char* __s2) {return __libcpp_strstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      char* strstr(      char* __s1, const char* __s2) {return __libcpp_strstr(__s1, __s2);}
}
#endif
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4

#endif  // _LIBCPP_STRING_H
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3 4
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 2 3 4
#endif
# 94 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined (__GNUC__) && _FORTIFY_SOURCE > 0 && !defined (__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 96 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
/* Security checking functions.  */
#if 0 /* expanded by -frewrite-includes */
#include <secure/_strings.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4
#endif
# 99 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4

#endif  /* _STRINGS_H_ */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/strings.h" 3 4

# 181 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 2 3 4
#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 182 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4


#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_string.h>
#endif /* expanded by -frewrite-includes */
# 185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined (__GNUC__) && _FORTIFY_SOURCE > 0 && !defined (__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 189 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
/* Security checking functions.  */
#if 0 /* expanded by -frewrite-includes */
#include <secure/_string.h>
#endif /* expanded by -frewrite-includes */
# 190 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 191 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
#endif
# 192 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4

#endif /* _STRING_H_ */
# 194 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/string.h" 3 4
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 2 3

// MSVCRT, GNU libc and its derivates may already have the correct prototype in
// <string.h>. This macro can be defined by users if their C library provides
// the right signature.
#if 0 /* disabled by -frewrite-includes */
#if defined(__CORRECT_ISO_CPP_STRING_H_PROTO) || defined(_LIBCPP_MSVCRT) || \
    defined(__sun__) || defined(_STRING_H_CPLUSPLUS_98_CONFORMANCE_)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 67 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3
#define _LIBCPP_STRING_H_HAS_CONST_OVERLOADS
#endif
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && !defined(_LIBCPP_STRING_H_HAS_CONST_OVERLOADS) && defined(_LIBCPP_PREFERRED_OVERLOAD)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 71 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3
extern "C++" {
inline _LIBCPP_INLINE_VISIBILITY
char* __libcpp_strchr(const char* __s, int __c) {return (char*)strchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const char* strchr(const char* __s, int __c) {return __libcpp_strchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      char* strchr(      char* __s, int __c) {return __libcpp_strchr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY
char* __libcpp_strpbrk(const char* __s1, const char* __s2) {return (char*)strpbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const char* strpbrk(const char* __s1, const char* __s2) {return __libcpp_strpbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      char* strpbrk(      char* __s1, const char* __s2) {return __libcpp_strpbrk(__s1, __s2);}

inline _LIBCPP_INLINE_VISIBILITY
char* __libcpp_strrchr(const char* __s, int __c) {return (char*)strrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const char* strrchr(const char* __s, int __c) {return __libcpp_strrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      char* strrchr(      char* __s, int __c) {return __libcpp_strrchr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY
void* __libcpp_memchr(const void* __s, int __c, size_t __n) {return (void*)memchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const void* memchr(const void* __s, int __c, size_t __n) {return __libcpp_memchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      void* memchr(      void* __s, int __c, size_t __n) {return __libcpp_memchr(__s, __c, __n);}

inline _LIBCPP_INLINE_VISIBILITY
char* __libcpp_strstr(const char* __s1, const char* __s2) {return (char*)strstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const char* strstr(const char* __s1, const char* __s2) {return __libcpp_strstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      char* strstr(      char* __s1, const char* __s2) {return __libcpp_strstr(__s1, __s2);}
}
#endif
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3

#endif  // _LIBCPP_STRING_H
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string.h" 3
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 64 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 3
#endif
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::size_t;
using ::memcpy;
using ::memmove;
using ::strcpy;
using ::strncpy;
using ::strcat;
using ::strncat;
using ::memcmp;
using ::strcmp;
using ::strncmp;
using ::strcoll;
using ::strxfrm;
using ::memchr;
using ::strchr;
using ::strcspn;
using ::strpbrk;
using ::strrchr;
using ::strspn;
using ::strstr;
#ifndef _LIBCPP_HAS_NO_THREAD_UNSAFE_C_FUNCTIONS
using ::strtok;
#endif
# 90 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 3
using ::memset;
using ::strerror;
using ::strlen;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTRING
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstring" 3
# 204 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 204 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 1 3
// -*- C++ -*-
//===--------------------------- cstdint ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDINT
#define _LIBCPP_CSTDINT

/*
    cstdint synopsis

Macros:

    INT8_MIN
    INT16_MIN
    INT32_MIN
    INT64_MIN

    INT8_MAX
    INT16_MAX
    INT32_MAX
    INT64_MAX

    UINT8_MAX
    UINT16_MAX
    UINT32_MAX
    UINT64_MAX

    INT_LEAST8_MIN
    INT_LEAST16_MIN
    INT_LEAST32_MIN
    INT_LEAST64_MIN

    INT_LEAST8_MAX
    INT_LEAST16_MAX
    INT_LEAST32_MAX
    INT_LEAST64_MAX

    UINT_LEAST8_MAX
    UINT_LEAST16_MAX
    UINT_LEAST32_MAX
    UINT_LEAST64_MAX

    INT_FAST8_MIN
    INT_FAST16_MIN
    INT_FAST32_MIN
    INT_FAST64_MIN

    INT_FAST8_MAX
    INT_FAST16_MAX
    INT_FAST32_MAX
    INT_FAST64_MAX

    UINT_FAST8_MAX
    UINT_FAST16_MAX
    UINT_FAST32_MAX
    UINT_FAST64_MAX

    INTPTR_MIN
    INTPTR_MAX
    UINTPTR_MAX

    INTMAX_MIN
    INTMAX_MAX

    UINTMAX_MAX

    PTRDIFF_MIN
    PTRDIFF_MAX

    SIG_ATOMIC_MIN
    SIG_ATOMIC_MAX

    SIZE_MAX

    WCHAR_MIN
    WCHAR_MAX

    WINT_MIN
    WINT_MAX

    INT8_C(value)
    INT16_C(value)
    INT32_C(value)
    INT64_C(value)

    UINT8_C(value)
    UINT16_C(value)
    UINT32_C(value)
    UINT64_C(value)

    INTMAX_C(value)
    UINTMAX_C(value)

namespace std
{

Types:

    int8_t
    int16_t
    int32_t
    int64_t

    uint8_t
    uint16_t
    uint32_t
    uint64_t

    int_least8_t
    int_least16_t
    int_least32_t
    int_least64_t

    uint_least8_t
    uint_least16_t
    uint_least32_t
    uint_least64_t

    int_fast8_t
    int_fast16_t
    int_fast32_t
    int_fast64_t

    uint_fast8_t
    uint_fast16_t
    uint_fast32_t
    uint_fast64_t

    intptr_t
    uintptr_t

    intmax_t
    uintmax_t

}  // std
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 143 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 3
# 144 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdint.h>
#endif /* expanded by -frewrite-includes */
# 144 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 3
# 145 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 147 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 3
#endif
# 149 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using::int8_t;
using::int16_t;
using::int32_t;
using::int64_t;

using::uint8_t;
using::uint16_t;
using::uint32_t;
using::uint64_t;

using::int_least8_t;
using::int_least16_t;
using::int_least32_t;
using::int_least64_t;

using::uint_least8_t;
using::uint_least16_t;
using::uint_least32_t;
using::uint_least64_t;

using::int_fast8_t;
using::int_fast16_t;
using::int_fast32_t;
using::int_fast64_t;

using::uint_fast8_t;
using::uint_fast16_t;
using::uint_fast32_t;
using::uint_fast64_t;

using::intptr_t;
using::uintptr_t;

using::intmax_t;
using::uintmax_t;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTDINT
# 191 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdint" 3
# 205 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 205 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 206 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 206 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 1 3
// -*- C++ -*-
//===--------------------------- __debug ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_DEBUG_H
#define _LIBCPP_DEBUG_H

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 1 3
// -*- C++ -*-
//===--------------------------- iosfwd -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_IOSFWD
#define _LIBCPP_IOSFWD

/*
    iosfwd synopsis

namespace std
{

template<class charT> struct char_traits;
template<>            struct char_traits<char>;
template<>            struct char_traits<char8_t>;  // C++20
template<>            struct char_traits<char16_t>;
template<>            struct char_traits<char32_t>;
template<>            struct char_traits<wchar_t>;

template<class T>     class allocator;

class ios_base;
template <class charT, class traits = char_traits<charT> > class basic_ios;

template <class charT, class traits = char_traits<charT> > class basic_streambuf;
template <class charT, class traits = char_traits<charT> > class basic_istream;
template <class charT, class traits = char_traits<charT> > class basic_ostream;
template <class charT, class traits = char_traits<charT> > class basic_iostream;

template <class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
    class basic_stringbuf;
template <class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
    class basic_istringstream;
template <class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
    class basic_ostringstream;
template <class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
    class basic_stringstream;

template <class charT, class traits = char_traits<charT> > class basic_filebuf;
template <class charT, class traits = char_traits<charT> > class basic_ifstream;
template <class charT, class traits = char_traits<charT> > class basic_ofstream;
template <class charT, class traits = char_traits<charT> > class basic_fstream;

template <class charT, class traits = char_traits<charT> > class istreambuf_iterator;
template <class charT, class traits = char_traits<charT> > class ostreambuf_iterator;

typedef basic_ios<char>              ios;
typedef basic_ios<wchar_t>           wios;

typedef basic_streambuf<char>        streambuf;
typedef basic_istream<char>          istream;
typedef basic_ostream<char>          ostream;
typedef basic_iostream<char>         iostream;

typedef basic_stringbuf<char>        stringbuf;
typedef basic_istringstream<char>    istringstream;
typedef basic_ostringstream<char>    ostringstream;
typedef basic_stringstream<char>     stringstream;

typedef basic_filebuf<char>          filebuf;
typedef basic_ifstream<char>         ifstream;
typedef basic_ofstream<char>         ofstream;
typedef basic_fstream<char>          fstream;

typedef basic_streambuf<wchar_t>     wstreambuf;
typedef basic_istream<wchar_t>       wistream;
typedef basic_ostream<wchar_t>       wostream;
typedef basic_iostream<wchar_t>      wiostream;

typedef basic_stringbuf<wchar_t>     wstringbuf;
typedef basic_istringstream<wchar_t> wistringstream;
typedef basic_ostringstream<wchar_t> wostringstream;
typedef basic_stringstream<wchar_t>  wstringstream;

typedef basic_filebuf<wchar_t>       wfilebuf;
typedef basic_ifstream<wchar_t>      wifstream;
typedef basic_ofstream<wchar_t>      wofstream;
typedef basic_fstream<wchar_t>       wfstream;

template <class state> class fpos;
typedef fpos<char_traits<char>::state_type>    streampos;
typedef fpos<char_traits<wchar_t>::state_type> wstreampos;

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
#if 0 /* expanded by -frewrite-includes */
#include <wchar.h>  // for mbstate_t
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 1 3
// -*- C++ -*-
//===--------------------------- wchar.h ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_wint_t) || defined(__need_mbstate_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <wchar.h>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_WCHAR_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#define _LIBCPP_WCHAR_H

/*
    wchar.h synopsis

Macros:

    NULL
    WCHAR_MAX
    WCHAR_MIN
    WEOF

Types:

    mbstate_t
    size_t
    tm
    wint_t

int fwprintf(FILE* restrict stream, const wchar_t* restrict format, ...);
int fwscanf(FILE* restrict stream, const wchar_t* restrict format, ...);
int swprintf(wchar_t* restrict s, size_t n, const wchar_t* restrict format, ...);
int swscanf(const wchar_t* restrict s, const wchar_t* restrict format, ...);
int vfwprintf(FILE* restrict stream, const wchar_t* restrict format, va_list arg);
int vfwscanf(FILE* restrict stream, const wchar_t* restrict format, va_list arg);  // C99
int vswprintf(wchar_t* restrict s, size_t n, const wchar_t* restrict format, va_list arg);
int vswscanf(const wchar_t* restrict s, const wchar_t* restrict format, va_list arg);  // C99
int vwprintf(const wchar_t* restrict format, va_list arg);
int vwscanf(const wchar_t* restrict format, va_list arg);  // C99
int wprintf(const wchar_t* restrict format, ...);
int wscanf(const wchar_t* restrict format, ...);
wint_t fgetwc(FILE* stream);
wchar_t* fgetws(wchar_t* restrict s, int n, FILE* restrict stream);
wint_t fputwc(wchar_t c, FILE* stream);
int fputws(const wchar_t* restrict s, FILE* restrict stream);
int fwide(FILE* stream, int mode);
wint_t getwc(FILE* stream);
wint_t getwchar();
wint_t putwc(wchar_t c, FILE* stream);
wint_t putwchar(wchar_t c);
wint_t ungetwc(wint_t c, FILE* stream);
double wcstod(const wchar_t* restrict nptr, wchar_t** restrict endptr);
float wcstof(const wchar_t* restrict nptr, wchar_t** restrict endptr);         // C99
long double wcstold(const wchar_t* restrict nptr, wchar_t** restrict endptr);  // C99
long wcstol(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
long long wcstoll(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);  // C99
unsigned long wcstoul(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
unsigned long long wcstoull(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);  // C99
wchar_t* wcscpy(wchar_t* restrict s1, const wchar_t* restrict s2);
wchar_t* wcsncpy(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wcscat(wchar_t* restrict s1, const wchar_t* restrict s2);
wchar_t* wcsncat(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
int wcscmp(const wchar_t* s1, const wchar_t* s2);
int wcscoll(const wchar_t* s1, const wchar_t* s2);
int wcsncmp(const wchar_t* s1, const wchar_t* s2, size_t n);
size_t wcsxfrm(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
const wchar_t* wcschr(const wchar_t* s, wchar_t c);
      wchar_t* wcschr(      wchar_t* s, wchar_t c);
size_t wcscspn(const wchar_t* s1, const wchar_t* s2);
size_t wcslen(const wchar_t* s);
const wchar_t* wcspbrk(const wchar_t* s1, const wchar_t* s2);
      wchar_t* wcspbrk(      wchar_t* s1, const wchar_t* s2);
const wchar_t* wcsrchr(const wchar_t* s, wchar_t c);
      wchar_t* wcsrchr(      wchar_t* s, wchar_t c);
size_t wcsspn(const wchar_t* s1, const wchar_t* s2);
const wchar_t* wcsstr(const wchar_t* s1, const wchar_t* s2);
      wchar_t* wcsstr(      wchar_t* s1, const wchar_t* s2);
wchar_t* wcstok(wchar_t* restrict s1, const wchar_t* restrict s2, wchar_t** restrict ptr);
const wchar_t* wmemchr(const wchar_t* s, wchar_t c, size_t n);
      wchar_t* wmemchr(      wchar_t* s, wchar_t c, size_t n);
int wmemcmp(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wmemcpy(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wmemmove(wchar_t* s1, const wchar_t* s2, size_t n);
wchar_t* wmemset(wchar_t* s, wchar_t c, size_t n);
size_t wcsftime(wchar_t* restrict s, size_t maxsize, const wchar_t* restrict format,
                const tm* restrict timeptr);
wint_t btowc(int c);
int wctob(wint_t c);
int mbsinit(const mbstate_t* ps);
size_t mbrlen(const char* restrict s, size_t n, mbstate_t* restrict ps);
size_t mbrtowc(wchar_t* restrict pwc, const char* restrict s, size_t n, mbstate_t* restrict ps);
size_t wcrtomb(char* restrict s, wchar_t wc, mbstate_t* restrict ps);
size_t mbsrtowcs(wchar_t* restrict dst, const char** restrict src, size_t len,
                 mbstate_t* restrict ps);
size_t wcsrtombs(char* restrict dst, const wchar_t** restrict src, size_t len,
                 mbstate_t* restrict ps);

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
# 109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#endif
# 113 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#ifdef __cplusplus
#define __CORRECT_ISO_CPP_WCHAR_H_PROTO
#endif
# 117 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <wchar.h>
#endif /* expanded by -frewrite-includes */
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 1 3 4
/*-
 * Copyright (c)1999 Citrus Project,
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: /repoman/r/ncvs/src/include/wchar.h,v 1.34 2003/03/13 06:29:53 tjr Exp $
 */

/*-
 * Copyright (c) 1999, 2000 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Julian Coleman.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *        This product includes software developed by the NetBSD
 *        Foundation, Inc. and its contributors.
 * 4. Neither the name of The NetBSD Foundation nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 *	$NetBSD: wchar.h,v 1.8 2000/12/22 05:31:42 itojun Exp $
 */

#ifndef _WCHAR_H_
#define _WCHAR_H_

#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_null.h>
#endif /* expanded by -frewrite-includes */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef NULL
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __DARWIN_NULL */
#endif /* expanded by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
#define NULL  __DARWIN_NULL
#endif  /* NULL */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_mbstate_t.h>
#endif /* expanded by -frewrite-includes */
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_mbstate_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _MBSTATE_T
#define _MBSTATE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_mbstate_t */
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_mbstate_t.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_mbstate_t.h" 3 4
typedef __darwin_mbstate_t mbstate_t;
#endif /* _MBSTATE_T */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_mbstate_t.h" 3 4
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ct_rune_t.h>
#endif /* expanded by -frewrite-includes */
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_rune_t.h>
#endif /* expanded by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_wchar_t.h>
#endif /* expanded by -frewrite-includes */
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

/* wchar_t is a built-in type in C++ */
#ifndef __cplusplus
#ifndef _WCHAR_T
#define _WCHAR_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_wchar_t */
#endif /* expanded by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
typedef __darwin_wchar_t wchar_t;
#endif /* _WCHAR_T */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
#endif /* __cplusplus */
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 2 3 4

#ifndef WCHAR_MIN
#define WCHAR_MIN	__DARWIN_WCHAR_MIN
#endif
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4

#ifndef WCHAR_MAX
#define WCHAR_MAX	__DARWIN_WCHAR_MAX
#endif
# 88 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <stdarg.h>
#endif /* expanded by -frewrite-includes */
# 89 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdarg.h" 1 3 4
/*===---- stdarg.h - Variable argument handling ----------------------------===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __STDARG_H
#define __STDARG_H

#ifndef _VA_LIST
typedef __builtin_va_list va_list;
#define _VA_LIST
#endif
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdarg.h" 3 4
#define va_start(ap, param) __builtin_va_start(ap, param)
#define va_end(ap)          __builtin_va_end(ap)
#define va_arg(ap, type)    __builtin_va_arg(ap, type)

/* GCC always defines __va_copy, but does not define va_copy unless in c99 mode
 * or -ansi is not specified, since it was not part of C90.
 */
#define __va_copy(d,s) __builtin_va_copy(d,s)

#if 0 /* disabled by -frewrite-includes */
#if __STDC_VERSION__ >= 199901L || __cplusplus >= 201103L || !defined(__STRICT_ANSI__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdarg.h" 3 4
#define va_copy(dest, src)  __builtin_va_copy(dest, src)
#endif
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdarg.h" 3 4

#ifndef __GNUC_VA_LIST
#define __GNUC_VA_LIST 1
typedef __builtin_va_list __gnuc_va_list;
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdarg.h" 3 4

#endif /* __STDARG_H */
# 36 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/stdarg.h" 3 4
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <stdio.h>
#endif /* expanded by -frewrite-includes */
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 1 3 4
// -*- C++ -*-
//===---------------------------- stdio.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_FILE) || defined(__need___FILE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdio.h>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDIO_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4
#define _LIBCPP_STDIO_H

/*
    stdio.h synopsis

Macros:

    BUFSIZ
    EOF
    FILENAME_MAX
    FOPEN_MAX
    L_tmpnam
    NULL
    SEEK_CUR
    SEEK_END
    SEEK_SET
    TMP_MAX
    _IOFBF
    _IOLBF
    _IONBF
    stderr
    stdin
    stdout

Types:

FILE
fpos_t
size_t

int remove(const char* filename);
int rename(const char* old, const char* new);
FILE* tmpfile(void);
char* tmpnam(char* s);
int fclose(FILE* stream);
int fflush(FILE* stream);
FILE* fopen(const char* restrict filename, const char* restrict mode);
FILE* freopen(const char* restrict filename, const char * restrict mode,
              FILE * restrict stream);
void setbuf(FILE* restrict stream, char* restrict buf);
int setvbuf(FILE* restrict stream, char* restrict buf, int mode, size_t size);
int fprintf(FILE* restrict stream, const char* restrict format, ...);
int fscanf(FILE* restrict stream, const char * restrict format, ...);
int printf(const char* restrict format, ...);
int scanf(const char* restrict format, ...);
int snprintf(char* restrict s, size_t n, const char* restrict format, ...);    // C99
int sprintf(char* restrict s, const char* restrict format, ...);
int sscanf(const char* restrict s, const char* restrict format, ...);
int vfprintf(FILE* restrict stream, const char* restrict format, va_list arg);
int vfscanf(FILE* restrict stream, const char* restrict format, va_list arg);  // C99
int vprintf(const char* restrict format, va_list arg);
int vscanf(const char* restrict format, va_list arg);                          // C99
int vsnprintf(char* restrict s, size_t n, const char* restrict format,         // C99
              va_list arg);
int vsprintf(char* restrict s, const char* restrict format, va_list arg);
int vsscanf(const char* restrict s, const char* restrict format, va_list arg); // C99
int fgetc(FILE* stream);
char* fgets(char* restrict s, int n, FILE* restrict stream);
int fputc(int c, FILE* stream);
int fputs(const char* restrict s, FILE* restrict stream);
int getc(FILE* stream);
int getchar(void);
char* gets(char* s);  // removed in C++14
int putc(int c, FILE* stream);
int putchar(int c);
int puts(const char* s);
int ungetc(int c, FILE* stream);
size_t fread(void* restrict ptr, size_t size, size_t nmemb,
             FILE* restrict stream);
size_t fwrite(const void* restrict ptr, size_t size, size_t nmemb,
              FILE* restrict stream);
int fgetpos(FILE* restrict stream, fpos_t* restrict pos);
int fseek(FILE* stream, long offset, int whence);
int fsetpos(FILE*stream, const fpos_t* pos);
long ftell(FILE* stream);
void rewind(FILE* stream);
void clearerr(FILE* stream);
int feof(FILE* stream);
int ferror(FILE* stream);
void perror(const char* s);
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
#endif
# 106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdio.h>
#endif /* expanded by -frewrite-includes */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 1 3 4
/*
 * Copyright (c) 2000, 2005, 2007, 2009, 2010 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Chris Torek.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)stdio.h	8.5 (Berkeley) 4/29/95
 */

#ifndef	_STDIO_H_
#define	_STDIO_H_

#if 0 /* expanded by -frewrite-includes */
#include <_stdio.h>
#endif /* expanded by -frewrite-includes */
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 1 3 4
/*
 * Copyright (c) 2000, 2005, 2007, 2009, 2010 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Chris Torek.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)stdio.h	8.5 (Berkeley) 4/29/95
 */

/*
 * Common header for stdio.h and xlocale/_stdio.h
 */

#ifndef	__STDIO_H_
#define	__STDIO_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4

/* DO NOT REMOVE THIS COMMENT: fixincludes needs to see:
 * __gnuc_va_list and include <stdarg.h> */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_va_list.h>
#endif /* expanded by -frewrite-includes */
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_va_list.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _VA_LIST_T
#define _VA_LIST_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_va_list */
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_va_list.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_va_list.h" 3 4
typedef __darwin_va_list va_list;
#endif /* _VA_LIST_T */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_va_list.h" 3 4
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_null.h>
#endif /* expanded by -frewrite-includes */
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef NULL
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __DARWIN_NULL */
#endif /* expanded by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
#define NULL  __DARWIN_NULL
#endif  /* NULL */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 2 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/stdio.h>
#endif /* expanded by -frewrite-includes */
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 1 3 4
/*
 * Copyright (c) 2013 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _SYS_STDIO_H_
#define _SYS_STDIO_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200809L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4

__BEGIN_DECLS

int     renameat(int, const char *, int, const char *) __OSX_AVAILABLE_STARTING(__MAC_10_10, __IPHONE_8_0);

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4

#define RENAME_SECLUDE          0x00000001
#define RENAME_SWAP                     0x00000002
#define RENAME_EXCL                     0x00000004
int renamex_np(const char *, const char *, unsigned int) __OSX_AVAILABLE(10.12) __IOS_AVAILABLE(10.0) __TVOS_AVAILABLE(10.0) __WATCHOS_AVAILABLE(3.0);
int renameatx_np(int, const char *, int, const char *, unsigned int) __OSX_AVAILABLE(10.12) __IOS_AVAILABLE(10.0) __TVOS_AVAILABLE(10.0) __WATCHOS_AVAILABLE(3.0);

#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 50 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4

__END_DECLS

#endif /* __DARWIN_C_LEVEL >= 200809L */
# 54 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4

#endif /* _SYS_STDIO_H_ */
# 56 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/stdio.h" 3 4
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 2 3 4

typedef __darwin_off_t		fpos_t;

#define	_FSTDIO			/* Define for new stdio with functions. */

/*
 * NB: to fit things in six character monocase externals, the stdio
 * code uses the prefix `__s' for stdio objects, typically followed
 * by a three-character attempt at a mnemonic.
 */

/* stdio buffers */
struct __sbuf {
	unsigned char	*_base;
	int		_size;
};

/* hold a buncha junk that would grow the ABI */
struct __sFILEX;

/*
 * stdio state variables.
 *
 * The following always hold:
 *
 *	if (_flags&(__SLBF|__SWR)) == (__SLBF|__SWR),
 *		_lbfsize is -_bf._size, else _lbfsize is 0
 *	if _flags&__SRD, _w is 0
 *	if _flags&__SWR, _r is 0
 *
 * This ensures that the getc and putc macros (or inline functions) never
 * try to write or read from a file that is in `read' or `write' mode.
 * (Moreover, they can, and do, automatically switch from read mode to
 * write mode, and back, on "r+" and "w+" files.)
 *
 * _lbfsize is used only to make the inline line-buffered output stream
 * code as compact as possible.
 *
 * _ub, _up, and _ur are used when ungetc() pushes back more characters
 * than fit in the current _bf, or when ungetc() pushes back a character
 * that does not match the previous one in _bf.  When this happens,
 * _ub._base becomes non-nil (i.e., a stream has ungetc() data iff
 * _ub._base!=NULL) and _up and _ur save the current values of _p and _r.
 *
 * NB: see WARNING above before changing the layout of this structure!
 */
typedef	struct __sFILE {
	unsigned char *_p;	/* current position in (some) buffer */
	int	_r;		/* read space left for getc() */
	int	_w;		/* write space left for putc() */
	short	_flags;		/* flags, below; this FILE is free if 0 */
	short	_file;		/* fileno, if Unix descriptor, else -1 */
	struct	__sbuf _bf;	/* the buffer (at least 1 byte, if !NULL) */
	int	_lbfsize;	/* 0 or -_bf._size, for inline putc */

	/* operations */
	void	*_cookie;	/* cookie passed to io functions */
	int	(* _Nullable _close)(void *);
	int	(* _Nullable _read) (void *, char *, int);
	fpos_t	(* _Nullable _seek) (void *, fpos_t, int);
	int	(* _Nullable _write)(void *, const char *, int);

	/* separate buffer for long sequences of ungetc() */
	struct	__sbuf _ub;	/* ungetc buffer */
	struct __sFILEX *_extra; /* additions to FILE to not break ABI */
	int	_ur;		/* saved _r when _r is counting ungetc data */

	/* tricks to meet minimum requirements even when malloc() fails */
	unsigned char _ubuf[3];	/* guarantee an ungetc() buffer */
	unsigned char _nbuf[1];	/* guarantee a getc() buffer */

	/* separate buffer for fgetln() when line crosses buffer boundary */
	struct	__sbuf _lb;	/* buffer for fgetln() */

	/* Unix stdio files get aligned to block boundaries on fseek() */
	int	_blksize;	/* stat.st_blksize (may be != _bf._size) */
	fpos_t	_offset;	/* current lseek offset (see WARNING) */
} FILE;

#endif /* __STDIO_H_ */
# 160 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_stdio.h" 3 4
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 2 3 4

__BEGIN_DECLS
extern FILE *__stdinp;
extern FILE *__stdoutp;
extern FILE *__stderrp;
__END_DECLS

#define	__SLBF	0x0001		/* line buffered */
#define	__SNBF	0x0002		/* unbuffered */
#define	__SRD	0x0004		/* OK to read */
#define	__SWR	0x0008		/* OK to write */
	/* RD and WR are never simultaneously asserted */
#define	__SRW	0x0010		/* open for reading & writing */
#define	__SEOF	0x0020		/* found EOF */
#define	__SERR	0x0040		/* found error */
#define	__SMBF	0x0080		/* _buf is from malloc */
#define	__SAPP	0x0100		/* fdopen()ed in append mode */
#define	__SSTR	0x0200		/* this is an sprintf/snprintf string */
#define	__SOPT	0x0400		/* do fseek() optimisation */
#define	__SNPT	0x0800		/* do not do fseek() optimisation */
#define	__SOFF	0x1000		/* set iff _offset is in fact correct */
#define	__SMOD	0x2000		/* true => fgetln modified _p text */
#define __SALC  0x4000		/* allocate string space dynamically */
#define __SIGN  0x8000		/* ignore this file in _fwalk */

/*
 * The following three definitions are for ANSI C, which took them
 * from System V, which brilliantly took internal interface macros and
 * made them official arguments to setvbuf(), without renaming them.
 * Hence, these ugly _IOxxx names are *supposed* to appear in user code.
 *
 * Although numbered as their counterparts above, the implementation
 * does not rely on this.
 */
#define	_IOFBF	0		/* setvbuf should set fully buffered */
#define	_IOLBF	1		/* setvbuf should set line buffered */
#define	_IONBF	2		/* setvbuf should set unbuffered */

#define	BUFSIZ	1024		/* size of buffer used by setbuf */
#define	EOF	(-1)

				/* must be == _POSIX_STREAM_MAX <limits.h> */
#define	FOPEN_MAX	20	/* must be <= OPEN_MAX <sys/syslimits.h> */
#define	FILENAME_MAX	1024	/* must be <= PATH_MAX <sys/syslimits.h> */

/* System V/ANSI C; this is the wrong way to do this, do *not* use these. */
#ifndef _ANSI_SOURCE
#define	P_tmpdir	"/var/tmp/"
#endif
# 114 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#define	L_tmpnam	1024	/* XXX must be == PATH_MAX */
#define	TMP_MAX		308915776

#ifndef SEEK_SET
#define	SEEK_SET	0	/* set file offset to offset */
#endif
# 120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#ifndef SEEK_CUR
#define	SEEK_CUR	1	/* set file offset to current plus offset */
#endif
# 123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#ifndef SEEK_END
#define	SEEK_END	2	/* set file offset to EOF plus offset */
#endif
# 126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#define	stdin	__stdinp
#define	stdout	__stdoutp
#define	stderr	__stderrp

#ifdef _DARWIN_UNLIMITED_STREAMS
#if 0 /* disabled by -frewrite-includes */
#if defined(__IPHONE_OS_VERSION_MIN_REQUIRED) && __IPHONE_OS_VERSION_MIN_REQUIRED < __IPHONE_3_2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 133 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#error "_DARWIN_UNLIMITED_STREAMS specified, but -miphoneos-version-min version does not support it."
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__MAC_OS_X_VERSION_MIN_REQUIRED) && __MAC_OS_X_VERSION_MIN_REQUIRED < __MAC_10_6
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#error "_DARWIN_UNLIMITED_STREAMS specified, but -mmacosx-version-min version does not support it."
#endif
# 137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#endif
# 138 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

/* ANSI-C */

__BEGIN_DECLS
void	 clearerr(FILE *);
int	 fclose(FILE *);
int	 feof(FILE *);
int	 ferror(FILE *);
int	 fflush(FILE *);
int	 fgetc(FILE *);
int	 fgetpos(FILE * __restrict, fpos_t *);
char	*fgets(char * __restrict, int, FILE *);
#if 0 /* disabled by -frewrite-includes */
#if defined(_DARWIN_UNLIMITED_STREAMS) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
FILE	*fopen(const char * __restrict __filename, const char * __restrict __mode) __DARWIN_ALIAS_STARTING(__MAC_10_6, __IPHONE_3_2, __DARWIN_EXTSN(fopen));
#else /* !_DARWIN_UNLIMITED_STREAMS && !_DARWIN_C_SOURCE */
# 153 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
FILE	*fopen(const char * __restrict __filename, const char * __restrict __mode) __DARWIN_ALIAS_STARTING(__MAC_10_6, __IPHONE_2_0, __DARWIN_ALIAS(fopen));
#endif /* (DARWIN_UNLIMITED_STREAMS || _DARWIN_C_SOURCE) */
# 155 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
int	 fprintf(FILE * __restrict, const char * __restrict, ...) __printflike(2, 3);
int	 fputc(int, FILE *);
int	 fputs(const char * __restrict, FILE * __restrict) __DARWIN_ALIAS(fputs);
size_t	 fread(void * __restrict __ptr, size_t __size, size_t __nitems, FILE * __restrict __stream);
FILE	*freopen(const char * __restrict, const char * __restrict,
                 FILE * __restrict) __DARWIN_ALIAS(freopen);
int	 fscanf(FILE * __restrict, const char * __restrict, ...) __scanflike(2, 3);
int	 fseek(FILE *, long, int);
int	 fsetpos(FILE *, const fpos_t *);
long	 ftell(FILE *);
size_t	 fwrite(const void * __restrict __ptr, size_t __size, size_t __nitems, FILE * __restrict __stream) __DARWIN_ALIAS(fwrite);
int	 getc(FILE *);
int	 getchar(void);
char	*gets(char *);
void	 perror(const char *);
int	 printf(const char * __restrict, ...) __printflike(1, 2);
int	 putc(int, FILE *);
int	 putchar(int);
int	 puts(const char *);
int	 remove(const char *);
int	 rename (const char *__old, const char *__new);
void	 rewind(FILE *);
int	 scanf(const char * __restrict, ...) __scanflike(1, 2);
void	 setbuf(FILE * __restrict, char * __restrict);
int	 setvbuf(FILE * __restrict, char * __restrict, int, size_t);
int	 sprintf(char * __restrict, const char * __restrict, ...) __printflike(2, 3) __swift_unavailable("Use snprintf instead.");
int	 sscanf(const char * __restrict, const char * __restrict, ...) __scanflike(2, 3);
FILE	*tmpfile(void);

__swift_unavailable("Use mkstemp(3) instead.")
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
__deprecated_msg("This function is provided for compatibility reasons only.  Due to security concerns inherent in the design of tmpnam(3), it is highly recommended that you use mkstemp(3) instead.")
#endif
# 188 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
char	*tmpnam(char *);
int	 ungetc(int, FILE *);
int	 vfprintf(FILE * __restrict, const char * __restrict, va_list) __printflike(2, 0);
int	 vprintf(const char * __restrict, va_list) __printflike(1, 0);
int	 vsprintf(char * __restrict, const char * __restrict, va_list) __printflike(2, 0) __swift_unavailable("Use vsnprintf instead.");
__END_DECLS



/* Additional functionality provided by:
 * POSIX.1-1988
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 198808L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#define	L_ctermid	1024	/* size for ctermid(); PATH_MAX */

__BEGIN_DECLS
#ifndef __CTERMID_DEFINED
/* Multiply defined in stdio.h and unistd.h by SUS */
#define __CTERMID_DEFINED 1
char	*ctermid(char *);
#endif
# 210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_DARWIN_UNLIMITED_STREAMS) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
FILE	*fdopen(int, const char *) __DARWIN_ALIAS_STARTING(__MAC_10_6, __IPHONE_3_2, __DARWIN_EXTSN(fdopen));
#else /* !_DARWIN_UNLIMITED_STREAMS && !_DARWIN_C_SOURCE */
# 214 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
FILE	*fdopen(int, const char *) __DARWIN_ALIAS_STARTING(__MAC_10_6, __IPHONE_2_0, __DARWIN_ALIAS(fdopen));
#endif /* (DARWIN_UNLIMITED_STREAMS || _DARWIN_C_SOURCE) */
# 216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
int	 fileno(FILE *);
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 198808L */
# 219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4


/* Additional functionality provided by:
 * POSIX.2-1992 C Language Binding Option
 */
#if 0 /* disabled by -frewrite-includes */
#if TARGET_OS_EMBEDDED
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#define __swift_unavailable_on(osx_msg, ios_msg) __swift_unavailable(ios_msg)
#else
# 227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#define __swift_unavailable_on(osx_msg, ios_msg) __swift_unavailable(osx_msg)
#endif
# 229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 199209L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 231 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
__BEGIN_DECLS
int	 pclose(FILE *) __swift_unavailable_on("Use posix_spawn APIs or NSTask instead.", "Process spawning is unavailable.");
#if 0 /* disabled by -frewrite-includes */
#if defined(_DARWIN_UNLIMITED_STREAMS) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 234 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
FILE	*popen(const char *, const char *) __DARWIN_ALIAS_STARTING(__MAC_10_6, __IPHONE_3_2, __DARWIN_EXTSN(popen)) __swift_unavailable_on("Use posix_spawn APIs or NSTask instead.", "Process spawning is unavailable.");
#else /* !_DARWIN_UNLIMITED_STREAMS && !_DARWIN_C_SOURCE */
# 236 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
FILE	*popen(const char *, const char *) __DARWIN_ALIAS_STARTING(__MAC_10_6, __IPHONE_2_0, __DARWIN_ALIAS(popen)) __swift_unavailable_on("Use posix_spawn APIs or NSTask instead.", "Process spawning is unavailable.");
#endif /* (DARWIN_UNLIMITED_STREAMS || _DARWIN_C_SOURCE) */
# 238 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 199209L */
# 240 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#undef __swift_unavailable_on

/* Additional functionality provided by:
 * POSIX.1c-1995,
 * POSIX.1i-1995,
 * and the omnibus ISO/IEC 9945-1: 1996
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 199506L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

/* Functions internal to the implementation. */
__BEGIN_DECLS
int	__srget(FILE *);
int	__svfscanf(FILE *, const char *, va_list) __scanflike(2, 0);
int	__swbuf(int, FILE *);
__END_DECLS

/*
 * The __sfoo macros are here so that we can
 * define function versions in the C library.
 */
#define	__sgetc(p) (--(p)->_r < 0 ? __srget(p) : (int)(*(p)->_p++))
#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__) && defined(__STDC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 264 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
__header_always_inline int __sputc(int _c, FILE *_p) {
	if (--_p->_w >= 0 || (_p->_w >= _p->_lbfsize && (char)_c != '\n'))
		return (*_p->_p++ = _c);
	else
		return (__swbuf(_c, _p));
}
#else
# 271 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
/*
 * This has been tuned to generate reasonable code on the vax using pcc.
 */
#define	__sputc(c, p) \
	(--(p)->_w < 0 ? \
		(p)->_w >= (p)->_lbfsize ? \
			(*(p)->_p = (c)), *(p)->_p != '\n' ? \
				(int)*(p)->_p++ : \
				__swbuf('\n', p) : \
			__swbuf((int)(c), p) : \
		(*(p)->_p = (c), (int)*(p)->_p++))
#endif
# 283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#define	__sfeof(p)	(((p)->_flags & __SEOF) != 0)
#define	__sferror(p)	(((p)->_flags & __SERR) != 0)
#define	__sclearerr(p)	((void)((p)->_flags &= ~(__SERR|__SEOF)))
#define	__sfileno(p)	((p)->_file)

__BEGIN_DECLS
void	 flockfile(FILE *);
int	 ftrylockfile(FILE *);
void	 funlockfile(FILE *);
int	 getc_unlocked(FILE *);
int	 getchar_unlocked(void);
int	 putc_unlocked(int, FILE *);
int	 putchar_unlocked(int);

/* Removed in Issue 6 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || _POSIX_C_SOURCE < 200112L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 300 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
int	 getw(FILE *);
int	 putw(int, FILE *);
#endif
# 303 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

__swift_unavailable("Use mkstemp(3) instead.")
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 306 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
__deprecated_msg("This function is provided for compatibility reasons only.  Due to security concerns inherent in the design of tempnam(3), it is highly recommended that you use mkstemp(3) instead.")
#endif
# 308 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
char	*tempnam(const char *__dir, const char *__prefix) __DARWIN_ALIAS(tempnam);
__END_DECLS

#ifndef lint
#define	getc_unlocked(fp)	__sgetc(fp)
#define putc_unlocked(x, fp)	__sputc(x, fp)
#endif /* lint */
# 315 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#define	getchar_unlocked()	getc_unlocked(stdin)
#define	putchar_unlocked(x)	putc_unlocked(x, stdout)
#endif /* __DARWIN_C_LEVEL >= 199506L */
# 319 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4



/* Additional functionality provided by:
 * POSIX.1-2001
 * ISO C99
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200112L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 328 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_off_t.h>
#endif /* expanded by -frewrite-includes */
# 328 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_off_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _OFF_T
#define _OFF_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_off_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_off_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_off_t.h" 3 4
typedef __darwin_off_t          off_t;
#endif  /* _OFF_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_off_t.h" 3 4
# 329 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 2 3 4

__BEGIN_DECLS
int	 fseeko(FILE * __stream, off_t __offset, int __whence);
off_t	 ftello(FILE * __stream);
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 200112L */
# 335 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200112L || defined(_C99_SOURCE) || defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 337 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
__BEGIN_DECLS
int	 snprintf(char * __restrict __str, size_t __size, const char * __restrict __format, ...) __printflike(3, 4);
int	 vfscanf(FILE * __restrict __stream, const char * __restrict __format, va_list) __scanflike(2, 0);
int	 vscanf(const char * __restrict __format, va_list) __scanflike(1, 0);
int	 vsnprintf(char * __restrict __str, size_t __size, const char * __restrict __format, va_list) __printflike(3, 0);
int	 vsscanf(const char * __restrict __str, const char * __restrict __format, va_list) __scanflike(2, 0);
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 200112L || defined(_C99_SOURCE) || defined(__cplusplus) */
# 345 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4



/* Additional functionality provided by:
 * POSIX.1-2008
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200809L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ssize_t.h>
#endif /* expanded by -frewrite-includes */
# 353 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
# 354 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

__BEGIN_DECLS
int	dprintf(int, const char * __restrict, ...) __printflike(2, 3) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
int	vdprintf(int, const char * __restrict, va_list) __printflike(2, 0) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
ssize_t getdelim(char ** __restrict __linep, size_t * __restrict __linecapp, int __delimiter, FILE * __restrict __stream) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
ssize_t getline(char ** __restrict __linep, size_t * __restrict __linecapp, FILE * __restrict __stream) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
FILE *fmemopen(void * __restrict __buf, size_t __size, const char * __restrict __mode) __API_AVAILABLE(macos(10.13), ios(11.0), tvos(11.0), watchos(4.0));
FILE *open_memstream(char **__bufp, size_t *__sizep) __API_AVAILABLE(macos(10.13), ios(11.0), tvos(11.0), watchos(4.0));
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 200809L */
# 364 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4



/* Darwin extensions */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 370 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
__BEGIN_DECLS
extern __const int sys_nerr;		/* perror(3) external variables */
extern __const char *__const sys_errlist[];

int	 asprintf(char ** __restrict, const char * __restrict, ...) __printflike(2, 3);
char	*ctermid_r(char *);
char	*fgetln(FILE *, size_t *);
__const char *fmtcheck(const char *, const char *);
int	 fpurge(FILE *);
void	 setbuffer(FILE *, char *, int);
int	 setlinebuf(FILE *);
int	 vasprintf(char ** __restrict, const char * __restrict, va_list) __printflike(2, 0);
FILE	*zopen(const char *, const char *, int);


/*
 * Stdio function-access interface.
 */
FILE	*funopen(const void *,
                 int (* _Nullable)(void *, char *, int),
                 int (* _Nullable)(void *, const char *, int),
                 fpos_t (* _Nullable)(void *, fpos_t, int),
                 int (* _Nullable)(void *));
__END_DECLS
#define	fropen(cookie, fn) funopen(cookie, fn, 0, 0, 0)
#define	fwopen(cookie, fn) funopen(cookie, 0, fn, 0, 0)

#define	feof_unlocked(p)	__sfeof(p)
#define	ferror_unlocked(p)	__sferror(p)
#define	clearerr_unlocked(p)	__sclearerr(p)
#define	fileno_unlocked(p)	__sfileno(p)

#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 403 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4


#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_stdio.h>
#endif /* expanded by -frewrite-includes */
# 406 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
# 407 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 408 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined (__GNUC__) && _FORTIFY_SOURCE > 0 && !defined (__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 410 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
/* Security checking functions.  */
#if 0 /* expanded by -frewrite-includes */
#include <secure/_stdio.h>
#endif /* expanded by -frewrite-includes */
# 411 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
# 412 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
#endif
# 413 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4

#endif /* _STDIO_H_ */
# 415 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/stdio.h" 3 4
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 2 3

#ifdef __cplusplus

#undef getc
#undef putc
#undef clearerr
#undef feof
#undef ferror

#endif
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#endif  // _LIBCPP_STDIO_H
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <time.h>
#endif /* expanded by -frewrite-includes */
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 1 3 4
/*
 * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)time.h	8.3 (Berkeley) 1/21/94
 */

#ifndef _TIME_H_
#define	_TIME_H_

#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_clock_t.h>
#endif /* expanded by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_clock_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _CLOCK_T
#define _CLOCK_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_clock_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_clock_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_clock_t.h" 3 4
typedef __darwin_clock_t        clock_t;
#endif /* _CLOCK_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_clock_t.h" 3 4
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_null.h>
#endif /* expanded by -frewrite-includes */
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef NULL
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __DARWIN_NULL */
#endif /* expanded by -frewrite-includes */
# 29 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
#define NULL  __DARWIN_NULL
#endif  /* NULL */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_null.h" 3 4
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_time_t.h>
#endif /* expanded by -frewrite-includes */
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_time_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _TIME_T
#define _TIME_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_time_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_time_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_time_t.h" 3 4
typedef __darwin_time_t         time_t;
#endif  /* _TIME_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_time_t.h" 3 4
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_timespec.h>
#endif /* expanded by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timespec.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _STRUCT_TIMESPEC
#define _STRUCT_TIMESPEC        struct timespec

#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_time_t */
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timespec.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timespec.h" 3 4

_STRUCT_TIMESPEC
{
	__darwin_time_t tv_sec;
	long            tv_nsec;
};
#endif /* _STRUCT_TIMESPEC */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_timespec.h" 3 4
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 2 3 4

struct tm {
	int	tm_sec;		/* seconds after the minute [0-60] */
	int	tm_min;		/* minutes after the hour [0-59] */
	int	tm_hour;	/* hours since midnight [0-23] */
	int	tm_mday;	/* day of the month [1-31] */
	int	tm_mon;		/* months since January [0-11] */
	int	tm_year;	/* years since 1900 */
	int	tm_wday;	/* days since Sunday [0-6] */
	int	tm_yday;	/* days since January 1 [0-365] */
	int	tm_isdst;	/* Daylight Savings Time flag */
	long	tm_gmtoff;	/* offset from UTC in seconds */
	char	*tm_zone;	/* timezone abbreviation */
};

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 89 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#define CLOCKS_PER_SEC  1000000	/* [XSI] */
#else /* !__DARWIN_UNIX03 */
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_limits.h>	/* Include file containing CLK_TCK. */
#endif /* expanded by -frewrite-includes */
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

#define CLOCKS_PER_SEC  (__DARWIN_CLK_TCK)
#endif /* __DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

#ifndef _ANSI_SOURCE
extern char *tzname[];
#endif
# 99 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

extern int getdate_err;
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 102 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
extern long timezone __DARWIN_ALIAS(timezone);
#endif /* __DARWIN_UNIX03 */
# 104 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
extern int daylight;

__BEGIN_DECLS
char *asctime(const struct tm *);
clock_t clock(void) __DARWIN_ALIAS(clock);
char *ctime(const time_t *);
double difftime(time_t, time_t);
struct tm *getdate(const char *);
struct tm *gmtime(const time_t *);
struct tm *localtime(const time_t *);
time_t mktime(struct tm *) __DARWIN_ALIAS(mktime);
size_t strftime(char * __restrict, size_t, const char * __restrict, const struct tm * __restrict) __DARWIN_ALIAS(strftime);
char *strptime(const char * __restrict, const char * __restrict, struct tm * __restrict) __DARWIN_ALIAS(strptime);
time_t time(time_t *);

#ifndef _ANSI_SOURCE
void tzset(void);
#endif /* not ANSI */
# 122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

/* [TSF] Thread safe functions */
char *asctime_r(const struct tm * __restrict, char * __restrict);
char *ctime_r(const time_t *, char *);
struct tm *gmtime_r(const time_t * __restrict, struct tm * __restrict);
struct tm *localtime_r(const time_t * __restrict, struct tm * __restrict);

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 130 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
time_t posix2time(time_t);
#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 132 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
char *timezone(int, int);
#endif /* !__DARWIN_UNIX03 */
# 134 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
void tzsetwall(void);
time_t time2posix(time_t);
time_t timelocal(struct tm * const);
time_t timegm(struct tm * const);
#endif /* neither ANSI nor POSIX */
# 139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 141 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
int nanosleep(const struct timespec *__rqtp, struct timespec *__rmtp) __DARWIN_ALIAS_C(nanosleep);
#endif
# 143 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_DARWIN_FEATURE_CLOCK_GETTIME) || _DARWIN_FEATURE_CLOCK_GETTIME != 0
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 199309L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 146 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(enumerator_attributes)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#define __CLOCK_AVAILABILITY __OSX_AVAILABLE(10.12) __IOS_AVAILABLE(10.0) __TVOS_AVAILABLE(10.0) __WATCHOS_AVAILABLE(3.0)
#else
# 149 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#define __CLOCK_AVAILABILITY
#endif
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

typedef enum {
_CLOCK_REALTIME __CLOCK_AVAILABILITY = 0,
#define CLOCK_REALTIME _CLOCK_REALTIME
_CLOCK_MONOTONIC __CLOCK_AVAILABILITY = 6,
#define CLOCK_MONOTONIC _CLOCK_MONOTONIC
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
_CLOCK_MONOTONIC_RAW __CLOCK_AVAILABILITY = 4,
#define CLOCK_MONOTONIC_RAW _CLOCK_MONOTONIC_RAW
_CLOCK_MONOTONIC_RAW_APPROX __CLOCK_AVAILABILITY = 5,
#define CLOCK_MONOTONIC_RAW_APPROX _CLOCK_MONOTONIC_RAW_APPROX
_CLOCK_UPTIME_RAW __CLOCK_AVAILABILITY = 8,
#define CLOCK_UPTIME_RAW _CLOCK_UPTIME_RAW
_CLOCK_UPTIME_RAW_APPROX __CLOCK_AVAILABILITY = 9,
#define CLOCK_UPTIME_RAW_APPROX _CLOCK_UPTIME_RAW_APPROX
#endif
# 167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
_CLOCK_PROCESS_CPUTIME_ID __CLOCK_AVAILABILITY = 12,
#define CLOCK_PROCESS_CPUTIME_ID _CLOCK_PROCESS_CPUTIME_ID
_CLOCK_THREAD_CPUTIME_ID __CLOCK_AVAILABILITY = 16
#define CLOCK_THREAD_CPUTIME_ID _CLOCK_THREAD_CPUTIME_ID
} clockid_t;

__CLOCK_AVAILABILITY
int clock_getres(clockid_t __clock_id, struct timespec *__res);

__CLOCK_AVAILABILITY
int clock_gettime(clockid_t __clock_id, struct timespec *__tp);

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 180 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
__CLOCK_AVAILABILITY
__uint64_t clock_gettime_nsec_np(clockid_t __clock_id);
#endif
# 183 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

__OSX_AVAILABLE(10.12) __IOS_PROHIBITED
__TVOS_PROHIBITED __WATCHOS_PROHIBITED
int clock_settime(clockid_t __clock_id, const struct timespec *__tp);

#undef __CLOCK_AVAILABILITY
#endif /* __DARWIN_C_LEVEL */
# 190 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#endif /* _DARWIN_FEATURE_CLOCK_GETTIME */
# 191 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

__END_DECLS

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_time.h>
#endif /* expanded by -frewrite-includes */
# 195 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 196 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 197 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4

#endif /* !_TIME_H_ */
# 199 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/time.h" 3 4
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_wctype.h>
#endif /* expanded by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 1 3 4
/*-
 * Copyright (c)1999 Citrus Project,
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

/*
 * Common header for wctype.h and wchar.h
 *
 * Contains everything required by wctype.h except:
 *
 *	#include <_types/_wctrans_t.h>
 *	int iswblank(wint_t);
 *	wint_t towctrans(wint_t, wctrans_t);
 *	wctrans_t wctrans(const char *);
 */

#ifndef __WCTYPE_H_
#define __WCTYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <__wctype.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 1 3 4
/*
 * Copyright (c) 2017 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
/*-
 * Copyright (c)1999 Citrus Project,
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

/*
 * Common header for _wctype.h and xlocale/__wctype.h
 */

#ifndef ___WCTYPE_H_
#define ___WCTYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 57 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
# 59 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_wint_t.h>
#endif /* expanded by -frewrite-includes */
# 60 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wint_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _WINT_T
#define _WINT_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_wint_t */
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wint_t.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wint_t.h" 3 4
typedef __darwin_wint_t wint_t;
#endif /* _WINT_T */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wint_t.h" 3 4
# 61 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_wint_t.h>
#endif /* expanded by -frewrite-includes */
# 61 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types/_wctype_t.h>
#endif /* expanded by -frewrite-includes */
# 62 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_wctype_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _WCTYPE_T
#define _WCTYPE_T 
#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_wctype_t.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_wctype_t.h" 3 4
typedef __darwin_wctype_t wctype_t;
#endif /* _WCTYPE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_wctype_t.h" 3 4
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 2 3 4

#ifndef WEOF
#define WEOF			__DARWIN_WEOF
#endif
# 67 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4

#ifndef __DARWIN_WCTYPE_TOP_inline
#define __DARWIN_WCTYPE_TOP_inline __header_inline
#endif
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <ctype.h>
#endif /* expanded by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 1 3 4
// -*- C++ -*-
//===---------------------------- ctype.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CTYPE_H
#define _LIBCPP_CTYPE_H

/*
    ctype.h synopsis

int isalnum(int c);
int isalpha(int c);
int isblank(int c);  // C99
int iscntrl(int c);
int isdigit(int c);
int isgraph(int c);
int islower(int c);
int isprint(int c);
int ispunct(int c);
int isspace(int c);
int isupper(int c);
int isxdigit(int c);
int tolower(int c);
int toupper(int c);
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 3 4
# 33 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 35 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 36 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 3
#endif
# 37 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <ctype.h>
#endif /* expanded by -frewrite-includes */
# 38 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/ctype.h" 1 3 4
/*
 * Copyright (c) 2000, 2005, 2008 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * This code is derived from software contributed to Berkeley by
 * Paul Borman at Krystal Technologies.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)ctype.h	8.4 (Berkeley) 1/21/94
 */

#ifndef	_CTYPE_H_
#define _CTYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <_ctype.h>
#endif /* expanded by -frewrite-includes */
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/ctype.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 1 3 4
/*
 * Copyright (c) 2000, 2005, 2008 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * This code is derived from software contributed to Berkeley by
 * Paul Borman at Krystal Technologies.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)ctype.h	8.4 (Berkeley) 1/21/94
 */

#ifndef	__CTYPE_H_
#define __CTYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <runetype.h>
#endif /* expanded by -frewrite-includes */
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 1 3 4
/*-
 * Copyright (c) 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Paul Borman at Krystal Technologies.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)runetype.h	8.1 (Berkeley) 6/2/93
 */

#ifndef	_RUNETYPE_H_
#define	_RUNETYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 47 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ct_rune_t.h>
#endif /* expanded by -frewrite-includes */
# 47 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
# 48 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_rune_t.h>
#endif /* expanded by -frewrite-includes */
# 48 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
# 49 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_wchar_t.h>
#endif /* expanded by -frewrite-includes */
# 49 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

/* wchar_t is a built-in type in C++ */
#ifndef __cplusplus
#ifndef _WCHAR_T
#define _WCHAR_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_wchar_t */
#endif /* expanded by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
typedef __darwin_wchar_t wchar_t;
#endif /* _WCHAR_T */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
#endif /* __cplusplus */
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
# 50 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_wint_t.h>
#endif /* expanded by -frewrite-includes */
# 50 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
# 51 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4

#endif /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 53 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4

#define	_CACHED_RUNES	(1 <<8 )	/* Must be a power of 2 */
#define	_CRMASK		(~(_CACHED_RUNES - 1))

/*
 * The lower 8 bits of runetype[] contain the digit value of the rune.
 */
typedef struct {
	__darwin_rune_t	__min;		/* First rune of the range */
	__darwin_rune_t	__max;		/* Last rune (inclusive) of the range */
	__darwin_rune_t	__map;		/* What first maps to in maps */
	__uint32_t	*__types;	/* Array of types in range */
} _RuneEntry;

typedef struct {
	int		__nranges;	/* Number of ranges stored */
	_RuneEntry	*__ranges;	/* Pointer to the ranges */
} _RuneRange;

typedef struct {
	char		__name[14];	/* CHARCLASS_NAME_MAX = 14 */
	__uint32_t	__mask;		/* charclass mask */
} _RuneCharClass;

typedef struct {
	char		__magic[8];	/* Magic saying what version we are */
	char		__encoding[32];	/* ASCII name of this encoding */

	__darwin_rune_t	(*__sgetrune)(const char *, __darwin_size_t, char const **);
	int		(*__sputrune)(__darwin_rune_t, char *, __darwin_size_t, char **);
	__darwin_rune_t	__invalid_rune;

	__uint32_t	__runetype[_CACHED_RUNES];
	__darwin_rune_t	__maplower[_CACHED_RUNES];
	__darwin_rune_t	__mapupper[_CACHED_RUNES];

	/*
	 * The following are to deal with Runes larger than _CACHED_RUNES - 1.
	 * Their data is actually contiguous with this structure so as to make
	 * it easier to read/write from/to disk.
	 */
	_RuneRange	__runetype_ext;
	_RuneRange	__maplower_ext;
	_RuneRange	__mapupper_ext;

	void		*__variable;	/* Data which depends on the encoding */
	int		__variable_len;	/* how long that data is */

	/*
	 * extra fields to deal with arbitrary character classes
	 */
	int		__ncharclasses;
	_RuneCharClass	*__charclasses;
} _RuneLocale;

#define	_RUNE_MAGIC_A	"RuneMagA"	/* Indicates version A of RuneLocale */

__BEGIN_DECLS
extern _RuneLocale _DefaultRuneLocale;
extern _RuneLocale *_CurrentRuneLocale;
__END_DECLS

#endif	/* !_RUNETYPE_H_ */
# 116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/runetype.h" 3 4
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 2 3 4

#define	_CTYPE_A	0x00000100L		/* Alpha */
#define	_CTYPE_C	0x00000200L		/* Control */
#define	_CTYPE_D	0x00000400L		/* Digit */
#define	_CTYPE_G	0x00000800L		/* Graph */
#define	_CTYPE_L	0x00001000L		/* Lower */
#define	_CTYPE_P	0x00002000L		/* Punct */
#define	_CTYPE_S	0x00004000L		/* Space */
#define	_CTYPE_U	0x00008000L		/* Upper */
#define	_CTYPE_X	0x00010000L		/* X digit */
#define	_CTYPE_B	0x00020000L		/* Blank */
#define	_CTYPE_R	0x00040000L		/* Print */
#define	_CTYPE_I	0x00080000L		/* Ideogram */
#define	_CTYPE_T	0x00100000L		/* Special */
#define	_CTYPE_Q	0x00200000L		/* Phonogram */
#define	_CTYPE_SW0	0x20000000L		/* 0 width character */
#define	_CTYPE_SW1	0x40000000L		/* 1 width character */
#define	_CTYPE_SW2	0x80000000L		/* 2 width character */
#define	_CTYPE_SW3	0xc0000000L		/* 3 width character */
#define	_CTYPE_SWM	0xe0000000L		/* Mask for screen width data */
#define	_CTYPE_SWS	30			/* Bits to shift to get width */

#ifdef _NONSTD_SOURCE
/*
 * Backward compatibility
 */
#define	_A		_CTYPE_A		/* Alpha */
#define	_C		_CTYPE_C		/* Control */
#define	_D		_CTYPE_D		/* Digit */
#define	_G		_CTYPE_G		/* Graph */
#define	_L		_CTYPE_L		/* Lower */
#define	_P		_CTYPE_P		/* Punct */
#define	_S		_CTYPE_S		/* Space */
#define	_U		_CTYPE_U		/* Upper */
#define	_X		_CTYPE_X		/* X digit */
#define	_B		_CTYPE_B		/* Blank */
#define	_R		_CTYPE_R		/* Print */
#define	_I		_CTYPE_I		/* Ideogram */
#define	_T		_CTYPE_T		/* Special */
#define	_Q		_CTYPE_Q		/* Phonogram */
#define	_SW0		_CTYPE_SW0		/* 0 width character */
#define	_SW1		_CTYPE_SW1		/* 1 width character */
#define	_SW2		_CTYPE_SW2		/* 2 width character */
#define	_SW3		_CTYPE_SW3		/* 3 width character */
#endif /* _NONSTD_SOURCE */
# 116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4

#define __DARWIN_CTYPE_inline		__header_inline

#define __DARWIN_CTYPE_TOP_inline	__header_inline

/*
 * Use inline functions if we are allowed to and the compiler supports them.
 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_DONT_USE_CTYPE_INLINE_) && \
    (defined(_USE_CTYPE_INLINE_) || defined(__GNUC__) || defined(__cplusplus))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 126 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4

/* See comments in <machine/_type.h> about __darwin_ct_rune_t. */
__BEGIN_DECLS
unsigned long		___runetype(__darwin_ct_rune_t);
__darwin_ct_rune_t	___tolower(__darwin_ct_rune_t);
__darwin_ct_rune_t	___toupper(__darwin_ct_rune_t);
__END_DECLS

__DARWIN_CTYPE_TOP_inline int
isascii(int _c)
{
	return ((_c & ~0x7F) == 0);
}

#ifdef USE_ASCII
__DARWIN_CTYPE_inline int
__maskrune(__darwin_ct_rune_t _c, unsigned long _f)
{
	return (int)_DefaultRuneLocale.__runetype[_c & 0xff] & (__uint32_t)_f;
}
#else /* !USE_ASCII */
# 147 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
__BEGIN_DECLS
int             	__maskrune(__darwin_ct_rune_t, unsigned long);
__END_DECLS
#endif /* USE_ASCII */
# 151 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4

__DARWIN_CTYPE_inline int
__istype(__darwin_ct_rune_t _c, unsigned long _f)
{
#ifdef USE_ASCII
	return !!(__maskrune(_c, _f));
#else /* USE_ASCII */
# 158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
	return (isascii(_c) ? !!(_DefaultRuneLocale.__runetype[_c] & _f)
		: !!__maskrune(_c, _f));
#endif /* USE_ASCII */
# 161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
}

__DARWIN_CTYPE_inline __darwin_ct_rune_t
__isctype(__darwin_ct_rune_t _c, unsigned long _f)
{
#ifdef USE_ASCII
	return !!(__maskrune(_c, _f));
#else /* USE_ASCII */
# 169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
	return (_c < 0 || _c >= _CACHED_RUNES) ? 0 :
		!!(_DefaultRuneLocale.__runetype[_c] & _f);
#endif /* USE_ASCII */
# 172 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
}

#ifdef USE_ASCII
__DARWIN_CTYPE_inline __darwin_ct_rune_t
__toupper(__darwin_ct_rune_t _c)
{
	return _DefaultRuneLocale.__mapupper[_c & 0xff];
}

__DARWIN_CTYPE_inline __darwin_ct_rune_t
__tolower(__darwin_ct_rune_t _c)
{
	return _DefaultRuneLocale.__maplower[_c & 0xff];
}
#else /* !USE_ASCII */
# 187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
__BEGIN_DECLS
__darwin_ct_rune_t	__toupper(__darwin_ct_rune_t);
__darwin_ct_rune_t	__tolower(__darwin_ct_rune_t);
__END_DECLS
#endif /* USE_ASCII */
# 192 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4

__DARWIN_CTYPE_inline int
__wcwidth(__darwin_ct_rune_t _c)
{
	unsigned int _x;

	if (_c == 0)
		return (0);
	_x = (unsigned int)__maskrune(_c, _CTYPE_SWM|_CTYPE_R);
	if ((_x & _CTYPE_SWM) != 0)
		return ((_x & _CTYPE_SWM) >> _CTYPE_SWS);
	return ((_x & _CTYPE_R) != 0 ? 1 : -1);
}

#ifndef _EXTERNALIZE_CTYPE_INLINES_

#define	_tolower(c)	__tolower(c)
#define	_toupper(c)	__toupper(c)

__DARWIN_CTYPE_TOP_inline int
isalnum(int _c)
{
	return (__istype(_c, _CTYPE_A|_CTYPE_D));
}

__DARWIN_CTYPE_TOP_inline int
isalpha(int _c)
{
	return (__istype(_c, _CTYPE_A));
}

__DARWIN_CTYPE_TOP_inline int
isblank(int _c)
{
	return (__istype(_c, _CTYPE_B));
}

__DARWIN_CTYPE_TOP_inline int
iscntrl(int _c)
{
	return (__istype(_c, _CTYPE_C));
}

/* ANSI -- locale independent */
__DARWIN_CTYPE_TOP_inline int
isdigit(int _c)
{
	return (__isctype(_c, _CTYPE_D));
}

__DARWIN_CTYPE_TOP_inline int
isgraph(int _c)
{
	return (__istype(_c, _CTYPE_G));
}

__DARWIN_CTYPE_TOP_inline int
islower(int _c)
{
	return (__istype(_c, _CTYPE_L));
}

__DARWIN_CTYPE_TOP_inline int
isprint(int _c)
{
	return (__istype(_c, _CTYPE_R));
}

__DARWIN_CTYPE_TOP_inline int
ispunct(int _c)
{
	return (__istype(_c, _CTYPE_P));
}

__DARWIN_CTYPE_TOP_inline int
isspace(int _c)
{
	return (__istype(_c, _CTYPE_S));
}

__DARWIN_CTYPE_TOP_inline int
isupper(int _c)
{
	return (__istype(_c, _CTYPE_U));
}

/* ANSI -- locale independent */
__DARWIN_CTYPE_TOP_inline int
isxdigit(int _c)
{
	return (__isctype(_c, _CTYPE_X));
}

__DARWIN_CTYPE_TOP_inline int
toascii(int _c)
{
	return (_c & 0x7F);
}

__DARWIN_CTYPE_TOP_inline int
tolower(int _c)
{
        return (__tolower(_c));
}

__DARWIN_CTYPE_TOP_inline int
toupper(int _c)
{
        return (__toupper(_c));
}

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 304 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
__DARWIN_CTYPE_TOP_inline int
digittoint(int _c)
{
	return (__maskrune(_c, 0x0F));
}

__DARWIN_CTYPE_TOP_inline int
ishexnumber(int _c)
{
	return (__istype(_c, _CTYPE_X));
}

__DARWIN_CTYPE_TOP_inline int
isideogram(int _c)
{
	return (__istype(_c, _CTYPE_I));
}

__DARWIN_CTYPE_TOP_inline int
isnumber(int _c)
{
	return (__istype(_c, _CTYPE_D));
}

__DARWIN_CTYPE_TOP_inline int
isphonogram(int _c)
{
	return (__istype(_c, _CTYPE_Q));
}

__DARWIN_CTYPE_TOP_inline int
isrune(int _c)
{
	return (__istype(_c, 0xFFFFFFF0L));
}

__DARWIN_CTYPE_TOP_inline int
isspecial(int _c)
{
	return (__istype(_c, _CTYPE_T));
}
#endif /* !_ANSI_SOURCE && (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 346 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
#endif /* _EXTERNALIZE_CTYPE_INLINES_ */
# 347 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4

#else /* not using inlines */
# 349 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4

__BEGIN_DECLS
int     isalnum(int);
int     isalpha(int);
int     isblank(int);
int     iscntrl(int);
int     isdigit(int);
int     isgraph(int);
int     islower(int);
int     isprint(int);
int     ispunct(int);
int     isspace(int);
int     isupper(int);
int     isxdigit(int);
int     tolower(int);
int     toupper(int);
int     isascii(int);
int     toascii(int);

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 369 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
int     _tolower(int);
int     _toupper(int);
int     digittoint(int);
int     ishexnumber(int);
int     isideogram(int);
int     isnumber(int);
int     isphonogram(int);
int     isrune(int);
int     isspecial(int);
#endif
# 379 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
__END_DECLS

#endif /* using inlines */
# 382 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_ctype.h>
#endif /* expanded by -frewrite-includes */
# 384 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
# 385 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 386 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4

#endif /* !_CTYPE_H_ */
# 388 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_ctype.h" 3 4
# 70 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/ctype.h" 2 3 4

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_ctype.h>
#endif /* expanded by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/ctype.h" 3 4
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/ctype.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/ctype.h" 3 4

#endif /* !_CTYPE_H_ */
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/ctype.h" 3 4
# 39 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 2 3

#ifdef __cplusplus

#undef isalnum
#undef isalpha
#undef isblank
#undef iscntrl
#undef isdigit
#undef isgraph
#undef islower
#undef isprint
#undef ispunct
#undef isspace
#undef isupper
#undef isxdigit
#undef tolower
#undef toupper

#endif
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 3

#endif  // _LIBCPP_CTYPE_H
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctype.h" 3
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 2 3 4

#endif /* ___WCTYPE_H_ */
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/__wctype.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 2 3 4

/*
 * Use inline functions if we are allowed to and the compiler supports them.
 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_DONT_USE_CTYPE_INLINE_) && \
    (defined(_USE_CTYPE_INLINE_) || defined(__GNUC__) || defined(__cplusplus))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 49 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 3 4

__DARWIN_WCTYPE_TOP_inline int
iswalnum(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_A|_CTYPE_D));
}

__DARWIN_WCTYPE_TOP_inline int
iswalpha(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_A));
}

__DARWIN_WCTYPE_TOP_inline int
iswcntrl(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_C));
}

__DARWIN_WCTYPE_TOP_inline int
iswctype(wint_t _wc, wctype_t _charclass)
{
	return (__istype(_wc, _charclass));
}

__DARWIN_WCTYPE_TOP_inline int
iswdigit(wint_t _wc)
{
	return (__isctype(_wc, _CTYPE_D));
}

__DARWIN_WCTYPE_TOP_inline int
iswgraph(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_G));
}

__DARWIN_WCTYPE_TOP_inline int
iswlower(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_L));
}

__DARWIN_WCTYPE_TOP_inline int
iswprint(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_R));
}

__DARWIN_WCTYPE_TOP_inline int
iswpunct(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_P));
}

__DARWIN_WCTYPE_TOP_inline int
iswspace(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_S));
}

__DARWIN_WCTYPE_TOP_inline int
iswupper(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_U));
}

__DARWIN_WCTYPE_TOP_inline int
iswxdigit(wint_t _wc)
{
	return (__isctype(_wc, _CTYPE_X));
}

__DARWIN_WCTYPE_TOP_inline wint_t
towlower(wint_t _wc)
{
        return (__tolower(_wc));
}

__DARWIN_WCTYPE_TOP_inline wint_t
towupper(wint_t _wc)
{
        return (__toupper(_wc));
}

#else /* not using inlines */
# 135 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 3 4

__BEGIN_DECLS
int	iswalnum(wint_t);
int	iswalpha(wint_t);
int	iswcntrl(wint_t);
int	iswctype(wint_t, wctype_t);
int	iswdigit(wint_t);
int	iswgraph(wint_t);
int	iswlower(wint_t);
int	iswprint(wint_t);
int	iswpunct(wint_t);
int	iswspace(wint_t);
int	iswupper(wint_t);
int	iswxdigit(wint_t);
wint_t	towlower(wint_t);
wint_t	towupper(wint_t);
__END_DECLS

#endif /* using inlines */
# 154 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 3 4

__BEGIN_DECLS
wctype_t
	wctype(const char *);
__END_DECLS

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/__wctype.h>
#endif /* expanded by -frewrite-includes */
# 161 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 3 4
# 162 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 3 4

#endif /* __WCTYPE_H_ */
# 165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_wctype.h" 3 4
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 2 3 4


/* Initially added in Issue 4 */
__BEGIN_DECLS
wint_t	btowc(int);
wint_t	fgetwc(FILE *);
wchar_t	*fgetws(wchar_t * __restrict, int, FILE * __restrict);
wint_t	fputwc(wchar_t, FILE *);
int	fputws(const wchar_t * __restrict, FILE * __restrict);
int	fwide(FILE *, int);
int	fwprintf(FILE * __restrict, const wchar_t * __restrict, ...);
int	fwscanf(FILE * __restrict, const wchar_t * __restrict, ...);
wint_t	getwc(FILE *);
wint_t	getwchar(void);
size_t	mbrlen(const char * __restrict, size_t, mbstate_t * __restrict);
size_t	mbrtowc(wchar_t * __restrict, const char * __restrict, size_t,
	    mbstate_t * __restrict);
int	mbsinit(const mbstate_t *);
size_t	mbsrtowcs(wchar_t * __restrict, const char ** __restrict, size_t,
	    mbstate_t * __restrict);
wint_t	putwc(wchar_t, FILE *);
wint_t	putwchar(wchar_t);
int	swprintf(wchar_t * __restrict, size_t, const wchar_t * __restrict, ...);
int	swscanf(const wchar_t * __restrict, const wchar_t * __restrict, ...);
wint_t	ungetwc(wint_t, FILE *);
int	vfwprintf(FILE * __restrict, const wchar_t * __restrict,
	    __darwin_va_list);
int	vswprintf(wchar_t * __restrict, size_t, const wchar_t * __restrict,
	    __darwin_va_list);
int	vwprintf(const wchar_t * __restrict, __darwin_va_list);
size_t	wcrtomb(char * __restrict, wchar_t, mbstate_t * __restrict);
wchar_t	*wcscat(wchar_t * __restrict, const wchar_t * __restrict);
wchar_t	*wcschr(const wchar_t *, wchar_t);
int	wcscmp(const wchar_t *, const wchar_t *);
int	wcscoll(const wchar_t *, const wchar_t *);
wchar_t	*wcscpy(wchar_t * __restrict, const wchar_t * __restrict);
size_t	wcscspn(const wchar_t *, const wchar_t *);
size_t	wcsftime(wchar_t * __restrict, size_t, const wchar_t * __restrict,
	    const struct tm * __restrict) __DARWIN_ALIAS(wcsftime);
size_t	wcslen(const wchar_t *);
wchar_t	*wcsncat(wchar_t * __restrict, const wchar_t * __restrict, size_t);
int	wcsncmp(const wchar_t *, const wchar_t *, size_t);
wchar_t	*wcsncpy(wchar_t * __restrict , const wchar_t * __restrict, size_t);
wchar_t	*wcspbrk(const wchar_t *, const wchar_t *);
wchar_t	*wcsrchr(const wchar_t *, wchar_t);
size_t	wcsrtombs(char * __restrict, const wchar_t ** __restrict, size_t,
	    mbstate_t * __restrict);
size_t	wcsspn(const wchar_t *, const wchar_t *);
wchar_t	*wcsstr(const wchar_t * __restrict, const wchar_t * __restrict);
size_t	wcsxfrm(wchar_t * __restrict, const wchar_t * __restrict, size_t);
int	wctob(wint_t);
double	wcstod(const wchar_t * __restrict, wchar_t ** __restrict);
wchar_t	*wcstok(wchar_t * __restrict, const wchar_t * __restrict,
	    wchar_t ** __restrict);
long	 wcstol(const wchar_t * __restrict, wchar_t ** __restrict, int);
unsigned long
	 wcstoul(const wchar_t * __restrict, wchar_t ** __restrict, int);
wchar_t	*wmemchr(const wchar_t *, wchar_t, size_t);
int	wmemcmp(const wchar_t *, const wchar_t *, size_t);
wchar_t	*wmemcpy(wchar_t * __restrict, const wchar_t * __restrict, size_t);
wchar_t	*wmemmove(wchar_t *, const wchar_t *, size_t);
wchar_t	*wmemset(wchar_t *, wchar_t, size_t);
int	wprintf(const wchar_t * __restrict, ...);
int	wscanf(const wchar_t * __restrict, ...);
int	wcswidth(const wchar_t *, size_t);
int	wcwidth(wchar_t);
__END_DECLS



/* Additional functionality provided by:
 * POSIX.1-2001
 * ISO C99
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200112L || defined(_C99_SOURCE) || defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
__BEGIN_DECLS
int	vfwscanf(FILE * __restrict, const wchar_t * __restrict,
	    __darwin_va_list);
int	vswscanf(const wchar_t * __restrict, const wchar_t * __restrict,
	    __darwin_va_list);
int	vwscanf(const wchar_t * __restrict, __darwin_va_list);
float	wcstof(const wchar_t * __restrict, wchar_t ** __restrict);
long double
	wcstold(const wchar_t * __restrict, wchar_t ** __restrict);
#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_NO_LONG_LONG
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 179 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
long long
	wcstoll(const wchar_t * __restrict, wchar_t ** __restrict, int);
unsigned long long
	wcstoull(const wchar_t * __restrict, wchar_t ** __restrict, int);
#endif /* !__DARWIN_NO_LONG_LONG */
# 184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
__END_DECLS
#endif
# 186 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4



/* Additional functionality provided by:
 * POSIX.1-2008
 */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200809L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 194 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
__BEGIN_DECLS
size_t  mbsnrtowcs(wchar_t * __restrict, const char ** __restrict, size_t,
            size_t, mbstate_t * __restrict);
wchar_t *wcpcpy(wchar_t * __restrict, const wchar_t * __restrict) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
wchar_t *wcpncpy(wchar_t * __restrict, const wchar_t * __restrict, size_t) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
wchar_t *wcsdup(const wchar_t *) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
int     wcscasecmp(const wchar_t *, const wchar_t *) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
int     wcsncasecmp(const wchar_t *, const wchar_t *, size_t n) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
size_t  wcsnlen(const wchar_t *, size_t) __pure __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
size_t  wcsnrtombs(char * __restrict, const wchar_t ** __restrict, size_t,
            size_t, mbstate_t * __restrict);
FILE *open_wmemstream(wchar_t ** __bufp, size_t * __sizep) __API_AVAILABLE(macos(10.13), ios(11.0), tvos(11.0), watchos(4.0));
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= 200809L */
# 208 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4



/* Darwin extensions */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 214 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
__BEGIN_DECLS
wchar_t *fgetwln(FILE * __restrict, size_t *) __OSX_AVAILABLE_STARTING(__MAC_10_7, __IPHONE_4_3);
size_t	wcslcat(wchar_t *, const wchar_t *, size_t);
size_t	wcslcpy(wchar_t *, const wchar_t *, size_t);
__END_DECLS
#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4


/* Poison the following routines if -fshort-wchar is set */
#if 0 /* disabled by -frewrite-includes */
#if !defined(__cplusplus) && defined(__WCHAR_MAX__) && __WCHAR_MAX__ <= 0xffffU
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
#pragma GCC poison fgetwln fgetws fputwc fputws fwprintf fwscanf mbrtowc mbsnrtowcs mbsrtowcs putwc putwchar swprintf swscanf vfwprintf vfwscanf vswprintf vswscanf vwprintf vwscanf wcrtomb wcscat wcschr wcscmp wcscoll wcscpy wcscspn wcsftime wcsftime wcslcat wcslcpy wcslen wcsncat wcsncmp wcsncpy wcsnrtombs wcspbrk wcsrchr wcsrtombs wcsspn wcsstr wcstod wcstof wcstok wcstol wcstold wcstoll wcstoul wcstoull wcswidth wcsxfrm wcwidth wmemchr wmemcmp wmemcpy wmemmove wmemset wprintf wscanf
#endif
# 226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_wchar.h>
#endif /* expanded by -frewrite-includes */
# 228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 230 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4

#endif /* !_WCHAR_H_ */
# 232 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wchar.h" 3 4
# 119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 2 3

// Determine whether we have const-correct overloads for wcschr and friends.
#if 0 /* disabled by -frewrite-includes */
#if defined(_WCHAR_H_CPLUSPLUS_98_CONFORMANCE_)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#  define _LIBCPP_WCHAR_H_HAS_CONST_OVERLOADS 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GLIBC_PREREQ)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 124 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* disabled by -frewrite-includes */
#  if __GLIBC_PREREQ(2, 10)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 125 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#    define _LIBCPP_WCHAR_H_HAS_CONST_OVERLOADS 1
#  endif
# 127 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_MSVCRT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 128 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(_CRT_CONST_CORRECT_OVERLOADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 129 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#    define _LIBCPP_WCHAR_H_HAS_CONST_OVERLOADS 1
#  endif
# 131 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#endif
# 132 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && !defined(_LIBCPP_WCHAR_H_HAS_CONST_OVERLOADS) && defined(_LIBCPP_PREFERRED_OVERLOAD)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 134 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
extern "C++" {
inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wcschr(const wchar_t* __s, wchar_t __c) {return (wchar_t*)wcschr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wcschr(const wchar_t* __s, wchar_t __c) {return __libcpp_wcschr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wcschr(      wchar_t* __s, wchar_t __c) {return __libcpp_wcschr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wcspbrk(const wchar_t* __s1, const wchar_t* __s2) {return (wchar_t*)wcspbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wcspbrk(const wchar_t* __s1, const wchar_t* __s2) {return __libcpp_wcspbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wcspbrk(      wchar_t* __s1, const wchar_t* __s2) {return __libcpp_wcspbrk(__s1, __s2);}

inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wcsrchr(const wchar_t* __s, wchar_t __c) {return (wchar_t*)wcsrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wcsrchr(const wchar_t* __s, wchar_t __c) {return __libcpp_wcsrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wcsrchr(      wchar_t* __s, wchar_t __c) {return __libcpp_wcsrchr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wcsstr(const wchar_t* __s1, const wchar_t* __s2) {return (wchar_t*)wcsstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wcsstr(const wchar_t* __s1, const wchar_t* __s2) {return __libcpp_wcsstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wcsstr(      wchar_t* __s1, const wchar_t* __s2) {return __libcpp_wcsstr(__s1, __s2);}

inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wmemchr(const wchar_t* __s, wchar_t __c, size_t __n) {return (wchar_t*)wmemchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wmemchr(const wchar_t* __s, wchar_t __c, size_t __n) {return __libcpp_wmemchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wmemchr(      wchar_t* __s, wchar_t __c, size_t __n) {return __libcpp_wmemchr(__s, __c, __n);}
}
#endif
# 171 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && defined(_LIBCPP_MSVCRT_LIKE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 173 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
extern "C" {
size_t mbsnrtowcs(wchar_t *__restrict dst, const char **__restrict src,
                  size_t nmc, size_t len, mbstate_t *__restrict ps);
size_t wcsnrtombs(char *__restrict dst, const wchar_t **__restrict src,
                  size_t nwc, size_t len, mbstate_t *__restrict ps);
}  // extern "C++"
#endif  // __cplusplus && _LIBCPP_MSVCRT
# 180 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#endif  // _LIBCPP_WCHAR_H
# 182 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 99 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
#endif
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3

_LIBCPP_BEGIN_NAMESPACE_STD

class _LIBCPP_TYPE_VIS ios_base;

template<class _CharT>  struct _LIBCPP_TEMPLATE_VIS char_traits;
template<> struct char_traits<char>;
#ifndef _LIBCPP_NO_HAS_CHAR8_T
template<> struct char_traits<char8_t>;
#endif
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
template<> struct char_traits<char16_t>;
template<> struct char_traits<char32_t>;
template<> struct char_traits<wchar_t>;

template<class _Tp>     class _LIBCPP_TEMPLATE_VIS allocator;

template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_ios;

template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_streambuf;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_istream;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_ostream;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_iostream;

template <class _CharT, class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_stringbuf;
template <class _CharT, class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_istringstream;
template <class _CharT, class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_ostringstream;
template <class _CharT, class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_stringstream;

template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_filebuf;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_ifstream;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_ofstream;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_fstream;

template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS istreambuf_iterator;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TEMPLATE_VIS ostreambuf_iterator;

typedef basic_ios<char>              ios;
typedef basic_ios<wchar_t>           wios;

typedef basic_streambuf<char>        streambuf;
typedef basic_istream<char>          istream;
typedef basic_ostream<char>          ostream;
typedef basic_iostream<char>         iostream;

typedef basic_stringbuf<char>        stringbuf;
typedef basic_istringstream<char>    istringstream;
typedef basic_ostringstream<char>    ostringstream;
typedef basic_stringstream<char>     stringstream;

typedef basic_filebuf<char>          filebuf;
typedef basic_ifstream<char>         ifstream;
typedef basic_ofstream<char>         ofstream;
typedef basic_fstream<char>          fstream;

typedef basic_streambuf<wchar_t>     wstreambuf;
typedef basic_istream<wchar_t>       wistream;
typedef basic_ostream<wchar_t>       wostream;
typedef basic_iostream<wchar_t>      wiostream;

typedef basic_stringbuf<wchar_t>     wstringbuf;
typedef basic_istringstream<wchar_t> wistringstream;
typedef basic_ostringstream<wchar_t> wostringstream;
typedef basic_stringstream<wchar_t>  wstringstream;

typedef basic_filebuf<wchar_t>       wfilebuf;
typedef basic_ifstream<wchar_t>      wifstream;
typedef basic_ofstream<wchar_t>      wofstream;
typedef basic_fstream<wchar_t>       wfstream;

template <class _State>             class _LIBCPP_TEMPLATE_VIS fpos;
typedef fpos<mbstate_t>    streampos;
typedef fpos<mbstate_t>    wstreampos;
#ifndef _LIBCPP_NO_HAS_CHAR8_T
typedef fpos<mbstate_t>    u8streampos;
#endif
# 194 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
typedef fpos<mbstate_t>    u16streampos;
typedef fpos<mbstate_t>    u32streampos;
#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 198 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_NEWLIB_VERSION)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 200 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
// On newlib, off_t is 'long int'
typedef long int streamoff;         // for char_traits in <string>
#else
# 203 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
typedef long long streamoff;        // for char_traits in <string>
#endif
# 205 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3

template <class _CharT,             // for <stdexcept>
          class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TEMPLATE_VIS basic_string;
typedef basic_string<char, char_traits<char>, allocator<char> > string;
typedef basic_string<wchar_t, char_traits<wchar_t>, allocator<wchar_t> > wstring;


// Include other forward declarations here
template <class _Tp, class _Alloc = allocator<_Tp> >
class _LIBCPP_TEMPLATE_VIS vector;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_IOSFWD
# 221 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iosfwd" 3
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_NO_NULLPTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#if 0 /* expanded by -frewrite-includes */
# include <cstddef>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#endif
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 1 || defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#if 0 /* expanded by -frewrite-includes */
#   include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#if 0 /* expanded by -frewrite-includes */
#   include <cstdio>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#if 0 /* expanded by -frewrite-includes */
#   include <cstddef>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
# 28 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#endif
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 1 && !defined(_LIBCPP_ASSERT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
# define _LIBCPP_ASSERT(x, m) ((x) ? (void)0 : \
  _VSTD::__libcpp_debug_function(_VSTD::__libcpp_debug_info(__FILE__, __LINE__, #x, m)))
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 36 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#ifndef _LIBCPP_DEBUG_ASSERT
#define _LIBCPP_DEBUG_ASSERT(x, m) _LIBCPP_ASSERT(x, m)
#endif
# 39 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#define _LIBCPP_DEBUG_MODE(...) __VA_ARGS__
#endif
# 41 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3

#ifndef _LIBCPP_ASSERT
#   define _LIBCPP_ASSERT(x, m) ((void)0)
#endif
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#ifndef _LIBCPP_DEBUG_ASSERT
#   define _LIBCPP_DEBUG_ASSERT(x, m) ((void)0)
#endif
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
#ifndef _LIBCPP_DEBUG_MODE
#define _LIBCPP_DEBUG_MODE(...) ((void)0)
#endif
# 51 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3

_LIBCPP_BEGIN_NAMESPACE_STD

struct _LIBCPP_TEMPLATE_VIS __libcpp_debug_info {
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
  __libcpp_debug_info()
      : __file_(nullptr), __line_(-1), __pred_(nullptr), __msg_(nullptr) {}
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
  __libcpp_debug_info(const char* __f, int __l, const char* __p, const char* __m)
    : __file_(__f), __line_(__l), __pred_(__p), __msg_(__m) {}

  _LIBCPP_FUNC_VIS std::string what() const;

  const char* __file_;
  int __line_;
  const char* __pred_;
  const char* __msg_;
};

/// __libcpp_debug_function_type - The type of the assertion failure handler.
typedef void(*__libcpp_debug_function_type)(__libcpp_debug_info const&);

/// __libcpp_debug_function - The handler function called when a _LIBCPP_ASSERT
///    fails.
extern _LIBCPP_EXPORTED_FROM_ABI __libcpp_debug_function_type __libcpp_debug_function;

/// __libcpp_abort_debug_function - A debug handler that aborts when called.
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS
void __libcpp_abort_debug_function(__libcpp_debug_info const&);

/// __libcpp_set_debug_function - Set the debug handler to the specified
///    function.
_LIBCPP_FUNC_VIS
bool __libcpp_set_debug_function(__libcpp_debug_function_type __func);

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2 || defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 87 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3

struct _LIBCPP_TYPE_VIS __c_node;

struct _LIBCPP_TYPE_VIS __i_node
{
    void* __i_;
    __i_node* __next_;
    __c_node* __c_;

#ifndef _LIBCPP_CXX03_LANG
    __i_node(const __i_node&) = delete;
    __i_node& operator=(const __i_node&) = delete;
#else
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
private:
    __i_node(const __i_node&);
    __i_node& operator=(const __i_node&);
public:
#endif
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
    _LIBCPP_INLINE_VISIBILITY
    __i_node(void* __i, __i_node* __next, __c_node* __c)
        : __i_(__i), __next_(__next), __c_(__c) {}
    ~__i_node();
};

struct _LIBCPP_TYPE_VIS __c_node
{
    void* __c_;
    __c_node* __next_;
    __i_node** beg_;
    __i_node** end_;
    __i_node** cap_;

#ifndef _LIBCPP_CXX03_LANG
    __c_node(const __c_node&) = delete;
    __c_node& operator=(const __c_node&) = delete;
#else
# 123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
private:
    __c_node(const __c_node&);
    __c_node& operator=(const __c_node&);
public:
#endif
# 128 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
    _LIBCPP_INLINE_VISIBILITY
    __c_node(void* __c, __c_node* __next)
        : __c_(__c), __next_(__next), beg_(nullptr), end_(nullptr), cap_(nullptr) {}
    virtual ~__c_node();

    virtual bool __dereferenceable(const void*) const = 0;
    virtual bool __decrementable(const void*) const = 0;
    virtual bool __addable(const void*, ptrdiff_t) const = 0;
    virtual bool __subscriptable(const void*, ptrdiff_t) const = 0;

    void __add(__i_node* __i);
    _LIBCPP_HIDDEN void __remove(__i_node* __i);
};

template <class _Cont>
struct _C_node
    : public __c_node
{
    _C_node(void* __c, __c_node* __n)
        : __c_node(__c, __n) {}

    virtual bool __dereferenceable(const void*) const;
    virtual bool __decrementable(const void*) const;
    virtual bool __addable(const void*, ptrdiff_t) const;
    virtual bool __subscriptable(const void*, ptrdiff_t) const;
};

template <class _Cont>
inline bool
_C_node<_Cont>::__dereferenceable(const void* __i) const
{
    typedef typename _Cont::const_iterator iterator;
    const iterator* __j = static_cast<const iterator*>(__i);
    _Cont* _Cp = static_cast<_Cont*>(__c_);
    return _Cp->__dereferenceable(__j);
}

template <class _Cont>
inline bool
_C_node<_Cont>::__decrementable(const void* __i) const
{
    typedef typename _Cont::const_iterator iterator;
    const iterator* __j = static_cast<const iterator*>(__i);
    _Cont* _Cp = static_cast<_Cont*>(__c_);
    return _Cp->__decrementable(__j);
}

template <class _Cont>
inline bool
_C_node<_Cont>::__addable(const void* __i, ptrdiff_t __n) const
{
    typedef typename _Cont::const_iterator iterator;
    const iterator* __j = static_cast<const iterator*>(__i);
    _Cont* _Cp = static_cast<_Cont*>(__c_);
    return _Cp->__addable(__j, __n);
}

template <class _Cont>
inline bool
_C_node<_Cont>::__subscriptable(const void* __i, ptrdiff_t __n) const
{
    typedef typename _Cont::const_iterator iterator;
    const iterator* __j = static_cast<const iterator*>(__i);
    _Cont* _Cp = static_cast<_Cont*>(__c_);
    return _Cp->__subscriptable(__j, __n);
}

class _LIBCPP_TYPE_VIS __libcpp_db
{
    __c_node** __cbeg_;
    __c_node** __cend_;
    size_t   __csz_;
    __i_node** __ibeg_;
    __i_node** __iend_;
    size_t   __isz_;

    __libcpp_db();
public:
#ifndef _LIBCPP_CXX03_LANG
    __libcpp_db(const __libcpp_db&) = delete;
    __libcpp_db& operator=(const __libcpp_db&) = delete;
#else
# 210 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
private:
    __libcpp_db(const __libcpp_db&);
    __libcpp_db& operator=(const __libcpp_db&);
public:
#endif
# 215 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
    ~__libcpp_db();

    class __db_c_iterator;
    class __db_c_const_iterator;
    class __db_i_iterator;
    class __db_i_const_iterator;

    __db_c_const_iterator __c_end() const;
    __db_i_const_iterator __i_end() const;

    typedef __c_node*(_InsertConstruct)(void*, void*, __c_node*);

    template <class _Cont>
    _LIBCPP_INLINE_VISIBILITY static __c_node* __create_C_node(void *__mem, void *__c, __c_node *__next) {
        return ::new(__mem) _C_node<_Cont>(__c, __next);
    }

    template <class _Cont>
    _LIBCPP_INLINE_VISIBILITY
    void __insert_c(_Cont* __c)
    {
        __insert_c(static_cast<void*>(__c), &__create_C_node<_Cont>);
    }

    void __insert_i(void* __i);
    void __insert_c(void* __c, _InsertConstruct* __fn);
    void __erase_c(void* __c);

    void __insert_ic(void* __i, const void* __c);
    void __iterator_copy(void* __i, const void* __i0);
    void __erase_i(void* __i);

    void* __find_c_from_i(void* __i) const;
    void __invalidate_all(void* __c);
    __c_node* __find_c_and_lock(void* __c) const;
    __c_node* __find_c(void* __c) const;
    void unlock() const;

    void swap(void* __c1, void* __c2);


    bool __dereferenceable(const void* __i) const;
    bool __decrementable(const void* __i) const;
    bool __addable(const void* __i, ptrdiff_t __n) const;
    bool __subscriptable(const void* __i, ptrdiff_t __n) const;
    bool __less_than_comparable(const void* __i, const void* __j) const;
private:
    _LIBCPP_HIDDEN
    __i_node* __insert_iterator(void* __i);
    _LIBCPP_HIDDEN
    __i_node* __find_iterator(const void* __i) const;

    friend _LIBCPP_FUNC_VIS __libcpp_db* __get_db();
};

_LIBCPP_FUNC_VIS __libcpp_db* __get_db();
_LIBCPP_FUNC_VIS const __libcpp_db* __get_const_db();


#endif // _LIBCPP_DEBUG_LEVEL >= 2 || defined(_LIBCPP_BUILDING_LIBRARY)
# 275 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_DEBUG_H
# 279 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__debug" 3
# 207 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 209 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 210 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
#endif
# 211 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

_LIBCPP_BEGIN_NAMESPACE_STD

namespace rel_ops
{

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const _Tp& __x, const _Tp& __y)
{
    return !(__x == __y);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const _Tp& __x, const _Tp& __y)
{
    return __y < __x;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const _Tp& __x, const _Tp& __y)
{
    return !(__y < __x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const _Tp& __x, const _Tp& __y)
{
    return !(__x < __y);
}

}  // rel_ops

// swap_ranges is defined in <type_traits>`

// swap is defined in <type_traits>

// move_if_noexcept

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
#ifndef _LIBCPP_CXX03_LANG
typename conditional
<
    !is_nothrow_move_constructible<_Tp>::value && is_copy_constructible<_Tp>::value,
    const _Tp&,
    _Tp&&
>::type
#else  // _LIBCPP_CXX03_LANG
# 267 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
const _Tp&
#endif
# 269 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
move_if_noexcept(_Tp& __x) _NOEXCEPT
{
    return _VSTD::move(__x);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 275 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
template <class _Tp> constexpr add_const_t<_Tp>& as_const(_Tp& __t) noexcept { return __t; }
template <class _Tp>                        void as_const(const _Tp&&) = delete;
#endif
# 278 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

struct _LIBCPP_TEMPLATE_VIS piecewise_construct_t { explicit piecewise_construct_t() = default; };
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_CXX03_LANG) || defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 281 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
extern _LIBCPP_EXPORTED_FROM_ABI const piecewise_construct_t piecewise_construct;// = piecewise_construct_t();
#else
# 283 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
/* _LIBCPP_INLINE_VAR */ constexpr piecewise_construct_t piecewise_construct = piecewise_construct_t();
#endif
# 285 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_DEPRECATED_ABI_DISABLE_PAIR_TRIVIAL_COPY_CTOR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 287 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
template <class, class>
struct __non_trivially_copyable_base {
  _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
  __non_trivially_copyable_base() _NOEXCEPT {}
  _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
  __non_trivially_copyable_base(__non_trivially_copyable_base const&) _NOEXCEPT {}
};
#endif
# 295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <class _T1, class _T2>
struct _LIBCPP_TEMPLATE_VIS pair
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_DEPRECATED_ABI_DISABLE_PAIR_TRIVIAL_COPY_CTOR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 299 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
: private __non_trivially_copyable_base<_T1, _T2>
#endif
# 301 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
{
    typedef _T1 first_type;
    typedef _T2 second_type;

    _T1 first;
    _T2 second;

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 309 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
    pair(pair const&) = default;
    pair(pair&&) = default;
#else
# 312 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
  // Use the implicitly declared copy constructor in C++03
#endif
# 314 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#ifdef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    pair() : first(), second() {}

    _LIBCPP_INLINE_VISIBILITY
    pair(_T1 const& __t1, _T2 const& __t2) : first(__t1), second(__t2) {}

    template <class _U1, class _U2>
    _LIBCPP_INLINE_VISIBILITY
    pair(const pair<_U1, _U2>& __p) : first(__p.first), second(__p.second) {}

    _LIBCPP_INLINE_VISIBILITY
    pair& operator=(pair const& __p) {
        first = __p.first;
        second = __p.second;
        return *this;
    }
#else
# 333 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
    template <bool _Val>
    using _EnableB _LIBCPP_NODEBUG_TYPE = typename enable_if<_Val, bool>::type;

    struct _CheckArgs {
      template <int&...>
      static constexpr bool __enable_explicit_default() {
          return is_default_constructible<_T1>::value
              && is_default_constructible<_T2>::value
              && !__enable_implicit_default<>();
      }

      template <int&...>
      static constexpr bool __enable_implicit_default() {
          return __is_implicitly_default_constructible<_T1>::value
              && __is_implicitly_default_constructible<_T2>::value;
      }

      template <class _U1, class _U2>
      static constexpr bool __enable_explicit() {
          return is_constructible<first_type, _U1>::value
              && is_constructible<second_type, _U2>::value
              && (!is_convertible<_U1, first_type>::value
                  || !is_convertible<_U2, second_type>::value);
      }

      template <class _U1, class _U2>
      static constexpr bool __enable_implicit() {
          return is_constructible<first_type, _U1>::value
              && is_constructible<second_type, _U2>::value
              && is_convertible<_U1, first_type>::value
              && is_convertible<_U2, second_type>::value;
      }
    };

    template <bool _MaybeEnable>
    using _CheckArgsDep _LIBCPP_NODEBUG_TYPE = typename conditional<
      _MaybeEnable, _CheckArgs, __check_tuple_constructor_fail>::type;

    struct _CheckTupleLikeConstructor {
        template <class _Tuple>
        static constexpr bool __enable_implicit() {
            return __tuple_convertible<_Tuple, pair>::value;
        }

        template <class _Tuple>
        static constexpr bool __enable_explicit() {
            return __tuple_constructible<_Tuple, pair>::value
               && !__tuple_convertible<_Tuple, pair>::value;
        }

        template <class _Tuple>
        static constexpr bool __enable_assign() {
            return __tuple_assignable<_Tuple, pair>::value;
        }
    };

    template <class _Tuple>
    using _CheckTLC _LIBCPP_NODEBUG_TYPE = typename conditional<
        __tuple_like_with_size<_Tuple, 2>::value
            && !is_same<typename decay<_Tuple>::type, pair>::value,
        _CheckTupleLikeConstructor,
        __check_tuple_constructor_fail
    >::type;

    template<bool _Dummy = true, _EnableB<
            _CheckArgsDep<_Dummy>::__enable_explicit_default()
    > = false>
    explicit _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    pair() _NOEXCEPT_(is_nothrow_default_constructible<first_type>::value &&
                      is_nothrow_default_constructible<second_type>::value)
        : first(), second() {}

    template<bool _Dummy = true, _EnableB<
            _CheckArgsDep<_Dummy>::__enable_implicit_default()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    pair() _NOEXCEPT_(is_nothrow_default_constructible<first_type>::value &&
                      is_nothrow_default_constructible<second_type>::value)
        : first(), second() {}

    template <bool _Dummy = true, _EnableB<
             _CheckArgsDep<_Dummy>::template __enable_explicit<_T1 const&, _T2 const&>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    explicit pair(_T1 const& __t1, _T2 const& __t2)
        _NOEXCEPT_(is_nothrow_copy_constructible<first_type>::value &&
                   is_nothrow_copy_constructible<second_type>::value)
        : first(__t1), second(__t2) {}

    template<bool _Dummy = true, _EnableB<
            _CheckArgsDep<_Dummy>::template __enable_implicit<_T1 const&, _T2 const&>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    pair(_T1 const& __t1, _T2 const& __t2)
        _NOEXCEPT_(is_nothrow_copy_constructible<first_type>::value &&
                   is_nothrow_copy_constructible<second_type>::value)
        : first(__t1), second(__t2) {}

    template<class _U1, class _U2, _EnableB<
             _CheckArgs::template __enable_explicit<_U1, _U2>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    explicit pair(_U1&& __u1, _U2&& __u2)
        _NOEXCEPT_((is_nothrow_constructible<first_type, _U1>::value &&
                    is_nothrow_constructible<second_type, _U2>::value))
        : first(_VSTD::forward<_U1>(__u1)), second(_VSTD::forward<_U2>(__u2)) {}

    template<class _U1, class _U2, _EnableB<
            _CheckArgs::template __enable_implicit<_U1, _U2>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    pair(_U1&& __u1, _U2&& __u2)
        _NOEXCEPT_((is_nothrow_constructible<first_type, _U1>::value &&
                    is_nothrow_constructible<second_type, _U2>::value))
        : first(_VSTD::forward<_U1>(__u1)), second(_VSTD::forward<_U2>(__u2)) {}

    template<class _U1, class _U2, _EnableB<
            _CheckArgs::template __enable_explicit<_U1 const&, _U2 const&>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    explicit pair(pair<_U1, _U2> const& __p)
        _NOEXCEPT_((is_nothrow_constructible<first_type, _U1 const&>::value &&
                    is_nothrow_constructible<second_type, _U2 const&>::value))
        : first(__p.first), second(__p.second) {}

    template<class _U1, class _U2, _EnableB<
            _CheckArgs::template __enable_implicit<_U1 const&, _U2 const&>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    pair(pair<_U1, _U2> const& __p)
        _NOEXCEPT_((is_nothrow_constructible<first_type, _U1 const&>::value &&
                    is_nothrow_constructible<second_type, _U2 const&>::value))
        : first(__p.first), second(__p.second) {}

    template<class _U1, class _U2, _EnableB<
            _CheckArgs::template __enable_explicit<_U1, _U2>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    explicit pair(pair<_U1, _U2>&&__p)
        _NOEXCEPT_((is_nothrow_constructible<first_type, _U1&&>::value &&
                    is_nothrow_constructible<second_type, _U2&&>::value))
        : first(_VSTD::forward<_U1>(__p.first)), second(_VSTD::forward<_U2>(__p.second)) {}

    template<class _U1, class _U2, _EnableB<
            _CheckArgs::template __enable_implicit<_U1, _U2>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    pair(pair<_U1, _U2>&& __p)
        _NOEXCEPT_((is_nothrow_constructible<first_type, _U1&&>::value &&
                    is_nothrow_constructible<second_type, _U2&&>::value))
        : first(_VSTD::forward<_U1>(__p.first)), second(_VSTD::forward<_U2>(__p.second)) {}

    template<class _Tuple, _EnableB<
            _CheckTLC<_Tuple>::template __enable_explicit<_Tuple>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    explicit pair(_Tuple&& __p)
        : first(_VSTD::get<0>(_VSTD::forward<_Tuple>(__p))),
          second(_VSTD::get<1>(_VSTD::forward<_Tuple>(__p))) {}

    template<class _Tuple, _EnableB<
            _CheckTLC<_Tuple>::template __enable_implicit<_Tuple>()
    > = false>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    pair(_Tuple&& __p)
        : first(_VSTD::get<0>(_VSTD::forward<_Tuple>(__p))),
          second(_VSTD::get<1>(_VSTD::forward<_Tuple>(__p))) {}

    template <class... _Args1, class... _Args2>
    _LIBCPP_INLINE_VISIBILITY
    pair(piecewise_construct_t __pc,
         tuple<_Args1...> __first_args, tuple<_Args2...> __second_args)
        _NOEXCEPT_((is_nothrow_constructible<first_type, _Args1...>::value &&
                    is_nothrow_constructible<second_type, _Args2...>::value))
        : pair(__pc, __first_args, __second_args,
                typename __make_tuple_indices<sizeof...(_Args1)>::type(),
                typename __make_tuple_indices<sizeof...(_Args2) >::type()) {}

    _LIBCPP_INLINE_VISIBILITY
    pair& operator=(typename conditional<
                        is_copy_assignable<first_type>::value &&
                        is_copy_assignable<second_type>::value,
                    pair, __nat>::type const& __p)
        _NOEXCEPT_(is_nothrow_copy_assignable<first_type>::value &&
                   is_nothrow_copy_assignable<second_type>::value)
    {
        first = __p.first;
        second = __p.second;
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    pair& operator=(typename conditional<
                        is_move_assignable<first_type>::value &&
                        is_move_assignable<second_type>::value,
                    pair, __nat>::type&& __p)
        _NOEXCEPT_(is_nothrow_move_assignable<first_type>::value &&
                   is_nothrow_move_assignable<second_type>::value)
    {
        first = _VSTD::forward<first_type>(__p.first);
        second = _VSTD::forward<second_type>(__p.second);
        return *this;
    }

    template <class _Tuple, _EnableB<
            _CheckTLC<_Tuple>::template __enable_assign<_Tuple>()
     > = false>
    _LIBCPP_INLINE_VISIBILITY
    pair& operator=(_Tuple&& __p) {
        first = _VSTD::get<0>(_VSTD::forward<_Tuple>(__p));
        second = _VSTD::get<1>(_VSTD::forward<_Tuple>(__p));
        return *this;
    }
#endif
# 547 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

    _LIBCPP_INLINE_VISIBILITY
    void
    swap(pair& __p) _NOEXCEPT_(__is_nothrow_swappable<first_type>::value &&
                               __is_nothrow_swappable<second_type>::value)
    {
        using _VSTD::swap;
        swap(first,  __p.first);
        swap(second, __p.second);
    }
private:

#ifndef _LIBCPP_CXX03_LANG
    template <class... _Args1, class... _Args2, size_t... _I1, size_t... _I2>
        _LIBCPP_INLINE_VISIBILITY
        pair(piecewise_construct_t,
             tuple<_Args1...>& __first_args, tuple<_Args2...>& __second_args,
             __tuple_indices<_I1...>, __tuple_indices<_I2...>);
#endif
# 566 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _T1, class _T2>
pair(_T1, _T2) -> pair<_T1, _T2>;
#endif // _LIBCPP_HAS_NO_DEDUCTION_GUIDES
# 572 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator==(const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return __x.first == __y.first && __x.second == __y.second;
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator!=(const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return !(__x == __y);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator< (const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return __x.first < __y.first || (!(__y.first < __x.first) && __x.second < __y.second);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator> (const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return __y < __x;
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>=(const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return !(__x < __y);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<=(const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return !(__y < __x);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    __is_swappable<_T1>::value &&
    __is_swappable<_T2>::value,
    void
>::type
swap(pair<_T1, _T2>& __x, pair<_T1, _T2>& __y)
                     _NOEXCEPT_((__is_nothrow_swappable<_T1>::value &&
                                 __is_nothrow_swappable<_T2>::value))
{
    __x.swap(__y);
}

template <class _Tp>
struct __unwrap_reference { typedef _LIBCPP_NODEBUG_TYPE _Tp type; };

template <class _Tp>
struct __unwrap_reference<reference_wrapper<_Tp> > { typedef _LIBCPP_NODEBUG_TYPE _Tp& type; };

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 643 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
template <class _Tp>
struct unwrap_reference : __unwrap_reference<_Tp> { };

template <class _Tp>
struct unwrap_ref_decay : unwrap_reference<typename decay<_Tp>::type> { };
#endif // > C++17
# 649 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <class _Tp>
struct __unwrap_ref_decay
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
    : unwrap_ref_decay<_Tp>
#else
# 655 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
    : __unwrap_reference<typename decay<_Tp>::type>
#endif
# 657 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
{ };

#ifndef _LIBCPP_CXX03_LANG

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
pair<typename __unwrap_ref_decay<_T1>::type, typename __unwrap_ref_decay<_T2>::type>
make_pair(_T1&& __t1, _T2&& __t2)
{
    return pair<typename __unwrap_ref_decay<_T1>::type, typename __unwrap_ref_decay<_T2>::type>
               (_VSTD::forward<_T1>(__t1), _VSTD::forward<_T2>(__t2));
}

#else  // _LIBCPP_CXX03_LANG
# 671 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
pair<_T1,_T2>
make_pair(_T1 __x, _T2 __y)
{
    return pair<_T1, _T2>(__x, __y);
}

#endif  // _LIBCPP_CXX03_LANG
# 681 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <class _T1, class _T2>
  struct _LIBCPP_TEMPLATE_VIS tuple_size<pair<_T1, _T2> >
    : public integral_constant<size_t, 2> {};

template <size_t _Ip, class _T1, class _T2>
struct _LIBCPP_TEMPLATE_VIS tuple_element<_Ip, pair<_T1, _T2> >
{
    static_assert(_Ip < 2, "Index out of bounds in std::tuple_element<std::pair<T1, T2>>");
};

template <class _T1, class _T2>
struct _LIBCPP_TEMPLATE_VIS tuple_element<0, pair<_T1, _T2> >
{
    typedef _LIBCPP_NODEBUG_TYPE _T1 type;
};

template <class _T1, class _T2>
struct _LIBCPP_TEMPLATE_VIS tuple_element<1, pair<_T1, _T2> >
{
    typedef _LIBCPP_NODEBUG_TYPE _T2 type;
};

template <size_t _Ip> struct __get_pair;

template <>
struct __get_pair<0>
{
    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    _T1&
    get(pair<_T1, _T2>& __p) _NOEXCEPT {return __p.first;}

    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _T1&
    get(const pair<_T1, _T2>& __p) _NOEXCEPT {return __p.first;}

#ifndef _LIBCPP_CXX03_LANG
    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    _T1&&
    get(pair<_T1, _T2>&& __p) _NOEXCEPT {return _VSTD::forward<_T1>(__p.first);}

    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _T1&&
    get(const pair<_T1, _T2>&& __p) _NOEXCEPT {return _VSTD::forward<const _T1>(__p.first);}
#endif  // _LIBCPP_CXX03_LANG
# 734 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
};

template <>
struct __get_pair<1>
{
    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    _T2&
    get(pair<_T1, _T2>& __p) _NOEXCEPT {return __p.second;}

    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _T2&
    get(const pair<_T1, _T2>& __p) _NOEXCEPT {return __p.second;}

#ifndef _LIBCPP_CXX03_LANG
    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    _T2&&
    get(pair<_T1, _T2>&& __p) _NOEXCEPT {return _VSTD::forward<_T2>(__p.second);}

    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _T2&&
    get(const pair<_T1, _T2>&& __p) _NOEXCEPT {return _VSTD::forward<const _T2>(__p.second);}
#endif  // _LIBCPP_CXX03_LANG
# 764 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
};

template <size_t _Ip, class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, pair<_T1, _T2> >::type&
get(pair<_T1, _T2>& __p) _NOEXCEPT
{
    return __get_pair<_Ip>::get(__p);
}

template <size_t _Ip, class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, pair<_T1, _T2> >::type&
get(const pair<_T1, _T2>& __p) _NOEXCEPT
{
    return __get_pair<_Ip>::get(__p);
}

#ifndef _LIBCPP_CXX03_LANG
template <size_t _Ip, class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, pair<_T1, _T2> >::type&&
get(pair<_T1, _T2>&& __p) _NOEXCEPT
{
    return __get_pair<_Ip>::get(_VSTD::move(__p));
}

template <size_t _Ip, class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, pair<_T1, _T2> >::type&&
get(const pair<_T1, _T2>&& __p) _NOEXCEPT
{
    return __get_pair<_Ip>::get(_VSTD::move(__p));
}
#endif  // _LIBCPP_CXX03_LANG
# 799 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 801 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 & get(pair<_T1, _T2>& __p) _NOEXCEPT
{
    return __get_pair<0>::get(__p);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const & get(pair<_T1, _T2> const& __p) _NOEXCEPT
{
    return __get_pair<0>::get(__p);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 && get(pair<_T1, _T2>&& __p) _NOEXCEPT
{
    return __get_pair<0>::get(_VSTD::move(__p));
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const && get(pair<_T1, _T2> const&& __p) _NOEXCEPT
{
    return __get_pair<0>::get(_VSTD::move(__p));
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 & get(pair<_T2, _T1>& __p) _NOEXCEPT
{
    return __get_pair<1>::get(__p);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const & get(pair<_T2, _T1> const& __p) _NOEXCEPT
{
    return __get_pair<1>::get(__p);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 && get(pair<_T2, _T1>&& __p) _NOEXCEPT
{
    return __get_pair<1>::get(_VSTD::move(__p));
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const && get(pair<_T2, _T1> const&& __p) _NOEXCEPT
{
    return __get_pair<1>::get(_VSTD::move(__p));
}

#endif
# 858 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 860 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template<class _Tp, _Tp... _Ip>
struct _LIBCPP_TEMPLATE_VIS integer_sequence
{
    typedef _Tp value_type;
    static_assert( is_integral<_Tp>::value,
                  "std::integer_sequence can only be instantiated with an integral type" );
    static
    _LIBCPP_INLINE_VISIBILITY
    constexpr
    size_t
    size() noexcept { return sizeof...(_Ip); }
};

template<size_t... _Ip>
    using index_sequence = integer_sequence<size_t, _Ip...>;

#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__make_integer_seq) && !defined(_LIBCPP_TESTING_FALLBACK_MAKE_INTEGER_SEQUENCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 878 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <class _Tp, _Tp _Ep>
using __make_integer_sequence _LIBCPP_NODEBUG_TYPE = __make_integer_seq<integer_sequence, _Tp, _Ep>;

#else
# 883 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template<typename _Tp, _Tp _Np> using __make_integer_sequence_unchecked _LIBCPP_NODEBUG_TYPE  =
  typename __detail::__make<_Np>::type::template __convert<integer_sequence, _Tp>;

template <class _Tp, _Tp _Ep>
struct __make_integer_sequence_checked
{
    static_assert(is_integral<_Tp>::value,
                  "std::make_integer_sequence can only be instantiated with an integral type" );
    static_assert(0 <= _Ep, "std::make_integer_sequence must have a non-negative sequence length");
    // Workaround GCC bug by preventing bad installations when 0 <= _Ep
    // https://gcc.gnu.org/bugzilla/show_bug.cgi?id=68929
    typedef _LIBCPP_NODEBUG_TYPE  __make_integer_sequence_unchecked<_Tp, 0 <= _Ep ? _Ep : 0> type;
};

template <class _Tp, _Tp _Ep>
using __make_integer_sequence _LIBCPP_NODEBUG_TYPE = typename __make_integer_sequence_checked<_Tp, _Ep>::type;

#endif
# 902 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template<class _Tp, _Tp _Np>
    using make_integer_sequence = __make_integer_sequence<_Tp, _Np>;

template<size_t _Np>
    using make_index_sequence = make_integer_sequence<size_t, _Np>;

template<class... _Tp>
    using index_sequence_for = make_index_sequence<sizeof...(_Tp)>;

#endif  // _LIBCPP_STD_VER > 11
# 913 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 915 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
template<class _T1, class _T2 = _T1>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_T1 exchange(_T1& __obj, _T2 && __new_value)
{
    _T1 __old_value = _VSTD::move(__obj);
    __obj = _VSTD::forward<_T2>(__new_value);
    return __old_value;
}
#endif  // _LIBCPP_STD_VER > 11
# 924 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 926 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

struct _LIBCPP_TYPE_VIS in_place_t {
    explicit in_place_t() = default;
};
_LIBCPP_INLINE_VAR constexpr in_place_t in_place{};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS in_place_type_t {
    explicit in_place_type_t() = default;
};
template <class _Tp>
_LIBCPP_INLINE_VAR constexpr in_place_type_t<_Tp> in_place_type{};

template <size_t _Idx>
struct _LIBCPP_TYPE_VIS in_place_index_t {
    explicit in_place_index_t() = default;
};
template <size_t _Idx>
_LIBCPP_INLINE_VAR constexpr in_place_index_t<_Idx> in_place_index{};

template <class _Tp> struct __is_inplace_type_imp : false_type {};
template <class _Tp> struct __is_inplace_type_imp<in_place_type_t<_Tp>> : true_type {};

template <class _Tp>
using __is_inplace_type = __is_inplace_type_imp<__uncvref_t<_Tp>>;

template <class _Tp> struct __is_inplace_index_imp : false_type {};
template <size_t _Idx> struct __is_inplace_index_imp<in_place_index_t<_Idx>> : true_type {};

template <class _Tp>
using __is_inplace_index = __is_inplace_index_imp<__uncvref_t<_Tp>>;

#endif // _LIBCPP_STD_VER > 14
# 959 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <class _Arg, class _Result>
struct _LIBCPP_TEMPLATE_VIS unary_function
{
    typedef _Arg    argument_type;
    typedef _Result result_type;
};

template <class _Size>
inline _LIBCPP_INLINE_VISIBILITY
_Size
__loadword(const void* __p)
{
    _Size __r;
    std::memcpy(&__r, __p, sizeof(__r));
    return __r;
}

// We use murmur2 when size_t is 32 bits, and cityhash64 when size_t
// is 64 bits.  This is because cityhash64 uses 64bit x 64bit
// multiplication, which can be very slow on 32-bit systems.
template <class _Size, size_t = sizeof(_Size)*__CHAR_BIT__>
struct __murmur2_or_cityhash;

template <class _Size>
struct __murmur2_or_cityhash<_Size, 32>
{
    inline _Size operator()(const void* __key, _Size __len)
         _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK;
};

// murmur2
template <class _Size>
_Size
__murmur2_or_cityhash<_Size, 32>::operator()(const void* __key, _Size __len)
{
    const _Size __m = 0x5bd1e995;
    const _Size __r = 24;
    _Size __h = __len;
    const unsigned char* __data = static_cast<const unsigned char*>(__key);
    for (; __len >= 4; __data += 4, __len -= 4)
    {
        _Size __k = __loadword<_Size>(__data);
        __k *= __m;
        __k ^= __k >> __r;
        __k *= __m;
        __h *= __m;
        __h ^= __k;
    }
    switch (__len)
    {
    case 3:
        __h ^= __data[2] << 16;
        _LIBCPP_FALLTHROUGH();
    case 2:
        __h ^= __data[1] << 8;
        _LIBCPP_FALLTHROUGH();
    case 1:
        __h ^= __data[0];
        __h *= __m;
    }
    __h ^= __h >> 13;
    __h *= __m;
    __h ^= __h >> 15;
    return __h;
}

template <class _Size>
struct __murmur2_or_cityhash<_Size, 64>
{
    inline _Size operator()(const void* __key, _Size __len)  _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK;

 private:
  // Some primes between 2^63 and 2^64.
  static const _Size __k0 = 0xc3a5c85c97cb3127ULL;
  static const _Size __k1 = 0xb492b66fbe98f273ULL;
  static const _Size __k2 = 0x9ae16a3b2f90404fULL;
  static const _Size __k3 = 0xc949d7c7509e6557ULL;

  static _Size __rotate(_Size __val, int __shift) {
    return __shift == 0 ? __val : ((__val >> __shift) | (__val << (64 - __shift)));
  }

  static _Size __rotate_by_at_least_1(_Size __val, int __shift) {
    return (__val >> __shift) | (__val << (64 - __shift));
  }

  static _Size __shift_mix(_Size __val) {
    return __val ^ (__val >> 47);
  }

  static _Size __hash_len_16(_Size __u, _Size __v)
     _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
  {
    const _Size __mul = 0x9ddfea08eb382d69ULL;
    _Size __a = (__u ^ __v) * __mul;
    __a ^= (__a >> 47);
    _Size __b = (__v ^ __a) * __mul;
    __b ^= (__b >> 47);
    __b *= __mul;
    return __b;
  }

  static _Size __hash_len_0_to_16(const char* __s, _Size __len)
     _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
  {
    if (__len > 8) {
      const _Size __a = __loadword<_Size>(__s);
      const _Size __b = __loadword<_Size>(__s + __len - 8);
      return __hash_len_16(__a, __rotate_by_at_least_1(__b + __len, __len)) ^ __b;
    }
    if (__len >= 4) {
      const uint32_t __a = __loadword<uint32_t>(__s);
      const uint32_t __b = __loadword<uint32_t>(__s + __len - 4);
      return __hash_len_16(__len + (__a << 3), __b);
    }
    if (__len > 0) {
      const unsigned char __a = __s[0];
      const unsigned char __b = __s[__len >> 1];
      const unsigned char __c = __s[__len - 1];
      const uint32_t __y = static_cast<uint32_t>(__a) +
                           (static_cast<uint32_t>(__b) << 8);
      const uint32_t __z = __len + (static_cast<uint32_t>(__c) << 2);
      return __shift_mix(__y * __k2 ^ __z * __k3) * __k2;
    }
    return __k2;
  }

  static _Size __hash_len_17_to_32(const char *__s, _Size __len)
     _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
  {
    const _Size __a = __loadword<_Size>(__s) * __k1;
    const _Size __b = __loadword<_Size>(__s + 8);
    const _Size __c = __loadword<_Size>(__s + __len - 8) * __k2;
    const _Size __d = __loadword<_Size>(__s + __len - 16) * __k0;
    return __hash_len_16(__rotate(__a - __b, 43) + __rotate(__c, 30) + __d,
                         __a + __rotate(__b ^ __k3, 20) - __c + __len);
  }

  // Return a 16-byte hash for 48 bytes.  Quick and dirty.
  // Callers do best to use "random-looking" values for a and b.
  static pair<_Size, _Size> __weak_hash_len_32_with_seeds(
      _Size __w, _Size __x, _Size __y, _Size __z, _Size __a, _Size __b)
        _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
  {
    __a += __w;
    __b = __rotate(__b + __a + __z, 21);
    const _Size __c = __a;
    __a += __x;
    __a += __y;
    __b += __rotate(__a, 44);
    return pair<_Size, _Size>(__a + __z, __b + __c);
  }

  // Return a 16-byte hash for s[0] ... s[31], a, and b.  Quick and dirty.
  static pair<_Size, _Size> __weak_hash_len_32_with_seeds(
      const char* __s, _Size __a, _Size __b)
    _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
  {
    return __weak_hash_len_32_with_seeds(__loadword<_Size>(__s),
                                         __loadword<_Size>(__s + 8),
                                         __loadword<_Size>(__s + 16),
                                         __loadword<_Size>(__s + 24),
                                         __a,
                                         __b);
  }

  // Return an 8-byte hash for 33 to 64 bytes.
  static _Size __hash_len_33_to_64(const char *__s, size_t __len)
    _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
  {
    _Size __z = __loadword<_Size>(__s + 24);
    _Size __a = __loadword<_Size>(__s) +
                (__len + __loadword<_Size>(__s + __len - 16)) * __k0;
    _Size __b = __rotate(__a + __z, 52);
    _Size __c = __rotate(__a, 37);
    __a += __loadword<_Size>(__s + 8);
    __c += __rotate(__a, 7);
    __a += __loadword<_Size>(__s + 16);
    _Size __vf = __a + __z;
    _Size __vs = __b + __rotate(__a, 31) + __c;
    __a = __loadword<_Size>(__s + 16) + __loadword<_Size>(__s + __len - 32);
    __z += __loadword<_Size>(__s + __len - 8);
    __b = __rotate(__a + __z, 52);
    __c = __rotate(__a, 37);
    __a += __loadword<_Size>(__s + __len - 24);
    __c += __rotate(__a, 7);
    __a += __loadword<_Size>(__s + __len - 16);
    _Size __wf = __a + __z;
    _Size __ws = __b + __rotate(__a, 31) + __c;
    _Size __r = __shift_mix((__vf + __ws) * __k2 + (__wf + __vs) * __k0);
    return __shift_mix(__r * __k0 + __vs) * __k2;
  }
};

// cityhash64
template <class _Size>
_Size
__murmur2_or_cityhash<_Size, 64>::operator()(const void* __key, _Size __len)
{
  const char* __s = static_cast<const char*>(__key);
  if (__len <= 32) {
    if (__len <= 16) {
      return __hash_len_0_to_16(__s, __len);
    } else {
      return __hash_len_17_to_32(__s, __len);
    }
  } else if (__len <= 64) {
    return __hash_len_33_to_64(__s, __len);
  }

  // For strings over 64 bytes we hash the end first, and then as we
  // loop we keep 56 bytes of state: v, w, x, y, and z.
  _Size __x = __loadword<_Size>(__s + __len - 40);
  _Size __y = __loadword<_Size>(__s + __len - 16) +
              __loadword<_Size>(__s + __len - 56);
  _Size __z = __hash_len_16(__loadword<_Size>(__s + __len - 48) + __len,
                          __loadword<_Size>(__s + __len - 24));
  pair<_Size, _Size> __v = __weak_hash_len_32_with_seeds(__s + __len - 64, __len, __z);
  pair<_Size, _Size> __w = __weak_hash_len_32_with_seeds(__s + __len - 32, __y + __k1, __x);
  __x = __x * __k1 + __loadword<_Size>(__s);

  // Decrease len to the nearest multiple of 64, and operate on 64-byte chunks.
  __len = (__len - 1) & ~static_cast<_Size>(63);
  do {
    __x = __rotate(__x + __y + __v.first + __loadword<_Size>(__s + 8), 37) * __k1;
    __y = __rotate(__y + __v.second + __loadword<_Size>(__s + 48), 42) * __k1;
    __x ^= __w.second;
    __y += __v.first + __loadword<_Size>(__s + 40);
    __z = __rotate(__z + __w.first, 33) * __k1;
    __v = __weak_hash_len_32_with_seeds(__s, __v.second * __k1, __x + __w.first);
    __w = __weak_hash_len_32_with_seeds(__s + 32, __z + __w.second,
                                        __y + __loadword<_Size>(__s + 16));
    std::swap(__z, __x);
    __s += 64;
    __len -= 64;
  } while (__len != 0);
  return __hash_len_16(
      __hash_len_16(__v.first, __w.first) + __shift_mix(__y) * __k1 + __z,
      __hash_len_16(__v.second, __w.second) + __x);
}

template <class _Tp, size_t = sizeof(_Tp) / sizeof(size_t)>
struct __scalar_hash;

template <class _Tp>
struct __scalar_hash<_Tp, 0>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp    __t;
            size_t __a;
        } __u;
        __u.__a = 0;
        __u.__t = __v;
        return __u.__a;
    }
};

template <class _Tp>
struct __scalar_hash<_Tp, 1>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp    __t;
            size_t __a;
        } __u;
        __u.__t = __v;
        return __u.__a;
    }
};

template <class _Tp>
struct __scalar_hash<_Tp, 2>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp __t;
            struct
            {
                size_t __a;
                size_t __b;
            } __s;
        } __u;
        __u.__t = __v;
        return __murmur2_or_cityhash<size_t>()(&__u, sizeof(__u));
    }
};

template <class _Tp>
struct __scalar_hash<_Tp, 3>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp __t;
            struct
            {
                size_t __a;
                size_t __b;
                size_t __c;
            } __s;
        } __u;
        __u.__t = __v;
        return __murmur2_or_cityhash<size_t>()(&__u, sizeof(__u));
    }
};

template <class _Tp>
struct __scalar_hash<_Tp, 4>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp __t;
            struct
            {
                size_t __a;
                size_t __b;
                size_t __c;
                size_t __d;
            } __s;
        } __u;
        __u.__t = __v;
        return __murmur2_or_cityhash<size_t>()(&__u, sizeof(__u));
    }
};

struct _PairT {
  size_t first;
  size_t second;
};

_LIBCPP_INLINE_VISIBILITY
inline size_t __hash_combine(size_t __lhs, size_t __rhs) _NOEXCEPT {
    typedef __scalar_hash<_PairT> _HashT;
    const _PairT __p = {__lhs, __rhs};
    return _HashT()(__p);
}

template<class _Tp>
struct _LIBCPP_TEMPLATE_VIS hash<_Tp*>
    : public unary_function<_Tp*, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp* __v) const _NOEXCEPT
    {
        union
        {
            _Tp* __t;
            size_t __a;
        } __u;
        __u.__t = __v;
        return __murmur2_or_cityhash<size_t>()(&__u, sizeof(__u));
    }
};


template <>
struct _LIBCPP_TEMPLATE_VIS hash<bool>
    : public unary_function<bool, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(bool __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<char>
    : public unary_function<char, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<signed char>
    : public unary_function<signed char, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(signed char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<unsigned char>
    : public unary_function<unsigned char, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(unsigned char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS

template <>
struct _LIBCPP_TEMPLATE_VIS hash<char16_t>
    : public unary_function<char16_t, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(char16_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<char32_t>
    : public unary_function<char32_t, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(char32_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 1386 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <>
struct _LIBCPP_TEMPLATE_VIS hash<wchar_t>
    : public unary_function<wchar_t, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(wchar_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<short>
    : public unary_function<short, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(short __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<unsigned short>
    : public unary_function<unsigned short, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(unsigned short __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<int>
    : public unary_function<int, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(int __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<unsigned int>
    : public unary_function<unsigned int, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(unsigned int __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<long>
    : public unary_function<long, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(long __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<unsigned long>
    : public unary_function<unsigned long, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(unsigned long __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<long long>
    : public __scalar_hash<long long>
{
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<unsigned long long>
    : public __scalar_hash<unsigned long long>
{
};

#ifndef _LIBCPP_HAS_NO_INT128

template <>
struct _LIBCPP_TEMPLATE_VIS hash<__int128_t>
    : public __scalar_hash<__int128_t>
{
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<__uint128_t>
    : public __scalar_hash<__uint128_t>
{
};

#endif
# 1470 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <>
struct _LIBCPP_TEMPLATE_VIS hash<float>
    : public __scalar_hash<float>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(float __v) const _NOEXCEPT
    {
        // -0.0 and 0.0 should return same hash
       if (__v == 0.0f)
           return 0;
        return __scalar_hash<float>::operator()(__v);
    }
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<double>
    : public __scalar_hash<double>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(double __v) const _NOEXCEPT
    {
        // -0.0 and 0.0 should return same hash
       if (__v == 0.0)
           return 0;
        return __scalar_hash<double>::operator()(__v);
    }
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<long double>
    : public __scalar_hash<long double>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(long double __v) const _NOEXCEPT
    {
        // -0.0 and 0.0 should return same hash
        if (__v == 0.0L)
            return 0;
#if 0 /* disabled by -frewrite-includes */
#if defined(__i386__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1510 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
        // Zero out padding bits
        union
        {
            long double __t;
            struct
            {
                size_t __a;
                size_t __b;
                size_t __c;
                size_t __d;
            } __s;
        } __u;
        __u.__s.__a = 0;
        __u.__s.__b = 0;
        __u.__s.__c = 0;
        __u.__s.__d = 0;
        __u.__t = __v;
        return __u.__s.__a ^ __u.__s.__b ^ __u.__s.__c ^ __u.__s.__d;
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 1529 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
        // Zero out padding bits
        union
        {
            long double __t;
            struct
            {
                size_t __a;
                size_t __b;
            } __s;
        } __u;
        __u.__s.__a = 0;
        __u.__s.__b = 0;
        __u.__t = __v;
        return __u.__s.__a ^ __u.__s.__b;
#else
# 1544 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
        return __scalar_hash<long double>::operator()(__v);
#endif
# 1546 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
    }
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1550 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <class _Tp, bool = is_enum<_Tp>::value>
struct _LIBCPP_TEMPLATE_VIS __enum_hash
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        typedef typename underlying_type<_Tp>::type type;
        return hash<type>{}(static_cast<type>(__v));
    }
};
template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS __enum_hash<_Tp, false> {
    __enum_hash() = delete;
    __enum_hash(__enum_hash const&) = delete;
    __enum_hash& operator=(__enum_hash const&) = delete;
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS hash : public __enum_hash<_Tp>
{
};
#endif
# 1574 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1576 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

template <>
struct _LIBCPP_TEMPLATE_VIS hash<nullptr_t>
  : public unary_function<nullptr_t, size_t>
{
  _LIBCPP_INLINE_VISIBILITY
  size_t operator()(nullptr_t) const _NOEXCEPT {
    return 662607004ull;
  }
};
#endif
# 1587 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#ifndef _LIBCPP_CXX03_LANG
template <class _Key, class _Hash>
using __check_hash_requirements _LIBCPP_NODEBUG_TYPE  = integral_constant<bool,
    is_copy_constructible<_Hash>::value &&
    is_move_constructible<_Hash>::value &&
    __invokable_r<size_t, _Hash, _Key const&>::value
>;

template <class _Key, class _Hash = std::hash<_Key> >
using __has_enabled_hash _LIBCPP_NODEBUG_TYPE = integral_constant<bool,
    __check_hash_requirements<_Key, _Hash>::value &&
    is_default_constructible<_Hash>::value
>;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1603 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
template <class _Type, class>
using __enable_hash_helper_imp _LIBCPP_NODEBUG_TYPE  = _Type;

template <class _Type, class ..._Keys>
using __enable_hash_helper _LIBCPP_NODEBUG_TYPE  = __enable_hash_helper_imp<_Type,
  typename enable_if<__all<__has_enabled_hash<_Keys>::value...>::value>::type
>;
#else
# 1611 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
template <class _Type, class ...>
using __enable_hash_helper _LIBCPP_NODEBUG_TYPE = _Type;
#endif
# 1614 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

#endif // !_LIBCPP_CXX03_LANG
# 1616 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_UTILITY
# 1620 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/utility" 3
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h" 2

namespace llvm {


/// Metafunction that determines whether the given type is either an
/// integral type or an enumeration type, including enum classes.
///
/// Note that this accepts potentially more integral types than is_integral
/// because it is based on being implicitly convertible to an integral type.
/// Also note that enum classes aren't implicitly convertible to integral types,
/// the value may therefore need to be explicitly converted before being used.
template <typename T> class is_integral_or_enum {
  using UnderlyingT = std::remove_reference_t<T>;

public:
  static const bool value =
      !std::is_class<UnderlyingT>::value && // Filter conversion operators.
      !std::is_pointer<UnderlyingT>::value &&
      !std::is_floating_point<UnderlyingT>::value &&
      (std::is_enum<UnderlyingT>::value ||
       std::is_convertible<UnderlyingT, unsigned long long>::value);
};

/// If T is a pointer, just return it. If it is not, return T&.
template<typename T, typename Enable = void>
struct add_lvalue_reference_if_not_pointer { using type = T &; };

template <typename T>
struct add_lvalue_reference_if_not_pointer<
    T, std::enable_if_t<std::is_pointer<T>::value>> {
  using type = T;
};

/// If T is a pointer to X, return a pointer to const X. If it is not,
/// return const T.
template<typename T, typename Enable = void>
struct add_const_past_pointer { using type = const T; };

template <typename T>
struct add_const_past_pointer<T, std::enable_if_t<std::is_pointer<T>::value>> {
  using type = const std::remove_pointer_t<T> *;
};

template <typename T, typename Enable = void>
struct const_pointer_or_const_ref {
  using type = const T &;
};
template <typename T>
struct const_pointer_or_const_ref<T,
                                  std::enable_if_t<std::is_pointer<T>::value>> {
  using type = typename add_const_past_pointer<T>::type;
};

namespace detail {
/// Internal utility to detect trivial copy construction.
template<typename T> union copy_construction_triviality_helper {
    T t;
    copy_construction_triviality_helper() = default;
    copy_construction_triviality_helper(const copy_construction_triviality_helper&) = default;
    ~copy_construction_triviality_helper() = default;
};
/// Internal utility to detect trivial move construction.
template<typename T> union move_construction_triviality_helper {
    T t;
    move_construction_triviality_helper() = default;
    move_construction_triviality_helper(move_construction_triviality_helper&&) = default;
    ~move_construction_triviality_helper() = default;
};

template<class T>
union trivial_helper {
    T t;
};

} // end namespace detail

/// An implementation of `std::is_trivially_copy_constructible` since we have
/// users with STLs that don't yet include it.
template <typename T>
struct is_trivially_copy_constructible
    : std::is_copy_constructible<
          ::llvm::detail::copy_construction_triviality_helper<T>> {};
template <typename T>
struct is_trivially_copy_constructible<T &> : std::true_type {};
template <typename T>
struct is_trivially_copy_constructible<T &&> : std::false_type {};

/// An implementation of `std::is_trivially_move_constructible` since we have
/// users with STLs that don't yet include it.
template <typename T>
struct is_trivially_move_constructible
    : std::is_move_constructible<
          ::llvm::detail::move_construction_triviality_helper<T>> {};
template <typename T>
struct is_trivially_move_constructible<T &> : std::true_type {};
template <typename T>
struct is_trivially_move_constructible<T &&> : std::true_type {};


template <typename T>
struct is_copy_assignable {
  template<class F>
    static auto get(F*) -> decltype(std::declval<F &>() = std::declval<const F &>(), std::true_type{});
    static std::false_type get(...);
    static constexpr bool value = decltype(get((T*)nullptr))::value;
};

template <typename T>
struct is_move_assignable {
  template<class F>
    static auto get(F*) -> decltype(std::declval<F &>() = std::declval<F &&>(), std::true_type{});
    static std::false_type get(...);
    static constexpr bool value = decltype(get((T*)nullptr))::value;
};


// An implementation of `std::is_trivially_copyable` since STL version
// is not equally supported by all compilers, especially GCC 4.9.
// Uniform implementation of this trait is important for ABI compatibility
// as it has an impact on SmallVector's ABI (among others).
template <typename T>
class is_trivially_copyable {

  // copy constructors
  static constexpr bool has_trivial_copy_constructor =
      std::is_copy_constructible<detail::trivial_helper<T>>::value;
  static constexpr bool has_deleted_copy_constructor =
      !std::is_copy_constructible<T>::value;

  // move constructors
  static constexpr bool has_trivial_move_constructor =
      std::is_move_constructible<detail::trivial_helper<T>>::value;
  static constexpr bool has_deleted_move_constructor =
      !std::is_move_constructible<T>::value;

  // copy assign
  static constexpr bool has_trivial_copy_assign =
      is_copy_assignable<detail::trivial_helper<T>>::value;
  static constexpr bool has_deleted_copy_assign =
      !is_copy_assignable<T>::value;

  // move assign
  static constexpr bool has_trivial_move_assign =
      is_move_assignable<detail::trivial_helper<T>>::value;
  static constexpr bool has_deleted_move_assign =
      !is_move_assignable<T>::value;

  // destructor
  static constexpr bool has_trivial_destructor =
      std::is_destructible<detail::trivial_helper<T>>::value;

  public:

  static constexpr bool value =
      has_trivial_destructor &&
      (has_deleted_move_assign || has_trivial_move_assign) &&
      (has_deleted_move_constructor || has_trivial_move_constructor) &&
      (has_deleted_copy_assign || has_trivial_copy_assign) &&
      (has_deleted_copy_constructor || has_trivial_copy_constructor);

#ifdef HAVE_STD_IS_TRIVIALLY_COPYABLE
  static_assert(value == std::is_trivially_copyable<T>::value,
                "inconsistent behavior between llvm:: and std:: implementation of is_trivially_copyable");
#endif
# 183 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h"
};
template <typename T>
class is_trivially_copyable<T*> : public std::true_type {
};


} // end namespace llvm

#endif // LLVM_SUPPORT_TYPE_TRAITS_H
# 192 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/type_traits.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 1 3
// -*- C++ -*-
//===-------------------------- memory ------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_MEMORY
#define _LIBCPP_MEMORY

/*
    memory synopsis

namespace std
{

struct allocator_arg_t { };
inline constexpr allocator_arg_t allocator_arg = allocator_arg_t();

template <class T, class Alloc> struct uses_allocator;

template <class Ptr>
struct pointer_traits
{
    typedef Ptr pointer;
    typedef <details> element_type;
    typedef <details> difference_type;

    template <class U> using rebind = <details>;

    static pointer pointer_to(<details>);
};

template <class T>
struct pointer_traits<T*>
{
    typedef T* pointer;
    typedef T element_type;
    typedef ptrdiff_t difference_type;

    template <class U> using rebind = U*;

    static pointer pointer_to(<details>) noexcept; // constexpr in C++20
};

template <class T> constexpr T* to_address(T* p) noexcept; // C++20
template <class Ptr> auto to_address(const Ptr& p) noexcept; // C++20

template <class Alloc>
struct allocator_traits
{
    typedef Alloc                        allocator_type;
    typedef typename allocator_type::value_type
                                         value_type;

    typedef Alloc::pointer | value_type* pointer;
    typedef Alloc::const_pointer
          | pointer_traits<pointer>::rebind<const value_type>
                                         const_pointer;
    typedef Alloc::void_pointer
          | pointer_traits<pointer>::rebind<void>
                                         void_pointer;
    typedef Alloc::const_void_pointer
          | pointer_traits<pointer>::rebind<const void>
                                         const_void_pointer;
    typedef Alloc::difference_type
          | pointer_traits<pointer>::difference_type
                                         difference_type;
    typedef Alloc::size_type
          | make_unsigned<difference_type>::type
                                         size_type;
    typedef Alloc::propagate_on_container_copy_assignment
          | false_type                   propagate_on_container_copy_assignment;
    typedef Alloc::propagate_on_container_move_assignment
          | false_type                   propagate_on_container_move_assignment;
    typedef Alloc::propagate_on_container_swap
          | false_type                   propagate_on_container_swap;
    typedef Alloc::is_always_equal
          | is_empty                     is_always_equal;

    template <class T> using rebind_alloc  = Alloc::rebind<U>::other | Alloc<T, Args...>;
    template <class T> using rebind_traits = allocator_traits<rebind_alloc<T>>;

    static pointer allocate(allocator_type& a, size_type n);                          // [[nodiscard]] in C++20
    static pointer allocate(allocator_type& a, size_type n, const_void_pointer hint); // [[nodiscard]] in C++20

    static void deallocate(allocator_type& a, pointer p, size_type n) noexcept;

    template <class T, class... Args>
        static void construct(allocator_type& a, T* p, Args&&... args);

    template <class T>
        static void destroy(allocator_type& a, T* p);

    static size_type max_size(const allocator_type& a); // noexcept in C++14

    static allocator_type
        select_on_container_copy_construction(const allocator_type& a);
};

template <>
class allocator<void>
{
public:
    typedef void*                                 pointer;
    typedef const void*                           const_pointer;
    typedef void                                  value_type;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};
};

template <class T>
class allocator
{
public:
    typedef size_t                                size_type;
    typedef ptrdiff_t                             difference_type;
    typedef T*                                    pointer;
    typedef const T*                              const_pointer;
    typedef typename add_lvalue_reference<T>::type       reference;
    typedef typename add_lvalue_reference<const T>::type const_reference;
    typedef T                                     value_type;

    template <class U> struct rebind {typedef allocator<U> other;};

    constexpr allocator() noexcept;                      // constexpr in C++20
    constexpr allocator(const allocator&) noexcept;      // constexpr in C++20
    template <class U>
      constexpr allocator(const allocator<U>&) noexcept; // constexpr in C++20
    ~allocator();
    pointer address(reference x) const noexcept;
    const_pointer address(const_reference x) const noexcept;
    pointer allocate(size_type, allocator<void>::const_pointer hint = 0);
    void deallocate(pointer p, size_type n) noexcept;
    size_type max_size() const noexcept;
    template<class U, class... Args>
        void construct(U* p, Args&&... args);
    template <class U>
        void destroy(U* p);
};

template <class T, class U>
bool operator==(const allocator<T>&, const allocator<U>&) noexcept;

template <class T, class U>
bool operator!=(const allocator<T>&, const allocator<U>&) noexcept;

template <class OutputIterator, class T>
class raw_storage_iterator
    : public iterator<output_iterator_tag,
                      T,                               // purposefully not C++03
                      ptrdiff_t,                       // purposefully not C++03
                      T*,                              // purposefully not C++03
                      raw_storage_iterator&>           // purposefully not C++03
{
public:
    explicit raw_storage_iterator(OutputIterator x);
    raw_storage_iterator& operator*();
    raw_storage_iterator& operator=(const T& element);
    raw_storage_iterator& operator++();
    raw_storage_iterator  operator++(int);
};

template <class T> pair<T*,ptrdiff_t> get_temporary_buffer(ptrdiff_t n) noexcept;
template <class T> void               return_temporary_buffer(T* p) noexcept;

template <class T> T* addressof(T& r) noexcept;
template <class T> T* addressof(const T&& r) noexcept = delete;

template <class InputIterator, class ForwardIterator>
ForwardIterator
uninitialized_copy(InputIterator first, InputIterator last, ForwardIterator result);

template <class InputIterator, class Size, class ForwardIterator>
ForwardIterator
uninitialized_copy_n(InputIterator first, Size n, ForwardIterator result);

template <class ForwardIterator, class T>
void uninitialized_fill(ForwardIterator first, ForwardIterator last, const T& x);

template <class ForwardIterator, class Size, class T>
ForwardIterator
uninitialized_fill_n(ForwardIterator first, Size n, const T& x);

template <class T>
void destroy_at(T* location);

template <class ForwardIterator>
 void destroy(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Size>
 ForwardIterator destroy_n(ForwardIterator first, Size n);

template <class InputIterator, class ForwardIterator>
 ForwardIterator uninitialized_move(InputIterator first, InputIterator last, ForwardIterator result);

template <class InputIterator, class Size, class ForwardIterator>
 pair<InputIterator,ForwardIterator> uninitialized_move_n(InputIterator first, Size n, ForwardIterator result);

template <class ForwardIterator>
 void uninitialized_value_construct(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Size>
 ForwardIterator uninitialized_value_construct_n(ForwardIterator first, Size n);

template <class ForwardIterator>
 void uninitialized_default_construct(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Size>
 ForwardIterator uninitialized_default_construct_n(ForwardIterator first, Size n);

template <class Y> struct auto_ptr_ref {};      // deprecated in C++11, removed in C++17

template<class X>
class auto_ptr                                  // deprecated in C++11, removed in C++17
{
public:
    typedef X element_type;

    explicit auto_ptr(X* p =0) throw();
    auto_ptr(auto_ptr&) throw();
    template<class Y> auto_ptr(auto_ptr<Y>&) throw();
    auto_ptr& operator=(auto_ptr&) throw();
    template<class Y> auto_ptr& operator=(auto_ptr<Y>&) throw();
    auto_ptr& operator=(auto_ptr_ref<X> r) throw();
    ~auto_ptr() throw();

    typename add_lvalue_reference<X>::type operator*() const throw();
    X* operator->() const throw();
    X* get() const throw();
    X* release() throw();
    void reset(X* p =0) throw();

    auto_ptr(auto_ptr_ref<X>) throw();
    template<class Y> operator auto_ptr_ref<Y>() throw();
    template<class Y> operator auto_ptr<Y>() throw();
};

template <class T>
struct default_delete
{
    constexpr default_delete() noexcept = default;
    template <class U> default_delete(const default_delete<U>&) noexcept;

    void operator()(T*) const noexcept;
};

template <class T>
struct default_delete<T[]>
{
    constexpr default_delete() noexcept = default;
    void operator()(T*) const noexcept;
    template <class U> void operator()(U*) const = delete;
};

template <class T, class D = default_delete<T>>
class unique_ptr
{
public:
    typedef see below pointer;
    typedef T element_type;
    typedef D deleter_type;

    // constructors
    constexpr unique_ptr() noexcept;
    explicit unique_ptr(pointer p) noexcept;
    unique_ptr(pointer p, see below d1) noexcept;
    unique_ptr(pointer p, see below d2) noexcept;
    unique_ptr(unique_ptr&& u) noexcept;
    unique_ptr(nullptr_t) noexcept : unique_ptr() { }
    template <class U, class E>
        unique_ptr(unique_ptr<U, E>&& u) noexcept;
    template <class U>
        unique_ptr(auto_ptr<U>&& u) noexcept;       // removed in C++17

    // destructor
    ~unique_ptr();

    // assignment
    unique_ptr& operator=(unique_ptr&& u) noexcept;
    template <class U, class E> unique_ptr& operator=(unique_ptr<U, E>&& u) noexcept;
    unique_ptr& operator=(nullptr_t) noexcept;

    // observers
    typename add_lvalue_reference<T>::type operator*() const;
    pointer operator->() const noexcept;
    pointer get() const noexcept;
    deleter_type& get_deleter() noexcept;
    const deleter_type& get_deleter() const noexcept;
    explicit operator bool() const noexcept;

    // modifiers
    pointer release() noexcept;
    void reset(pointer p = pointer()) noexcept;
    void swap(unique_ptr& u) noexcept;
};

template <class T, class D>
class unique_ptr<T[], D>
{
public:
    typedef implementation-defined pointer;
    typedef T element_type;
    typedef D deleter_type;

    // constructors
    constexpr unique_ptr() noexcept;
    explicit unique_ptr(pointer p) noexcept;
    unique_ptr(pointer p, see below d) noexcept;
    unique_ptr(pointer p, see below d) noexcept;
    unique_ptr(unique_ptr&& u) noexcept;
    unique_ptr(nullptr_t) noexcept : unique_ptr() { }

    // destructor
    ~unique_ptr();

    // assignment
    unique_ptr& operator=(unique_ptr&& u) noexcept;
    unique_ptr& operator=(nullptr_t) noexcept;

    // observers
    T& operator[](size_t i) const;
    pointer get() const noexcept;
    deleter_type& get_deleter() noexcept;
    const deleter_type& get_deleter() const noexcept;
    explicit operator bool() const noexcept;

    // modifiers
    pointer release() noexcept;
    void reset(pointer p = pointer()) noexcept;
    void reset(nullptr_t) noexcept;
    template <class U> void reset(U) = delete;
    void swap(unique_ptr& u) noexcept;
};

template <class T, class D>
    void swap(unique_ptr<T, D>& x, unique_ptr<T, D>& y) noexcept;

template <class T1, class D1, class T2, class D2>
    bool operator==(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator!=(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator<(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator<=(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator>(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator>=(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);

template <class T, class D>
    bool operator==(const unique_ptr<T, D>& x, nullptr_t) noexcept;
template <class T, class D>
    bool operator==(nullptr_t, const unique_ptr<T, D>& y) noexcept;
template <class T, class D>
    bool operator!=(const unique_ptr<T, D>& x, nullptr_t) noexcept;
template <class T, class D>
    bool operator!=(nullptr_t, const unique_ptr<T, D>& y) noexcept;

template <class T, class D>
    bool operator<(const unique_ptr<T, D>& x, nullptr_t);
template <class T, class D>
    bool operator<(nullptr_t, const unique_ptr<T, D>& y);
template <class T, class D>
    bool operator<=(const unique_ptr<T, D>& x, nullptr_t);
template <class T, class D>
    bool operator<=(nullptr_t, const unique_ptr<T, D>& y);
template <class T, class D>
    bool operator>(const unique_ptr<T, D>& x, nullptr_t);
template <class T, class D>
    bool operator>(nullptr_t, const unique_ptr<T, D>& y);
template <class T, class D>
    bool operator>=(const unique_ptr<T, D>& x, nullptr_t);
template <class T, class D>
    bool operator>=(nullptr_t, const unique_ptr<T, D>& y);

class bad_weak_ptr
    : public std::exception
{
    bad_weak_ptr() noexcept;
};

template<class T, class... Args> unique_ptr<T> make_unique(Args&&... args);     // C++14
template<class T>                unique_ptr<T> make_unique(size_t n);           // C++14
template<class T, class... Args> unspecified   make_unique(Args&&...) = delete; // C++14, T == U[N]

template<class E, class T, class Y, class D>
    basic_ostream<E, T>& operator<< (basic_ostream<E, T>& os, unique_ptr<Y, D> const& p);

template<class T>
class shared_ptr
{
public:
    typedef T element_type;
    typedef weak_ptr<T> weak_type; // C++17

    // constructors:
    constexpr shared_ptr() noexcept;
    template<class Y> explicit shared_ptr(Y* p);
    template<class Y, class D> shared_ptr(Y* p, D d);
    template<class Y, class D, class A> shared_ptr(Y* p, D d, A a);
    template <class D> shared_ptr(nullptr_t p, D d);
    template <class D, class A> shared_ptr(nullptr_t p, D d, A a);
    template<class Y> shared_ptr(const shared_ptr<Y>& r, T *p) noexcept;
    shared_ptr(const shared_ptr& r) noexcept;
    template<class Y> shared_ptr(const shared_ptr<Y>& r) noexcept;
    shared_ptr(shared_ptr&& r) noexcept;
    template<class Y> shared_ptr(shared_ptr<Y>&& r) noexcept;
    template<class Y> explicit shared_ptr(const weak_ptr<Y>& r);
    template<class Y> shared_ptr(auto_ptr<Y>&& r);          // removed in C++17
    template <class Y, class D> shared_ptr(unique_ptr<Y, D>&& r);
    shared_ptr(nullptr_t) : shared_ptr() { }

    // destructor:
    ~shared_ptr();

    // assignment:
    shared_ptr& operator=(const shared_ptr& r) noexcept;
    template<class Y> shared_ptr& operator=(const shared_ptr<Y>& r) noexcept;
    shared_ptr& operator=(shared_ptr&& r) noexcept;
    template<class Y> shared_ptr& operator=(shared_ptr<Y>&& r);
    template<class Y> shared_ptr& operator=(auto_ptr<Y>&& r); // removed in C++17
    template <class Y, class D> shared_ptr& operator=(unique_ptr<Y, D>&& r);

    // modifiers:
    void swap(shared_ptr& r) noexcept;
    void reset() noexcept;
    template<class Y> void reset(Y* p);
    template<class Y, class D> void reset(Y* p, D d);
    template<class Y, class D, class A> void reset(Y* p, D d, A a);

    // observers:
    T* get() const noexcept;
    T& operator*() const noexcept;
    T* operator->() const noexcept;
    long use_count() const noexcept;
    bool unique() const noexcept;
    explicit operator bool() const noexcept;
    template<class U> bool owner_before(shared_ptr<U> const& b) const noexcept;
    template<class U> bool owner_before(weak_ptr<U> const& b) const noexcept;
};

// shared_ptr comparisons:
template<class T, class U>
    bool operator==(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator!=(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator<(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator>(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator<=(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator>=(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;

template <class T>
    bool operator==(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator==(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator!=(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator!=(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator<(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
bool operator<(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator<=(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator<=(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator>(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator>(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator>=(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator>=(nullptr_t, const shared_ptr<T>& y) noexcept;

// shared_ptr specialized algorithms:
template<class T> void swap(shared_ptr<T>& a, shared_ptr<T>& b) noexcept;

// shared_ptr casts:
template<class T, class U>
    shared_ptr<T> static_pointer_cast(shared_ptr<U> const& r) noexcept;
template<class T, class U>
    shared_ptr<T> dynamic_pointer_cast(shared_ptr<U> const& r) noexcept;
template<class T, class U>
    shared_ptr<T> const_pointer_cast(shared_ptr<U> const& r) noexcept;

// shared_ptr I/O:
template<class E, class T, class Y>
    basic_ostream<E, T>& operator<< (basic_ostream<E, T>& os, shared_ptr<Y> const& p);

// shared_ptr get_deleter:
template<class D, class T> D* get_deleter(shared_ptr<T> const& p) noexcept;

template<class T, class... Args>
    shared_ptr<T> make_shared(Args&&... args);
template<class T, class A, class... Args>
    shared_ptr<T> allocate_shared(const A& a, Args&&... args);

template<class T>
class weak_ptr
{
public:
    typedef T element_type;

    // constructors
    constexpr weak_ptr() noexcept;
    template<class Y> weak_ptr(shared_ptr<Y> const& r) noexcept;
    weak_ptr(weak_ptr const& r) noexcept;
    template<class Y> weak_ptr(weak_ptr<Y> const& r) noexcept;
    weak_ptr(weak_ptr&& r) noexcept;                      // C++14
    template<class Y> weak_ptr(weak_ptr<Y>&& r) noexcept; // C++14

    // destructor
    ~weak_ptr();

    // assignment
    weak_ptr& operator=(weak_ptr const& r) noexcept;
    template<class Y> weak_ptr& operator=(weak_ptr<Y> const& r) noexcept;
    template<class Y> weak_ptr& operator=(shared_ptr<Y> const& r) noexcept;
    weak_ptr& operator=(weak_ptr&& r) noexcept;                      // C++14
    template<class Y> weak_ptr& operator=(weak_ptr<Y>&& r) noexcept; // C++14

    // modifiers
    void swap(weak_ptr& r) noexcept;
    void reset() noexcept;

    // observers
    long use_count() const noexcept;
    bool expired() const noexcept;
    shared_ptr<T> lock() const noexcept;
    template<class U> bool owner_before(shared_ptr<U> const& b) const noexcept;
    template<class U> bool owner_before(weak_ptr<U> const& b) const noexcept;
};

// weak_ptr specialized algorithms:
template<class T> void swap(weak_ptr<T>& a, weak_ptr<T>& b) noexcept;

// class owner_less:
template<class T> struct owner_less;

template<class T>
struct owner_less<shared_ptr<T> >
    : binary_function<shared_ptr<T>, shared_ptr<T>, bool>
{
    typedef bool result_type;
    bool operator()(shared_ptr<T> const&, shared_ptr<T> const&) const noexcept;
    bool operator()(shared_ptr<T> const&, weak_ptr<T> const&) const noexcept;
    bool operator()(weak_ptr<T> const&, shared_ptr<T> const&) const noexcept;
};

template<class T>
struct owner_less<weak_ptr<T> >
    : binary_function<weak_ptr<T>, weak_ptr<T>, bool>
{
    typedef bool result_type;
    bool operator()(weak_ptr<T> const&, weak_ptr<T> const&) const noexcept;
    bool operator()(shared_ptr<T> const&, weak_ptr<T> const&) const noexcept;
    bool operator()(weak_ptr<T> const&, shared_ptr<T> const&) const noexcept;
};

template <>  // Added in C++14
struct owner_less<void>
{
    template <class _Tp, class _Up>
    bool operator()( shared_ptr<_Tp> const& __x, shared_ptr<_Up> const& __y) const noexcept;
    template <class _Tp, class _Up>
    bool operator()( shared_ptr<_Tp> const& __x,   weak_ptr<_Up> const& __y) const noexcept;
    template <class _Tp, class _Up>
    bool operator()(   weak_ptr<_Tp> const& __x, shared_ptr<_Up> const& __y) const noexcept;
    template <class _Tp, class _Up>
    bool operator()(   weak_ptr<_Tp> const& __x,   weak_ptr<_Up> const& __y) const noexcept;

    typedef void is_transparent;
};

template<class T>
class enable_shared_from_this
{
protected:
    constexpr enable_shared_from_this() noexcept;
    enable_shared_from_this(enable_shared_from_this const&) noexcept;
    enable_shared_from_this& operator=(enable_shared_from_this const&) noexcept;
    ~enable_shared_from_this();
public:
    shared_ptr<T> shared_from_this();
    shared_ptr<T const> shared_from_this() const;
};

template<class T>
    bool atomic_is_lock_free(const shared_ptr<T>* p);
template<class T>
    shared_ptr<T> atomic_load(const shared_ptr<T>* p);
template<class T>
    shared_ptr<T> atomic_load_explicit(const shared_ptr<T>* p, memory_order mo);
template<class T>
    void atomic_store(shared_ptr<T>* p, shared_ptr<T> r);
template<class T>
    void atomic_store_explicit(shared_ptr<T>* p, shared_ptr<T> r, memory_order mo);
template<class T>
    shared_ptr<T> atomic_exchange(shared_ptr<T>* p, shared_ptr<T> r);
template<class T>
    shared_ptr<T>
    atomic_exchange_explicit(shared_ptr<T>* p, shared_ptr<T> r, memory_order mo);
template<class T>
    bool
    atomic_compare_exchange_weak(shared_ptr<T>* p, shared_ptr<T>* v, shared_ptr<T> w);
template<class T>
    bool
    atomic_compare_exchange_strong( shared_ptr<T>* p, shared_ptr<T>* v, shared_ptr<T> w);
template<class T>
    bool
    atomic_compare_exchange_weak_explicit(shared_ptr<T>* p, shared_ptr<T>* v,
                                          shared_ptr<T> w, memory_order success,
                                          memory_order failure);
template<class T>
    bool
    atomic_compare_exchange_strong_explicit(shared_ptr<T>* p, shared_ptr<T>* v,
                                            shared_ptr<T> w, memory_order success,
                                            memory_order failure);
// Hash support
template <class T> struct hash;
template <class T, class D> struct hash<unique_ptr<T, D> >;
template <class T> struct hash<shared_ptr<T> >;

template <class T, class Alloc>
  inline constexpr bool uses_allocator_v = uses_allocator<T, Alloc>::value;

// Pointer safety
enum class pointer_safety { relaxed, preferred, strict };
void declare_reachable(void *p);
template <class T> T *undeclare_reachable(T *p);
void declare_no_pointers(char *p, size_t n);
void undeclare_no_pointers(char *p, size_t n);
pointer_safety get_pointer_safety() noexcept;

void* align(size_t alignment, size_t size, void*& ptr, size_t& space);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 651 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 652 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 652 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <typeinfo>
#endif /* expanded by -frewrite-includes */
# 653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 1 3
// -*- C++ -*-
//===-------------------------- typeinfo ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef __LIBCPP_TYPEINFO
#define __LIBCPP_TYPEINFO

/*

    typeinfo synopsis

namespace std {

class type_info
{
public:
    virtual ~type_info();

    bool operator==(const type_info& rhs) const noexcept;
    bool operator!=(const type_info& rhs) const noexcept;

    bool before(const type_info& rhs) const noexcept;
    size_t hash_code() const noexcept;
    const char* name() const noexcept;

    type_info(const type_info& rhs) = delete;
    type_info& operator=(const type_info& rhs) = delete;
};

class bad_cast
    : public exception
{
public:
    bad_cast() noexcept;
    bad_cast(const bad_cast&) noexcept;
    bad_cast& operator=(const bad_cast&) noexcept;
    virtual const char* what() const noexcept;
};

class bad_typeid
    : public exception
{
public:
    bad_typeid() noexcept;
    bad_typeid(const bad_typeid&) noexcept;
    bad_typeid& operator=(const bad_typeid&) noexcept;
    virtual const char* what() const noexcept;
};

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
# 64 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#ifdef _LIBCPP_NO_EXCEPTIONS
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
# 66 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#endif
# 67 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 70 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#endif
# 71 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_VCRUNTIME)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 73 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#if 0 /* expanded by -frewrite-includes */
#include <vcruntime_typeinfo.h>
#endif /* expanded by -frewrite-includes */
# 73 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
# 74 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#else
# 75 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3

namespace std  // purposefully not using versioning namespace
{


#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_MICROSOFT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 81 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3

class _LIBCPP_EXCEPTION_ABI type_info
{
    type_info& operator=(const type_info&);
    type_info(const type_info&);

    mutable struct {
      const char *__undecorated_name;
      const char __decorated_name[1];
    } __data;

    int __compare(const type_info &__rhs) const _NOEXCEPT;

public:
    _LIBCPP_AVAILABILITY_TYPEINFO_VTABLE
    virtual ~type_info();

    const char *name() const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    bool before(const type_info& __arg) const _NOEXCEPT {
      return __compare(__arg) < 0;
    }

    size_t hash_code() const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    bool operator==(const type_info& __arg) const _NOEXCEPT {
      return __compare(__arg) == 0;
    }

    _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const type_info& __arg) const _NOEXCEPT
    { return !operator==(__arg); }
};

#else // !defined(_LIBCPP_ABI_MICROSOFT)
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3

// ========================================================================== //
//                           Implementations
// ========================================================================== //
// ------------------------------------------------------------------------- //
//                               Unique
// ------------------------------------------------------------------------- //
// This implementation of type_info assumes a unique copy of the RTTI for a
// given type inside a program. This is a valid assumption when abiding to
// Itanium ABI (http://itanium-cxx-abi.github.io/cxx-abi/abi.html#vtable-components).
// Under this assumption, we can always compare the addresses of the type names
// to implement equality-comparison of type_infos instead of having to perform
// a deep string comparison.
// -------------------------------------------------------------------------- //
//                             NonUnique
// -------------------------------------------------------------------------- //
// This implementation of type_info does not assume there is always a unique
// copy of the RTTI for a given type inside a program. For various reasons
// the linker may have failed to merge every copy of a types RTTI
// (For example: -Bsymbolic or llvm.org/PR37398). Under this assumption, two
// type_infos are equal if their addresses are equal or if a deep string
// comparison is equal.
// -------------------------------------------------------------------------- //
//                          NonUniqueARMRTTIBit
// -------------------------------------------------------------------------- //
// This implementation of type_info does not assume always a unique copy of
// the RTTI for a given type inside a program. It packs the pointer to the
// type name into a uintptr_t and reserves the high bit of that pointer (which
// is assumed to be free for use under the ABI in use) to represent whether
// that specific copy of the RTTI can be assumed unique inside the program.
// To implement equality-comparison of type_infos, we check whether BOTH
// type_infos are guaranteed unique, and if so, we simply compare the addresses
// of their type names instead of doing a deep string comparison, which is
// faster. If at least one of the type_infos can't guarantee uniqueness, we
// have no choice but to fall back to a deep string comparison.
//
// This implementation is specific to ARM64 on Apple platforms.
//
// Note that the compiler is the one setting (or unsetting) the high bit of
// the pointer when it constructs the type_info, depending on whether it can
// guarantee uniqueness for that specific type_info.

struct __type_info_implementations {
  struct __string_impl_base {
    typedef const char* __type_name_t;
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    _LIBCPP_CONSTEXPR static const char* __type_name_to_string(__type_name_t __v) _NOEXCEPT {
      return __v;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    _LIBCPP_CONSTEXPR static __type_name_t __string_to_type_name(const char* __v) _NOEXCEPT {
      return __v;
    }
  };

  struct __unique_impl : __string_impl_base {
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static size_t __hash(__type_name_t __v) _NOEXCEPT {
      return reinterpret_cast<size_t>(__v);
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static bool __eq(__type_name_t __lhs, __type_name_t __rhs) _NOEXCEPT {
      return __lhs == __rhs;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static bool __lt(__type_name_t __lhs, __type_name_t __rhs) _NOEXCEPT {
      return __lhs < __rhs;
    }
  };

  struct __non_unique_impl : __string_impl_base {
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static size_t __hash(__type_name_t __ptr) _NOEXCEPT {
      size_t __hash = 5381;
      while (unsigned char __c = static_cast<unsigned char>(*__ptr++))
        __hash = (__hash * 33) ^ __c;
      return __hash;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static bool __eq(__type_name_t __lhs, __type_name_t __rhs) _NOEXCEPT {
      return __lhs == __rhs || __builtin_strcmp(__lhs, __rhs) == 0;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static bool __lt(__type_name_t __lhs, __type_name_t __rhs) _NOEXCEPT {
      return __builtin_strcmp(__lhs, __rhs) < 0;
    }
  };

  struct __non_unique_arm_rtti_bit_impl {
    typedef uintptr_t __type_name_t;

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static const char* __type_name_to_string(__type_name_t __v) _NOEXCEPT {
      return reinterpret_cast<const char*>(__v &
          ~__non_unique_rtti_bit::value);
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static __type_name_t __string_to_type_name(const char* __v) _NOEXCEPT {
      return reinterpret_cast<__type_name_t>(__v);
    }

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static size_t __hash(__type_name_t __v) _NOEXCEPT {
      if (__is_type_name_unique(__v))
        return reinterpret_cast<size_t>(__v);
      return __non_unique_impl::__hash(__type_name_to_string(__v));
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static bool __eq(__type_name_t __lhs, __type_name_t __rhs) _NOEXCEPT {
      if (__lhs == __rhs)
        return true;
      if (__is_type_name_unique(__lhs, __rhs))
        return false;
      return __builtin_strcmp(__type_name_to_string(__lhs), __type_name_to_string(__rhs)) == 0;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_ALWAYS_INLINE
    static bool __lt(__type_name_t __lhs, __type_name_t __rhs) _NOEXCEPT {
      if (__is_type_name_unique(__lhs, __rhs))
        return __lhs < __rhs;
      return __builtin_strcmp(__type_name_to_string(__lhs), __type_name_to_string(__rhs)) < 0;
    }

   private:
    // The unique bit is the top bit. It is expected that __type_name_t is 64 bits when
    // this implementation is actually used.
    typedef std::integral_constant<__type_name_t,
      (1ULL << ((__CHAR_BIT__ * sizeof(__type_name_t)) - 1))> __non_unique_rtti_bit;

    _LIBCPP_INLINE_VISIBILITY
    static bool __is_type_name_unique(__type_name_t __lhs) _NOEXCEPT {
      return !(__lhs & __non_unique_rtti_bit::value);
    }
    _LIBCPP_INLINE_VISIBILITY
    static bool __is_type_name_unique(__type_name_t __lhs, __type_name_t __rhs) _NOEXCEPT {
      return !((__lhs & __rhs) & __non_unique_rtti_bit::value);
    }
  };

  typedef
#if 0 /* disabled by -frewrite-includes */
#if defined(__APPLE__) && defined(__LP64__) && !defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 258 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
    __non_unique_arm_rtti_bit_impl
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _LIBCPP_HAS_MERGED_TYPEINFO_NAMES_DEFAULT == 0
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 260 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
    __non_unique_impl
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _LIBCPP_HAS_MERGED_TYPEINFO_NAMES_DEFAULT == 1
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 262 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
    __unique_impl
#else
# 264 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
#   error invalid configuration for _LIBCPP_HAS_MERGED_TYPEINFO_NAMES_DEFAULT
#endif
# 266 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
     __impl;
};

class _LIBCPP_EXCEPTION_ABI type_info
{
  type_info& operator=(const type_info&);
  type_info(const type_info&);

 protected:
    typedef __type_info_implementations::__impl __impl;

    __impl::__type_name_t __type_name;

    _LIBCPP_INLINE_VISIBILITY
    explicit type_info(const char* __n)
      : __type_name(__impl::__string_to_type_name(__n)) {}

public:
    _LIBCPP_AVAILABILITY_TYPEINFO_VTABLE
    virtual ~type_info();

    _LIBCPP_INLINE_VISIBILITY
    const char* name() const _NOEXCEPT
    {
      return __impl::__type_name_to_string(__type_name);
    }

    _LIBCPP_INLINE_VISIBILITY
    bool before(const type_info& __arg) const _NOEXCEPT
    {
      return __impl::__lt(__type_name, __arg.__type_name);
    }

    _LIBCPP_INLINE_VISIBILITY
    size_t hash_code() const _NOEXCEPT
    {
      return __impl::__hash(__type_name);
    }

    _LIBCPP_INLINE_VISIBILITY
    bool operator==(const type_info& __arg) const _NOEXCEPT
    {
      return __impl::__eq(__type_name, __arg.__type_name);
    }

    _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const type_info& __arg) const _NOEXCEPT
    { return !operator==(__arg); }
};
#endif // defined(_LIBCPP_ABI_MICROSOFT)
# 316 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3

class _LIBCPP_EXCEPTION_ABI bad_cast
    : public exception
{
 public:
  bad_cast() _NOEXCEPT;
  virtual ~bad_cast() _NOEXCEPT;
  virtual const char* what() const _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI bad_typeid
    : public exception
{
 public:
  bad_typeid() _NOEXCEPT;
  virtual ~bad_typeid() _NOEXCEPT;
  virtual const char* what() const _NOEXCEPT;
};

}  // std

#endif // defined(_LIBCPP_ABI_VCRUNTIME)
# 338 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3

_LIBCPP_BEGIN_NAMESPACE_STD
_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_bad_cast()
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw bad_cast();
#else
# 346 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
    _VSTD::abort();
#endif
# 348 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
}
_LIBCPP_END_NAMESPACE_STD

#endif  // __LIBCPP_TYPEINFO
# 352 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/typeinfo" 3
# 654 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 654 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 655 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 655 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 656 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 656 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 657 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 657 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 658 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 658 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 659 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 659 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 1 3
// -*- C++ -*-
//===-------------------------- iterator ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_ITERATOR
#define _LIBCPP_ITERATOR

/*
    iterator synopsis

namespace std
{

template<class Iterator>
struct iterator_traits
{
    typedef typename Iterator::difference_type difference_type;
    typedef typename Iterator::value_type value_type;
    typedef typename Iterator::pointer pointer;
    typedef typename Iterator::reference reference;
    typedef typename Iterator::iterator_category iterator_category;
};

template<class T>
struct iterator_traits<T*>
{
    typedef ptrdiff_t difference_type;
    typedef T value_type;
    typedef T* pointer;
    typedef T& reference;
    typedef random_access_iterator_tag iterator_category;
};

template<class Category, class T, class Distance = ptrdiff_t,
         class Pointer = T*, class Reference = T&>
struct iterator
{
    typedef T         value_type;
    typedef Distance  difference_type;
    typedef Pointer   pointer;
    typedef Reference reference;
    typedef Category  iterator_category;
};

struct input_iterator_tag  {};
struct output_iterator_tag {};
struct forward_iterator_tag       : public input_iterator_tag         {};
struct bidirectional_iterator_tag : public forward_iterator_tag       {};
struct random_access_iterator_tag : public bidirectional_iterator_tag {};

// 27.4.3, iterator operations
// extension: second argument not conforming to C++03
template <class InputIterator>  // constexpr in C++17
  constexpr void advance(InputIterator& i,
             typename iterator_traits<InputIterator>::difference_type n);

template <class InputIterator>  // constexpr in C++17
  constexpr typename iterator_traits<InputIterator>::difference_type
    distance(InputIterator first, InputIterator last);

template <class InputIterator>  // constexpr in C++17
  constexpr InputIterator next(InputIterator x,
typename iterator_traits<InputIterator>::difference_type n = 1);

template <class BidirectionalIterator>  // constexpr in C++17
  constexpr BidirectionalIterator prev(BidirectionalIterator x,
    typename iterator_traits<BidirectionalIterator>::difference_type n = 1);

template <class Iterator>
class reverse_iterator
    : public iterator<typename iterator_traits<Iterator>::iterator_category,
                      typename iterator_traits<Iterator>::value_type,
                      typename iterator_traits<Iterator>::difference_type,
                      typename iterator_traits<Iterator>::pointer,
                      typename iterator_traits<Iterator>::reference>
{
protected:
    Iterator current;
public:
    typedef Iterator                                            iterator_type;
    typedef typename iterator_traits<Iterator>::difference_type difference_type;
    typedef typename iterator_traits<Iterator>::reference       reference;
    typedef typename iterator_traits<Iterator>::pointer         pointer;

    constexpr reverse_iterator();
    constexpr explicit reverse_iterator(Iterator x);
    template <class U> constexpr reverse_iterator(const reverse_iterator<U>& u);
    template <class U> constexpr reverse_iterator& operator=(const reverse_iterator<U>& u);
    constexpr Iterator base() const;
    constexpr reference operator*() const;
    constexpr pointer   operator->() const;
    constexpr reverse_iterator& operator++();
    constexpr reverse_iterator  operator++(int);
    constexpr reverse_iterator& operator--();
    constexpr reverse_iterator  operator--(int);
    constexpr reverse_iterator  operator+ (difference_type n) const;
    constexpr reverse_iterator& operator+=(difference_type n);
    constexpr reverse_iterator  operator- (difference_type n) const;
    constexpr reverse_iterator& operator-=(difference_type n);
    constexpr reference         operator[](difference_type n) const;
};

template <class Iterator1, class Iterator2>
constexpr bool                          // constexpr in C++17
operator==(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool                          // constexpr in C++17
operator<(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool                          // constexpr in C++17
operator!=(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool                          // constexpr in C++17
operator>(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool                          // constexpr in C++17
operator>=(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool                          // constexpr in C++17
operator<=(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr auto
operator-(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y)
-> decltype(__y.base() - __x.base());   // constexpr in C++17

template <class Iterator>
constexpr reverse_iterator<Iterator>
operator+(typename reverse_iterator<Iterator>::difference_type n,
          const reverse_iterator<Iterator>& x);   // constexpr in C++17

template <class Iterator>
constexpr reverse_iterator<Iterator> make_reverse_iterator(Iterator i); // C++14, constexpr in C++17

template <class Container>
class back_insert_iterator
{
protected:
    Container* container;
public:
    typedef Container                   container_type;
    typedef void                        value_type;
    typedef void                        difference_type;
    typedef void                        reference;
    typedef void                        pointer;

    explicit back_insert_iterator(Container& x);
    back_insert_iterator& operator=(const typename Container::value_type& value);
    back_insert_iterator& operator*();
    back_insert_iterator& operator++();
    back_insert_iterator  operator++(int);
};

template <class Container> back_insert_iterator<Container> back_inserter(Container& x);

template <class Container>
class front_insert_iterator
{
protected:
    Container* container;
public:
    typedef Container                    container_type;
    typedef void                         value_type;
    typedef void                         difference_type;
    typedef void                         reference;
    typedef void                         pointer;

    explicit front_insert_iterator(Container& x);
    front_insert_iterator& operator=(const typename Container::value_type& value);
    front_insert_iterator& operator*();
    front_insert_iterator& operator++();
    front_insert_iterator  operator++(int);
};

template <class Container> front_insert_iterator<Container> front_inserter(Container& x);

template <class Container>
class insert_iterator
{
protected:
    Container* container;
    typename Container::iterator iter;
public:
    typedef Container              container_type;
    typedef void                   value_type;
    typedef void                   difference_type;
    typedef void                   reference;
    typedef void                   pointer;

    insert_iterator(Container& x, typename Container::iterator i);
    insert_iterator& operator=(const typename Container::value_type& value);
    insert_iterator& operator*();
    insert_iterator& operator++();
    insert_iterator& operator++(int);
};

template <class Container, class Iterator>
insert_iterator<Container> inserter(Container& x, Iterator i);

template <class Iterator>
class move_iterator {
public:
    typedef Iterator                                              iterator_type;
    typedef typename iterator_traits<Iterator>::difference_type   difference_type;
    typedef Iterator                                              pointer;
    typedef typename iterator_traits<Iterator>::value_type        value_type;
    typedef typename iterator_traits<Iterator>::iterator_category iterator_category;
    typedef value_type&&                                          reference;

    constexpr move_iterator();  // all the constexprs are in C++17
    constexpr explicit move_iterator(Iterator i);
    template <class U>
      constexpr move_iterator(const move_iterator<U>& u);
    template <class U>
      constexpr move_iterator& operator=(const move_iterator<U>& u);
    constexpr iterator_type base() const;
    constexpr reference operator*() const;
    constexpr pointer operator->() const;
    constexpr move_iterator& operator++();
    constexpr move_iterator operator++(int);
    constexpr move_iterator& operator--();
    constexpr move_iterator operator--(int);
    constexpr move_iterator operator+(difference_type n) const;
    constexpr move_iterator& operator+=(difference_type n);
    constexpr move_iterator operator-(difference_type n) const;
    constexpr move_iterator& operator-=(difference_type n);
    constexpr unspecified operator[](difference_type n) const;
private:
    Iterator current; // exposition only
};

template <class Iterator1, class Iterator2>
constexpr bool   // constexpr in C++17
operator==(const move_iterator<Iterator1>& x, const move_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool   // constexpr in C++17
operator!=(const move_iterator<Iterator1>& x, const move_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool   // constexpr in C++17
operator<(const move_iterator<Iterator1>& x, const move_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool   // constexpr in C++17
operator<=(const move_iterator<Iterator1>& x, const move_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool   // constexpr in C++17
operator>(const move_iterator<Iterator1>& x, const move_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr bool   // constexpr in C++17
operator>=(const move_iterator<Iterator1>& x, const move_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
constexpr auto   // constexpr in C++17
operator-(const move_iterator<Iterator1>& x,
          const move_iterator<Iterator2>& y) -> decltype(x.base() - y.base());

template <class Iterator>
constexpr move_iterator<Iterator> operator+(   // constexpr in C++17
            typename move_iterator<Iterator>::difference_type n,
            const move_iterator<Iterator>& x);

template <class Iterator>   // constexpr in C++17
constexpr  move_iterator<Iterator> make_move_iterator(const Iterator& i);


template <class T, class charT = char, class traits = char_traits<charT>, class Distance = ptrdiff_t>
class istream_iterator
    : public iterator<input_iterator_tag, T, Distance, const T*, const T&>
{
public:
    typedef charT char_type;
    typedef traits traits_type;
    typedef basic_istream<charT,traits> istream_type;

    constexpr istream_iterator();
    istream_iterator(istream_type& s);
    istream_iterator(const istream_iterator& x);
    ~istream_iterator();

    const T& operator*() const;
    const T* operator->() const;
    istream_iterator& operator++();
    istream_iterator  operator++(int);
};

template <class T, class charT, class traits, class Distance>
bool operator==(const istream_iterator<T,charT,traits,Distance>& x,
                const istream_iterator<T,charT,traits,Distance>& y);
template <class T, class charT, class traits, class Distance>
bool operator!=(const istream_iterator<T,charT,traits,Distance>& x,
                const istream_iterator<T,charT,traits,Distance>& y);

template <class T, class charT = char, class traits = char_traits<charT> >
class ostream_iterator
    : public iterator<output_iterator_tag, void, void, void ,void>
{
public:
    typedef charT char_type;
    typedef traits traits_type;
    typedef basic_ostream<charT,traits> ostream_type;

    ostream_iterator(ostream_type& s);
    ostream_iterator(ostream_type& s, const charT* delimiter);
    ostream_iterator(const ostream_iterator& x);
    ~ostream_iterator();
    ostream_iterator& operator=(const T& value);

    ostream_iterator& operator*();
    ostream_iterator& operator++();
    ostream_iterator& operator++(int);
};

template<class charT, class traits = char_traits<charT> >
class istreambuf_iterator
    : public iterator<input_iterator_tag, charT,
                      typename traits::off_type, unspecified,
                      charT>
{
public:
    typedef charT                         char_type;
    typedef traits                        traits_type;
    typedef typename traits::int_type     int_type;
    typedef basic_streambuf<charT,traits> streambuf_type;
    typedef basic_istream<charT,traits>   istream_type;

    istreambuf_iterator() noexcept;
    istreambuf_iterator(istream_type& s) noexcept;
    istreambuf_iterator(streambuf_type* s) noexcept;
    istreambuf_iterator(a-private-type) noexcept;

    charT                operator*() const;
    pointer operator->() const;
    istreambuf_iterator& operator++();
    a-private-type       operator++(int);

    bool equal(const istreambuf_iterator& b) const;
};

template <class charT, class traits>
bool operator==(const istreambuf_iterator<charT,traits>& a,
                const istreambuf_iterator<charT,traits>& b);
template <class charT, class traits>
bool operator!=(const istreambuf_iterator<charT,traits>& a,
                const istreambuf_iterator<charT,traits>& b);

template <class charT, class traits = char_traits<charT> >
class ostreambuf_iterator
    : public iterator<output_iterator_tag, void, void, void, void>
{
public:
    typedef charT                         char_type;
    typedef traits                        traits_type;
    typedef basic_streambuf<charT,traits> streambuf_type;
    typedef basic_ostream<charT,traits>   ostream_type;

    ostreambuf_iterator(ostream_type& s) noexcept;
    ostreambuf_iterator(streambuf_type* s) noexcept;
    ostreambuf_iterator& operator=(charT c);
    ostreambuf_iterator& operator*();
    ostreambuf_iterator& operator++();
    ostreambuf_iterator& operator++(int);
    bool failed() const noexcept;
};

template <class C> constexpr auto begin(C& c) -> decltype(c.begin());
template <class C> constexpr auto begin(const C& c) -> decltype(c.begin());
template <class C> constexpr auto end(C& c) -> decltype(c.end());
template <class C> constexpr auto end(const C& c) -> decltype(c.end());
template <class T, size_t N> constexpr T* begin(T (&array)[N]);
template <class T, size_t N> constexpr T* end(T (&array)[N]);

template <class C> auto constexpr cbegin(const C& c) -> decltype(std::begin(c));        // C++14
template <class C> auto constexpr cend(const C& c) -> decltype(std::end(c));            // C++14
template <class C> auto constexpr rbegin(C& c) -> decltype(c.rbegin());                 // C++14
template <class C> auto constexpr rbegin(const C& c) -> decltype(c.rbegin());           // C++14
template <class C> auto constexpr rend(C& c) -> decltype(c.rend());                     // C++14
template <class C> constexpr auto rend(const C& c) -> decltype(c.rend());               // C++14
template <class E> reverse_iterator<const E*> constexpr rbegin(initializer_list<E> il); // C++14
template <class E> reverse_iterator<const E*> constexpr rend(initializer_list<E> il);   // C++14
template <class T, size_t N> reverse_iterator<T*> constexpr rbegin(T (&array)[N]);      // C++14
template <class T, size_t N> reverse_iterator<T*> constexpr rend(T (&array)[N]);        // C++14
template <class C> constexpr auto crbegin(const C& c) -> decltype(std::rbegin(c));      // C++14
template <class C> constexpr auto crend(const C& c) -> decltype(std::rend(c));          // C++14

// 24.8, container access:
template <class C> constexpr auto size(const C& c) -> decltype(c.size());         // C++17
template <class T, size_t N> constexpr size_t size(const T (&array)[N]) noexcept; // C++17

template <class C> constexpr auto ssize(const C& c)
    -> common_type_t<ptrdiff_t, make_signed_t<decltype(c.size())>>;				       // C++20
template <class T, ptrdiff_t> constexpr ptrdiff_t ssize(const T (&array)[N]) noexcept; // C++20

template <class C> constexpr auto empty(const C& c) -> decltype(c.empty());       // C++17
template <class T, size_t N> constexpr bool empty(const T (&array)[N]) noexcept;  // C++17
template <class E> constexpr bool empty(initializer_list<E> il) noexcept;         // C++17
template <class C> constexpr auto data(C& c) -> decltype(c.data());               // C++17
template <class C> constexpr auto data(const C& c) -> decltype(c.data());         // C++17
template <class T, size_t N> constexpr T* data(T (&array)[N]) noexcept;           // C++17
template <class E> constexpr const E* data(initializer_list<E> il) noexcept;      // C++17

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 419 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 420 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd> // for forward declarations of vector and string.
#endif /* expanded by -frewrite-includes */
# 420 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 421 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 421 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_FUNCTIONAL_BASE
#define _LIBCPP_FUNCTIONAL_BASE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <typeinfo>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
#endif
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Arg1, class _Arg2, class _Result>
struct _LIBCPP_TEMPLATE_VIS binary_function
{
    typedef _Arg1   first_argument_type;
    typedef _Arg2   second_argument_type;
    typedef _Result result_type;
};

template <class _Tp>
struct __has_result_type
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::result_type* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
template <class _Tp = void>
#else
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
template <class _Tp>
#endif
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
struct _LIBCPP_TEMPLATE_VIS less : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x < __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
template <>
struct _LIBCPP_TEMPLATE_VIS less<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) < _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) < _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) < _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 70 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

// __weak_result_type

template <class _Tp>
struct __derives_from_unary_function
{
private:
    struct __two {char __lx; char __lxx;};
    static __two __test(...);
    template <class _Ap, class _Rp>
        static unary_function<_Ap, _Rp>
        __test(const volatile unary_function<_Ap, _Rp>*);
public:
    static const bool value = !is_same<decltype(__test((_Tp*)0)), __two>::value;
    typedef decltype(__test((_Tp*)0)) type;
};

template <class _Tp>
struct __derives_from_binary_function
{
private:
    struct __two {char __lx; char __lxx;};
    static __two __test(...);
    template <class _A1, class _A2, class _Rp>
        static binary_function<_A1, _A2, _Rp>
        __test(const volatile binary_function<_A1, _A2, _Rp>*);
public:
    static const bool value = !is_same<decltype(__test((_Tp*)0)), __two>::value;
    typedef decltype(__test((_Tp*)0)) type;
};

template <class _Tp, bool = __derives_from_unary_function<_Tp>::value>
struct __maybe_derive_from_unary_function  // bool is true
    : public __derives_from_unary_function<_Tp>::type
{
};

template <class _Tp>
struct __maybe_derive_from_unary_function<_Tp, false>
{
};

template <class _Tp, bool = __derives_from_binary_function<_Tp>::value>
struct __maybe_derive_from_binary_function  // bool is true
    : public __derives_from_binary_function<_Tp>::type
{
};

template <class _Tp>
struct __maybe_derive_from_binary_function<_Tp, false>
{
};

template <class _Tp, bool = __has_result_type<_Tp>::value>
struct __weak_result_type_imp // bool is true
    : public __maybe_derive_from_unary_function<_Tp>,
      public __maybe_derive_from_binary_function<_Tp>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Tp::result_type result_type;
};

template <class _Tp>
struct __weak_result_type_imp<_Tp, false>
    : public __maybe_derive_from_unary_function<_Tp>,
      public __maybe_derive_from_binary_function<_Tp>
{
};

template <class _Tp>
struct __weak_result_type
    : public __weak_result_type_imp<_Tp>
{
};

// 0 argument case

template <class _Rp>
struct __weak_result_type<_Rp ()>
{
    typedef _LIBCPP_NODEBUG_TYPE  _Rp result_type;
};

template <class _Rp>
struct __weak_result_type<_Rp (&)()>
{
    typedef _LIBCPP_NODEBUG_TYPE  _Rp result_type;
};

template <class _Rp>
struct __weak_result_type<_Rp (*)()>
{
    typedef _LIBCPP_NODEBUG_TYPE  _Rp result_type;
};

// 1 argument case

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (&)(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (*)(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)()>
    : public unary_function<_Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() const>
    : public unary_function<const _Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() volatile>
    : public unary_function<volatile _Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() const volatile>
    : public unary_function<const volatile _Cp*, _Rp>
{
};

// 2 argument case

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (*)(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (&)(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1)>
    : public binary_function<_Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) const>
    : public binary_function<const _Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) volatile>
    : public binary_function<volatile _Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) const volatile>
    : public binary_function<const volatile _Cp*, _A1, _Rp>
{
};


#ifndef _LIBCPP_CXX03_LANG
// 3 or more arguments

template <class _Rp, class _A1, class _A2, class _A3, class ..._A4>
struct __weak_result_type<_Rp (_A1, _A2, _A3, _A4...)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _A1, class _A2, class _A3, class ..._A4>
struct __weak_result_type<_Rp (&)(_A1, _A2, _A3, _A4...)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _A1, class _A2, class _A3, class ..._A4>
struct __weak_result_type<_Rp (*)(_A1, _A2, _A3, _A4...)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2, class ..._A3>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2, _A3...)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2, class ..._A3>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2, _A3...) const>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2, class ..._A3>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2, _A3...) volatile>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2, class ..._A3>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2, _A3...) const volatile>
{
    typedef _Rp result_type;
};

template <class _Tp, class ..._Args>
struct __invoke_return
{
    typedef decltype(__invoke(_VSTD::declval<_Tp>(), _VSTD::declval<_Args>()...)) type;
};

#else // defined(_LIBCPP_CXX03_LANG)
# 305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

#if 0 /* expanded by -frewrite-includes */
#include <__functional_base_03>
#endif /* expanded by -frewrite-includes */
# 306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
# 307 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

#endif  // !defined(_LIBCPP_CXX03_LANG)
# 309 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3


template <class _Ret>
struct __invoke_void_return_wrapper
{
#ifndef _LIBCPP_CXX03_LANG
    template <class ..._Args>
    static _Ret __call(_Args&&... __args) {
        return __invoke(_VSTD::forward<_Args>(__args)...);
    }
#else
# 320 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
    template <class _Fn>
    static _Ret __call(_Fn __f) {
        return __invoke(__f);
    }

    template <class _Fn, class _A0>
    static _Ret __call(_Fn __f, _A0& __a0) {
        return __invoke(__f, __a0);
    }

    template <class _Fn, class _A0, class _A1>
    static _Ret __call(_Fn __f, _A0& __a0, _A1& __a1) {
        return __invoke(__f, __a0, __a1);
    }

    template <class _Fn, class _A0, class _A1, class _A2>
    static _Ret __call(_Fn __f, _A0& __a0, _A1& __a1, _A2& __a2){
        return __invoke(__f, __a0, __a1, __a2);
    }
#endif
# 340 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
};

template <>
struct __invoke_void_return_wrapper<void>
{
#ifndef _LIBCPP_CXX03_LANG
    template <class ..._Args>
    static void __call(_Args&&... __args) {
        __invoke(_VSTD::forward<_Args>(__args)...);
    }
#else
# 351 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
    template <class _Fn>
    static void __call(_Fn __f) {
        __invoke(__f);
    }

    template <class _Fn, class _A0>
    static void __call(_Fn __f, _A0& __a0) {
        __invoke(__f, __a0);
    }

    template <class _Fn, class _A0, class _A1>
    static void __call(_Fn __f, _A0& __a0, _A1& __a1) {
        __invoke(__f, __a0, __a1);
    }

    template <class _Fn, class _A0, class _A1, class _A2>
    static void __call(_Fn __f, _A0& __a0, _A1& __a1, _A2& __a2) {
        __invoke(__f, __a0, __a1, __a2);
    }
#endif
# 371 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
};

template <class _Tp>
class _LIBCPP_TEMPLATE_VIS reference_wrapper
    : public __weak_result_type<_Tp>
{
public:
    // types
    typedef _Tp type;
private:
    type* __f_;

public:
    // construct/copy/destroy
    _LIBCPP_INLINE_VISIBILITY reference_wrapper(type& __f) _NOEXCEPT
        : __f_(_VSTD::addressof(__f)) {}
#ifndef _LIBCPP_CXX03_LANG
    private: reference_wrapper(type&&); public: // = delete; // do not bind to temps
#endif
# 390 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

    // access
    _LIBCPP_INLINE_VISIBILITY operator type&    () const _NOEXCEPT {return *__f_;}
    _LIBCPP_INLINE_VISIBILITY          type& get() const _NOEXCEPT {return *__f_;}

#ifndef _LIBCPP_CXX03_LANG
    // invoke
    template <class... _ArgTypes>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_of<type&, _ArgTypes...>::type
    operator() (_ArgTypes&&... __args) const {
        return __invoke(get(), _VSTD::forward<_ArgTypes>(__args)...);
    }
#else
# 404 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return<type>::type
    operator() () const {
        return __invoke(get());
    }

    template <class _A0>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return0<type, _A0>::type
    operator() (_A0& __a0) const {
        return __invoke(get(), __a0);
    }

    template <class _A0>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return0<type, _A0 const>::type
    operator() (_A0 const& __a0) const {
        return __invoke(get(), __a0);
    }

    template <class _A0, class _A1>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return1<type, _A0, _A1>::type
    operator() (_A0& __a0, _A1& __a1) const {
        return __invoke(get(), __a0, __a1);
    }

    template <class _A0, class _A1>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return1<type, _A0 const, _A1>::type
    operator() (_A0 const& __a0, _A1& __a1) const {
        return __invoke(get(), __a0, __a1);
    }

    template <class _A0, class _A1>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return1<type, _A0, _A1 const>::type
    operator() (_A0& __a0, _A1 const& __a1) const {
        return __invoke(get(), __a0, __a1);
    }

    template <class _A0, class _A1>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return1<type, _A0 const, _A1 const>::type
    operator() (_A0 const& __a0, _A1 const& __a1) const {
        return __invoke(get(), __a0, __a1);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0, _A1, _A2>::type
    operator() (_A0& __a0, _A1& __a1, _A2& __a2) const {
        return __invoke(get(), __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0 const, _A1, _A2>::type
    operator() (_A0 const& __a0, _A1& __a1, _A2& __a2) const {
        return __invoke(get(), __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0, _A1 const, _A2>::type
    operator() (_A0& __a0, _A1 const& __a1, _A2& __a2) const {
        return __invoke(get(), __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0, _A1, _A2 const>::type
    operator() (_A0& __a0, _A1& __a1, _A2 const& __a2) const {
        return __invoke(get(), __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0 const, _A1 const, _A2>::type
    operator() (_A0 const& __a0, _A1 const& __a1, _A2& __a2) const {
        return __invoke(get(), __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0 const, _A1, _A2 const>::type
    operator() (_A0 const& __a0, _A1& __a1, _A2 const& __a2) const {
        return __invoke(get(), __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0, _A1 const, _A2 const>::type
    operator() (_A0& __a0, _A1 const& __a1, _A2 const& __a2) const {
        return __invoke(get(), __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0 const, _A1 const, _A2 const>::type
    operator() (_A0 const& __a0, _A1 const& __a1, _A2 const& __a2) const {
        return __invoke(get(), __a0, __a1, __a2);
    }
#endif // _LIBCPP_CXX03_LANG
# 509 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
};


template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<_Tp>
ref(_Tp& __t) _NOEXCEPT
{
    return reference_wrapper<_Tp>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<_Tp>
ref(reference_wrapper<_Tp> __t) _NOEXCEPT
{
    return ref(__t.get());
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<const _Tp>
cref(const _Tp& __t) _NOEXCEPT
{
    return reference_wrapper<const _Tp>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<const _Tp>
cref(reference_wrapper<_Tp> __t) _NOEXCEPT
{
    return cref(__t.get());
}

#ifndef _LIBCPP_CXX03_LANG
template <class _Tp> void ref(const _Tp&&) = delete;
template <class _Tp> void cref(const _Tp&&) = delete;
#endif
# 548 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 550 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
template <class _Tp, class, class = void>
struct __is_transparent : false_type {};

template <class _Tp, class _Up>
struct __is_transparent<_Tp, _Up,
                        typename __void_t<typename _Tp::is_transparent>::type>
   : true_type {};
#endif
# 558 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

// allocator_arg_t

struct _LIBCPP_TEMPLATE_VIS allocator_arg_t { explicit allocator_arg_t() = default; };

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_CXX03_LANG) || defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 564 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
extern _LIBCPP_EXPORTED_FROM_ABI const allocator_arg_t allocator_arg;
#else
# 566 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
/* _LIBCPP_INLINE_VAR */ constexpr allocator_arg_t allocator_arg = allocator_arg_t();
#endif
# 568 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

// uses_allocator

template <class _Tp>
struct __has_allocator_type
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::allocator_type* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Tp, class _Alloc, bool = __has_allocator_type<_Tp>::value>
struct __uses_allocator
    : public integral_constant<bool,
        is_convertible<_Alloc, typename _Tp::allocator_type>::value>
{
};

template <class _Tp, class _Alloc>
struct __uses_allocator<_Tp, _Alloc, false>
    : public false_type
{
};

template <class _Tp, class _Alloc>
struct _LIBCPP_TEMPLATE_VIS uses_allocator
    : public __uses_allocator<_Tp, _Alloc>
{
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 602 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
template <class _Tp, class _Alloc>
_LIBCPP_INLINE_VAR constexpr size_t uses_allocator_v = uses_allocator<_Tp, _Alloc>::value;
#endif
# 605 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

#ifndef _LIBCPP_CXX03_LANG

// allocator construction

template <class _Tp, class _Alloc, class ..._Args>
struct __uses_alloc_ctor_imp
{
    typedef _LIBCPP_NODEBUG_TYPE typename __uncvref<_Alloc>::type _RawAlloc;
    static const bool __ua = uses_allocator<_Tp, _RawAlloc>::value;
    static const bool __ic =
        is_constructible<_Tp, allocator_arg_t, _Alloc, _Args...>::value;
    static const int value = __ua ? 2 - __ic : 0;
};

template <class _Tp, class _Alloc, class ..._Args>
struct __uses_alloc_ctor
    : integral_constant<int, __uses_alloc_ctor_imp<_Tp, _Alloc, _Args...>::value>
    {};

template <class _Tp, class _Allocator, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
void __user_alloc_construct_impl (integral_constant<int, 0>, _Tp *__storage, const _Allocator &, _Args &&... __args )
{
    new (__storage) _Tp (_VSTD::forward<_Args>(__args)...);
}

// FIXME: This should have a version which takes a non-const alloc.
template <class _Tp, class _Allocator, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
void __user_alloc_construct_impl (integral_constant<int, 1>, _Tp *__storage, const _Allocator &__a, _Args &&... __args )
{
    new (__storage) _Tp (allocator_arg, __a, _VSTD::forward<_Args>(__args)...);
}

// FIXME: This should have a version which takes a non-const alloc.
template <class _Tp, class _Allocator, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
void __user_alloc_construct_impl (integral_constant<int, 2>, _Tp *__storage, const _Allocator &__a, _Args &&... __args )
{
    new (__storage) _Tp (_VSTD::forward<_Args>(__args)..., __a);
}

#endif  // _LIBCPP_CXX03_LANG
# 649 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_FUNCTIONAL_BASE
# 653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__functional_base" 3
# 422 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 422 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 423 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 423 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 424 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 424 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 425 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 425 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 426 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#ifdef __APPLE__
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 427 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 428 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#endif
# 429 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 430 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 431 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 433 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 434 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
#endif
# 435 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

_LIBCPP_BEGIN_NAMESPACE_STD
template <class _Iter>
struct _LIBCPP_TEMPLATE_VIS iterator_traits;

struct _LIBCPP_TEMPLATE_VIS input_iterator_tag {};
struct _LIBCPP_TEMPLATE_VIS output_iterator_tag {};
struct _LIBCPP_TEMPLATE_VIS forward_iterator_tag       : public input_iterator_tag {};
struct _LIBCPP_TEMPLATE_VIS bidirectional_iterator_tag : public forward_iterator_tag {};
struct _LIBCPP_TEMPLATE_VIS random_access_iterator_tag : public bidirectional_iterator_tag {};
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 446 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
// TODO(EricWF)  contiguous_iterator_tag is provided as an extension prior to
//  C++20 to allow optimizations for users providing wrapped iterator types.
struct _LIBCPP_TEMPLATE_VIS contiguous_iterator_tag: public random_access_iterator_tag { };
#endif
# 450 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Iter>
struct __iter_traits_cache {
  using type = _If<
    __is_primary_template<iterator_traits<_Iter> >::value,
    _Iter,
    iterator_traits<_Iter>
  >;
};
template <class _Iter>
using _ITER_TRAITS = typename __iter_traits_cache<_Iter>::type;

struct __iter_concept_concept_test {
  template <class _Iter>
  using _Apply = typename _ITER_TRAITS<_Iter>::iterator_concept;
};
struct __iter_concept_category_test {
  template <class _Iter>
  using _Apply = typename _ITER_TRAITS<_Iter>::iterator_category;
};
struct __iter_concept_random_fallback {
  template <class _Iter>
  using _Apply = _EnableIf<
                          __is_primary_template<iterator_traits<_Iter> >::value,
                          random_access_iterator_tag
                        >;
};

template <class _Iter, class _Tester> struct __test_iter_concept
    : _IsValidExpansion<_Tester::template _Apply, _Iter>,
      _Tester
{
};

template <class _Iter>
struct __iter_concept_cache {
  using type = _Or<
    __test_iter_concept<_Iter, __iter_concept_concept_test>,
    __test_iter_concept<_Iter, __iter_concept_category_test>,
    __test_iter_concept<_Iter, __iter_concept_random_fallback>
  >;
};

template <class _Iter>
using _ITER_CONCEPT = typename __iter_concept_cache<_Iter>::type::template _Apply<_Iter>;


template <class _Tp>
struct __has_iterator_typedefs
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename std::__void_t<typename _Up::iterator_category>::type* = 0,
    										typename std::__void_t<typename _Up::difference_type>::type* = 0,
    										typename std::__void_t<typename _Up::value_type>::type* = 0,
    										typename std::__void_t<typename _Up::reference>::type* = 0,
    										typename std::__void_t<typename _Up::pointer>::type* = 0
    										);
public:
    static const bool value = sizeof(__test<_Tp>(0,0,0,0,0)) == 1;
};


template <class _Tp>
struct __has_iterator_category
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::iterator_category* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Iter, bool> struct __iterator_traits_impl {};

template <class _Iter>
struct __iterator_traits_impl<_Iter, true>
{
    typedef typename _Iter::difference_type   difference_type;
    typedef typename _Iter::value_type        value_type;
    typedef typename _Iter::pointer           pointer;
    typedef typename _Iter::reference         reference;
    typedef typename _Iter::iterator_category iterator_category;
};

template <class _Iter, bool> struct __iterator_traits {};

template <class _Iter>
struct __iterator_traits<_Iter, true>
    :  __iterator_traits_impl
      <
        _Iter,
        is_convertible<typename _Iter::iterator_category, input_iterator_tag>::value ||
        is_convertible<typename _Iter::iterator_category, output_iterator_tag>::value
      >
{};

// iterator_traits<Iterator> will only have the nested types if Iterator::iterator_category
//    exists.  Else iterator_traits<Iterator> will be an empty class.  This is a
//    conforming extension which allows some programs to compile and behave as
//    the client expects instead of failing at compile time.

template <class _Iter>
struct _LIBCPP_TEMPLATE_VIS iterator_traits
    : __iterator_traits<_Iter, __has_iterator_typedefs<_Iter>::value> {

  using __primary_template = iterator_traits;
};

template<class _Tp>
struct _LIBCPP_TEMPLATE_VIS iterator_traits<_Tp*>
{
    typedef ptrdiff_t difference_type;
    typedef typename remove_cv<_Tp>::type value_type;
    typedef _Tp* pointer;
    typedef _Tp& reference;
    typedef random_access_iterator_tag iterator_category;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 570 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    typedef contiguous_iterator_tag    iterator_concept;
#endif
# 572 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
};

template <class _Tp, class _Up, bool = __has_iterator_category<iterator_traits<_Tp> >::value>
struct __has_iterator_category_convertible_to
    : public integral_constant<bool, is_convertible<typename iterator_traits<_Tp>::iterator_category, _Up>::value>
{};

template <class _Tp, class _Up>
struct __has_iterator_category_convertible_to<_Tp, _Up, false> : public false_type {};

template <class _Tp>
struct __is_cpp17_input_iterator : public __has_iterator_category_convertible_to<_Tp, input_iterator_tag> {};

template <class _Tp>
struct __is_cpp17_forward_iterator : public __has_iterator_category_convertible_to<_Tp, forward_iterator_tag> {};

template <class _Tp>
struct __is_cpp17_bidirectional_iterator : public __has_iterator_category_convertible_to<_Tp, bidirectional_iterator_tag> {};

template <class _Tp>
struct __is_cpp17_random_access_iterator : public __has_iterator_category_convertible_to<_Tp, random_access_iterator_tag> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 595 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
template <class _Tp>
struct __is_cpp17_contiguous_iterator : public __has_iterator_category_convertible_to<_Tp, contiguous_iterator_tag> {};
#else
# 598 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
template <class _Tp>
struct __is_cpp17_contiguous_iterator : public false_type {};
#endif
# 601 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3


template <class _Tp>
struct __is_exactly_cpp17_input_iterator
    : public integral_constant<bool,
         __has_iterator_category_convertible_to<_Tp, input_iterator_tag>::value &&
        !__has_iterator_category_convertible_to<_Tp, forward_iterator_tag>::value> {};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _InputIterator>
using __iter_value_type = typename iterator_traits<_InputIterator>::value_type;

template<class _InputIterator>
using __iter_key_type = remove_const_t<typename iterator_traits<_InputIterator>::value_type::first_type>;

template<class _InputIterator>
using __iter_mapped_type = typename iterator_traits<_InputIterator>::value_type::second_type;

template<class _InputIterator>
using __iter_to_alloc_type = pair<
    add_const_t<typename iterator_traits<_InputIterator>::value_type::first_type>,
    typename iterator_traits<_InputIterator>::value_type::second_type>;
#endif
# 624 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template<class _Category, class _Tp, class _Distance = ptrdiff_t,
         class _Pointer = _Tp*, class _Reference = _Tp&>
struct _LIBCPP_TEMPLATE_VIS iterator
{
    typedef _Tp        value_type;
    typedef _Distance  difference_type;
    typedef _Pointer   pointer;
    typedef _Reference reference;
    typedef _Category  iterator_category;
};

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
void __advance(_InputIter& __i,
             typename iterator_traits<_InputIter>::difference_type __n, input_iterator_tag)
{
    for (; __n > 0; --__n)
        ++__i;
}

template <class _BiDirIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
void __advance(_BiDirIter& __i,
             typename iterator_traits<_BiDirIter>::difference_type __n, bidirectional_iterator_tag)
{
    if (__n >= 0)
        for (; __n > 0; --__n)
            ++__i;
    else
        for (; __n < 0; ++__n)
            --__i;
}

template <class _RandIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
void __advance(_RandIter& __i,
             typename iterator_traits<_RandIter>::difference_type __n, random_access_iterator_tag)
{
   __i += __n;
}

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
void advance(_InputIter& __i,
             typename iterator_traits<_InputIter>::difference_type __n)
{
    _LIBCPP_ASSERT(__n >= 0 || __is_cpp17_bidirectional_iterator<_InputIter>::value,
                       "Attempt to advance(it, -n) on a non-bidi iterator");
    __advance(__i, __n, typename iterator_traits<_InputIter>::iterator_category());
}

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
typename iterator_traits<_InputIter>::difference_type
__distance(_InputIter __first, _InputIter __last, input_iterator_tag)
{
    typename iterator_traits<_InputIter>::difference_type __r(0);
    for (; __first != __last; ++__first)
        ++__r;
    return __r;
}

template <class _RandIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
typename iterator_traits<_RandIter>::difference_type
__distance(_RandIter __first, _RandIter __last, random_access_iterator_tag)
{
    return __last - __first;
}

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
typename iterator_traits<_InputIter>::difference_type
distance(_InputIter __first, _InputIter __last)
{
    return __distance(__first, __last, typename iterator_traits<_InputIter>::iterator_category());
}

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
typename enable_if
<
    __is_cpp17_input_iterator<_InputIter>::value,
    _InputIter
>::type
next(_InputIter __x,
     typename iterator_traits<_InputIter>::difference_type __n = 1)
{
    _LIBCPP_ASSERT(__n >= 0 || __is_cpp17_bidirectional_iterator<_InputIter>::value,
                       "Attempt to next(it, -n) on a non-bidi iterator");

    _VSTD::advance(__x, __n);
    return __x;
}

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
typename enable_if
<
    __is_cpp17_input_iterator<_InputIter>::value,
    _InputIter
>::type
prev(_InputIter __x,
     typename iterator_traits<_InputIter>::difference_type __n = 1)
{
    _LIBCPP_ASSERT(__n <= 0 || __is_cpp17_bidirectional_iterator<_InputIter>::value,
                       "Attempt to prev(it, +n) on a non-bidi iterator");
    _VSTD::advance(__x, -__n);
    return __x;
}


template <class _Tp, class = void>
struct __is_stashing_iterator : false_type {};

template <class _Tp>
struct __is_stashing_iterator<_Tp, typename __void_t<typename _Tp::__stashing_iterator_tag>::type>
  : true_type {};

template <class _Iter>
class _LIBCPP_TEMPLATE_VIS reverse_iterator
    : public iterator<typename iterator_traits<_Iter>::iterator_category,
                      typename iterator_traits<_Iter>::value_type,
                      typename iterator_traits<_Iter>::difference_type,
                      typename iterator_traits<_Iter>::pointer,
                      typename iterator_traits<_Iter>::reference>
{
private:
    /*mutable*/ _Iter __t;  // no longer used as of LWG #2360, not removed due to ABI break

    static_assert(!__is_stashing_iterator<_Iter>::value,
      "The specified iterator type cannot be used with reverse_iterator; "
      "Using stashing iterators with reverse_iterator causes undefined behavior");

protected:
    _Iter current;
public:
    typedef _Iter                                            iterator_type;
    typedef typename iterator_traits<_Iter>::difference_type difference_type;
    typedef typename iterator_traits<_Iter>::reference       reference;
    typedef typename iterator_traits<_Iter>::pointer         pointer;

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator() : __t(), current() {}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    explicit reverse_iterator(_Iter __x) : __t(__x), current(__x) {}
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
        reverse_iterator(const reverse_iterator<_Up>& __u) : __t(__u.base()), current(__u.base()) {}
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
        reverse_iterator& operator=(const reverse_iterator<_Up>& __u)
            { __t = current = __u.base(); return *this; }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    _Iter base() const {return current;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reference operator*() const {_Iter __tmp = current; return *--__tmp;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    pointer  operator->() const {return _VSTD::addressof(operator*());}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator& operator++() {--current; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator  operator++(int) {reverse_iterator __tmp(*this); --current; return __tmp;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator& operator--() {++current; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator  operator--(int) {reverse_iterator __tmp(*this); ++current; return __tmp;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator  operator+ (difference_type __n) const {return reverse_iterator(current - __n);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator& operator+=(difference_type __n) {current -= __n; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator  operator- (difference_type __n) const {return reverse_iterator(current + __n);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator& operator-=(difference_type __n) {current += __n; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reference         operator[](difference_type __n) const {return *(*this + __n);}
};

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator==(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() == __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator<(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() > __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator!=(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() != __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator>(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() < __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator>=(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() <= __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator<=(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() >= __y.base();
}

#ifndef _LIBCPP_CXX03_LANG
template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto
operator-(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
-> decltype(__y.base() - __x.base())
{
    return __y.base() - __x.base();
}
#else
# 862 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
typename reverse_iterator<_Iter1>::difference_type
operator-(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __y.base() - __x.base();
}
#endif
# 870 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
reverse_iterator<_Iter>
operator+(typename reverse_iterator<_Iter>::difference_type __n, const reverse_iterator<_Iter>& __x)
{
    return reverse_iterator<_Iter>(__x.base() - __n);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 880 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
reverse_iterator<_Iter> make_reverse_iterator(_Iter __i)
{
    return reverse_iterator<_Iter>(__i);
}
#endif
# 887 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Container>
class _LIBCPP_TEMPLATE_VIS back_insert_iterator
    : public iterator<output_iterator_tag,
                      void,
                      void,
                      void,
                      void>
{
protected:
    _Container* container;
public:
    typedef _Container container_type;

    _LIBCPP_INLINE_VISIBILITY explicit back_insert_iterator(_Container& __x) : container(_VSTD::addressof(__x)) {}
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator& operator=(const typename _Container::value_type& __value_)
        {container->push_back(__value_); return *this;}
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator& operator=(typename _Container::value_type&& __value_)
        {container->push_back(_VSTD::move(__value_)); return *this;}
#endif  // _LIBCPP_CXX03_LANG
# 908 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator& operator*()     {return *this;}
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator& operator++()    {return *this;}
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator  operator++(int) {return *this;}
};

template <class _Container>
inline _LIBCPP_INLINE_VISIBILITY
back_insert_iterator<_Container>
back_inserter(_Container& __x)
{
    return back_insert_iterator<_Container>(__x);
}

template <class _Container>
class _LIBCPP_TEMPLATE_VIS front_insert_iterator
    : public iterator<output_iterator_tag,
                      void,
                      void,
                      void,
                      void>
{
protected:
    _Container* container;
public:
    typedef _Container container_type;

    _LIBCPP_INLINE_VISIBILITY explicit front_insert_iterator(_Container& __x) : container(_VSTD::addressof(__x)) {}
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator& operator=(const typename _Container::value_type& __value_)
        {container->push_front(__value_); return *this;}
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator& operator=(typename _Container::value_type&& __value_)
        {container->push_front(_VSTD::move(__value_)); return *this;}
#endif  // _LIBCPP_CXX03_LANG
# 941 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator& operator*()     {return *this;}
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator& operator++()    {return *this;}
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator  operator++(int) {return *this;}
};

template <class _Container>
inline _LIBCPP_INLINE_VISIBILITY
front_insert_iterator<_Container>
front_inserter(_Container& __x)
{
    return front_insert_iterator<_Container>(__x);
}

template <class _Container>
class _LIBCPP_TEMPLATE_VIS insert_iterator
    : public iterator<output_iterator_tag,
                      void,
                      void,
                      void,
                      void>
{
protected:
    _Container* container;
    typename _Container::iterator iter;
public:
    typedef _Container container_type;

    _LIBCPP_INLINE_VISIBILITY insert_iterator(_Container& __x, typename _Container::iterator __i)
        : container(_VSTD::addressof(__x)), iter(__i) {}
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator=(const typename _Container::value_type& __value_)
        {iter = container->insert(iter, __value_); ++iter; return *this;}
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator=(typename _Container::value_type&& __value_)
        {iter = container->insert(iter, _VSTD::move(__value_)); ++iter; return *this;}
#endif  // _LIBCPP_CXX03_LANG
# 976 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator*()        {return *this;}
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator++()       {return *this;}
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator++(int)    {return *this;}
};

template <class _Container>
inline _LIBCPP_INLINE_VISIBILITY
insert_iterator<_Container>
inserter(_Container& __x, typename _Container::iterator __i)
{
    return insert_iterator<_Container>(__x, __i);
}

template <class _Tp, class _CharT = char,
          class _Traits = char_traits<_CharT>, class _Distance = ptrdiff_t>
class _LIBCPP_TEMPLATE_VIS istream_iterator
    : public iterator<input_iterator_tag, _Tp, _Distance, const _Tp*, const _Tp&>
{
public:
    typedef _CharT char_type;
    typedef _Traits traits_type;
    typedef basic_istream<_CharT,_Traits> istream_type;
private:
    istream_type* __in_stream_;
    _Tp __value_;
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR istream_iterator() : __in_stream_(0), __value_() {}
    _LIBCPP_INLINE_VISIBILITY istream_iterator(istream_type& __s) : __in_stream_(_VSTD::addressof(__s))
        {
            if (!(*__in_stream_ >> __value_))
                __in_stream_ = 0;
        }

    _LIBCPP_INLINE_VISIBILITY const _Tp& operator*() const {return __value_;}
    _LIBCPP_INLINE_VISIBILITY const _Tp* operator->() const {return _VSTD::addressof((operator*()));}
    _LIBCPP_INLINE_VISIBILITY istream_iterator& operator++()
        {
            if (!(*__in_stream_ >> __value_))
                __in_stream_ = 0;
            return *this;
        }
    _LIBCPP_INLINE_VISIBILITY istream_iterator  operator++(int)
        {istream_iterator __t(*this); ++(*this); return __t;}

    template <class _Up, class _CharU, class _TraitsU, class _DistanceU>
    friend _LIBCPP_INLINE_VISIBILITY
    bool
    operator==(const istream_iterator<_Up, _CharU, _TraitsU, _DistanceU>& __x,
               const istream_iterator<_Up, _CharU, _TraitsU, _DistanceU>& __y);

    template <class _Up, class _CharU, class _TraitsU, class _DistanceU>
    friend _LIBCPP_INLINE_VISIBILITY
    bool
    operator==(const istream_iterator<_Up, _CharU, _TraitsU, _DistanceU>& __x,
               const istream_iterator<_Up, _CharU, _TraitsU, _DistanceU>& __y);
};

template <class _Tp, class _CharT, class _Traits, class _Distance>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const istream_iterator<_Tp, _CharT, _Traits, _Distance>& __x,
           const istream_iterator<_Tp, _CharT, _Traits, _Distance>& __y)
{
    return __x.__in_stream_ == __y.__in_stream_;
}

template <class _Tp, class _CharT, class _Traits, class _Distance>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const istream_iterator<_Tp, _CharT, _Traits, _Distance>& __x,
           const istream_iterator<_Tp, _CharT, _Traits, _Distance>& __y)
{
    return !(__x == __y);
}

template <class _Tp, class _CharT = char, class _Traits = char_traits<_CharT> >
class _LIBCPP_TEMPLATE_VIS ostream_iterator
    : public iterator<output_iterator_tag, void, void, void, void>
{
public:
    typedef _CharT char_type;
    typedef _Traits traits_type;
    typedef basic_ostream<_CharT,_Traits> ostream_type;
private:
    ostream_type* __out_stream_;
    const char_type* __delim_;
public:
    _LIBCPP_INLINE_VISIBILITY ostream_iterator(ostream_type& __s) _NOEXCEPT
        : __out_stream_(_VSTD::addressof(__s)), __delim_(0) {}
    _LIBCPP_INLINE_VISIBILITY ostream_iterator(ostream_type& __s, const _CharT* __delimiter) _NOEXCEPT
        : __out_stream_(_VSTD::addressof(__s)), __delim_(__delimiter) {}
    _LIBCPP_INLINE_VISIBILITY ostream_iterator& operator=(const _Tp& __value_)
        {
            *__out_stream_ << __value_;
            if (__delim_)
                *__out_stream_ << __delim_;
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY ostream_iterator& operator*()     {return *this;}
    _LIBCPP_INLINE_VISIBILITY ostream_iterator& operator++()    {return *this;}
    _LIBCPP_INLINE_VISIBILITY ostream_iterator& operator++(int) {return *this;}
};

template<class _CharT, class _Traits>
class _LIBCPP_TEMPLATE_VIS istreambuf_iterator
    : public iterator<input_iterator_tag, _CharT,
                      typename _Traits::off_type, _CharT*,
                      _CharT>
{
public:
    typedef _CharT                          char_type;
    typedef _Traits                         traits_type;
    typedef typename _Traits::int_type      int_type;
    typedef basic_streambuf<_CharT,_Traits> streambuf_type;
    typedef basic_istream<_CharT,_Traits>   istream_type;
private:
    mutable streambuf_type* __sbuf_;

    class __proxy
    {
        char_type __keep_;
        streambuf_type* __sbuf_;
        _LIBCPP_INLINE_VISIBILITY __proxy(char_type __c, streambuf_type* __s)
            : __keep_(__c), __sbuf_(__s) {}
        friend class istreambuf_iterator;
    public:
        _LIBCPP_INLINE_VISIBILITY char_type operator*() const {return __keep_;}
    };

    _LIBCPP_INLINE_VISIBILITY
    bool __test_for_eof() const
    {
        if (__sbuf_ && traits_type::eq_int_type(__sbuf_->sgetc(), traits_type::eof()))
            __sbuf_ = 0;
        return __sbuf_ == 0;
    }
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR istreambuf_iterator() _NOEXCEPT : __sbuf_(0) {}
    _LIBCPP_INLINE_VISIBILITY istreambuf_iterator(istream_type& __s) _NOEXCEPT
        : __sbuf_(__s.rdbuf()) {}
    _LIBCPP_INLINE_VISIBILITY istreambuf_iterator(streambuf_type* __s) _NOEXCEPT
        : __sbuf_(__s) {}
    _LIBCPP_INLINE_VISIBILITY istreambuf_iterator(const __proxy& __p) _NOEXCEPT
        : __sbuf_(__p.__sbuf_) {}

    _LIBCPP_INLINE_VISIBILITY char_type  operator*() const
        {return static_cast<char_type>(__sbuf_->sgetc());}
    _LIBCPP_INLINE_VISIBILITY istreambuf_iterator& operator++()
        {
            __sbuf_->sbumpc();
            return *this;
        }
    _LIBCPP_INLINE_VISIBILITY __proxy              operator++(int)
        {
            return __proxy(__sbuf_->sbumpc(), __sbuf_);
        }

    _LIBCPP_INLINE_VISIBILITY bool equal(const istreambuf_iterator& __b) const
        {return __test_for_eof() == __b.__test_for_eof();}
};

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
bool operator==(const istreambuf_iterator<_CharT,_Traits>& __a,
                const istreambuf_iterator<_CharT,_Traits>& __b)
                {return __a.equal(__b);}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
bool operator!=(const istreambuf_iterator<_CharT,_Traits>& __a,
                const istreambuf_iterator<_CharT,_Traits>& __b)
                {return !__a.equal(__b);}

template <class _CharT, class _Traits>
class _LIBCPP_TEMPLATE_VIS ostreambuf_iterator
    : public iterator<output_iterator_tag, void, void, void, void>
{
public:
    typedef _CharT                          char_type;
    typedef _Traits                         traits_type;
    typedef basic_streambuf<_CharT,_Traits> streambuf_type;
    typedef basic_ostream<_CharT,_Traits>   ostream_type;
private:
    streambuf_type* __sbuf_;
public:
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator(ostream_type& __s) _NOEXCEPT
        : __sbuf_(__s.rdbuf()) {}
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator(streambuf_type* __s) _NOEXCEPT
        : __sbuf_(__s) {}
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator& operator=(_CharT __c)
        {
            if (__sbuf_ && traits_type::eq_int_type(__sbuf_->sputc(__c), traits_type::eof()))
                __sbuf_ = 0;
            return *this;
        }
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator& operator*()     {return *this;}
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator& operator++()    {return *this;}
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator& operator++(int) {return *this;}
    _LIBCPP_INLINE_VISIBILITY bool failed() const _NOEXCEPT {return __sbuf_ == 0;}

    template <class _Ch, class _Tr>
    friend
    _LIBCPP_HIDDEN
    ostreambuf_iterator<_Ch, _Tr>
    __pad_and_output(ostreambuf_iterator<_Ch, _Tr> __s,
                     const _Ch* __ob, const _Ch* __op, const _Ch* __oe,
                     ios_base& __iob, _Ch __fl);
};

template <class _Iter>
class _LIBCPP_TEMPLATE_VIS move_iterator
{
private:
    _Iter __i;
public:
    typedef _Iter                                            iterator_type;
    typedef typename iterator_traits<iterator_type>::iterator_category iterator_category;
    typedef typename iterator_traits<iterator_type>::value_type value_type;
    typedef typename iterator_traits<iterator_type>::difference_type difference_type;
    typedef iterator_type pointer;
#ifndef _LIBCPP_CXX03_LANG
    typedef typename iterator_traits<iterator_type>::reference __reference;
    typedef typename conditional<
            is_reference<__reference>::value,
            typename remove_reference<__reference>::type&&,
            __reference
        >::type reference;
#else
# 1205 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    typedef typename iterator_traits<iterator_type>::reference reference;
#endif
# 1207 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator() : __i() {}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    explicit move_iterator(_Iter __x) : __i(__x) {}
    template <class _Up>
      _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
      move_iterator(const move_iterator<_Up>& __u) : __i(__u.base()) {}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 _Iter base() const {return __i;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reference operator*() const { return static_cast<reference>(*__i); }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    pointer  operator->() const { return __i;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator& operator++() {++__i; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator  operator++(int) {move_iterator __tmp(*this); ++__i; return __tmp;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator& operator--() {--__i; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator  operator--(int) {move_iterator __tmp(*this); --__i; return __tmp;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator  operator+ (difference_type __n) const {return move_iterator(__i + __n);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator& operator+=(difference_type __n) {__i += __n; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator  operator- (difference_type __n) const {return move_iterator(__i - __n);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    move_iterator& operator-=(difference_type __n) {__i -= __n; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reference operator[](difference_type __n) const { return static_cast<reference>(__i[__n]); }
};

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator==(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() == __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator<(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() < __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator!=(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() != __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator>(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() > __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator>=(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() >= __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
bool
operator<=(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() <= __y.base();
}

#ifndef _LIBCPP_CXX03_LANG
template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto
operator-(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
-> decltype(__x.base() - __y.base())
{
    return __x.base() - __y.base();
}
#else
# 1298 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
typename move_iterator<_Iter1>::difference_type
operator-(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() - __y.base();
}
#endif
# 1306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
move_iterator<_Iter>
operator+(typename move_iterator<_Iter>::difference_type __n, const move_iterator<_Iter>& __x)
{
    return move_iterator<_Iter>(__x.base() + __n);
}

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
move_iterator<_Iter>
make_move_iterator(_Iter __i)
{
    return move_iterator<_Iter>(__i);
}

// __wrap_iter

template <class _Iter> class __wrap_iter;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator==(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator<(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator!=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator>(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator>=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator<=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

#ifndef _LIBCPP_CXX03_LANG
template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
auto
operator-(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
-> decltype(__x.base() - __y.base());
#else
# 1364 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY
typename __wrap_iter<_Iter1>::difference_type
operator-(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;
#endif
# 1369 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Iter>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
__wrap_iter<_Iter>
operator+(typename __wrap_iter<_Iter>::difference_type, __wrap_iter<_Iter>) _NOEXCEPT;

template <class _Ip, class _Op> _Op _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17 copy(_Ip, _Ip, _Op);
template <class _B1, class _B2> _B2 _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17 copy_backward(_B1, _B1, _B2);
template <class _Ip, class _Op> _Op _LIBCPP_INLINE_VISIBILITY move(_Ip, _Ip, _Op);
template <class _B1, class _B2> _B2 _LIBCPP_INLINE_VISIBILITY move_backward(_B1, _B1, _B2);

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL < 2
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1381 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    _Tp*
>::type
__unwrap_iter(__wrap_iter<_Tp*>);

#else
# 1392 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    __wrap_iter<_Tp*>
>::type
__unwrap_iter(__wrap_iter<_Tp*> __i);

#endif
# 1403 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Iter>
class __wrap_iter
{
public:
    typedef _Iter                                                      iterator_type;
    typedef typename iterator_traits<iterator_type>::iterator_category iterator_category;
    typedef typename iterator_traits<iterator_type>::value_type        value_type;
    typedef typename iterator_traits<iterator_type>::difference_type   difference_type;
    typedef typename iterator_traits<iterator_type>::pointer           pointer;
    typedef typename iterator_traits<iterator_type>::reference         reference;
private:
    iterator_type __i;
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter() _NOEXCEPT
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1419 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
                : __i{}
#endif
# 1421 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1423 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        __get_db()->__insert_i(this);
#endif
# 1425 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    }
    template <class _Up> _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
        __wrap_iter(const __wrap_iter<_Up>& __u,
            typename enable_if<is_convertible<_Up, iterator_type>::value>::type* = 0) _NOEXCEPT
            : __i(__u.base())
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1432 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        __get_db()->__iterator_copy(this, &__u);
#endif
# 1434 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    }
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1436 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
    __wrap_iter(const __wrap_iter& __x)
        : __i(__x.base())
    {
        __get_db()->__iterator_copy(this, &__x);
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
    __wrap_iter& operator=(const __wrap_iter& __x)
    {
        if (this != &__x)
        {
            __get_db()->__iterator_copy(this, &__x);
            __i = __x.__i;
        }
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
    ~__wrap_iter()
    {
        __get_db()->__erase_i(this);
    }
#endif
# 1458 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG reference operator*() const _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1461 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to dereference a non-dereferenceable iterator");
#endif
# 1464 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        return *__i;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG pointer  operator->() const _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1469 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to dereference a non-dereferenceable iterator");
#endif
# 1472 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        return (pointer)_VSTD::addressof(*__i);
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter& operator++() _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1477 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to increment non-incrementable iterator");
#endif
# 1480 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        ++__i;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter  operator++(int) _NOEXCEPT
        {__wrap_iter __tmp(*this); ++(*this); return __tmp;}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter& operator--() _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1489 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        _LIBCPP_ASSERT(__get_const_db()->__decrementable(this),
                       "Attempted to decrement non-decrementable iterator");
#endif
# 1492 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        --__i;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter  operator--(int) _NOEXCEPT
        {__wrap_iter __tmp(*this); --(*this); return __tmp;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter  operator+ (difference_type __n) const _NOEXCEPT
        {__wrap_iter __w(*this); __w += __n; return __w;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter& operator+=(difference_type __n) _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1502 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        _LIBCPP_ASSERT(__get_const_db()->__addable(this, __n),
                   "Attempted to add/subtract iterator outside of valid range");
#endif
# 1505 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        __i += __n;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter  operator- (difference_type __n) const _NOEXCEPT
        {return *this + (-__n);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter& operator-=(difference_type __n) _NOEXCEPT
        {*this += -__n; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG reference    operator[](difference_type __n) const _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1515 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        _LIBCPP_ASSERT(__get_const_db()->__subscriptable(this, __n),
                   "Attempted to subscript iterator outside of valid range");
#endif
# 1518 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
        return __i[__n];
    }

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG iterator_type base() const _NOEXCEPT {return __i;}

private:
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1525 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter(const void* __p, iterator_type __x) : __i(__x)
    {
        __get_db()->__insert_ic(this, __p);
    }
#else
# 1530 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG __wrap_iter(iterator_type __x) _NOEXCEPT : __i(__x) {}
#endif
# 1532 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

    template <class _Up> friend class __wrap_iter;
    template <class _CharT, class _Traits, class _Alloc> friend class basic_string;
    template <class _Tp, class _Alloc> friend class _LIBCPP_TEMPLATE_VIS vector;
    template <class _Tp, size_t> friend class _LIBCPP_TEMPLATE_VIS span;

    template <class _Iter1, class _Iter2>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    bool
    operator==(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    bool
    operator<(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    bool
    operator!=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    bool
    operator>(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    bool
    operator>=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    bool
    operator<=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

#ifndef _LIBCPP_CXX03_LANG
    template <class _Iter1, class _Iter2>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    auto
    operator-(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
    -> decltype(__x.base() - __y.base());
#else
# 1575 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    template <class _Iter1, class _Iter2>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    typename __wrap_iter<_Iter1>::difference_type
    operator-(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;
#endif
# 1580 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

    template <class _Iter1>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    __wrap_iter<_Iter1>
    operator+(typename __wrap_iter<_Iter1>::difference_type, __wrap_iter<_Iter1>) _NOEXCEPT;

    template <class _Ip, class _Op> friend _LIBCPP_CONSTEXPR_AFTER_CXX17 _Op copy(_Ip, _Ip, _Op);
    template <class _B1, class _B2> friend _LIBCPP_CONSTEXPR_AFTER_CXX17 _B2 copy_backward(_B1, _B1, _B2);
    template <class _Ip, class _Op> friend _Op move(_Ip, _Ip, _Op);
    template <class _B1, class _B2> friend _B2 move_backward(_B1, _B1, _B2);

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL < 2
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1592 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    template <class _Tp>
    _LIBCPP_CONSTEXPR_IF_NODEBUG friend
    typename enable_if
    <
        is_trivially_copy_assignable<_Tp>::value,
        _Tp*
    >::type
    __unwrap_iter(__wrap_iter<_Tp*>);
#else
# 1601 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
  template <class _Tp>
  inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
  typename enable_if
  <
      is_trivially_copy_assignable<_Tp>::value,
      __wrap_iter<_Tp*>
  >::type
  __unwrap_iter(__wrap_iter<_Tp*> __i);
#endif
# 1610 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
};

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator==(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return __x.base() == __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator<(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1626 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_ASSERT(__get_const_db()->__less_than_comparable(&__x, &__y),
                   "Attempted to compare incomparable iterators");
#endif
# 1629 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    return __x.base() < __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator!=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return !(__x == __y);
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator>(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return __y < __x;
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator>=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return !(__x < __y);
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator<=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return !(__y < __x);
}

template <class _Iter1>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator!=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter1>& __y) _NOEXCEPT
{
    return !(__x == __y);
}

template <class _Iter1>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator>(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter1>& __y) _NOEXCEPT
{
    return __y < __x;
}

template <class _Iter1>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator>=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter1>& __y) _NOEXCEPT
{
    return !(__x < __y);
}

template <class _Iter1>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
bool
operator<=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter1>& __y) _NOEXCEPT
{
    return !(__y < __x);
}

#ifndef _LIBCPP_CXX03_LANG
template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
auto
operator-(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
-> decltype(__x.base() - __y.base())
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1704 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_ASSERT(__get_const_db()->__less_than_comparable(&__x, &__y),
                   "Attempted to subtract incompatible iterators");
#endif
# 1707 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    return __x.base() - __y.base();
}
#else
# 1710 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
typename __wrap_iter<_Iter1>::difference_type
operator-(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1716 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    _LIBCPP_ASSERT(__get_const_db()->__less_than_comparable(&__x, &__y),
                   "Attempted to subtract incompatible iterators");
#endif
# 1719 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
    return __x.base() - __y.base();
}
#endif
# 1722 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
__wrap_iter<_Iter>
operator+(typename __wrap_iter<_Iter>::difference_type __n,
          __wrap_iter<_Iter> __x) _NOEXCEPT
{
    __x += __n;
    return __x;
}

template <class _Iter>
struct __libcpp_is_trivial_iterator
    : public _LIBCPP_BOOL_CONSTANT(is_pointer<_Iter>::value) {};

template <class _Iter>
struct __libcpp_is_trivial_iterator<move_iterator<_Iter> >
    : public _LIBCPP_BOOL_CONSTANT(__libcpp_is_trivial_iterator<_Iter>::value) {};

template <class _Iter>
struct __libcpp_is_trivial_iterator<reverse_iterator<_Iter> >
    : public _LIBCPP_BOOL_CONSTANT(__libcpp_is_trivial_iterator<_Iter>::value) {};

template <class _Iter>
struct __libcpp_is_trivial_iterator<__wrap_iter<_Iter> >
    : public _LIBCPP_BOOL_CONSTANT(__libcpp_is_trivial_iterator<_Iter>::value) {};


template <class _Tp, size_t _Np>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp*
begin(_Tp (&__array)[_Np])
{
    return __array;
}

template <class _Tp, size_t _Np>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp*
end(_Tp (&__array)[_Np])
{
    return __array + _Np;
}

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1767 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto
begin(_Cp& __c) -> decltype(__c.begin())
{
    return __c.begin();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto
begin(const _Cp& __c) -> decltype(__c.begin())
{
    return __c.begin();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto
end(_Cp& __c) -> decltype(__c.end())
{
    return __c.end();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto
end(const _Cp& __c) -> decltype(__c.end())
{
    return __c.end();
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1801 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Tp, size_t _Np>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
reverse_iterator<_Tp*> rbegin(_Tp (&__array)[_Np])
{
    return reverse_iterator<_Tp*>(__array + _Np);
}

template <class _Tp, size_t _Np>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
reverse_iterator<_Tp*> rend(_Tp (&__array)[_Np])
{
    return reverse_iterator<_Tp*>(__array);
}

template <class _Ep>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
reverse_iterator<const _Ep*> rbegin(initializer_list<_Ep> __il)
{
    return reverse_iterator<const _Ep*>(__il.end());
}

template <class _Ep>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
reverse_iterator<const _Ep*> rend(initializer_list<_Ep> __il)
{
    return reverse_iterator<const _Ep*>(__il.begin());
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
auto cbegin(const _Cp& __c) -> decltype(_VSTD::begin(__c))
{
    return _VSTD::begin(__c);
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
auto cend(const _Cp& __c) -> decltype(_VSTD::end(__c))
{
    return _VSTD::end(__c);
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto rbegin(_Cp& __c) -> decltype(__c.rbegin())
{
    return __c.rbegin();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto rbegin(const _Cp& __c) -> decltype(__c.rbegin())
{
    return __c.rbegin();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto rend(_Cp& __c) -> decltype(__c.rend())
{
    return __c.rend();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto rend(const _Cp& __c) -> decltype(__c.rend())
{
    return __c.rend();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto crbegin(const _Cp& __c) -> decltype(_VSTD::rbegin(__c))
{
    return _VSTD::rbegin(__c);
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
auto crend(const _Cp& __c) -> decltype(_VSTD::rend(__c))
{
    return _VSTD::rend(__c);
}

#endif
# 1887 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3


#else  // defined(_LIBCPP_CXX03_LANG)
# 1890 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY
typename _Cp::iterator
begin(_Cp& __c)
{
    return __c.begin();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY
typename _Cp::const_iterator
begin(const _Cp& __c)
{
    return __c.begin();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY
typename _Cp::iterator
end(_Cp& __c)
{
    return __c.end();
}

template <class _Cp>
_LIBCPP_INLINE_VISIBILITY
typename _Cp::const_iterator
end(const _Cp& __c)
{
    return __c.end();
}

#endif  // !defined(_LIBCPP_CXX03_LANG)
# 1924 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1926 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

// #if _LIBCPP_STD_VER > 11
// template <>
// struct _LIBCPP_TEMPLATE_VIS plus<void>
// {
//     template <class _T1, class _T2>
//     _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
//     auto operator()(_T1&& __t, _T2&& __u) const
//     _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) + _VSTD::forward<_T2>(__u)))
//     -> decltype        (_VSTD::forward<_T1>(__t) + _VSTD::forward<_T2>(__u))
//         { return        _VSTD::forward<_T1>(__t) + _VSTD::forward<_T2>(__u); }
//     typedef void is_transparent;
// };
// #endif

template <class _Cont>
_LIBCPP_INLINE_VISIBILITY
constexpr auto size(const _Cont& __c)
_NOEXCEPT_(noexcept(__c.size()))
-> decltype        (__c.size())
{ return            __c.size(); }

template <class _Tp, size_t _Sz>
_LIBCPP_INLINE_VISIBILITY
constexpr size_t size(const _Tp (&)[_Sz]) noexcept { return _Sz; }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1953 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
template <class _Cont>
_LIBCPP_INLINE_VISIBILITY
constexpr auto ssize(const _Cont& __c)
_NOEXCEPT_(noexcept(static_cast<common_type_t<ptrdiff_t, make_signed_t<decltype(__c.size())>>>(__c.size())))
->                              common_type_t<ptrdiff_t, make_signed_t<decltype(__c.size())>>
{ return            static_cast<common_type_t<ptrdiff_t, make_signed_t<decltype(__c.size())>>>(__c.size()); }

template <class _Tp, ptrdiff_t _Sz>
_LIBCPP_INLINE_VISIBILITY
constexpr ptrdiff_t ssize(const _Tp (&)[_Sz]) noexcept { return _Sz; }
#endif
# 1964 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3

template <class _Cont>
_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
constexpr auto empty(const _Cont& __c)
_NOEXCEPT_(noexcept(__c.empty()))
-> decltype        (__c.empty())
{ return            __c.empty(); }

template <class _Tp, size_t _Sz>
_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
constexpr bool empty(const _Tp (&)[_Sz]) noexcept { return false; }

template <class _Ep>
_LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
constexpr bool empty(initializer_list<_Ep> __il) noexcept { return __il.size() == 0; }

template <class _Cont> constexpr
_LIBCPP_INLINE_VISIBILITY
auto data(_Cont& __c)
_NOEXCEPT_(noexcept(__c.data()))
-> decltype        (__c.data())
{ return            __c.data(); }

template <class _Cont> constexpr
_LIBCPP_INLINE_VISIBILITY
auto data(const _Cont& __c)
_NOEXCEPT_(noexcept(__c.data()))
-> decltype        (__c.data())
{ return            __c.data(); }

template <class _Tp, size_t _Sz>
_LIBCPP_INLINE_VISIBILITY
constexpr _Tp* data(_Tp (&__array)[_Sz]) noexcept { return __array; }

template <class _Ep>
_LIBCPP_INLINE_VISIBILITY
constexpr const _Ep* data(initializer_list<_Ep> __il) noexcept { return __il.begin(); }
#endif
# 2002 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3


_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_ITERATOR
# 2007 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/iterator" 3
# 660 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 660 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 661 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 661 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 662 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 662 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 1 3
// -*- C++ -*-
//===--------------------------- tuple ------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_TUPLE
#define _LIBCPP_TUPLE

/*
    tuple synopsis

namespace std
{

template <class... T>
class tuple {
public:
    explicit(see-below) constexpr tuple();
    explicit(see-below) tuple(const T&...);  // constexpr in C++14
    template <class... U>
        explicit(see-below) tuple(U&&...);  // constexpr in C++14
    tuple(const tuple&) = default;
    tuple(tuple&&) = default;
    template <class... U>
        explicit(see-below) tuple(const tuple<U...>&);  // constexpr in C++14
    template <class... U>
        explicit(see-below) tuple(tuple<U...>&&);  // constexpr in C++14
    template <class U1, class U2>
        explicit(see-below) tuple(const pair<U1, U2>&); // iff sizeof...(T) == 2 // constexpr in C++14
    template <class U1, class U2>
        explicit(see-below) tuple(pair<U1, U2>&&); // iff sizeof...(T) == 2  // constexpr in C++14

    // allocator-extended constructors
    template <class Alloc>
        tuple(allocator_arg_t, const Alloc& a);
    template <class Alloc>
        explicit(see-below) tuple(allocator_arg_t, const Alloc& a, const T&...);
    template <class Alloc, class... U>
        explicit(see-below) tuple(allocator_arg_t, const Alloc& a, U&&...);
    template <class Alloc>
        tuple(allocator_arg_t, const Alloc& a, const tuple&);
    template <class Alloc>
        tuple(allocator_arg_t, const Alloc& a, tuple&&);
    template <class Alloc, class... U>
        explicit(see-below) tuple(allocator_arg_t, const Alloc& a, const tuple<U...>&);
    template <class Alloc, class... U>
        explicit(see-below) tuple(allocator_arg_t, const Alloc& a, tuple<U...>&&);
    template <class Alloc, class U1, class U2>
        explicit(see-below) tuple(allocator_arg_t, const Alloc& a, const pair<U1, U2>&);
    template <class Alloc, class U1, class U2>
        explicit(see-below) tuple(allocator_arg_t, const Alloc& a, pair<U1, U2>&&);

    tuple& operator=(const tuple&);
    tuple&
        operator=(tuple&&) noexcept(AND(is_nothrow_move_assignable<T>::value ...));
    template <class... U>
        tuple& operator=(const tuple<U...>&);
    template <class... U>
        tuple& operator=(tuple<U...>&&);
    template <class U1, class U2>
        tuple& operator=(const pair<U1, U2>&); // iff sizeof...(T) == 2
    template <class U1, class U2>
        tuple& operator=(pair<U1, U2>&&); // iff sizeof...(T) == 2

    void swap(tuple&) noexcept(AND(swap(declval<T&>(), declval<T&>())...));
};

template <class ...T>
tuple(T...) -> tuple<T...>;                                         // since C++17
template <class T1, class T2>
tuple(pair<T1, T2>) -> tuple<T1, T2>;                               // since C++17
template <class Alloc, class ...T>
tuple(allocator_arg_t, Alloc, T...) -> tuple<T...>;                 // since C++17
template <class Alloc, class T1, class T2>
tuple(allocator_arg_t, Alloc, pair<T1, T2>) -> tuple<T1, T2>;       // since C++17
template <class Alloc, class ...T>
tuple(allocator_arg_t, Alloc, tuple<T...>) -> tuple<T...>;          // since C++17

inline constexpr unspecified ignore;

template <class... T> tuple<V...>  make_tuple(T&&...); // constexpr in C++14
template <class... T> tuple<ATypes...> forward_as_tuple(T&&...) noexcept; // constexpr in C++14
template <class... T> tuple<T&...> tie(T&...) noexcept; // constexpr in C++14
template <class... Tuples> tuple<CTypes...> tuple_cat(Tuples&&... tpls); // constexpr in C++14

// [tuple.apply], calling a function with a tuple of arguments:
template <class F, class Tuple>
  constexpr decltype(auto) apply(F&& f, Tuple&& t); // C++17
template <class T, class Tuple>
  constexpr T make_from_tuple(Tuple&& t); // C++17

// 20.4.1.4, tuple helper classes:
template <class T> struct tuple_size; // undefined
template <class... T> struct tuple_size<tuple<T...>>;
template <class T>
 inline constexpr size_t tuple_size_v = tuple_size<T>::value; // C++17
template <size_t I, class T> struct tuple_element; // undefined
template <size_t I, class... T> struct tuple_element<I, tuple<T...>>;
template <size_t I, class T>
  using tuple_element_t = typename tuple_element <I, T>::type; // C++14

// 20.4.1.5, element access:
template <size_t I, class... T>
    typename tuple_element<I, tuple<T...>>::type&
    get(tuple<T...>&) noexcept; // constexpr in C++14
template <size_t I, class... T>
    const typename tuple_element<I, tuple<T...>>::type&
    get(const tuple<T...>&) noexcept; // constexpr in C++14
template <size_t I, class... T>
    typename tuple_element<I, tuple<T...>>::type&&
    get(tuple<T...>&&) noexcept; // constexpr in C++14
template <size_t I, class... T>
    const typename tuple_element<I, tuple<T...>>::type&&
    get(const tuple<T...>&&) noexcept; // constexpr in C++14

template <class T1, class... T>
    constexpr T1& get(tuple<T...>&) noexcept;  // C++14
template <class T1, class... T>
    constexpr const T1& get(const tuple<T...>&) noexcept;   // C++14
template <class T1, class... T>
    constexpr T1&& get(tuple<T...>&&) noexcept;   // C++14
template <class T1, class... T>
    constexpr const T1&& get(const tuple<T...>&&) noexcept;   // C++14

// 20.4.1.6, relational operators:
template<class... T, class... U> bool operator==(const tuple<T...>&, const tuple<U...>&); // constexpr in C++14
template<class... T, class... U> bool operator<(const tuple<T...>&, const tuple<U...>&);  // constexpr in C++14
template<class... T, class... U> bool operator!=(const tuple<T...>&, const tuple<U...>&); // constexpr in C++14
template<class... T, class... U> bool operator>(const tuple<T...>&, const tuple<U...>&);  // constexpr in C++14
template<class... T, class... U> bool operator<=(const tuple<T...>&, const tuple<U...>&); // constexpr in C++14
template<class... T, class... U> bool operator>=(const tuple<T...>&, const tuple<U...>&); // constexpr in C++14

template <class... Types, class Alloc>
  struct uses_allocator<tuple<Types...>, Alloc>;

template <class... Types>
  void
  swap(tuple<Types...>& x, tuple<Types...>& y) noexcept(noexcept(x.swap(y)));

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
# 149 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <__tuple>
#endif /* expanded by -frewrite-includes */
# 149 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
# 150 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 150 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
# 151 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 151 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
# 153 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 153 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
# 154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
# 155 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 157 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
#endif
# 159 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3

_LIBCPP_BEGIN_NAMESPACE_STD

#ifndef _LIBCPP_CXX03_LANG


// __tuple_leaf

template <size_t _Ip, class _Hp,
          bool=is_empty<_Hp>::value && !__libcpp_is_final<_Hp>::value
         >
class __tuple_leaf;

template <size_t _Ip, class _Hp, bool _Ep>
inline _LIBCPP_INLINE_VISIBILITY
void swap(__tuple_leaf<_Ip, _Hp, _Ep>& __x, __tuple_leaf<_Ip, _Hp, _Ep>& __y)
    _NOEXCEPT_(__is_nothrow_swappable<_Hp>::value)
{
    swap(__x.get(), __y.get());
}

template <size_t _Ip, class _Hp, bool>
class __tuple_leaf
{
    _Hp __value_;

    template <class _Tp>
    static constexpr bool __can_bind_reference() {
#if 0 /* disabled by -frewrite-includes */
#if __has_keyword(__reference_binds_to_temporary)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 188 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
      return !__reference_binds_to_temporary(_Hp, _Tp);
#else
# 190 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
      return true;
#endif
# 192 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
    }

    __tuple_leaf& operator=(const __tuple_leaf&);
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR __tuple_leaf()
             _NOEXCEPT_(is_nothrow_default_constructible<_Hp>::value) : __value_()
       {static_assert(!is_reference<_Hp>::value,
              "Attempted to default construct a reference element in a tuple");}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 0>, const _Alloc&)
            : __value_()
        {static_assert(!is_reference<_Hp>::value,
              "Attempted to default construct a reference element in a tuple");}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 1>, const _Alloc& __a)
            : __value_(allocator_arg_t(), __a)
        {static_assert(!is_reference<_Hp>::value,
              "Attempted to default construct a reference element in a tuple");}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 2>, const _Alloc& __a)
            : __value_(__a)
        {static_assert(!is_reference<_Hp>::value,
              "Attempted to default construct a reference element in a tuple");}

    template <class _Tp,
              class = _EnableIf<
                  _And<
                      _IsNotSame<__uncvref_t<_Tp>, __tuple_leaf>,
                      is_constructible<_Hp, _Tp>
                    >::value
                >
            >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit __tuple_leaf(_Tp&& __t) _NOEXCEPT_((is_nothrow_constructible<_Hp, _Tp>::value))
            : __value_(_VSTD::forward<_Tp>(__t))
        {static_assert(__can_bind_reference<_Tp&&>(),
       "Attempted construction of reference element binds to a temporary whose lifetime has ended");}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 0>, const _Alloc&, _Tp&& __t)
            : __value_(_VSTD::forward<_Tp>(__t))
        {static_assert(__can_bind_reference<_Tp&&>(),
       "Attempted construction of reference element binds to a temporary whose lifetime has ended");}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 1>, const _Alloc& __a, _Tp&& __t)
            : __value_(allocator_arg_t(), __a, _VSTD::forward<_Tp>(__t))
        {static_assert(!is_reference<_Hp>::value,
            "Attempted to uses-allocator construct a reference element in a tuple");}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 2>, const _Alloc& __a, _Tp&& __t)
            : __value_(_VSTD::forward<_Tp>(__t), __a)
        {static_assert(!is_reference<_Hp>::value,
           "Attempted to uses-allocator construct a reference element in a tuple");}

    __tuple_leaf(const __tuple_leaf& __t) = default;
    __tuple_leaf(__tuple_leaf&& __t) = default;

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf&
        operator=(_Tp&& __t) _NOEXCEPT_((is_nothrow_assignable<_Hp&, _Tp>::value))
        {
            __value_ = _VSTD::forward<_Tp>(__t);
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    int swap(__tuple_leaf& __t) _NOEXCEPT_(__is_nothrow_swappable<__tuple_leaf>::value)
    {
        _VSTD::swap(*this, __t);
        return 0;
    }

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11       _Hp& get()       _NOEXCEPT {return __value_;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 const _Hp& get() const _NOEXCEPT {return __value_;}
};

template <size_t _Ip, class _Hp>
class __tuple_leaf<_Ip, _Hp, true>
    : private _Hp
{

    __tuple_leaf& operator=(const __tuple_leaf&);
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR __tuple_leaf()
             _NOEXCEPT_(is_nothrow_default_constructible<_Hp>::value) {}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 0>, const _Alloc&) {}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 1>, const _Alloc& __a)
            : _Hp(allocator_arg_t(), __a) {}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 2>, const _Alloc& __a)
            : _Hp(__a) {}

    template <class _Tp,
              class = _EnableIf<
                  _And<
                    _IsNotSame<__uncvref_t<_Tp>, __tuple_leaf>,
                    is_constructible<_Hp, _Tp>
                  >::value
                >
            >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit __tuple_leaf(_Tp&& __t) _NOEXCEPT_((is_nothrow_constructible<_Hp, _Tp>::value))
            : _Hp(_VSTD::forward<_Tp>(__t)) {}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 0>, const _Alloc&, _Tp&& __t)
            : _Hp(_VSTD::forward<_Tp>(__t)) {}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 1>, const _Alloc& __a, _Tp&& __t)
            : _Hp(allocator_arg_t(), __a, _VSTD::forward<_Tp>(__t)) {}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 2>, const _Alloc& __a, _Tp&& __t)
            : _Hp(_VSTD::forward<_Tp>(__t), __a) {}

    __tuple_leaf(__tuple_leaf const &) = default;
    __tuple_leaf(__tuple_leaf &&) = default;

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf&
        operator=(_Tp&& __t) _NOEXCEPT_((is_nothrow_assignable<_Hp&, _Tp>::value))
        {
            _Hp::operator=(_VSTD::forward<_Tp>(__t));
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    int
    swap(__tuple_leaf& __t) _NOEXCEPT_(__is_nothrow_swappable<__tuple_leaf>::value)
    {
        _VSTD::swap(*this, __t);
        return 0;
    }

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11       _Hp& get()       _NOEXCEPT {return static_cast<_Hp&>(*this);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 const _Hp& get() const _NOEXCEPT {return static_cast<const _Hp&>(*this);}
};

template <class ..._Tp>
_LIBCPP_INLINE_VISIBILITY
void __swallow(_Tp&&...) _NOEXCEPT {}

template <class _Tp>
struct __all_default_constructible;

template <class ..._Tp>
struct __all_default_constructible<__tuple_types<_Tp...>>
    : __all<is_default_constructible<_Tp>::value...>
{ };

// __tuple_impl

template<class _Indx, class ..._Tp> struct __tuple_impl;

template<size_t ..._Indx, class ..._Tp>
struct _LIBCPP_DECLSPEC_EMPTY_BASES __tuple_impl<__tuple_indices<_Indx...>, _Tp...>
    : public __tuple_leaf<_Indx, _Tp>...
{
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR __tuple_impl()
        _NOEXCEPT_(__all<is_nothrow_default_constructible<_Tp>::value...>::value) {}

    template <size_t ..._Uf, class ..._Tf,
              size_t ..._Ul, class ..._Tl, class ..._Up>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit
        __tuple_impl(__tuple_indices<_Uf...>, __tuple_types<_Tf...>,
                     __tuple_indices<_Ul...>, __tuple_types<_Tl...>,
                     _Up&&... __u)
                     _NOEXCEPT_((__all<is_nothrow_constructible<_Tf, _Up>::value...>::value &&
                                 __all<is_nothrow_default_constructible<_Tl>::value...>::value)) :
            __tuple_leaf<_Uf, _Tf>(_VSTD::forward<_Up>(__u))...,
            __tuple_leaf<_Ul, _Tl>()...
            {}

    template <class _Alloc, size_t ..._Uf, class ..._Tf,
              size_t ..._Ul, class ..._Tl, class ..._Up>
        _LIBCPP_INLINE_VISIBILITY
        explicit
        __tuple_impl(allocator_arg_t, const _Alloc& __a,
                     __tuple_indices<_Uf...>, __tuple_types<_Tf...>,
                     __tuple_indices<_Ul...>, __tuple_types<_Tl...>,
                     _Up&&... __u) :
            __tuple_leaf<_Uf, _Tf>(__uses_alloc_ctor<_Tf, _Alloc, _Up>(), __a,
            _VSTD::forward<_Up>(__u))...,
            __tuple_leaf<_Ul, _Tl>(__uses_alloc_ctor<_Tl, _Alloc>(), __a)...
            {}

    template <class _Tuple,
              class = typename enable_if
                      <
                         __tuple_constructible<_Tuple, tuple<_Tp...> >::value
                      >::type
             >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        __tuple_impl(_Tuple&& __t) _NOEXCEPT_((__all<is_nothrow_constructible<_Tp, typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>::value...>::value))
            : __tuple_leaf<_Indx, _Tp>(_VSTD::forward<typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>(_VSTD::get<_Indx>(__t)))...
            {}

    template <class _Alloc, class _Tuple,
              class = typename enable_if
                      <
                         __tuple_constructible<_Tuple, tuple<_Tp...> >::value
                      >::type
             >
        _LIBCPP_INLINE_VISIBILITY
        __tuple_impl(allocator_arg_t, const _Alloc& __a, _Tuple&& __t)
            : __tuple_leaf<_Indx, _Tp>(__uses_alloc_ctor<_Tp, _Alloc, typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>(), __a,
                                       _VSTD::forward<typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>(_VSTD::get<_Indx>(__t)))...
            {}

    template <class _Tuple>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            __tuple_assignable<_Tuple, tuple<_Tp...> >::value,
            __tuple_impl&
        >::type
        operator=(_Tuple&& __t) _NOEXCEPT_((__all<is_nothrow_assignable<_Tp&, typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>::value...>::value))
        {
            __swallow(__tuple_leaf<_Indx, _Tp>::operator=(_VSTD::forward<typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>(_VSTD::get<_Indx>(__t)))...);
            return *this;
        }

    __tuple_impl(const __tuple_impl&) = default;
    __tuple_impl(__tuple_impl&&) = default;

    _LIBCPP_INLINE_VISIBILITY
    __tuple_impl&
    operator=(const __tuple_impl& __t) _NOEXCEPT_((__all<is_nothrow_copy_assignable<_Tp>::value...>::value))
    {
        __swallow(__tuple_leaf<_Indx, _Tp>::operator=(static_cast<const __tuple_leaf<_Indx, _Tp>&>(__t).get())...);
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __tuple_impl&
    operator=(__tuple_impl&& __t) _NOEXCEPT_((__all<is_nothrow_move_assignable<_Tp>::value...>::value))
    {
        __swallow(__tuple_leaf<_Indx, _Tp>::operator=(_VSTD::forward<_Tp>(static_cast<__tuple_leaf<_Indx, _Tp>&>(__t).get()))...);
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    void swap(__tuple_impl& __t)
        _NOEXCEPT_(__all<__is_nothrow_swappable<_Tp>::value...>::value)
    {
        __swallow(__tuple_leaf<_Indx, _Tp>::swap(static_cast<__tuple_leaf<_Indx, _Tp>&>(__t))...);
    }
};



template <class ..._Tp>
class _LIBCPP_TEMPLATE_VIS tuple
{
    typedef __tuple_impl<typename __make_tuple_indices<sizeof...(_Tp)>::type, _Tp...> _BaseT;

    _BaseT __base_;

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ENABLE_TUPLE_IMPLICIT_REDUCED_ARITY_EXTENSION)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 484 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
    static constexpr bool _EnableImplicitReducedArityExtension = true;
#else
# 486 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
    static constexpr bool _EnableImplicitReducedArityExtension = false;
#endif
# 488 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3

    template <class ..._Args>
    struct _PackExpandsToThisTuple : false_type {};

    template <class _Arg>
    struct _PackExpandsToThisTuple<_Arg>
        : is_same<typename __uncvref<_Arg>::type, tuple> {};

    template <bool _MaybeEnable, class _Dummy = void>
    struct _CheckArgsConstructor : __check_tuple_constructor_fail {};

    template <class _Dummy>
    struct _CheckArgsConstructor<true, _Dummy>
    {
        template <int&...>
        static constexpr bool __enable_implicit_default() {
           return __all<__is_implicitly_default_constructible<_Tp>::value... >::value;
        }

        template <int&...>
        static constexpr bool __enable_explicit_default() {
            return
                __all<is_default_constructible<_Tp>::value...>::value &&
                !__enable_implicit_default< >();
        }


        template <class ..._Args>
        static constexpr bool __enable_explicit() {
            return
                __tuple_constructible<
                    tuple<_Args...>,
                    typename __make_tuple_types<tuple,
                             sizeof...(_Args) < sizeof...(_Tp) ?
                                 sizeof...(_Args) :
                                 sizeof...(_Tp)>::type
                >::value &&
                !__tuple_convertible<
                    tuple<_Args...>,
                    typename __make_tuple_types<tuple,
                             sizeof...(_Args) < sizeof...(_Tp) ?
                                 sizeof...(_Args) :
                                 sizeof...(_Tp)>::type
                >::value &&
                __all_default_constructible<
                    typename __make_tuple_types<tuple, sizeof...(_Tp),
                             sizeof...(_Args) < sizeof...(_Tp) ?
                                 sizeof...(_Args) :
                                 sizeof...(_Tp)>::type
                >::value;
        }

        template <class ..._Args>
        static constexpr bool __enable_implicit() {
            return
               __tuple_constructible<
                    tuple<_Args...>,
                    typename __make_tuple_types<tuple,
                             sizeof...(_Args) < sizeof...(_Tp) ?
                                 sizeof...(_Args) :
                                 sizeof...(_Tp)>::type
                >::value &&
                __tuple_convertible<
                    tuple<_Args...>,
                    typename __make_tuple_types<tuple,
                             sizeof...(_Args) < sizeof...(_Tp) ?
                                 sizeof...(_Args) :
                                 sizeof...(_Tp)>::type
                >::value &&
                __all_default_constructible<
                    typename __make_tuple_types<tuple, sizeof...(_Tp),
                             sizeof...(_Args) < sizeof...(_Tp) ?
                                 sizeof...(_Args) :
                                 sizeof...(_Tp)>::type
                >::value;
        }
    };

    template <bool _MaybeEnable,
              bool = sizeof...(_Tp) == 1,
              class _Dummy = void>
    struct _CheckTupleLikeConstructor : __check_tuple_constructor_fail {};

    template <class _Dummy>
    struct _CheckTupleLikeConstructor<true, false, _Dummy>
    {
        template <class _Tuple>
        static constexpr bool __enable_implicit() {
            return __tuple_constructible<_Tuple, tuple>::value
                && __tuple_convertible<_Tuple, tuple>::value;
        }

        template <class _Tuple>
        static constexpr bool __enable_explicit() {
            return __tuple_constructible<_Tuple, tuple>::value
               && !__tuple_convertible<_Tuple, tuple>::value;
        }
    };

    template <class _Dummy>
    struct _CheckTupleLikeConstructor<true, true, _Dummy>
    {
        // This trait is used to disable the tuple-like constructor when
        // the UTypes... constructor should be selected instead.
        // See LWG issue #2549.
        template <class _Tuple>
        using _PreferTupleLikeConstructor = _Or<
            // Don't attempt the two checks below if the tuple we are given
            // has the same type as this tuple.
            _IsSame<__uncvref_t<_Tuple>, tuple>,
            _Lazy<_And,
                _Not<is_constructible<_Tp..., _Tuple>>,
                _Not<is_convertible<_Tuple, _Tp...>>
            >
        >;

        template <class _Tuple>
        static constexpr bool __enable_implicit() {
            return _And<
                __tuple_constructible<_Tuple, tuple>,
                __tuple_convertible<_Tuple, tuple>,
                _PreferTupleLikeConstructor<_Tuple>
            >::value;
        }

        template <class _Tuple>
        static constexpr bool __enable_explicit() {
            return _And<
                __tuple_constructible<_Tuple, tuple>,
                _PreferTupleLikeConstructor<_Tuple>,
                _Not<__tuple_convertible<_Tuple, tuple>>
            >::value;
        }
    };

    template <class _Tuple, bool _DisableIfLValue>
    using _EnableImplicitTupleLikeConstructor = _EnableIf<
                         _CheckTupleLikeConstructor<
                             __tuple_like_with_size<_Tuple, sizeof...(_Tp)>::value
                             && !_PackExpandsToThisTuple<_Tuple>::value
                             && (!is_lvalue_reference<_Tuple>::value || !_DisableIfLValue)
                         >::template __enable_implicit<_Tuple>(),
                         bool
                      >;

    template <class _Tuple, bool _DisableIfLValue>
    using _EnableExplicitTupleLikeConstructor = _EnableIf<
                         _CheckTupleLikeConstructor<
                             __tuple_like_with_size<_Tuple, sizeof...(_Tp)>::value
                             && !_PackExpandsToThisTuple<_Tuple>::value
                             && (!is_lvalue_reference<_Tuple>::value || !_DisableIfLValue)
                         >::template __enable_explicit<_Tuple>(),
                         bool
                      >;
    template <size_t _Jp, class ..._Up> friend _LIBCPP_CONSTEXPR_AFTER_CXX11
        typename tuple_element<_Jp, tuple<_Up...> >::type& get(tuple<_Up...>&) _NOEXCEPT;
    template <size_t _Jp, class ..._Up> friend _LIBCPP_CONSTEXPR_AFTER_CXX11
        const typename tuple_element<_Jp, tuple<_Up...> >::type& get(const tuple<_Up...>&) _NOEXCEPT;
    template <size_t _Jp, class ..._Up> friend _LIBCPP_CONSTEXPR_AFTER_CXX11
        typename tuple_element<_Jp, tuple<_Up...> >::type&& get(tuple<_Up...>&&) _NOEXCEPT;
    template <size_t _Jp, class ..._Up> friend _LIBCPP_CONSTEXPR_AFTER_CXX11
        const typename tuple_element<_Jp, tuple<_Up...> >::type&& get(const tuple<_Up...>&&) _NOEXCEPT;
public:

    template <bool _Dummy = true, _EnableIf<
        _CheckArgsConstructor<_Dummy>::__enable_implicit_default()
    , void*> = nullptr>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    tuple()
        _NOEXCEPT_(__all<is_nothrow_default_constructible<_Tp>::value...>::value) {}

    template <bool _Dummy = true, _EnableIf<
        _CheckArgsConstructor<_Dummy>::__enable_explicit_default()
    , void*> = nullptr>
    explicit _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    tuple()
        _NOEXCEPT_(__all<is_nothrow_default_constructible<_Tp>::value...>::value) {}

    tuple(tuple const&) = default;
    tuple(tuple&&) = default;

    template <class _AllocArgT, class _Alloc, _EnableIf<
             _CheckArgsConstructor<_IsSame<allocator_arg_t, _AllocArgT>::value >::__enable_implicit_default()
      , void*> = nullptr
    >
    _LIBCPP_INLINE_VISIBILITY
    tuple(_AllocArgT, _Alloc const& __a)
      : __base_(allocator_arg_t(), __a,
                    __tuple_indices<>(), __tuple_types<>(),
                    typename __make_tuple_indices<sizeof...(_Tp), 0>::type(),
                    __tuple_types<_Tp...>()) {}

    template <class _AllocArgT, class _Alloc, _EnableIf<
             _CheckArgsConstructor<_IsSame<allocator_arg_t, _AllocArgT>::value>::__enable_explicit_default()
      , void*> = nullptr
    >
    explicit _LIBCPP_INLINE_VISIBILITY
    tuple(_AllocArgT, _Alloc const& __a)
      : __base_(allocator_arg_t(), __a,
                    __tuple_indices<>(), __tuple_types<>(),
                    typename __make_tuple_indices<sizeof...(_Tp), 0>::type(),
                    __tuple_types<_Tp...>()) {}

    template <bool _Dummy = true,
              typename enable_if
                      <
                         _CheckArgsConstructor<
                            _Dummy
                         >::template __enable_implicit<_Tp const&...>(),
                         bool
                      >::type = false
        >
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    tuple(const _Tp& ... __t) _NOEXCEPT_((__all<is_nothrow_copy_constructible<_Tp>::value...>::value))
        : __base_(typename __make_tuple_indices<sizeof...(_Tp)>::type(),
                typename __make_tuple_types<tuple, sizeof...(_Tp)>::type(),
                typename __make_tuple_indices<0>::type(),
                typename __make_tuple_types<tuple, 0>::type(),
                __t...
               ) {}

    template <bool _Dummy = true,
              typename enable_if
                      <
                         _CheckArgsConstructor<
                            _Dummy
                         >::template __enable_explicit<_Tp const&...>(),
                         bool
                      >::type = false
        >
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    explicit tuple(const _Tp& ... __t) _NOEXCEPT_((__all<is_nothrow_copy_constructible<_Tp>::value...>::value))
        : __base_(typename __make_tuple_indices<sizeof...(_Tp)>::type(),
                typename __make_tuple_types<tuple, sizeof...(_Tp)>::type(),
                typename __make_tuple_indices<0>::type(),
                typename __make_tuple_types<tuple, 0>::type(),
                __t...
               ) {}

    template <class _Alloc, bool _Dummy = true,
              typename enable_if
                      <
                         _CheckArgsConstructor<
                            _Dummy
                         >::template __enable_implicit<_Tp const&...>(),
                         bool
                      >::type = false
        >
      _LIBCPP_INLINE_VISIBILITY
      tuple(allocator_arg_t, const _Alloc& __a, const _Tp& ... __t)
        : __base_(allocator_arg_t(), __a,
                typename __make_tuple_indices<sizeof...(_Tp)>::type(),
                typename __make_tuple_types<tuple, sizeof...(_Tp)>::type(),
                typename __make_tuple_indices<0>::type(),
                typename __make_tuple_types<tuple, 0>::type(),
                __t...
               ) {}

    template <class _Alloc, bool _Dummy = true,
              typename enable_if
                      <
                         _CheckArgsConstructor<
                            _Dummy
                         >::template __enable_explicit<_Tp const&...>(),
                         bool
                      >::type = false
        >
      _LIBCPP_INLINE_VISIBILITY
      explicit
      tuple(allocator_arg_t, const _Alloc& __a, const _Tp& ... __t)
        : __base_(allocator_arg_t(), __a,
                typename __make_tuple_indices<sizeof...(_Tp)>::type(),
                typename __make_tuple_types<tuple, sizeof...(_Tp)>::type(),
                typename __make_tuple_indices<0>::type(),
                typename __make_tuple_types<tuple, 0>::type(),
                __t...
               ) {}

    template <class ..._Up,
              bool _PackIsTuple = _PackExpandsToThisTuple<_Up...>::value,
              typename enable_if
                      <
                         _CheckArgsConstructor<
                             sizeof...(_Up) == sizeof...(_Tp)
                             && !_PackIsTuple
                         >::template __enable_implicit<_Up...>() ||
                        _CheckArgsConstructor<
                            _EnableImplicitReducedArityExtension
                            && sizeof...(_Up) < sizeof...(_Tp)
                            && !_PackIsTuple
                         >::template __enable_implicit<_Up...>(),
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        tuple(_Up&&... __u)
            _NOEXCEPT_((
                is_nothrow_constructible<_BaseT,
                    typename __make_tuple_indices<sizeof...(_Up)>::type,
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type,
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type,
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type,
                    _Up...
                >::value
            ))
            : __base_(typename __make_tuple_indices<sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type(),
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type(),
                    _VSTD::forward<_Up>(__u)...) {}

    template <class ..._Up,
              typename enable_if
                      <
                         _CheckArgsConstructor<
                             sizeof...(_Up) <= sizeof...(_Tp)
                             && !_PackExpandsToThisTuple<_Up...>::value
                         >::template __enable_explicit<_Up...>() ||
                         _CheckArgsConstructor<
                            !_EnableImplicitReducedArityExtension
                            && sizeof...(_Up) < sizeof...(_Tp)
                            && !_PackExpandsToThisTuple<_Up...>::value
                         >::template __enable_implicit<_Up...>(),
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit
        tuple(_Up&&... __u)
            _NOEXCEPT_((
                is_nothrow_constructible<_BaseT,
                    typename __make_tuple_indices<sizeof...(_Up)>::type,
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type,
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type,
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type,
                    _Up...
                >::value
            ))
            : __base_(typename __make_tuple_indices<sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type(),
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type(),
                    _VSTD::forward<_Up>(__u)...) {}

    template <class _Alloc, class ..._Up,
              typename enable_if
                      <
                         _CheckArgsConstructor<
                             sizeof...(_Up) == sizeof...(_Tp) &&
                             !_PackExpandsToThisTuple<_Up...>::value
                         >::template __enable_implicit<_Up...>(),
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc& __a, _Up&&... __u)
            : __base_(allocator_arg_t(), __a,
                    typename __make_tuple_indices<sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type(),
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type(),
                    _VSTD::forward<_Up>(__u)...) {}

    template <class _Alloc, class ..._Up,
              typename enable_if
                      <
                         _CheckArgsConstructor<
                             sizeof...(_Up) == sizeof...(_Tp) &&
                             !_PackExpandsToThisTuple<_Up...>::value
                         >::template __enable_explicit<_Up...>(),
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY
        explicit
        tuple(allocator_arg_t, const _Alloc& __a, _Up&&... __u)
            : __base_(allocator_arg_t(), __a,
                    typename __make_tuple_indices<sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type(),
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type(),
                    _VSTD::forward<_Up>(__u)...) {}

    template <class _Tuple, _EnableImplicitTupleLikeConstructor<_Tuple, true> = false>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        tuple(_Tuple&& __t) _NOEXCEPT_((is_nothrow_constructible<_BaseT, _Tuple>::value))
            : __base_(_VSTD::forward<_Tuple>(__t)) {}

    template <class _Tuple, _EnableImplicitTupleLikeConstructor<const _Tuple&, false> = false>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        tuple(const _Tuple& __t) _NOEXCEPT_((is_nothrow_constructible<_BaseT, const _Tuple&>::value))
            : __base_(__t) {}
    template <class _Tuple, _EnableExplicitTupleLikeConstructor<_Tuple, true> = false>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit
        tuple(_Tuple&& __t) _NOEXCEPT_((is_nothrow_constructible<_BaseT, _Tuple>::value))
            : __base_(_VSTD::forward<_Tuple>(__t)) {}

    template <class _Tuple, _EnableExplicitTupleLikeConstructor<const _Tuple&, false> = false>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit
        tuple(const _Tuple& __t) _NOEXCEPT_((is_nothrow_constructible<_BaseT, const _Tuple&>::value))
            : __base_(__t) {}

    template <class _Alloc, class _Tuple,
              typename enable_if
                      <
                         _CheckTupleLikeConstructor<
                             __tuple_like_with_size<_Tuple, sizeof...(_Tp)>::value
                         >::template __enable_implicit<_Tuple>(),
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc& __a, _Tuple&& __t)
            : __base_(allocator_arg_t(), __a, _VSTD::forward<_Tuple>(__t)) {}

    template <class _Alloc, class _Tuple,
              typename enable_if
                      <
                         _CheckTupleLikeConstructor<
                             __tuple_like_with_size<_Tuple, sizeof...(_Tp)>::value
                         >::template __enable_explicit<_Tuple>(),
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY
        explicit
        tuple(allocator_arg_t, const _Alloc& __a, _Tuple&& __t)
            : __base_(allocator_arg_t(), __a, _VSTD::forward<_Tuple>(__t)) {}

    using _CanCopyAssign = __all<is_copy_assignable<_Tp>::value...>;
    using _CanMoveAssign = __all<is_move_assignable<_Tp>::value...>;

    _LIBCPP_INLINE_VISIBILITY
    tuple& operator=(typename conditional<_CanCopyAssign::value, tuple, __nat>::type const& __t)
        _NOEXCEPT_((__all<is_nothrow_copy_assignable<_Tp>::value...>::value))
    {
        __base_.operator=(__t.__base_);
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    tuple& operator=(typename conditional<_CanMoveAssign::value, tuple, __nat>::type&& __t)
        _NOEXCEPT_((__all<is_nothrow_move_assignable<_Tp>::value...>::value))
    {
        __base_.operator=(static_cast<_BaseT&&>(__t.__base_));
        return *this;
    }

    template <class _Tuple,
              class = typename enable_if
                      <
                         __tuple_assignable<_Tuple, tuple>::value
                      >::type
             >
        _LIBCPP_INLINE_VISIBILITY
        tuple&
        operator=(_Tuple&& __t) _NOEXCEPT_((is_nothrow_assignable<_BaseT&, _Tuple>::value))
        {
            __base_.operator=(_VSTD::forward<_Tuple>(__t));
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    void swap(tuple& __t) _NOEXCEPT_(__all<__is_nothrow_swappable<_Tp>::value...>::value)
        {__base_.swap(__t.__base_);}
};

template <>
class _LIBCPP_TEMPLATE_VIS tuple<>
{
public:
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR tuple() _NOEXCEPT = default;
    template <class _Alloc>
    _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc&) _NOEXCEPT {}
    template <class _Alloc>
    _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc&, const tuple&) _NOEXCEPT {}
    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY
        tuple(array<_Up, 0>) _NOEXCEPT {}
    template <class _Alloc, class _Up>
    _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc&, array<_Up, 0>) _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY
    void swap(tuple&) _NOEXCEPT {}
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template <class ..._Tp>
tuple(_Tp...) -> tuple<_Tp...>;
template <class _Tp1, class _Tp2>
tuple(pair<_Tp1, _Tp2>) -> tuple<_Tp1, _Tp2>;
template <class _Alloc, class ..._Tp>
tuple(allocator_arg_t, _Alloc, _Tp...) -> tuple<_Tp...>;
template <class _Alloc, class _Tp1, class _Tp2>
tuple(allocator_arg_t, _Alloc, pair<_Tp1, _Tp2>) -> tuple<_Tp1, _Tp2>;
template <class _Alloc, class ..._Tp>
tuple(allocator_arg_t, _Alloc, tuple<_Tp...>) -> tuple<_Tp...>;
#endif
# 991 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3

template <class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    __all<__is_swappable<_Tp>::value...>::value,
    void
>::type
swap(tuple<_Tp...>& __t, tuple<_Tp...>& __u)
                 _NOEXCEPT_(__all<__is_nothrow_swappable<_Tp>::value...>::value)
    {__t.swap(__u);}

// get

template <size_t _Ip, class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, tuple<_Tp...> >::type&
get(tuple<_Tp...>& __t) _NOEXCEPT
{
    typedef _LIBCPP_NODEBUG_TYPE typename tuple_element<_Ip, tuple<_Tp...> >::type type;
    return static_cast<__tuple_leaf<_Ip, type>&>(__t.__base_).get();
}

template <size_t _Ip, class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, tuple<_Tp...> >::type&
get(const tuple<_Tp...>& __t) _NOEXCEPT
{
    typedef _LIBCPP_NODEBUG_TYPE typename tuple_element<_Ip, tuple<_Tp...> >::type type;
    return static_cast<const __tuple_leaf<_Ip, type>&>(__t.__base_).get();
}

template <size_t _Ip, class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, tuple<_Tp...> >::type&&
get(tuple<_Tp...>&& __t) _NOEXCEPT
{
    typedef _LIBCPP_NODEBUG_TYPE typename tuple_element<_Ip, tuple<_Tp...> >::type type;
    return static_cast<type&&>(
             static_cast<__tuple_leaf<_Ip, type>&&>(__t.__base_).get());
}

template <size_t _Ip, class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, tuple<_Tp...> >::type&&
get(const tuple<_Tp...>&& __t) _NOEXCEPT
{
    typedef _LIBCPP_NODEBUG_TYPE typename tuple_element<_Ip, tuple<_Tp...> >::type type;
    return static_cast<const type&&>(
             static_cast<const __tuple_leaf<_Ip, type>&&>(__t.__base_).get());
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1044 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3

namespace __find_detail {

static constexpr size_t __not_found = -1;
static constexpr size_t __ambiguous = __not_found - 1;

inline _LIBCPP_INLINE_VISIBILITY
constexpr size_t __find_idx_return(size_t __curr_i, size_t __res, bool __matches) {
    return !__matches ? __res :
        (__res == __not_found ? __curr_i : __ambiguous);
}

template <size_t _Nx>
inline _LIBCPP_INLINE_VISIBILITY
constexpr size_t __find_idx(size_t __i, const bool (&__matches)[_Nx]) {
  return __i == _Nx ? __not_found :
      __find_idx_return(__i, __find_idx(__i + 1, __matches), __matches[__i]);
}

template <class _T1, class ..._Args>
struct __find_exactly_one_checked {
    static constexpr bool __matches[sizeof...(_Args)] = {is_same<_T1, _Args>::value...};
    static constexpr size_t value = __find_detail::__find_idx(0, __matches);
    static_assert(value != __not_found, "type not found in type list" );
    static_assert(value != __ambiguous, "type occurs more than once in type list");
};

template <class _T1>
struct __find_exactly_one_checked<_T1> {
    static_assert(!is_same<_T1, _T1>::value, "type not in empty type list");
};

} // namespace __find_detail;

template <typename _T1, typename... _Args>
struct __find_exactly_one_t
    : public __find_detail::__find_exactly_one_checked<_T1, _Args...> {
};

template <class _T1, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1& get(tuple<_Args...>& __tup) noexcept
{
    return _VSTD::get<__find_exactly_one_t<_T1, _Args...>::value>(__tup);
}

template <class _T1, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const& get(tuple<_Args...> const& __tup) noexcept
{
    return _VSTD::get<__find_exactly_one_t<_T1, _Args...>::value>(__tup);
}

template <class _T1, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1&& get(tuple<_Args...>&& __tup) noexcept
{
    return _VSTD::get<__find_exactly_one_t<_T1, _Args...>::value>(_VSTD::move(__tup));
}

template <class _T1, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const&& get(tuple<_Args...> const&& __tup) noexcept
{
    return _VSTD::get<__find_exactly_one_t<_T1, _Args...>::value>(_VSTD::move(__tup));
}

#endif
# 1112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3

// tie

template <class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
tuple<_Tp&...>
tie(_Tp&... __t) _NOEXCEPT
{
    return tuple<_Tp&...>(__t...);
}

template <class _Up>
struct __ignore_t
{
    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const __ignore_t& operator=(_Tp&&) const {return *this;}
};

namespace {
  _LIBCPP_INLINE_VAR constexpr __ignore_t<unsigned char> ignore = __ignore_t<unsigned char>();
}

template <class... _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
tuple<typename __unwrap_ref_decay<_Tp>::type...>
make_tuple(_Tp&&... __t)
{
    return tuple<typename __unwrap_ref_decay<_Tp>::type...>(_VSTD::forward<_Tp>(__t)...);
}

template <class... _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
tuple<_Tp&&...>
forward_as_tuple(_Tp&&... __t) _NOEXCEPT
{
    return tuple<_Tp&&...>(_VSTD::forward<_Tp>(__t)...);
}

template <size_t _Ip>
struct __tuple_equal
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _Tp& __x, const _Up& __y)
    {
        return __tuple_equal<_Ip - 1>()(__x, __y) && _VSTD::get<_Ip-1>(__x) == _VSTD::get<_Ip-1>(__y);
    }
};

template <>
struct __tuple_equal<0>
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _Tp&, const _Up&)
    {
        return true;
    }
};

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator==(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    static_assert (sizeof...(_Tp) == sizeof...(_Up), "Can't compare tuples of different sizes");
    return __tuple_equal<sizeof...(_Tp)>()(__x, __y);
}

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator!=(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return !(__x == __y);
}

template <size_t _Ip>
struct __tuple_less
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _Tp& __x, const _Up& __y)
    {
        const size_t __idx = tuple_size<_Tp>::value - _Ip;
        if (_VSTD::get<__idx>(__x) < _VSTD::get<__idx>(__y))
            return true;
        if (_VSTD::get<__idx>(__y) < _VSTD::get<__idx>(__x))
            return false;
        return __tuple_less<_Ip-1>()(__x, __y);
    }
};

template <>
struct __tuple_less<0>
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _Tp&, const _Up&)
    {
        return false;
    }
};

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    static_assert (sizeof...(_Tp) == sizeof...(_Up), "Can't compare tuples of different sizes");
    return __tuple_less<sizeof...(_Tp)>()(__x, __y);
}

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return __y < __x;
}

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>=(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return !(__x < __y);
}

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<=(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return !(__y < __x);
}

// tuple_cat

template <class _Tp, class _Up> struct __tuple_cat_type;

template <class ..._Ttypes, class ..._Utypes>
struct __tuple_cat_type<tuple<_Ttypes...>, __tuple_types<_Utypes...> >
{
    typedef _LIBCPP_NODEBUG_TYPE tuple<_Ttypes..., _Utypes...> type;
};

template <class _ResultTuple, bool _Is_Tuple0TupleLike, class ..._Tuples>
struct __tuple_cat_return_1
{
};

template <class ..._Types, class _Tuple0>
struct __tuple_cat_return_1<tuple<_Types...>, true, _Tuple0>
{
    typedef _LIBCPP_NODEBUG_TYPE typename __tuple_cat_type<tuple<_Types...>,
            typename __make_tuple_types<typename __uncvref<_Tuple0>::type>::type>::type
                                                                           type;
};

template <class ..._Types, class _Tuple0, class _Tuple1, class ..._Tuples>
struct __tuple_cat_return_1<tuple<_Types...>, true, _Tuple0, _Tuple1, _Tuples...>
    : public __tuple_cat_return_1<
                 typename __tuple_cat_type<
                     tuple<_Types...>,
                     typename __make_tuple_types<typename __uncvref<_Tuple0>::type>::type
                 >::type,
                 __tuple_like<typename remove_reference<_Tuple1>::type>::value,
                 _Tuple1, _Tuples...>
{
};

template <class ..._Tuples> struct __tuple_cat_return;

template <class _Tuple0, class ..._Tuples>
struct __tuple_cat_return<_Tuple0, _Tuples...>
    : public __tuple_cat_return_1<tuple<>,
         __tuple_like<typename remove_reference<_Tuple0>::type>::value, _Tuple0,
                                                                     _Tuples...>
{
};

template <>
struct __tuple_cat_return<>
{
    typedef _LIBCPP_NODEBUG_TYPE tuple<> type;
};

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
tuple<>
tuple_cat()
{
    return tuple<>();
}

template <class _Rp, class _Indices, class _Tuple0, class ..._Tuples>
struct __tuple_cat_return_ref_imp;

template <class ..._Types, size_t ..._I0, class _Tuple0>
struct __tuple_cat_return_ref_imp<tuple<_Types...>, __tuple_indices<_I0...>, _Tuple0>
{
    typedef _LIBCPP_NODEBUG_TYPE typename remove_reference<_Tuple0>::type _T0;
    typedef tuple<_Types..., typename __apply_cv<_Tuple0,
                          typename tuple_element<_I0, _T0>::type>::type&&...> type;
};

template <class ..._Types, size_t ..._I0, class _Tuple0, class _Tuple1, class ..._Tuples>
struct __tuple_cat_return_ref_imp<tuple<_Types...>, __tuple_indices<_I0...>,
                                  _Tuple0, _Tuple1, _Tuples...>
    : public __tuple_cat_return_ref_imp<
         tuple<_Types..., typename __apply_cv<_Tuple0,
               typename tuple_element<_I0,
                  typename remove_reference<_Tuple0>::type>::type>::type&&...>,
         typename __make_tuple_indices<tuple_size<typename
                                 remove_reference<_Tuple1>::type>::value>::type,
         _Tuple1, _Tuples...>
{
};

template <class _Tuple0, class ..._Tuples>
struct __tuple_cat_return_ref
    : public __tuple_cat_return_ref_imp<tuple<>,
               typename __make_tuple_indices<
                        tuple_size<typename remove_reference<_Tuple0>::type>::value
               >::type, _Tuple0, _Tuples...>
{
};

template <class _Types, class _I0, class _J0>
struct __tuple_cat;

template <class ..._Types, size_t ..._I0, size_t ..._J0>
struct __tuple_cat<tuple<_Types...>, __tuple_indices<_I0...>, __tuple_indices<_J0...> >
{
    template <class _Tuple0>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    typename __tuple_cat_return_ref<tuple<_Types...>&&, _Tuple0&&>::type
    operator()(tuple<_Types...> __t, _Tuple0&& __t0)
    {
        return _VSTD::forward_as_tuple(
            _VSTD::forward<_Types>(_VSTD::get<_I0>(__t))...,
            _VSTD::get<_J0>(_VSTD::forward<_Tuple0>(__t0))...);
    }

    template <class _Tuple0, class _Tuple1, class ..._Tuples>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    typename __tuple_cat_return_ref<tuple<_Types...>&&, _Tuple0&&, _Tuple1&&, _Tuples&&...>::type
    operator()(tuple<_Types...> __t, _Tuple0&& __t0, _Tuple1&& __t1, _Tuples&& ...__tpls)
    {
        typedef _LIBCPP_NODEBUG_TYPE typename remove_reference<_Tuple0>::type _T0;
        typedef _LIBCPP_NODEBUG_TYPE typename remove_reference<_Tuple1>::type _T1;
        return __tuple_cat<
            tuple<_Types...,
                  typename __apply_cv<_Tuple0, typename tuple_element<
                                                   _J0, _T0>::type>::type&&...>,
            typename __make_tuple_indices<sizeof...(_Types) +
                                          tuple_size<_T0>::value>::type,
            typename __make_tuple_indices<tuple_size<_T1>::value>::type>()(
            _VSTD::forward_as_tuple(
                _VSTD::forward<_Types>(_VSTD::get<_I0>(__t))...,
                _VSTD::get<_J0>(_VSTD::forward<_Tuple0>(__t0))...),
            _VSTD::forward<_Tuple1>(__t1), _VSTD::forward<_Tuples>(__tpls)...);
    }
};

template <class _Tuple0, class... _Tuples>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename __tuple_cat_return<_Tuple0, _Tuples...>::type
tuple_cat(_Tuple0&& __t0, _Tuples&&... __tpls)
{
    typedef _LIBCPP_NODEBUG_TYPE typename remove_reference<_Tuple0>::type _T0;
    return __tuple_cat<tuple<>, __tuple_indices<>,
                  typename __make_tuple_indices<tuple_size<_T0>::value>::type>()
                  (tuple<>(), _VSTD::forward<_Tuple0>(__t0),
                                            _VSTD::forward<_Tuples>(__tpls)...);
}

template <class ..._Tp, class _Alloc>
struct _LIBCPP_TEMPLATE_VIS uses_allocator<tuple<_Tp...>, _Alloc>
    : true_type {};

template <class _T1, class _T2>
template <class... _Args1, class... _Args2, size_t ..._I1, size_t ..._I2>
inline _LIBCPP_INLINE_VISIBILITY
pair<_T1, _T2>::pair(piecewise_construct_t,
                     tuple<_Args1...>& __first_args, tuple<_Args2...>& __second_args,
                     __tuple_indices<_I1...>, __tuple_indices<_I2...>)
    :  first(_VSTD::forward<_Args1>(_VSTD::get<_I1>( __first_args))...),
      second(_VSTD::forward<_Args2>(_VSTD::get<_I2>(__second_args))...)
{
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1406 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
template <class _Tp>
_LIBCPP_INLINE_VAR constexpr size_t tuple_size_v = tuple_size<_Tp>::value;

#define _LIBCPP_NOEXCEPT_RETURN(...) noexcept(noexcept(__VA_ARGS__)) { return __VA_ARGS__; }

template <class _Fn, class _Tuple, size_t ..._Id>
inline _LIBCPP_INLINE_VISIBILITY
constexpr decltype(auto) __apply_tuple_impl(_Fn && __f, _Tuple && __t,
                                            __tuple_indices<_Id...>)
_LIBCPP_NOEXCEPT_RETURN(
    _VSTD::__invoke_constexpr(
        _VSTD::forward<_Fn>(__f),
        _VSTD::get<_Id>(_VSTD::forward<_Tuple>(__t))...)
)

template <class _Fn, class _Tuple>
inline _LIBCPP_INLINE_VISIBILITY
constexpr decltype(auto) apply(_Fn && __f, _Tuple && __t)
_LIBCPP_NOEXCEPT_RETURN(
    _VSTD::__apply_tuple_impl(
        _VSTD::forward<_Fn>(__f), _VSTD::forward<_Tuple>(__t),
        typename __make_tuple_indices<tuple_size_v<remove_reference_t<_Tuple>>>::type{})
)

template <class _Tp, class _Tuple, size_t... _Idx>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _Tp __make_from_tuple_impl(_Tuple&& __t, __tuple_indices<_Idx...>)
_LIBCPP_NOEXCEPT_RETURN(
    _Tp(_VSTD::get<_Idx>(_VSTD::forward<_Tuple>(__t))...)
)

template <class _Tp, class _Tuple>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _Tp make_from_tuple(_Tuple&& __t)
_LIBCPP_NOEXCEPT_RETURN(
    _VSTD::__make_from_tuple_impl<_Tp>(_VSTD::forward<_Tuple>(__t),
        typename __make_tuple_indices<tuple_size_v<remove_reference_t<_Tuple>>>::type{})
)

#undef _LIBCPP_NOEXCEPT_RETURN

#endif // _LIBCPP_STD_VER > 14
# 1448 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3

#endif // !defined(_LIBCPP_CXX03_LANG)
# 1450 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_TUPLE
# 1454 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/tuple" 3
# 663 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 663 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 1 3
// -*- C++ -*-
//===--------------------------- stdexcept --------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STDEXCEPT
#define _LIBCPP_STDEXCEPT

/*
    stdexcept synopsis

namespace std
{

class logic_error;
    class domain_error;
    class invalid_argument;
    class length_error;
    class out_of_range;
class runtime_error;
    class range_error;
    class overflow_error;
    class underflow_error;

for each class xxx_error:

class xxx_error : public exception // at least indirectly
{
public:
    explicit xxx_error(const string& what_arg);
    explicit xxx_error(const char*   what_arg);

    virtual const char* what() const noexcept // returns what_arg
};

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 44 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>  // for string forward decl
#endif /* expanded by -frewrite-includes */
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
# 47 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
#ifdef _LIBCPP_NO_EXCEPTIONS
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
# 49 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
#endif
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 52 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
#endif
# 54 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3

_LIBCPP_BEGIN_NAMESPACE_STD

#ifndef _LIBCPP_ABI_VCRUNTIME
class _LIBCPP_HIDDEN __libcpp_refstring
{
    const char* __imp_;

    bool __uses_refcount() const;
public:
    explicit __libcpp_refstring(const char* __msg);
    __libcpp_refstring(const __libcpp_refstring& __s) _NOEXCEPT;
    __libcpp_refstring& operator=(const __libcpp_refstring& __s) _NOEXCEPT;
    ~__libcpp_refstring();

    const char* c_str() const _NOEXCEPT {return __imp_;}
};
#endif // !_LIBCPP_ABI_VCRUNTIME
# 72 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3

_LIBCPP_END_NAMESPACE_STD

namespace std  // purposefully not using versioning namespace
{

class _LIBCPP_EXCEPTION_ABI logic_error
    : public exception
{
#ifndef _LIBCPP_ABI_VCRUNTIME
private:
    _VSTD::__libcpp_refstring __imp_;
public:
    explicit logic_error(const string&);
    explicit logic_error(const char*);

    logic_error(const logic_error&) _NOEXCEPT;
    logic_error& operator=(const logic_error&) _NOEXCEPT;

    virtual ~logic_error() _NOEXCEPT;

    virtual const char* what() const _NOEXCEPT;
#else
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
public:
    explicit logic_error(const _VSTD::string&); // Symbol uses versioned std::string
    _LIBCPP_INLINE_VISIBILITY explicit logic_error(const char* __s) : exception(__s) {}
#endif
# 99 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

class _LIBCPP_EXCEPTION_ABI runtime_error
    : public exception
{
#ifndef _LIBCPP_ABI_VCRUNTIME
private:
    _VSTD::__libcpp_refstring __imp_;
public:
    explicit runtime_error(const string&);
    explicit runtime_error(const char*);

    runtime_error(const runtime_error&) _NOEXCEPT;
    runtime_error& operator=(const runtime_error&) _NOEXCEPT;

    virtual ~runtime_error() _NOEXCEPT;

    virtual const char* what() const _NOEXCEPT;
#else
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
public:
   explicit runtime_error(const _VSTD::string&); // Symbol uses versioned std::string
   _LIBCPP_INLINE_VISIBILITY explicit runtime_error(const char* __s) : exception(__s) {}
#endif // _LIBCPP_ABI_VCRUNTIME
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

class _LIBCPP_EXCEPTION_ABI domain_error
    : public logic_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit domain_error(const string& __s) : logic_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit domain_error(const char* __s)   : logic_error(__s) {}

#ifndef _LIBCPP_ABI_VCRUNTIME
    virtual ~domain_error() _NOEXCEPT;
#endif
# 134 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

class _LIBCPP_EXCEPTION_ABI invalid_argument
    : public logic_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit invalid_argument(const string& __s) : logic_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit invalid_argument(const char* __s)   : logic_error(__s) {}

#ifndef _LIBCPP_ABI_VCRUNTIME
    virtual ~invalid_argument() _NOEXCEPT;
#endif
# 146 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

class _LIBCPP_EXCEPTION_ABI length_error
    : public logic_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit length_error(const string& __s) : logic_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit length_error(const char* __s)   : logic_error(__s) {}
#ifndef _LIBCPP_ABI_VCRUNTIME
    virtual ~length_error() _NOEXCEPT;
#endif
# 157 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

class _LIBCPP_EXCEPTION_ABI out_of_range
    : public logic_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit out_of_range(const string& __s) : logic_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit out_of_range(const char* __s)   : logic_error(__s) {}

#ifndef _LIBCPP_ABI_VCRUNTIME
    virtual ~out_of_range() _NOEXCEPT;
#endif
# 169 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

class _LIBCPP_EXCEPTION_ABI range_error
    : public runtime_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit range_error(const string& __s) : runtime_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit range_error(const char* __s)   : runtime_error(__s) {}

#ifndef _LIBCPP_ABI_VCRUNTIME
    virtual ~range_error() _NOEXCEPT;
#endif
# 181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

class _LIBCPP_EXCEPTION_ABI overflow_error
    : public runtime_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit overflow_error(const string& __s) : runtime_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit overflow_error(const char* __s)   : runtime_error(__s) {}

#ifndef _LIBCPP_ABI_VCRUNTIME
    virtual ~overflow_error() _NOEXCEPT;
#endif
# 193 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

class _LIBCPP_EXCEPTION_ABI underflow_error
    : public runtime_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit underflow_error(const string& __s) : runtime_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit underflow_error(const char* __s)   : runtime_error(__s) {}

#ifndef _LIBCPP_ABI_VCRUNTIME
    virtual ~underflow_error() _NOEXCEPT;
#endif
# 205 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
};

}  // std

_LIBCPP_BEGIN_NAMESPACE_STD

// in the dylib
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void __throw_runtime_error(const char*);

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_logic_error(const char*__msg)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw logic_error(__msg);
#else
# 220 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
    ((void)__msg);
    _VSTD::abort();
#endif
# 223 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
}

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_domain_error(const char*__msg)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw domain_error(__msg);
#else
# 231 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
    ((void)__msg);
    _VSTD::abort();
#endif
# 234 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
}

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_invalid_argument(const char*__msg)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw invalid_argument(__msg);
#else
# 242 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
    ((void)__msg);
    _VSTD::abort();
#endif
# 245 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
}

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_length_error(const char*__msg)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw length_error(__msg);
#else
# 253 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
    ((void)__msg);
    _VSTD::abort();
#endif
# 256 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
}

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_out_of_range(const char*__msg)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw out_of_range(__msg);
#else
# 264 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
    ((void)__msg);
    _VSTD::abort();
#endif
# 267 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
}

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_range_error(const char*__msg)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw range_error(__msg);
#else
# 275 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
    ((void)__msg);
    _VSTD::abort();
#endif
# 278 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
}

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_overflow_error(const char*__msg)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw overflow_error(__msg);
#else
# 286 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
    ((void)__msg);
    _VSTD::abort();
#endif
# 289 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
}

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_underflow_error(const char*__msg)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw underflow_error(__msg);
#else
# 297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
    ((void)__msg);
    _VSTD::abort();
#endif
# 300 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
}

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_STDEXCEPT
# 305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdexcept" 3
# 664 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 664 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 665 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_ATOMIC_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 666 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#  include <atomic>
#endif /* expanded by -frewrite-includes */
# 666 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 1 3
// -*- C++ -*-
//===--------------------------- atomic -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_ATOMIC
#define _LIBCPP_ATOMIC

/*
    atomic synopsis

namespace std
{

// feature test macro

#define __cpp_lib_atomic_is_always_lock_free // as specified by SG10

 // order and consistency

 enum memory_order: unspecified // enum class in C++20
 {
    relaxed,
    consume, // load-consume
    acquire, // load-acquire
    release, // store-release
    acq_rel, // store-release load-acquire
    seq_cst // store-release load-acquire
 };

 inline constexpr auto memory_order_relaxed = memory_order::relaxed;
 inline constexpr auto memory_order_consume = memory_order::consume;
 inline constexpr auto memory_order_acquire = memory_order::acquire;
 inline constexpr auto memory_order_release = memory_order::release;
 inline constexpr auto memory_order_acq_rel = memory_order::acq_rel;
 inline constexpr auto memory_order_seq_cst = memory_order::seq_cst;

template <class T> T kill_dependency(T y) noexcept;

// lock-free property

#define ATOMIC_BOOL_LOCK_FREE unspecified
#define ATOMIC_CHAR_LOCK_FREE unspecified
#define ATOMIC_CHAR16_T_LOCK_FREE unspecified
#define ATOMIC_CHAR32_T_LOCK_FREE unspecified
#define ATOMIC_WCHAR_T_LOCK_FREE unspecified
#define ATOMIC_SHORT_LOCK_FREE unspecified
#define ATOMIC_INT_LOCK_FREE unspecified
#define ATOMIC_LONG_LOCK_FREE unspecified
#define ATOMIC_LLONG_LOCK_FREE unspecified
#define ATOMIC_POINTER_LOCK_FREE unspecified

// flag type and operations

typedef struct atomic_flag
{
    bool test_and_set(memory_order m = memory_order_seq_cst) volatile noexcept;
    bool test_and_set(memory_order m = memory_order_seq_cst) noexcept;
    void clear(memory_order m = memory_order_seq_cst) volatile noexcept;
    void clear(memory_order m = memory_order_seq_cst) noexcept;
    atomic_flag()  noexcept = default;
    atomic_flag(const atomic_flag&) = delete;
    atomic_flag& operator=(const atomic_flag&) = delete;
    atomic_flag& operator=(const atomic_flag&) volatile = delete;
} atomic_flag;

bool
    atomic_flag_test_and_set(volatile atomic_flag* obj) noexcept;

bool
    atomic_flag_test_and_set(atomic_flag* obj) noexcept;

bool
    atomic_flag_test_and_set_explicit(volatile atomic_flag* obj,
                                      memory_order m) noexcept;

bool
    atomic_flag_test_and_set_explicit(atomic_flag* obj, memory_order m) noexcept;

void
    atomic_flag_clear(volatile atomic_flag* obj) noexcept;

void
    atomic_flag_clear(atomic_flag* obj) noexcept;

void
    atomic_flag_clear_explicit(volatile atomic_flag* obj, memory_order m) noexcept;

void
    atomic_flag_clear_explicit(atomic_flag* obj, memory_order m) noexcept;

#define ATOMIC_FLAG_INIT see below
#define ATOMIC_VAR_INIT(value) see below

template <class T>
struct atomic
{
    static constexpr bool is_always_lock_free;
    bool is_lock_free() const volatile noexcept;
    bool is_lock_free() const noexcept;
    void store(T desr, memory_order m = memory_order_seq_cst) volatile noexcept;
    void store(T desr, memory_order m = memory_order_seq_cst) noexcept;
    T load(memory_order m = memory_order_seq_cst) const volatile noexcept;
    T load(memory_order m = memory_order_seq_cst) const noexcept;
    operator T() const volatile noexcept;
    operator T() const noexcept;
    T exchange(T desr, memory_order m = memory_order_seq_cst) volatile noexcept;
    T exchange(T desr, memory_order m = memory_order_seq_cst) noexcept;
    bool compare_exchange_weak(T& expc, T desr,
                               memory_order s, memory_order f) volatile noexcept;
    bool compare_exchange_weak(T& expc, T desr, memory_order s, memory_order f) noexcept;
    bool compare_exchange_strong(T& expc, T desr,
                                 memory_order s, memory_order f) volatile noexcept;
    bool compare_exchange_strong(T& expc, T desr,
                                 memory_order s, memory_order f) noexcept;
    bool compare_exchange_weak(T& expc, T desr,
                               memory_order m = memory_order_seq_cst) volatile noexcept;
    bool compare_exchange_weak(T& expc, T desr,
                               memory_order m = memory_order_seq_cst) noexcept;
    bool compare_exchange_strong(T& expc, T desr,
                                memory_order m = memory_order_seq_cst) volatile noexcept;
    bool compare_exchange_strong(T& expc, T desr,
                                 memory_order m = memory_order_seq_cst) noexcept;

    atomic() noexcept = default;
    constexpr atomic(T desr) noexcept;
    atomic(const atomic&) = delete;
    atomic& operator=(const atomic&) = delete;
    atomic& operator=(const atomic&) volatile = delete;
    T operator=(T) volatile noexcept;
    T operator=(T) noexcept;
};

template <>
struct atomic<integral>
{
    static constexpr bool is_always_lock_free;
    bool is_lock_free() const volatile noexcept;
    bool is_lock_free() const noexcept;
    void store(integral desr, memory_order m = memory_order_seq_cst) volatile noexcept;
    void store(integral desr, memory_order m = memory_order_seq_cst) noexcept;
    integral load(memory_order m = memory_order_seq_cst) const volatile noexcept;
    integral load(memory_order m = memory_order_seq_cst) const noexcept;
    operator integral() const volatile noexcept;
    operator integral() const noexcept;
    integral exchange(integral desr,
                      memory_order m = memory_order_seq_cst) volatile noexcept;
    integral exchange(integral desr, memory_order m = memory_order_seq_cst) noexcept;
    bool compare_exchange_weak(integral& expc, integral desr,
                               memory_order s, memory_order f) volatile noexcept;
    bool compare_exchange_weak(integral& expc, integral desr,
                               memory_order s, memory_order f) noexcept;
    bool compare_exchange_strong(integral& expc, integral desr,
                                 memory_order s, memory_order f) volatile noexcept;
    bool compare_exchange_strong(integral& expc, integral desr,
                                 memory_order s, memory_order f) noexcept;
    bool compare_exchange_weak(integral& expc, integral desr,
                               memory_order m = memory_order_seq_cst) volatile noexcept;
    bool compare_exchange_weak(integral& expc, integral desr,
                               memory_order m = memory_order_seq_cst) noexcept;
    bool compare_exchange_strong(integral& expc, integral desr,
                                memory_order m = memory_order_seq_cst) volatile noexcept;
    bool compare_exchange_strong(integral& expc, integral desr,
                                 memory_order m = memory_order_seq_cst) noexcept;

    integral
        fetch_add(integral op, memory_order m = memory_order_seq_cst) volatile noexcept;
    integral fetch_add(integral op, memory_order m = memory_order_seq_cst) noexcept;
    integral
        fetch_sub(integral op, memory_order m = memory_order_seq_cst) volatile noexcept;
    integral fetch_sub(integral op, memory_order m = memory_order_seq_cst) noexcept;
    integral
        fetch_and(integral op, memory_order m = memory_order_seq_cst) volatile noexcept;
    integral fetch_and(integral op, memory_order m = memory_order_seq_cst) noexcept;
    integral
        fetch_or(integral op, memory_order m = memory_order_seq_cst) volatile noexcept;
    integral fetch_or(integral op, memory_order m = memory_order_seq_cst) noexcept;
    integral
        fetch_xor(integral op, memory_order m = memory_order_seq_cst) volatile noexcept;
    integral fetch_xor(integral op, memory_order m = memory_order_seq_cst) noexcept;

    atomic() noexcept = default;
    constexpr atomic(integral desr) noexcept;
    atomic(const atomic&) = delete;
    atomic& operator=(const atomic&) = delete;
    atomic& operator=(const atomic&) volatile = delete;
    integral operator=(integral desr) volatile noexcept;
    integral operator=(integral desr) noexcept;

    integral operator++(int) volatile noexcept;
    integral operator++(int) noexcept;
    integral operator--(int) volatile noexcept;
    integral operator--(int) noexcept;
    integral operator++() volatile noexcept;
    integral operator++() noexcept;
    integral operator--() volatile noexcept;
    integral operator--() noexcept;
    integral operator+=(integral op) volatile noexcept;
    integral operator+=(integral op) noexcept;
    integral operator-=(integral op) volatile noexcept;
    integral operator-=(integral op) noexcept;
    integral operator&=(integral op) volatile noexcept;
    integral operator&=(integral op) noexcept;
    integral operator|=(integral op) volatile noexcept;
    integral operator|=(integral op) noexcept;
    integral operator^=(integral op) volatile noexcept;
    integral operator^=(integral op) noexcept;
};

template <class T>
struct atomic<T*>
{
    static constexpr bool is_always_lock_free;
    bool is_lock_free() const volatile noexcept;
    bool is_lock_free() const noexcept;
    void store(T* desr, memory_order m = memory_order_seq_cst) volatile noexcept;
    void store(T* desr, memory_order m = memory_order_seq_cst) noexcept;
    T* load(memory_order m = memory_order_seq_cst) const volatile noexcept;
    T* load(memory_order m = memory_order_seq_cst) const noexcept;
    operator T*() const volatile noexcept;
    operator T*() const noexcept;
    T* exchange(T* desr, memory_order m = memory_order_seq_cst) volatile noexcept;
    T* exchange(T* desr, memory_order m = memory_order_seq_cst) noexcept;
    bool compare_exchange_weak(T*& expc, T* desr,
                               memory_order s, memory_order f) volatile noexcept;
    bool compare_exchange_weak(T*& expc, T* desr,
                               memory_order s, memory_order f) noexcept;
    bool compare_exchange_strong(T*& expc, T* desr,
                                 memory_order s, memory_order f) volatile noexcept;
    bool compare_exchange_strong(T*& expc, T* desr,
                                 memory_order s, memory_order f) noexcept;
    bool compare_exchange_weak(T*& expc, T* desr,
                               memory_order m = memory_order_seq_cst) volatile noexcept;
    bool compare_exchange_weak(T*& expc, T* desr,
                               memory_order m = memory_order_seq_cst) noexcept;
    bool compare_exchange_strong(T*& expc, T* desr,
                                memory_order m = memory_order_seq_cst) volatile noexcept;
    bool compare_exchange_strong(T*& expc, T* desr,
                                 memory_order m = memory_order_seq_cst) noexcept;
    T* fetch_add(ptrdiff_t op, memory_order m = memory_order_seq_cst) volatile noexcept;
    T* fetch_add(ptrdiff_t op, memory_order m = memory_order_seq_cst) noexcept;
    T* fetch_sub(ptrdiff_t op, memory_order m = memory_order_seq_cst) volatile noexcept;
    T* fetch_sub(ptrdiff_t op, memory_order m = memory_order_seq_cst) noexcept;

    atomic() noexcept = default;
    constexpr atomic(T* desr) noexcept;
    atomic(const atomic&) = delete;
    atomic& operator=(const atomic&) = delete;
    atomic& operator=(const atomic&) volatile = delete;

    T* operator=(T*) volatile noexcept;
    T* operator=(T*) noexcept;
    T* operator++(int) volatile noexcept;
    T* operator++(int) noexcept;
    T* operator--(int) volatile noexcept;
    T* operator--(int) noexcept;
    T* operator++() volatile noexcept;
    T* operator++() noexcept;
    T* operator--() volatile noexcept;
    T* operator--() noexcept;
    T* operator+=(ptrdiff_t op) volatile noexcept;
    T* operator+=(ptrdiff_t op) noexcept;
    T* operator-=(ptrdiff_t op) volatile noexcept;
    T* operator-=(ptrdiff_t op) noexcept;
};


template <class T>
    bool
    atomic_is_lock_free(const volatile atomic<T>* obj) noexcept;

template <class T>
    bool
    atomic_is_lock_free(const atomic<T>* obj) noexcept;

template <class T>
    void
    atomic_init(volatile atomic<T>* obj, T desr) noexcept;

template <class T>
    void
    atomic_init(atomic<T>* obj, T desr) noexcept;

template <class T>
    void
    atomic_store(volatile atomic<T>* obj, T desr) noexcept;

template <class T>
    void
    atomic_store(atomic<T>* obj, T desr) noexcept;

template <class T>
    void
    atomic_store_explicit(volatile atomic<T>* obj, T desr, memory_order m) noexcept;

template <class T>
    void
    atomic_store_explicit(atomic<T>* obj, T desr, memory_order m) noexcept;

template <class T>
    T
    atomic_load(const volatile atomic<T>* obj) noexcept;

template <class T>
    T
    atomic_load(const atomic<T>* obj) noexcept;

template <class T>
    T
    atomic_load_explicit(const volatile atomic<T>* obj, memory_order m) noexcept;

template <class T>
    T
    atomic_load_explicit(const atomic<T>* obj, memory_order m) noexcept;

template <class T>
    T
    atomic_exchange(volatile atomic<T>* obj, T desr) noexcept;

template <class T>
    T
    atomic_exchange(atomic<T>* obj, T desr) noexcept;

template <class T>
    T
    atomic_exchange_explicit(volatile atomic<T>* obj, T desr, memory_order m) noexcept;

template <class T>
    T
    atomic_exchange_explicit(atomic<T>* obj, T desr, memory_order m) noexcept;

template <class T>
    bool
    atomic_compare_exchange_weak(volatile atomic<T>* obj, T* expc, T desr) noexcept;

template <class T>
    bool
    atomic_compare_exchange_weak(atomic<T>* obj, T* expc, T desr) noexcept;

template <class T>
    bool
    atomic_compare_exchange_strong(volatile atomic<T>* obj, T* expc, T desr) noexcept;

template <class T>
    bool
    atomic_compare_exchange_strong(atomic<T>* obj, T* expc, T desr) noexcept;

template <class T>
    bool
    atomic_compare_exchange_weak_explicit(volatile atomic<T>* obj, T* expc,
                                          T desr,
                                          memory_order s, memory_order f) noexcept;

template <class T>
    bool
    atomic_compare_exchange_weak_explicit(atomic<T>* obj, T* expc, T desr,
                                          memory_order s, memory_order f) noexcept;

template <class T>
    bool
    atomic_compare_exchange_strong_explicit(volatile atomic<T>* obj,
                                            T* expc, T desr,
                                            memory_order s, memory_order f) noexcept;

template <class T>
    bool
    atomic_compare_exchange_strong_explicit(atomic<T>* obj, T* expc,
                                            T desr,
                                            memory_order s, memory_order f) noexcept;

template <class Integral>
    Integral
    atomic_fetch_add(volatile atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_add(atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_add_explicit(volatile atomic<Integral>* obj, Integral op,
                              memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_add_explicit(atomic<Integral>* obj, Integral op,
                              memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_sub(volatile atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_sub(atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_sub_explicit(volatile atomic<Integral>* obj, Integral op,
                              memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_sub_explicit(atomic<Integral>* obj, Integral op,
                              memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_and(volatile atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_and(atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_and_explicit(volatile atomic<Integral>* obj, Integral op,
                              memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_and_explicit(atomic<Integral>* obj, Integral op,
                              memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_or(volatile atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_or(atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_or_explicit(volatile atomic<Integral>* obj, Integral op,
                             memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_or_explicit(atomic<Integral>* obj, Integral op,
                             memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_xor(volatile atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_xor(atomic<Integral>* obj, Integral op) noexcept;

template <class Integral>
    Integral
    atomic_fetch_xor_explicit(volatile atomic<Integral>* obj, Integral op,
                              memory_order m) noexcept;
template <class Integral>
    Integral
    atomic_fetch_xor_explicit(atomic<Integral>* obj, Integral op,
                              memory_order m) noexcept;

template <class T>
    T*
    atomic_fetch_add(volatile atomic<T*>* obj, ptrdiff_t op) noexcept;

template <class T>
    T*
    atomic_fetch_add(atomic<T*>* obj, ptrdiff_t op) noexcept;

template <class T>
    T*
    atomic_fetch_add_explicit(volatile atomic<T*>* obj, ptrdiff_t op,
                              memory_order m) noexcept;
template <class T>
    T*
    atomic_fetch_add_explicit(atomic<T*>* obj, ptrdiff_t op, memory_order m) noexcept;

template <class T>
    T*
    atomic_fetch_sub(volatile atomic<T*>* obj, ptrdiff_t op) noexcept;

template <class T>
    T*
    atomic_fetch_sub(atomic<T*>* obj, ptrdiff_t op) noexcept;

template <class T>
    T*
    atomic_fetch_sub_explicit(volatile atomic<T*>* obj, ptrdiff_t op,
                              memory_order m) noexcept;
template <class T>
    T*
    atomic_fetch_sub_explicit(atomic<T*>* obj, ptrdiff_t op, memory_order m) noexcept;

// Atomics for standard typedef types

typedef atomic<bool>               atomic_bool;
typedef atomic<char>               atomic_char;
typedef atomic<signed char>        atomic_schar;
typedef atomic<unsigned char>      atomic_uchar;
typedef atomic<short>              atomic_short;
typedef atomic<unsigned short>     atomic_ushort;
typedef atomic<int>                atomic_int;
typedef atomic<unsigned int>       atomic_uint;
typedef atomic<long>               atomic_long;
typedef atomic<unsigned long>      atomic_ulong;
typedef atomic<long long>          atomic_llong;
typedef atomic<unsigned long long> atomic_ullong;
typedef atomic<char16_t>           atomic_char16_t;
typedef atomic<char32_t>           atomic_char32_t;
typedef atomic<wchar_t>            atomic_wchar_t;

typedef atomic<int_least8_t>   atomic_int_least8_t;
typedef atomic<uint_least8_t>  atomic_uint_least8_t;
typedef atomic<int_least16_t>  atomic_int_least16_t;
typedef atomic<uint_least16_t> atomic_uint_least16_t;
typedef atomic<int_least32_t>  atomic_int_least32_t;
typedef atomic<uint_least32_t> atomic_uint_least32_t;
typedef atomic<int_least64_t>  atomic_int_least64_t;
typedef atomic<uint_least64_t> atomic_uint_least64_t;

typedef atomic<int_fast8_t>   atomic_int_fast8_t;
typedef atomic<uint_fast8_t>  atomic_uint_fast8_t;
typedef atomic<int_fast16_t>  atomic_int_fast16_t;
typedef atomic<uint_fast16_t> atomic_uint_fast16_t;
typedef atomic<int_fast32_t>  atomic_int_fast32_t;
typedef atomic<uint_fast32_t> atomic_uint_fast32_t;
typedef atomic<int_fast64_t>  atomic_int_fast64_t;
typedef atomic<uint_fast64_t> atomic_uint_fast64_t;

typedef atomic<int8_t>   atomic_int8_t;
typedef atomic<uint8_t>  atomic_uint8_t;
typedef atomic<int16_t>  atomic_int16_t;
typedef atomic<uint16_t> atomic_uint16_t;
typedef atomic<int32_t>  atomic_int32_t;
typedef atomic<uint32_t> atomic_uint32_t;
typedef atomic<int64_t>  atomic_int64_t;
typedef atomic<uint64_t> atomic_uint64_t;

typedef atomic<intptr_t>  atomic_intptr_t;
typedef atomic<uintptr_t> atomic_uintptr_t;
typedef atomic<size_t>    atomic_size_t;
typedef atomic<ptrdiff_t> atomic_ptrdiff_t;
typedef atomic<intmax_t>  atomic_intmax_t;
typedef atomic<uintmax_t> atomic_uintmax_t;

// fences

void atomic_thread_fence(memory_order m) noexcept;
void atomic_signal_fence(memory_order m) noexcept;

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 549 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
# 550 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 550 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
# 551 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 551 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
# 552 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 552 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
# 553 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 553 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
# 554 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 556 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 557 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
#endif
# 558 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

#ifdef _LIBCPP_HAS_NO_THREADS
# error <atomic> is not supported on this single threaded system
#endif
# 562 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
#ifdef _LIBCPP_HAS_NO_ATOMIC_HEADER
# error <atomic> is not implemented
#endif
# 565 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
#ifdef kill_dependency
# error C++ standard library is incompatible with <stdatomic.h>
#endif
# 568 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

#define _LIBCPP_CHECK_STORE_MEMORY_ORDER(__m) \
  _LIBCPP_DIAGNOSE_WARNING(__m == memory_order_consume || \
                           __m == memory_order_acquire || \
                           __m == memory_order_acq_rel,   \
                        "memory order argument to atomic operation is invalid")

#define _LIBCPP_CHECK_LOAD_MEMORY_ORDER(__m) \
  _LIBCPP_DIAGNOSE_WARNING(__m == memory_order_release || \
                           __m == memory_order_acq_rel,   \
                        "memory order argument to atomic operation is invalid")

#define _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__m, __f) \
  _LIBCPP_DIAGNOSE_WARNING(__f == memory_order_release || \
                           __f == memory_order_acq_rel,   \
                        "memory order argument to atomic operation is invalid")

_LIBCPP_BEGIN_NAMESPACE_STD

// Figure out what the underlying type for `memory_order` would be if it were
// declared as an unscoped enum (accounting for -fshort-enums). Use this result
// to pin the underlying type in C++20.
enum __legacy_memory_order {
    __mo_relaxed,
    __mo_consume,
    __mo_acquire,
    __mo_release,
    __mo_acq_rel,
    __mo_seq_cst
};

typedef underlying_type<__legacy_memory_order>::type __memory_order_underlying_t;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 602 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

enum class memory_order : __memory_order_underlying_t {
  relaxed = __mo_relaxed,
  consume = __mo_consume,
  acquire = __mo_acquire,
  release = __mo_release,
  acq_rel = __mo_acq_rel,
  seq_cst = __mo_seq_cst
};

inline constexpr auto memory_order_relaxed = memory_order::relaxed;
inline constexpr auto memory_order_consume = memory_order::consume;
inline constexpr auto memory_order_acquire = memory_order::acquire;
inline constexpr auto memory_order_release = memory_order::release;
inline constexpr auto memory_order_acq_rel = memory_order::acq_rel;
inline constexpr auto memory_order_seq_cst = memory_order::seq_cst;

#else
# 620 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

typedef enum memory_order {
  memory_order_relaxed = __mo_relaxed,
  memory_order_consume = __mo_consume,
  memory_order_acquire = __mo_acquire,
  memory_order_release = __mo_release,
  memory_order_acq_rel = __mo_acq_rel,
  memory_order_seq_cst = __mo_seq_cst,
} memory_order;

#endif // _LIBCPP_STD_VER > 17
# 631 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

static_assert((is_same<underlying_type<memory_order>::type, __memory_order_underlying_t>::value),
  "unexpected underlying type for std::memory_order");

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_GCC_ATOMIC_IMP) || \
	defined(_LIBCPP_ATOMIC_ONLY_USE_BUILTINS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 637 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

// [atomics.types.generic]p1 guarantees _Tp is trivially copyable. Because
// the default operator= in an object is not volatile, a byte-by-byte copy
// is required.
template <typename _Tp, typename _Tv> _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_assignable<_Tp&, _Tv>::value>::type
__cxx_atomic_assign_volatile(_Tp& __a_value, _Tv const& __val) {
  __a_value = __val;
}
template <typename _Tp, typename _Tv> _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_assignable<_Tp&, _Tv>::value>::type
__cxx_atomic_assign_volatile(_Tp volatile& __a_value, _Tv volatile const& __val) {
  volatile char* __to = reinterpret_cast<volatile char*>(&__a_value);
  volatile char* __end = __to + sizeof(_Tp);
  volatile const char* __from = reinterpret_cast<volatile const char*>(&__val);
  while (__to != __end)
    *__to++ = *__from++;
}

#endif
# 657 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_GCC_ATOMIC_IMP)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 659 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

template <typename _Tp>
struct __cxx_atomic_base_impl {

  _LIBCPP_INLINE_VISIBILITY
#ifndef _LIBCPP_CXX03_LANG
    __cxx_atomic_base_impl() _NOEXCEPT = default;
#else
# 667 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
    __cxx_atomic_base_impl() _NOEXCEPT : __a_value() {}
#endif // _LIBCPP_CXX03_LANG
# 669 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
  _LIBCPP_CONSTEXPR explicit __cxx_atomic_base_impl(_Tp value) _NOEXCEPT
    : __a_value(value) {}
  _Tp __a_value;
};

_LIBCPP_INLINE_VISIBILITY inline _LIBCPP_CONSTEXPR int __to_gcc_order(memory_order __order) {
  // Avoid switch statement to make this a constexpr.
  return __order == memory_order_relaxed ? __ATOMIC_RELAXED:
         (__order == memory_order_acquire ? __ATOMIC_ACQUIRE:
          (__order == memory_order_release ? __ATOMIC_RELEASE:
           (__order == memory_order_seq_cst ? __ATOMIC_SEQ_CST:
            (__order == memory_order_acq_rel ? __ATOMIC_ACQ_REL:
              __ATOMIC_CONSUME))));
}

_LIBCPP_INLINE_VISIBILITY inline _LIBCPP_CONSTEXPR int __to_gcc_failure_order(memory_order __order) {
  // Avoid switch statement to make this a constexpr.
  return __order == memory_order_relaxed ? __ATOMIC_RELAXED:
         (__order == memory_order_acquire ? __ATOMIC_ACQUIRE:
          (__order == memory_order_release ? __ATOMIC_RELAXED:
           (__order == memory_order_seq_cst ? __ATOMIC_SEQ_CST:
            (__order == memory_order_acq_rel ? __ATOMIC_ACQUIRE:
              __ATOMIC_CONSUME))));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_init(volatile __cxx_atomic_base_impl<_Tp>* __a,  _Tp __val) {
  __cxx_atomic_assign_volatile(__a->__a_value, __val);
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_init(__cxx_atomic_base_impl<_Tp>* __a,  _Tp __val) {
  __a->__a_value = __val;
}

_LIBCPP_INLINE_VISIBILITY inline
void __cxx_atomic_thread_fence(memory_order __order) {
  __atomic_thread_fence(__to_gcc_order(__order));
}

_LIBCPP_INLINE_VISIBILITY inline
void __cxx_atomic_signal_fence(memory_order __order) {
  __atomic_signal_fence(__to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_store(volatile __cxx_atomic_base_impl<_Tp>* __a,  _Tp __val,
                        memory_order __order) {
  __atomic_store(&__a->__a_value, &__val,
                 __to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_store(__cxx_atomic_base_impl<_Tp>* __a,  _Tp __val,
                        memory_order __order) {
  __atomic_store(&__a->__a_value, &__val,
                 __to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_load(const volatile __cxx_atomic_base_impl<_Tp>* __a,
                      memory_order __order) {
  _Tp __ret;
  __atomic_load(&__a->__a_value, &__ret,
                __to_gcc_order(__order));
  return __ret;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_load(const __cxx_atomic_base_impl<_Tp>* __a, memory_order __order) {
  _Tp __ret;
  __atomic_load(&__a->__a_value, &__ret,
                __to_gcc_order(__order));
  return __ret;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_exchange(volatile __cxx_atomic_base_impl<_Tp>* __a,
                          _Tp __value, memory_order __order) {
  _Tp __ret;
  __atomic_exchange(&__a->__a_value, &__value, &__ret,
                    __to_gcc_order(__order));
  return __ret;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_exchange(__cxx_atomic_base_impl<_Tp>* __a, _Tp __value,
                          memory_order __order) {
  _Tp __ret;
  __atomic_exchange(&__a->__a_value, &__value, &__ret,
                    __to_gcc_order(__order));
  return __ret;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_strong(
    volatile __cxx_atomic_base_impl<_Tp>* __a, _Tp* __expected, _Tp __value,
    memory_order __success, memory_order __failure) {
  return __atomic_compare_exchange(&__a->__a_value, __expected, &__value,
                                   false,
                                   __to_gcc_order(__success),
                                   __to_gcc_failure_order(__failure));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_strong(
    __cxx_atomic_base_impl<_Tp>* __a, _Tp* __expected, _Tp __value, memory_order __success,
    memory_order __failure) {
  return __atomic_compare_exchange(&__a->__a_value, __expected, &__value,
                                   false,
                                   __to_gcc_order(__success),
                                   __to_gcc_failure_order(__failure));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_weak(
    volatile __cxx_atomic_base_impl<_Tp>* __a, _Tp* __expected, _Tp __value,
    memory_order __success, memory_order __failure) {
  return __atomic_compare_exchange(&__a->__a_value, __expected, &__value,
                                   true,
                                   __to_gcc_order(__success),
                                   __to_gcc_failure_order(__failure));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_weak(
    __cxx_atomic_base_impl<_Tp>* __a, _Tp* __expected, _Tp __value, memory_order __success,
    memory_order __failure) {
  return __atomic_compare_exchange(&__a->__a_value, __expected, &__value,
                                   true,
                                   __to_gcc_order(__success),
                                   __to_gcc_failure_order(__failure));
}

template <typename _Tp>
struct __skip_amt { enum {value = 1}; };

template <typename _Tp>
struct __skip_amt<_Tp*> { enum {value = sizeof(_Tp)}; };

// FIXME: Haven't figured out what the spec says about using arrays with
// atomic_fetch_add. Force a failure rather than creating bad behavior.
template <typename _Tp>
struct __skip_amt<_Tp[]> { };
template <typename _Tp, int n>
struct __skip_amt<_Tp[n]> { };

template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_add(volatile __cxx_atomic_base_impl<_Tp>* __a,
                           _Td __delta, memory_order __order) {
  return __atomic_fetch_add(&__a->__a_value, __delta * __skip_amt<_Tp>::value,
                            __to_gcc_order(__order));
}

template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_add(__cxx_atomic_base_impl<_Tp>* __a, _Td __delta,
                           memory_order __order) {
  return __atomic_fetch_add(&__a->__a_value, __delta * __skip_amt<_Tp>::value,
                            __to_gcc_order(__order));
}

template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_sub(volatile __cxx_atomic_base_impl<_Tp>* __a,
                           _Td __delta, memory_order __order) {
  return __atomic_fetch_sub(&__a->__a_value, __delta * __skip_amt<_Tp>::value,
                            __to_gcc_order(__order));
}

template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_sub(__cxx_atomic_base_impl<_Tp>* __a, _Td __delta,
                           memory_order __order) {
  return __atomic_fetch_sub(&__a->__a_value, __delta * __skip_amt<_Tp>::value,
                            __to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_and(volatile __cxx_atomic_base_impl<_Tp>* __a,
                           _Tp __pattern, memory_order __order) {
  return __atomic_fetch_and(&__a->__a_value, __pattern,
                            __to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_and(__cxx_atomic_base_impl<_Tp>* __a,
                           _Tp __pattern, memory_order __order) {
  return __atomic_fetch_and(&__a->__a_value, __pattern,
                            __to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_or(volatile __cxx_atomic_base_impl<_Tp>* __a,
                          _Tp __pattern, memory_order __order) {
  return __atomic_fetch_or(&__a->__a_value, __pattern,
                           __to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_or(__cxx_atomic_base_impl<_Tp>* __a, _Tp __pattern,
                          memory_order __order) {
  return __atomic_fetch_or(&__a->__a_value, __pattern,
                           __to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_xor(volatile __cxx_atomic_base_impl<_Tp>* __a,
                           _Tp __pattern, memory_order __order) {
  return __atomic_fetch_xor(&__a->__a_value, __pattern,
                            __to_gcc_order(__order));
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_xor(__cxx_atomic_base_impl<_Tp>* __a, _Tp __pattern,
                           memory_order __order) {
  return __atomic_fetch_xor(&__a->__a_value, __pattern,
                            __to_gcc_order(__order));
}

#define __cxx_atomic_is_lock_free(__s) __atomic_is_lock_free(__s, 0)

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_HAS_C_ATOMIC_IMP)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 911 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

template <typename _Tp>
struct __cxx_atomic_base_impl {

  _LIBCPP_INLINE_VISIBILITY
#ifndef _LIBCPP_CXX03_LANG
    __cxx_atomic_base_impl() _NOEXCEPT = default;
#else
# 919 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
    __cxx_atomic_base_impl() _NOEXCEPT : __a_value() {}
#endif // _LIBCPP_CXX03_LANG
# 921 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
  _LIBCPP_CONSTEXPR explicit __cxx_atomic_base_impl(_Tp value) _NOEXCEPT
    : __a_value(value) {}
  _LIBCPP_DISABLE_EXTENSION_WARNING _Atomic(_Tp) __a_value;
};

#define __cxx_atomic_is_lock_free(__s) __c11_atomic_is_lock_free(__s)

_LIBCPP_INLINE_VISIBILITY inline
void __cxx_atomic_thread_fence(memory_order __order) _NOEXCEPT {
    __c11_atomic_thread_fence(static_cast<__memory_order_underlying_t>(__order));
}

_LIBCPP_INLINE_VISIBILITY inline
void __cxx_atomic_signal_fence(memory_order __order) _NOEXCEPT {
    __c11_atomic_signal_fence(static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_init(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp __val) _NOEXCEPT {
    __c11_atomic_init(&__a->__a_value, __val);
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_init(__cxx_atomic_base_impl<_Tp> * __a, _Tp __val) _NOEXCEPT {
    __c11_atomic_init(&__a->__a_value, __val);
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_store(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp __val, memory_order __order) _NOEXCEPT {
    __c11_atomic_store(&__a->__a_value, __val, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_store(__cxx_atomic_base_impl<_Tp> * __a, _Tp __val, memory_order __order) _NOEXCEPT {
    __c11_atomic_store(&__a->__a_value, __val, static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_load(__cxx_atomic_base_impl<_Tp> const volatile* __a, memory_order __order) _NOEXCEPT {
    using __ptr_type = typename remove_const<decltype(__a->__a_value)>::type*;
    return __c11_atomic_load(const_cast<__ptr_type>(&__a->__a_value), static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_load(__cxx_atomic_base_impl<_Tp> const* __a, memory_order __order) _NOEXCEPT {
    using __ptr_type = typename remove_const<decltype(__a->__a_value)>::type*;
    return __c11_atomic_load(const_cast<__ptr_type>(&__a->__a_value), static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_exchange(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp __value, memory_order __order) _NOEXCEPT {
    return __c11_atomic_exchange(&__a->__a_value, __value, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_exchange(__cxx_atomic_base_impl<_Tp> * __a, _Tp __value, memory_order __order) _NOEXCEPT {
    return __c11_atomic_exchange(&__a->__a_value, __value, static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_strong(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp* __expected, _Tp __value, memory_order __success, memory_order __failure) _NOEXCEPT {
    return __c11_atomic_compare_exchange_strong(&__a->__a_value, __expected, __value, static_cast<__memory_order_underlying_t>(__success), static_cast<__memory_order_underlying_t>(__failure));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_strong(__cxx_atomic_base_impl<_Tp> * __a, _Tp* __expected, _Tp __value, memory_order __success, memory_order __failure) _NOEXCEPT {
    return __c11_atomic_compare_exchange_strong(&__a->__a_value, __expected, __value, static_cast<__memory_order_underlying_t>(__success), static_cast<__memory_order_underlying_t>(__failure));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_weak(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp* __expected, _Tp __value, memory_order __success, memory_order __failure) _NOEXCEPT {
    return __c11_atomic_compare_exchange_weak(&__a->__a_value, __expected, __value, static_cast<__memory_order_underlying_t>(__success), static_cast<__memory_order_underlying_t>(__failure));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_weak(__cxx_atomic_base_impl<_Tp> * __a, _Tp* __expected, _Tp __value, memory_order __success, memory_order __failure) _NOEXCEPT {
    return __c11_atomic_compare_exchange_weak(&__a->__a_value, __expected, __value,  static_cast<__memory_order_underlying_t>(__success), static_cast<__memory_order_underlying_t>(__failure));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_add(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp __delta, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_add(&__a->__a_value, __delta, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_add(__cxx_atomic_base_impl<_Tp> * __a, _Tp __delta, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_add(&__a->__a_value, __delta, static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp* __cxx_atomic_fetch_add(__cxx_atomic_base_impl<_Tp*> volatile* __a, ptrdiff_t __delta, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_add(&__a->__a_value, __delta, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp* __cxx_atomic_fetch_add(__cxx_atomic_base_impl<_Tp*> * __a, ptrdiff_t __delta, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_add(&__a->__a_value, __delta, static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_sub(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp __delta, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_sub(&__a->__a_value, __delta, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_sub(__cxx_atomic_base_impl<_Tp> * __a, _Tp __delta, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_sub(&__a->__a_value, __delta, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp* __cxx_atomic_fetch_sub(__cxx_atomic_base_impl<_Tp*> volatile* __a, ptrdiff_t __delta, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_sub(&__a->__a_value, __delta, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp* __cxx_atomic_fetch_sub(__cxx_atomic_base_impl<_Tp*> * __a, ptrdiff_t __delta, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_sub(&__a->__a_value, __delta, static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_and(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp __pattern, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_and(&__a->__a_value, __pattern, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_and(__cxx_atomic_base_impl<_Tp> * __a, _Tp __pattern, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_and(&__a->__a_value, __pattern, static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_or(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp __pattern, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_or(&__a->__a_value, __pattern, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_or(__cxx_atomic_base_impl<_Tp> * __a, _Tp __pattern, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_or(&__a->__a_value, __pattern, static_cast<__memory_order_underlying_t>(__order));
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_xor(__cxx_atomic_base_impl<_Tp> volatile* __a, _Tp __pattern, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_xor(&__a->__a_value, __pattern, static_cast<__memory_order_underlying_t>(__order));
}
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_xor(__cxx_atomic_base_impl<_Tp> * __a, _Tp __pattern, memory_order __order) _NOEXCEPT {
    return __c11_atomic_fetch_xor(&__a->__a_value, __pattern, static_cast<__memory_order_underlying_t>(__order));
}

#endif // _LIBCPP_HAS_GCC_ATOMIC_IMP, _LIBCPP_HAS_C_ATOMIC_IMP
# 1083 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp kill_dependency(_Tp __y) _NOEXCEPT
{
    return __y;
}

#if 0 /* disabled by -frewrite-includes */
#if defined(__CLANG_ATOMIC_BOOL_LOCK_FREE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1092 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
# define ATOMIC_BOOL_LOCK_FREE      __CLANG_ATOMIC_BOOL_LOCK_FREE
# define ATOMIC_CHAR_LOCK_FREE      __CLANG_ATOMIC_CHAR_LOCK_FREE
# define ATOMIC_CHAR16_T_LOCK_FREE  __CLANG_ATOMIC_CHAR16_T_LOCK_FREE
# define ATOMIC_CHAR32_T_LOCK_FREE  __CLANG_ATOMIC_CHAR32_T_LOCK_FREE
# define ATOMIC_WCHAR_T_LOCK_FREE   __CLANG_ATOMIC_WCHAR_T_LOCK_FREE
# define ATOMIC_SHORT_LOCK_FREE     __CLANG_ATOMIC_SHORT_LOCK_FREE
# define ATOMIC_INT_LOCK_FREE       __CLANG_ATOMIC_INT_LOCK_FREE
# define ATOMIC_LONG_LOCK_FREE      __CLANG_ATOMIC_LONG_LOCK_FREE
# define ATOMIC_LLONG_LOCK_FREE     __CLANG_ATOMIC_LLONG_LOCK_FREE
# define ATOMIC_POINTER_LOCK_FREE   __CLANG_ATOMIC_POINTER_LOCK_FREE
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GCC_ATOMIC_BOOL_LOCK_FREE)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 1103 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
# define ATOMIC_BOOL_LOCK_FREE      __GCC_ATOMIC_BOOL_LOCK_FREE
# define ATOMIC_CHAR_LOCK_FREE      __GCC_ATOMIC_CHAR_LOCK_FREE
# define ATOMIC_CHAR16_T_LOCK_FREE  __GCC_ATOMIC_CHAR16_T_LOCK_FREE
# define ATOMIC_CHAR32_T_LOCK_FREE  __GCC_ATOMIC_CHAR32_T_LOCK_FREE
# define ATOMIC_WCHAR_T_LOCK_FREE   __GCC_ATOMIC_WCHAR_T_LOCK_FREE
# define ATOMIC_SHORT_LOCK_FREE     __GCC_ATOMIC_SHORT_LOCK_FREE
# define ATOMIC_INT_LOCK_FREE       __GCC_ATOMIC_INT_LOCK_FREE
# define ATOMIC_LONG_LOCK_FREE      __GCC_ATOMIC_LONG_LOCK_FREE
# define ATOMIC_LLONG_LOCK_FREE     __GCC_ATOMIC_LLONG_LOCK_FREE
# define ATOMIC_POINTER_LOCK_FREE   __GCC_ATOMIC_POINTER_LOCK_FREE
#endif
# 1114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

#ifdef _LIBCPP_ATOMIC_ONLY_USE_BUILTINS

template<typename _Tp>
struct __cxx_atomic_lock_impl {

  _LIBCPP_INLINE_VISIBILITY
  __cxx_atomic_lock_impl() _NOEXCEPT
    : __a_value(), __a_lock(0) {}
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR explicit
  __cxx_atomic_lock_impl(_Tp value) _NOEXCEPT
    : __a_value(value), __a_lock(0) {}

  _Tp __a_value;
  mutable __cxx_atomic_base_impl<_LIBCPP_ATOMIC_FLAG_TYPE> __a_lock;

  _LIBCPP_INLINE_VISIBILITY void __lock() const volatile {
    while(1 == __cxx_atomic_exchange(&__a_lock, _LIBCPP_ATOMIC_FLAG_TYPE(true), memory_order_acquire))
        /*spin*/;
  }
  _LIBCPP_INLINE_VISIBILITY void __lock() const {
    while(1 == __cxx_atomic_exchange(&__a_lock, _LIBCPP_ATOMIC_FLAG_TYPE(true), memory_order_acquire))
        /*spin*/;
  }
  _LIBCPP_INLINE_VISIBILITY void __unlock() const volatile {
    __cxx_atomic_store(&__a_lock, _LIBCPP_ATOMIC_FLAG_TYPE(false), memory_order_release);
  }
  _LIBCPP_INLINE_VISIBILITY void __unlock() const {
    __cxx_atomic_store(&__a_lock, _LIBCPP_ATOMIC_FLAG_TYPE(false), memory_order_release);
  }
  _LIBCPP_INLINE_VISIBILITY _Tp __read() const volatile {
    __lock();
    _Tp __old;
    __cxx_atomic_assign_volatile(__old, __a_value);
    __unlock();
    return __old;
  }
  _LIBCPP_INLINE_VISIBILITY _Tp __read() const {
    __lock();
    _Tp __old = __a_value;
    __unlock();
    return __old;
  }
};

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_init(volatile __cxx_atomic_lock_impl<_Tp>* __a,  _Tp __val) {
  __cxx_atomic_assign_volatile(__a->__a_value, __val);
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_init(__cxx_atomic_lock_impl<_Tp>* __a,  _Tp __val) {
  __a->__a_value = __val;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_store(volatile __cxx_atomic_lock_impl<_Tp>* __a,  _Tp __val, memory_order) {
  __a->__lock();
  __cxx_atomic_assign_volatile(__a->__a_value, __val);
  __a->__unlock();
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
void __cxx_atomic_store(__cxx_atomic_lock_impl<_Tp>* __a,  _Tp __val, memory_order) {
  __a->__lock();
  __a->__a_value = __val;
  __a->__unlock();
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_load(const volatile __cxx_atomic_lock_impl<_Tp>* __a, memory_order) {
  return __a->__read();
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_load(const __cxx_atomic_lock_impl<_Tp>* __a, memory_order) {
  return __a->__read();
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_exchange(volatile __cxx_atomic_lock_impl<_Tp>* __a, _Tp __value, memory_order) {
  __a->__lock();
  _Tp __old;
  __cxx_atomic_assign_volatile(__old, __a->__a_value);
  __cxx_atomic_assign_volatile(__a->__a_value, __value);
  __a->__unlock();
  return __old;
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_exchange(__cxx_atomic_lock_impl<_Tp>* __a, _Tp __value, memory_order) {
  __a->__lock();
  _Tp __old = __a->__a_value;
  __a->__a_value = __value;
  __a->__unlock();
  return __old;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_strong(volatile __cxx_atomic_lock_impl<_Tp>* __a,
                                          _Tp* __expected, _Tp __value, memory_order, memory_order) {
  __a->__lock();
  _Tp temp;
  __cxx_atomic_assign_volatile(temp, __a->__a_value);
  bool __ret = temp == *__expected;
  if(__ret)
    __cxx_atomic_assign_volatile(__a->__a_value, __value);
  else
    __cxx_atomic_assign_volatile(*__expected, __a->__a_value);
  __a->__unlock();
  return __ret;
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_strong(__cxx_atomic_lock_impl<_Tp>* __a,
                                          _Tp* __expected, _Tp __value, memory_order, memory_order) {
  __a->__lock();
  bool __ret = __a->__a_value == *__expected;
  if(__ret)
    __a->__a_value = __value;
  else
    *__expected = __a->__a_value;
  __a->__unlock();
  return __ret;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_weak(volatile __cxx_atomic_lock_impl<_Tp>* __a,
                                        _Tp* __expected, _Tp __value, memory_order, memory_order) {
  __a->__lock();
  _Tp temp;
  __cxx_atomic_assign_volatile(temp, __a->__a_value);
  bool __ret = temp == *__expected;
  if(__ret)
    __cxx_atomic_assign_volatile(__a->__a_value, __value);
  else
    __cxx_atomic_assign_volatile(*__expected, __a->__a_value);
  __a->__unlock();
  return __ret;
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
bool __cxx_atomic_compare_exchange_weak(__cxx_atomic_lock_impl<_Tp>* __a,
                                        _Tp* __expected, _Tp __value, memory_order, memory_order) {
  __a->__lock();
  bool __ret = __a->__a_value == *__expected;
  if(__ret)
    __a->__a_value = __value;
  else
    *__expected = __a->__a_value;
  __a->__unlock();
  return __ret;
}

template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_add(volatile __cxx_atomic_lock_impl<_Tp>* __a,
                           _Td __delta, memory_order) {
  __a->__lock();
  _Tp __old;
  __cxx_atomic_assign_volatile(__old, __a->__a_value);
  __cxx_atomic_assign_volatile(__a->__a_value, _Tp(__old + __delta));
  __a->__unlock();
  return __old;
}
template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_add(__cxx_atomic_lock_impl<_Tp>* __a,
                           _Td __delta, memory_order) {
  __a->__lock();
  _Tp __old = __a->__a_value;
  __a->__a_value += __delta;
  __a->__unlock();
  return __old;
}

template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp* __cxx_atomic_fetch_add(volatile __cxx_atomic_lock_impl<_Tp*>* __a,
                           ptrdiff_t __delta, memory_order) {
  __a->__lock();
  _Tp* __old;
  __cxx_atomic_assign_volatile(__old, __a->__a_value);
  __cxx_atomic_assign_volatile(__a->__a_value, __old + __delta);
  __a->__unlock();
  return __old;
}
template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp* __cxx_atomic_fetch_add(__cxx_atomic_lock_impl<_Tp*>* __a,
                           ptrdiff_t __delta, memory_order) {
  __a->__lock();
  _Tp* __old = __a->__a_value;
  __a->__a_value += __delta;
  __a->__unlock();
  return __old;
}

template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_sub(volatile __cxx_atomic_lock_impl<_Tp>* __a,
                           _Td __delta, memory_order) {
  __a->__lock();
  _Tp __old;
  __cxx_atomic_assign_volatile(__old, __a->__a_value);
  __cxx_atomic_assign_volatile(__a->__a_value, _Tp(__old - __delta));
  __a->__unlock();
  return __old;
}
template <typename _Tp, typename _Td>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_sub(__cxx_atomic_lock_impl<_Tp>* __a,
                           _Td __delta, memory_order) {
  __a->__lock();
  _Tp __old = __a->__a_value;
  __a->__a_value -= __delta;
  __a->__unlock();
  return __old;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_and(volatile __cxx_atomic_lock_impl<_Tp>* __a,
                           _Tp __pattern, memory_order) {
  __a->__lock();
  _Tp __old;
  __cxx_atomic_assign_volatile(__old, __a->__a_value);
  __cxx_atomic_assign_volatile(__a->__a_value, _Tp(__old & __pattern));
  __a->__unlock();
  return __old;
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_and(__cxx_atomic_lock_impl<_Tp>* __a,
                           _Tp __pattern, memory_order) {
  __a->__lock();
  _Tp __old = __a->__a_value;
  __a->__a_value &= __pattern;
  __a->__unlock();
  return __old;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_or(volatile __cxx_atomic_lock_impl<_Tp>* __a,
                          _Tp __pattern, memory_order) {
  __a->__lock();
  _Tp __old;
  __cxx_atomic_assign_volatile(__old, __a->__a_value);
  __cxx_atomic_assign_volatile(__a->__a_value, _Tp(__old | __pattern));
  __a->__unlock();
  return __old;
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_or(__cxx_atomic_lock_impl<_Tp>* __a,
                          _Tp __pattern, memory_order) {
  __a->__lock();
  _Tp __old = __a->__a_value;
  __a->__a_value |= __pattern;
  __a->__unlock();
  return __old;
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_xor(volatile __cxx_atomic_lock_impl<_Tp>* __a,
                           _Tp __pattern, memory_order) {
  __a->__lock();
  _Tp __old;
  __cxx_atomic_assign_volatile(__old, __a->__a_value);
  __cxx_atomic_assign_volatile(__a->__a_value, _Tp(__old ^ __pattern));
  __a->__unlock();
  return __old;
}
template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp __cxx_atomic_fetch_xor(__cxx_atomic_lock_impl<_Tp>* __a,
                           _Tp __pattern, memory_order) {
  __a->__lock();
  _Tp __old = __a->__a_value;
  __a->__a_value ^= __pattern;
  __a->__unlock();
  return __old;
}

#ifdef __cpp_lib_atomic_is_always_lock_free

template<typename _Tp> struct __cxx_is_always_lock_free {
    enum { __value = __atomic_always_lock_free(sizeof(_Tp), 0) }; };

#else
# 1412 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

template<typename _Tp> struct __cxx_is_always_lock_free { enum { __value = false }; };
// Implementations must match the C ATOMIC_*_LOCK_FREE macro values.
template<> struct __cxx_is_always_lock_free<bool> { enum { __value = 2 == ATOMIC_BOOL_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<char> { enum { __value = 2 == ATOMIC_CHAR_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<signed char> { enum { __value = 2 == ATOMIC_CHAR_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<unsigned char> { enum { __value = 2 == ATOMIC_CHAR_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<char16_t> { enum { __value = 2 == ATOMIC_CHAR16_T_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<char32_t> { enum { __value = 2 == ATOMIC_CHAR32_T_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<wchar_t> { enum { __value = 2 == ATOMIC_WCHAR_T_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<short> { enum { __value = 2 == ATOMIC_SHORT_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<unsigned short> { enum { __value = 2 == ATOMIC_SHORT_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<int> { enum { __value = 2 == ATOMIC_INT_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<unsigned int> { enum { __value = 2 == ATOMIC_INT_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<long> { enum { __value = 2 == ATOMIC_LONG_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<unsigned long> { enum { __value = 2 == ATOMIC_LONG_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<long long> { enum { __value = 2 == ATOMIC_LLONG_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<unsigned long long> { enum { __value = 2 == ATOMIC_LLONG_LOCK_FREE }; };
template<typename _Tp> struct __cxx_is_always_lock_free<_Tp*> { enum { __value = 2 == ATOMIC_POINTER_LOCK_FREE }; };
template<> struct __cxx_is_always_lock_free<std::nullptr_t> { enum { __value = 2 == ATOMIC_POINTER_LOCK_FREE }; };

#endif //__cpp_lib_atomic_is_always_lock_free
# 1434 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

template <typename _Tp,
          typename _Base = typename conditional<__cxx_is_always_lock_free<_Tp>::__value,
                                                __cxx_atomic_base_impl<_Tp>,
                                                __cxx_atomic_lock_impl<_Tp> >::type>
#else
# 1440 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
template <typename _Tp,
          typename _Base = __cxx_atomic_base_impl<_Tp> >
#endif //_LIBCPP_ATOMIC_ONLY_USE_BUILTINS
# 1443 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
struct __cxx_atomic_impl : public _Base {

#if 0 /* disabled by -frewrite-includes */
#if _GNUC_VER >= 501
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1446 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
    static_assert(is_trivially_copyable<_Tp>::value,
      "std::atomic<Tp> requires that 'Tp' be a trivially copyable type");
#endif
# 1449 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

  _LIBCPP_INLINE_VISIBILITY __cxx_atomic_impl() _NOEXCEPT _LIBCPP_DEFAULT
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR explicit __cxx_atomic_impl(_Tp value) _NOEXCEPT
    : _Base(value) {}
};

// general atomic<T>

template <class _Tp, bool = is_integral<_Tp>::value && !is_same<_Tp, bool>::value>
struct __atomic_base  // false
{
    mutable __cxx_atomic_impl<_Tp> __a_;

#if 0 /* disabled by -frewrite-includes */
#if defined(__cpp_lib_atomic_is_always_lock_free)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1463 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
  static _LIBCPP_CONSTEXPR bool is_always_lock_free = __atomic_always_lock_free(sizeof(__a_), 0);
#endif
# 1465 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

    _LIBCPP_INLINE_VISIBILITY
    bool is_lock_free() const volatile _NOEXCEPT
        {return __cxx_atomic_is_lock_free(sizeof(_Tp));}
    _LIBCPP_INLINE_VISIBILITY
    bool is_lock_free() const _NOEXCEPT
        {return static_cast<__atomic_base const volatile*>(this)->is_lock_free();}
    _LIBCPP_INLINE_VISIBILITY
    void store(_Tp __d, memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
      _LIBCPP_CHECK_STORE_MEMORY_ORDER(__m)
        {__cxx_atomic_store(&__a_, __d, __m);}
    _LIBCPP_INLINE_VISIBILITY
    void store(_Tp __d, memory_order __m = memory_order_seq_cst) _NOEXCEPT
      _LIBCPP_CHECK_STORE_MEMORY_ORDER(__m)
        {__cxx_atomic_store(&__a_, __d, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp load(memory_order __m = memory_order_seq_cst) const volatile _NOEXCEPT
      _LIBCPP_CHECK_LOAD_MEMORY_ORDER(__m)
        {return __cxx_atomic_load(&__a_, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp load(memory_order __m = memory_order_seq_cst) const _NOEXCEPT
      _LIBCPP_CHECK_LOAD_MEMORY_ORDER(__m)
        {return __cxx_atomic_load(&__a_, __m);}
    _LIBCPP_INLINE_VISIBILITY
    operator _Tp() const volatile _NOEXCEPT {return load();}
    _LIBCPP_INLINE_VISIBILITY
    operator _Tp() const _NOEXCEPT          {return load();}
    _LIBCPP_INLINE_VISIBILITY
    _Tp exchange(_Tp __d, memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_exchange(&__a_, __d, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp exchange(_Tp __d, memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_exchange(&__a_, __d, __m);}
    _LIBCPP_INLINE_VISIBILITY
    bool compare_exchange_weak(_Tp& __e, _Tp __d,
                               memory_order __s, memory_order __f) volatile _NOEXCEPT
      _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__s, __f)
        {return __cxx_atomic_compare_exchange_weak(&__a_, &__e, __d, __s, __f);}
    _LIBCPP_INLINE_VISIBILITY
    bool compare_exchange_weak(_Tp& __e, _Tp __d,
                               memory_order __s, memory_order __f) _NOEXCEPT
      _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__s, __f)
        {return __cxx_atomic_compare_exchange_weak(&__a_, &__e, __d, __s, __f);}
    _LIBCPP_INLINE_VISIBILITY
    bool compare_exchange_strong(_Tp& __e, _Tp __d,
                                 memory_order __s, memory_order __f) volatile _NOEXCEPT
      _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__s, __f)
        {return __cxx_atomic_compare_exchange_strong(&__a_, &__e, __d, __s, __f);}
    _LIBCPP_INLINE_VISIBILITY
    bool compare_exchange_strong(_Tp& __e, _Tp __d,
                                 memory_order __s, memory_order __f) _NOEXCEPT
      _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__s, __f)
        {return __cxx_atomic_compare_exchange_strong(&__a_, &__e, __d, __s, __f);}
    _LIBCPP_INLINE_VISIBILITY
    bool compare_exchange_weak(_Tp& __e, _Tp __d,
                              memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_compare_exchange_weak(&__a_, &__e, __d, __m, __m);}
    _LIBCPP_INLINE_VISIBILITY
    bool compare_exchange_weak(_Tp& __e, _Tp __d,
                               memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_compare_exchange_weak(&__a_, &__e, __d, __m, __m);}
    _LIBCPP_INLINE_VISIBILITY
    bool compare_exchange_strong(_Tp& __e, _Tp __d,
                              memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_compare_exchange_strong(&__a_, &__e, __d, __m, __m);}
    _LIBCPP_INLINE_VISIBILITY
    bool compare_exchange_strong(_Tp& __e, _Tp __d,
                                 memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_compare_exchange_strong(&__a_, &__e, __d, __m, __m);}

    _LIBCPP_INLINE_VISIBILITY
    __atomic_base() _NOEXCEPT _LIBCPP_DEFAULT

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    __atomic_base(_Tp __d) _NOEXCEPT : __a_(__d) {}

#ifndef _LIBCPP_CXX03_LANG
    __atomic_base(const __atomic_base&) = delete;
    __atomic_base& operator=(const __atomic_base&) = delete;
    __atomic_base& operator=(const __atomic_base&) volatile = delete;
#else
# 1546 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
private:
    __atomic_base(const __atomic_base&);
    __atomic_base& operator=(const __atomic_base&);
    __atomic_base& operator=(const __atomic_base&) volatile;
#endif
# 1551 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
};

#if 0 /* disabled by -frewrite-includes */
#if defined(__cpp_lib_atomic_is_always_lock_free)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1554 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
template <class _Tp, bool __b>
_LIBCPP_CONSTEXPR bool __atomic_base<_Tp, __b>::is_always_lock_free;
#endif
# 1557 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3

// atomic<Integral>

template <class _Tp>
struct __atomic_base<_Tp, true>
    : public __atomic_base<_Tp, false>
{
    typedef __atomic_base<_Tp, false> __base;
    _LIBCPP_INLINE_VISIBILITY
    __atomic_base() _NOEXCEPT _LIBCPP_DEFAULT
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR __atomic_base(_Tp __d) _NOEXCEPT : __base(__d) {}

    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_add(_Tp __op, memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_fetch_add(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_add(_Tp __op, memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_fetch_add(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_sub(_Tp __op, memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_fetch_sub(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_sub(_Tp __op, memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_fetch_sub(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_and(_Tp __op, memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_fetch_and(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_and(_Tp __op, memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_fetch_and(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_or(_Tp __op, memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_fetch_or(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_or(_Tp __op, memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_fetch_or(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_xor(_Tp __op, memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_fetch_xor(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp fetch_xor(_Tp __op, memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_fetch_xor(&this->__a_, __op, __m);}

    _LIBCPP_INLINE_VISIBILITY
    _Tp operator++(int) volatile _NOEXCEPT      {return fetch_add(_Tp(1));}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator++(int) _NOEXCEPT               {return fetch_add(_Tp(1));}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator--(int) volatile _NOEXCEPT      {return fetch_sub(_Tp(1));}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator--(int) _NOEXCEPT               {return fetch_sub(_Tp(1));}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator++() volatile _NOEXCEPT         {return fetch_add(_Tp(1)) + _Tp(1);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator++() _NOEXCEPT                  {return fetch_add(_Tp(1)) + _Tp(1);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator--() volatile _NOEXCEPT         {return fetch_sub(_Tp(1)) - _Tp(1);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator--() _NOEXCEPT                  {return fetch_sub(_Tp(1)) - _Tp(1);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator+=(_Tp __op) volatile _NOEXCEPT {return fetch_add(__op) + __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator+=(_Tp __op) _NOEXCEPT          {return fetch_add(__op) + __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator-=(_Tp __op) volatile _NOEXCEPT {return fetch_sub(__op) - __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator-=(_Tp __op) _NOEXCEPT          {return fetch_sub(__op) - __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator&=(_Tp __op) volatile _NOEXCEPT {return fetch_and(__op) & __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator&=(_Tp __op) _NOEXCEPT          {return fetch_and(__op) & __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator|=(_Tp __op) volatile _NOEXCEPT {return fetch_or(__op) | __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator|=(_Tp __op) _NOEXCEPT          {return fetch_or(__op) | __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator^=(_Tp __op) volatile _NOEXCEPT {return fetch_xor(__op) ^ __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator^=(_Tp __op) _NOEXCEPT          {return fetch_xor(__op) ^ __op;}
};

// atomic<T>

template <class _Tp>
struct atomic
    : public __atomic_base<_Tp>
{
    typedef __atomic_base<_Tp> __base;
    _LIBCPP_INLINE_VISIBILITY
    atomic() _NOEXCEPT _LIBCPP_DEFAULT
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR atomic(_Tp __d) _NOEXCEPT : __base(__d) {}

    _LIBCPP_INLINE_VISIBILITY
    _Tp operator=(_Tp __d) volatile _NOEXCEPT
        {__base::store(__d); return __d;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp operator=(_Tp __d) _NOEXCEPT
        {__base::store(__d); return __d;}
};

// atomic<T*>

template <class _Tp>
struct atomic<_Tp*>
    : public __atomic_base<_Tp*>
{
    typedef __atomic_base<_Tp*> __base;
    _LIBCPP_INLINE_VISIBILITY
    atomic() _NOEXCEPT _LIBCPP_DEFAULT
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR atomic(_Tp* __d) _NOEXCEPT : __base(__d) {}

    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator=(_Tp* __d) volatile _NOEXCEPT
        {__base::store(__d); return __d;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator=(_Tp* __d) _NOEXCEPT
        {__base::store(__d); return __d;}

    _LIBCPP_INLINE_VISIBILITY
    _Tp* fetch_add(ptrdiff_t __op, memory_order __m = memory_order_seq_cst)
                                                                        volatile _NOEXCEPT
        {return __cxx_atomic_fetch_add(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* fetch_add(ptrdiff_t __op, memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_fetch_add(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* fetch_sub(ptrdiff_t __op, memory_order __m = memory_order_seq_cst)
                                                                        volatile _NOEXCEPT
        {return __cxx_atomic_fetch_sub(&this->__a_, __op, __m);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* fetch_sub(ptrdiff_t __op, memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_fetch_sub(&this->__a_, __op, __m);}

    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator++(int) volatile _NOEXCEPT            {return fetch_add(1);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator++(int) _NOEXCEPT                     {return fetch_add(1);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator--(int) volatile _NOEXCEPT            {return fetch_sub(1);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator--(int) _NOEXCEPT                     {return fetch_sub(1);}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator++() volatile _NOEXCEPT               {return fetch_add(1) + 1;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator++() _NOEXCEPT                        {return fetch_add(1) + 1;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator--() volatile _NOEXCEPT               {return fetch_sub(1) - 1;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator--() _NOEXCEPT                        {return fetch_sub(1) - 1;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator+=(ptrdiff_t __op) volatile _NOEXCEPT {return fetch_add(__op) + __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator+=(ptrdiff_t __op) _NOEXCEPT          {return fetch_add(__op) + __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator-=(ptrdiff_t __op) volatile _NOEXCEPT {return fetch_sub(__op) - __op;}
    _LIBCPP_INLINE_VISIBILITY
    _Tp* operator-=(ptrdiff_t __op) _NOEXCEPT          {return fetch_sub(__op) - __op;}
};

// atomic_is_lock_free

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_is_lock_free(const volatile atomic<_Tp>* __o) _NOEXCEPT
{
    return __o->is_lock_free();
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_is_lock_free(const atomic<_Tp>* __o) _NOEXCEPT
{
    return __o->is_lock_free();
}

// atomic_init

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
void
atomic_init(volatile atomic<_Tp>* __o, _Tp __d) _NOEXCEPT
{
    __cxx_atomic_init(&__o->__a_, __d);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
void
atomic_init(atomic<_Tp>* __o, _Tp __d) _NOEXCEPT
{
    __cxx_atomic_init(&__o->__a_, __d);
}

// atomic_store

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
void
atomic_store(volatile atomic<_Tp>* __o, _Tp __d) _NOEXCEPT
{
    __o->store(__d);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
void
atomic_store(atomic<_Tp>* __o, _Tp __d) _NOEXCEPT
{
    __o->store(__d);
}

// atomic_store_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
void
atomic_store_explicit(volatile atomic<_Tp>* __o, _Tp __d, memory_order __m) _NOEXCEPT
  _LIBCPP_CHECK_STORE_MEMORY_ORDER(__m)
{
    __o->store(__d, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
void
atomic_store_explicit(atomic<_Tp>* __o, _Tp __d, memory_order __m) _NOEXCEPT
  _LIBCPP_CHECK_STORE_MEMORY_ORDER(__m)
{
    __o->store(__d, __m);
}

// atomic_load

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp
atomic_load(const volatile atomic<_Tp>* __o) _NOEXCEPT
{
    return __o->load();
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp
atomic_load(const atomic<_Tp>* __o) _NOEXCEPT
{
    return __o->load();
}

// atomic_load_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp
atomic_load_explicit(const volatile atomic<_Tp>* __o, memory_order __m) _NOEXCEPT
  _LIBCPP_CHECK_LOAD_MEMORY_ORDER(__m)
{
    return __o->load(__m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp
atomic_load_explicit(const atomic<_Tp>* __o, memory_order __m) _NOEXCEPT
  _LIBCPP_CHECK_LOAD_MEMORY_ORDER(__m)
{
    return __o->load(__m);
}

// atomic_exchange

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp
atomic_exchange(volatile atomic<_Tp>* __o, _Tp __d) _NOEXCEPT
{
    return __o->exchange(__d);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp
atomic_exchange(atomic<_Tp>* __o, _Tp __d) _NOEXCEPT
{
    return __o->exchange(__d);
}

// atomic_exchange_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp
atomic_exchange_explicit(volatile atomic<_Tp>* __o, _Tp __d, memory_order __m) _NOEXCEPT
{
    return __o->exchange(__d, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp
atomic_exchange_explicit(atomic<_Tp>* __o, _Tp __d, memory_order __m) _NOEXCEPT
{
    return __o->exchange(__d, __m);
}

// atomic_compare_exchange_weak

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_weak(volatile atomic<_Tp>* __o, _Tp* __e, _Tp __d) _NOEXCEPT
{
    return __o->compare_exchange_weak(*__e, __d);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_weak(atomic<_Tp>* __o, _Tp* __e, _Tp __d) _NOEXCEPT
{
    return __o->compare_exchange_weak(*__e, __d);
}

// atomic_compare_exchange_strong

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_strong(volatile atomic<_Tp>* __o, _Tp* __e, _Tp __d) _NOEXCEPT
{
    return __o->compare_exchange_strong(*__e, __d);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_strong(atomic<_Tp>* __o, _Tp* __e, _Tp __d) _NOEXCEPT
{
    return __o->compare_exchange_strong(*__e, __d);
}

// atomic_compare_exchange_weak_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_weak_explicit(volatile atomic<_Tp>* __o, _Tp* __e,
                                      _Tp __d,
                                      memory_order __s, memory_order __f) _NOEXCEPT
  _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__s, __f)
{
    return __o->compare_exchange_weak(*__e, __d, __s, __f);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_weak_explicit(atomic<_Tp>* __o, _Tp* __e, _Tp __d,
                                      memory_order __s, memory_order __f) _NOEXCEPT
  _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__s, __f)
{
    return __o->compare_exchange_weak(*__e, __d, __s, __f);
}

// atomic_compare_exchange_strong_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_strong_explicit(volatile atomic<_Tp>* __o,
                                        _Tp* __e, _Tp __d,
                                        memory_order __s, memory_order __f) _NOEXCEPT
  _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__s, __f)
{
    return __o->compare_exchange_strong(*__e, __d, __s, __f);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_strong_explicit(atomic<_Tp>* __o, _Tp* __e,
                                        _Tp __d,
                                        memory_order __s, memory_order __f) _NOEXCEPT
  _LIBCPP_CHECK_EXCHANGE_MEMORY_ORDER(__s, __f)
{
    return __o->compare_exchange_strong(*__e, __d, __s, __f);
}

// atomic_fetch_add

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_add(volatile atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_add(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_add(atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_add(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp*
atomic_fetch_add(volatile atomic<_Tp*>* __o, ptrdiff_t __op) _NOEXCEPT
{
    return __o->fetch_add(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp*
atomic_fetch_add(atomic<_Tp*>* __o, ptrdiff_t __op) _NOEXCEPT
{
    return __o->fetch_add(__op);
}

// atomic_fetch_add_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_add_explicit(volatile atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_add(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_add_explicit(atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_add(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp*
atomic_fetch_add_explicit(volatile atomic<_Tp*>* __o, ptrdiff_t __op,
                          memory_order __m) _NOEXCEPT
{
    return __o->fetch_add(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp*
atomic_fetch_add_explicit(atomic<_Tp*>* __o, ptrdiff_t __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_add(__op, __m);
}

// atomic_fetch_sub

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_sub(volatile atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_sub(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_sub(atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_sub(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp*
atomic_fetch_sub(volatile atomic<_Tp*>* __o, ptrdiff_t __op) _NOEXCEPT
{
    return __o->fetch_sub(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp*
atomic_fetch_sub(atomic<_Tp*>* __o, ptrdiff_t __op) _NOEXCEPT
{
    return __o->fetch_sub(__op);
}

// atomic_fetch_sub_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_sub_explicit(volatile atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_sub(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_sub_explicit(atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_sub(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp*
atomic_fetch_sub_explicit(volatile atomic<_Tp*>* __o, ptrdiff_t __op,
                          memory_order __m) _NOEXCEPT
{
    return __o->fetch_sub(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
_Tp*
atomic_fetch_sub_explicit(atomic<_Tp*>* __o, ptrdiff_t __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_sub(__op, __m);
}

// atomic_fetch_and

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_and(volatile atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_and(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_and(atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_and(__op);
}

// atomic_fetch_and_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_and_explicit(volatile atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_and(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_and_explicit(atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_and(__op, __m);
}

// atomic_fetch_or

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_or(volatile atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_or(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_or(atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_or(__op);
}

// atomic_fetch_or_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_or_explicit(volatile atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_or(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_or_explicit(atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_or(__op, __m);
}

// atomic_fetch_xor

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_xor(volatile atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_xor(__op);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_xor(atomic<_Tp>* __o, _Tp __op) _NOEXCEPT
{
    return __o->fetch_xor(__op);
}

// atomic_fetch_xor_explicit

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_xor_explicit(volatile atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_xor(__op, __m);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && !is_same<_Tp, bool>::value,
    _Tp
>::type
atomic_fetch_xor_explicit(atomic<_Tp>* __o, _Tp __op, memory_order __m) _NOEXCEPT
{
    return __o->fetch_xor(__op, __m);
}

// flag type and operations

typedef struct atomic_flag
{
    __cxx_atomic_impl<_LIBCPP_ATOMIC_FLAG_TYPE> __a_;

    _LIBCPP_INLINE_VISIBILITY
    bool test_and_set(memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {return __cxx_atomic_exchange(&__a_, _LIBCPP_ATOMIC_FLAG_TYPE(true), __m);}
    _LIBCPP_INLINE_VISIBILITY
    bool test_and_set(memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {return __cxx_atomic_exchange(&__a_, _LIBCPP_ATOMIC_FLAG_TYPE(true), __m);}
    _LIBCPP_INLINE_VISIBILITY
    void clear(memory_order __m = memory_order_seq_cst) volatile _NOEXCEPT
        {__cxx_atomic_store(&__a_, _LIBCPP_ATOMIC_FLAG_TYPE(false), __m);}
    _LIBCPP_INLINE_VISIBILITY
    void clear(memory_order __m = memory_order_seq_cst) _NOEXCEPT
        {__cxx_atomic_store(&__a_, _LIBCPP_ATOMIC_FLAG_TYPE(false), __m);}

    _LIBCPP_INLINE_VISIBILITY
    atomic_flag() _NOEXCEPT _LIBCPP_DEFAULT

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    atomic_flag(bool __b) _NOEXCEPT : __a_(__b) {} // EXTENSION

#ifndef _LIBCPP_CXX03_LANG
    atomic_flag(const atomic_flag&) = delete;
    atomic_flag& operator=(const atomic_flag&) = delete;
    atomic_flag& operator=(const atomic_flag&) volatile = delete;
#else
# 2306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
private:
    atomic_flag(const atomic_flag&);
    atomic_flag& operator=(const atomic_flag&);
    atomic_flag& operator=(const atomic_flag&) volatile;
#endif
# 2311 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
} atomic_flag;

inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_flag_test_and_set(volatile atomic_flag* __o) _NOEXCEPT
{
    return __o->test_and_set();
}

inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_flag_test_and_set(atomic_flag* __o) _NOEXCEPT
{
    return __o->test_and_set();
}

inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_flag_test_and_set_explicit(volatile atomic_flag* __o, memory_order __m) _NOEXCEPT
{
    return __o->test_and_set(__m);
}

inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_flag_test_and_set_explicit(atomic_flag* __o, memory_order __m) _NOEXCEPT
{
    return __o->test_and_set(__m);
}

inline _LIBCPP_INLINE_VISIBILITY
void
atomic_flag_clear(volatile atomic_flag* __o) _NOEXCEPT
{
    __o->clear();
}

inline _LIBCPP_INLINE_VISIBILITY
void
atomic_flag_clear(atomic_flag* __o) _NOEXCEPT
{
    __o->clear();
}

inline _LIBCPP_INLINE_VISIBILITY
void
atomic_flag_clear_explicit(volatile atomic_flag* __o, memory_order __m) _NOEXCEPT
{
    __o->clear(__m);
}

inline _LIBCPP_INLINE_VISIBILITY
void
atomic_flag_clear_explicit(atomic_flag* __o, memory_order __m) _NOEXCEPT
{
    __o->clear(__m);
}

// fences

inline _LIBCPP_INLINE_VISIBILITY
void
atomic_thread_fence(memory_order __m) _NOEXCEPT
{
    __cxx_atomic_thread_fence(__m);
}

inline _LIBCPP_INLINE_VISIBILITY
void
atomic_signal_fence(memory_order __m) _NOEXCEPT
{
    __cxx_atomic_signal_fence(__m);
}

// Atomics for standard typedef types

typedef atomic<bool>               atomic_bool;
typedef atomic<char>               atomic_char;
typedef atomic<signed char>        atomic_schar;
typedef atomic<unsigned char>      atomic_uchar;
typedef atomic<short>              atomic_short;
typedef atomic<unsigned short>     atomic_ushort;
typedef atomic<int>                atomic_int;
typedef atomic<unsigned int>       atomic_uint;
typedef atomic<long>               atomic_long;
typedef atomic<unsigned long>      atomic_ulong;
typedef atomic<long long>          atomic_llong;
typedef atomic<unsigned long long> atomic_ullong;
typedef atomic<char16_t>           atomic_char16_t;
typedef atomic<char32_t>           atomic_char32_t;
typedef atomic<wchar_t>            atomic_wchar_t;

typedef atomic<int_least8_t>   atomic_int_least8_t;
typedef atomic<uint_least8_t>  atomic_uint_least8_t;
typedef atomic<int_least16_t>  atomic_int_least16_t;
typedef atomic<uint_least16_t> atomic_uint_least16_t;
typedef atomic<int_least32_t>  atomic_int_least32_t;
typedef atomic<uint_least32_t> atomic_uint_least32_t;
typedef atomic<int_least64_t>  atomic_int_least64_t;
typedef atomic<uint_least64_t> atomic_uint_least64_t;

typedef atomic<int_fast8_t>   atomic_int_fast8_t;
typedef atomic<uint_fast8_t>  atomic_uint_fast8_t;
typedef atomic<int_fast16_t>  atomic_int_fast16_t;
typedef atomic<uint_fast16_t> atomic_uint_fast16_t;
typedef atomic<int_fast32_t>  atomic_int_fast32_t;
typedef atomic<uint_fast32_t> atomic_uint_fast32_t;
typedef atomic<int_fast64_t>  atomic_int_fast64_t;
typedef atomic<uint_fast64_t> atomic_uint_fast64_t;

typedef atomic< int8_t>  atomic_int8_t;
typedef atomic<uint8_t>  atomic_uint8_t;
typedef atomic< int16_t> atomic_int16_t;
typedef atomic<uint16_t> atomic_uint16_t;
typedef atomic< int32_t> atomic_int32_t;
typedef atomic<uint32_t> atomic_uint32_t;
typedef atomic< int64_t> atomic_int64_t;
typedef atomic<uint64_t> atomic_uint64_t;

typedef atomic<intptr_t>  atomic_intptr_t;
typedef atomic<uintptr_t> atomic_uintptr_t;
typedef atomic<size_t>    atomic_size_t;
typedef atomic<ptrdiff_t> atomic_ptrdiff_t;
typedef atomic<intmax_t>  atomic_intmax_t;
typedef atomic<uintmax_t> atomic_uintmax_t;

#define ATOMIC_FLAG_INIT {false}
#define ATOMIC_VAR_INIT(__v) {__v}

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_ATOMIC
# 2443 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/atomic" 3
# 667 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 2 3
#endif
# 668 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 668 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 669 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 671 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 672 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#endif
# 673 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 675 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 676 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

template <class _ValueType>
inline _LIBCPP_INLINE_VISIBILITY
_ValueType __libcpp_relaxed_load(_ValueType const* __value) {
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_THREADS) && \
    defined(__ATOMIC_RELAXED) &&        \
    (__has_builtin(__atomic_load_n) || defined(_LIBCPP_COMPILER_GCC))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 686 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __atomic_load_n(__value, __ATOMIC_RELAXED);
#else
# 688 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return *__value;
#endif
# 690 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template <class _ValueType>
inline _LIBCPP_INLINE_VISIBILITY
_ValueType __libcpp_acquire_load(_ValueType const* __value) {
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_THREADS) && \
    defined(__ATOMIC_ACQUIRE) &&        \
    (__has_builtin(__atomic_load_n) || defined(_LIBCPP_COMPILER_GCC))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 698 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __atomic_load_n(__value, __ATOMIC_ACQUIRE);
#else
# 700 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return *__value;
#endif
# 702 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

// addressof moved to <type_traits>

template <class _Tp> class allocator;

template <>
class _LIBCPP_TEMPLATE_VIS allocator<void>
{
public:
    typedef void*             pointer;
    typedef const void*       const_pointer;
    typedef void              value_type;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};
};

template <>
class _LIBCPP_TEMPLATE_VIS allocator<const void>
{
public:
    typedef const void*       pointer;
    typedef const void*       const_pointer;
    typedef const void        value_type;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};
};

// pointer_traits

template <class _Tp, class = void>
struct __has_element_type : false_type {};

template <class _Tp>
struct __has_element_type<_Tp,
              typename __void_t<typename _Tp::element_type>::type> : true_type {};

template <class _Ptr, bool = __has_element_type<_Ptr>::value>
struct __pointer_traits_element_type;

template <class _Ptr>
struct __pointer_traits_element_type<_Ptr, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Ptr::element_type type;
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <template <class, class...> class _Sp, class _Tp, class ..._Args>
struct __pointer_traits_element_type<_Sp<_Tp, _Args...>, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Sp<_Tp, _Args...>::element_type type;
};

template <template <class, class...> class _Sp, class _Tp, class ..._Args>
struct __pointer_traits_element_type<_Sp<_Tp, _Args...>, false>
{
    typedef _LIBCPP_NODEBUG_TYPE _Tp type;
};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 763 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <template <class> class _Sp, class _Tp>
struct __pointer_traits_element_type<_Sp<_Tp>, true>
{
    typedef typename _Sp<_Tp>::element_type type;
};

template <template <class> class _Sp, class _Tp>
struct __pointer_traits_element_type<_Sp<_Tp>, false>
{
    typedef _Tp type;
};

template <template <class, class> class _Sp, class _Tp, class _A0>
struct __pointer_traits_element_type<_Sp<_Tp, _A0>, true>
{
    typedef typename _Sp<_Tp, _A0>::element_type type;
};

template <template <class, class> class _Sp, class _Tp, class _A0>
struct __pointer_traits_element_type<_Sp<_Tp, _A0>, false>
{
    typedef _Tp type;
};

template <template <class, class, class> class _Sp, class _Tp, class _A0, class _A1>
struct __pointer_traits_element_type<_Sp<_Tp, _A0, _A1>, true>
{
    typedef typename _Sp<_Tp, _A0, _A1>::element_type type;
};

template <template <class, class, class> class _Sp, class _Tp, class _A0, class _A1>
struct __pointer_traits_element_type<_Sp<_Tp, _A0, _A1>, false>
{
    typedef _Tp type;
};

template <template <class, class, class, class> class _Sp, class _Tp, class _A0,
                                                           class _A1, class _A2>
struct __pointer_traits_element_type<_Sp<_Tp, _A0, _A1, _A2>, true>
{
    typedef typename _Sp<_Tp, _A0, _A1, _A2>::element_type type;
};

template <template <class, class, class, class> class _Sp, class _Tp, class _A0,
                                                           class _A1, class _A2>
struct __pointer_traits_element_type<_Sp<_Tp, _A0, _A1, _A2>, false>
{
    typedef _Tp type;
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 815 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Tp, class = void>
struct __has_difference_type : false_type {};

template <class _Tp>
struct __has_difference_type<_Tp,
            typename __void_t<typename _Tp::difference_type>::type> : true_type {};

template <class _Ptr, bool = __has_difference_type<_Ptr>::value>
struct __pointer_traits_difference_type
{
    typedef _LIBCPP_NODEBUG_TYPE ptrdiff_t type;
};

template <class _Ptr>
struct __pointer_traits_difference_type<_Ptr, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Ptr::difference_type type;
};

template <class _Tp, class _Up>
struct __has_rebind
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Xp> static __two __test(...);
    template <class _Xp> static char __test(typename _Xp::template rebind<_Up>* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Tp, class _Up, bool = __has_rebind<_Tp, _Up>::value>
struct __pointer_traits_rebind
{
#ifndef _LIBCPP_CXX03_LANG
    typedef _LIBCPP_NODEBUG_TYPE typename _Tp::template rebind<_Up> type;
#else
# 852 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef _LIBCPP_NODEBUG_TYPE typename _Tp::template rebind<_Up>::other type;
#endif
# 854 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <template <class, class...> class _Sp, class _Tp, class ..._Args, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _Args...>, _Up, true>
{
#ifndef _LIBCPP_CXX03_LANG
    typedef _LIBCPP_NODEBUG_TYPE typename _Sp<_Tp, _Args...>::template rebind<_Up> type;
#else
# 864 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef _LIBCPP_NODEBUG_TYPE typename _Sp<_Tp, _Args...>::template rebind<_Up>::other type;
#endif
# 866 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

template <template <class, class...> class _Sp, class _Tp, class ..._Args, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _Args...>, _Up, false>
{
    typedef _Sp<_Up, _Args...> type;
};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 875 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <template <class> class _Sp, class _Tp, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp>, _Up, true>
{
#ifndef _LIBCPP_CXX03_LANG
    typedef typename _Sp<_Tp>::template rebind<_Up> type;
#else
# 882 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef typename _Sp<_Tp>::template rebind<_Up>::other type;
#endif
# 884 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

template <template <class> class _Sp, class _Tp, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp>, _Up, false>
{
    typedef _Sp<_Up> type;
};

template <template <class, class> class _Sp, class _Tp, class _A0, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0>, _Up, true>
{
#ifndef _LIBCPP_CXX03_LANG
    typedef typename _Sp<_Tp, _A0>::template rebind<_Up> type;
#else
# 898 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef typename _Sp<_Tp, _A0>::template rebind<_Up>::other type;
#endif
# 900 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

template <template <class, class> class _Sp, class _Tp, class _A0, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0>, _Up, false>
{
    typedef _Sp<_Up, _A0> type;
};

template <template <class, class, class> class _Sp, class _Tp, class _A0,
                                         class _A1, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0, _A1>, _Up, true>
{
#ifndef _LIBCPP_CXX03_LANG
    typedef typename _Sp<_Tp, _A0, _A1>::template rebind<_Up> type;
#else
# 915 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef typename _Sp<_Tp, _A0, _A1>::template rebind<_Up>::other type;
#endif
# 917 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

template <template <class, class, class> class _Sp, class _Tp, class _A0,
                                         class _A1, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0, _A1>, _Up, false>
{
    typedef _Sp<_Up, _A0, _A1> type;
};

template <template <class, class, class, class> class _Sp, class _Tp, class _A0,
                                                class _A1, class _A2, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0, _A1, _A2>, _Up, true>
{
#ifndef _LIBCPP_CXX03_LANG
    typedef typename _Sp<_Tp, _A0, _A1, _A2>::template rebind<_Up> type;
#else
# 933 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef typename _Sp<_Tp, _A0, _A1, _A2>::template rebind<_Up>::other type;
#endif
# 935 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

template <template <class, class, class, class> class _Sp, class _Tp, class _A0,
                                                class _A1, class _A2, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0, _A1, _A2>, _Up, false>
{
    typedef _Sp<_Up, _A0, _A1, _A2> type;
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 945 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Ptr>
struct _LIBCPP_TEMPLATE_VIS pointer_traits
{
    typedef _Ptr                                                     pointer;
    typedef typename __pointer_traits_element_type<pointer>::type    element_type;
    typedef typename __pointer_traits_difference_type<pointer>::type difference_type;

#ifndef _LIBCPP_CXX03_LANG
    template <class _Up> using rebind = typename __pointer_traits_rebind<pointer, _Up>::type;
#else
# 956 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Up> struct rebind
        {typedef typename __pointer_traits_rebind<pointer, _Up>::type other;};
#endif  // _LIBCPP_CXX03_LANG
# 959 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

private:
    struct __nat {};
public:
    _LIBCPP_INLINE_VISIBILITY
    static pointer pointer_to(typename conditional<is_void<element_type>::value,
                                           __nat, element_type>::type& __r)
        {return pointer::pointer_to(__r);}
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS pointer_traits<_Tp*>
{
    typedef _Tp*      pointer;
    typedef _Tp       element_type;
    typedef ptrdiff_t difference_type;

#ifndef _LIBCPP_CXX03_LANG
    template <class _Up> using rebind = _Up*;
#else
# 979 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Up> struct rebind {typedef _Up* other;};
#endif
# 981 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

private:
    struct __nat {};
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    static pointer pointer_to(typename conditional<is_void<element_type>::value,
                                      __nat, element_type>::type& __r) _NOEXCEPT
        {return _VSTD::addressof(__r);}
};

template <class _From, class _To>
struct __rebind_pointer {
#ifndef _LIBCPP_CXX03_LANG
    typedef typename pointer_traits<_From>::template rebind<_To>        type;
#else
# 996 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef typename pointer_traits<_From>::template rebind<_To>::other type;
#endif
# 998 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

// allocator_traits

template <class _Tp, class = void>
struct __has_pointer_type : false_type {};

template <class _Tp>
struct __has_pointer_type<_Tp,
          typename __void_t<typename _Tp::pointer>::type> : true_type {};

namespace __pointer_type_imp
{

template <class _Tp, class _Dp, bool = __has_pointer_type<_Dp>::value>
struct __pointer_type
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Dp::pointer type;
};

template <class _Tp, class _Dp>
struct __pointer_type<_Tp, _Dp, false>
{
    typedef _LIBCPP_NODEBUG_TYPE _Tp* type;
};

}  // __pointer_type_imp

template <class _Tp, class _Dp>
struct __pointer_type
{
    typedef _LIBCPP_NODEBUG_TYPE typename __pointer_type_imp::__pointer_type<_Tp, typename remove_reference<_Dp>::type>::type type;
};

template <class _Tp, class = void>
struct __has_const_pointer : false_type {};

template <class _Tp>
struct __has_const_pointer<_Tp,
            typename __void_t<typename _Tp::const_pointer>::type> : true_type {};

template <class _Tp, class _Ptr, class _Alloc, bool = __has_const_pointer<_Alloc>::value>
struct __const_pointer
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::const_pointer type;
};

template <class _Tp, class _Ptr, class _Alloc>
struct __const_pointer<_Tp, _Ptr, _Alloc, false>
{
#ifndef _LIBCPP_CXX03_LANG
    typedef _LIBCPP_NODEBUG_TYPE typename pointer_traits<_Ptr>::template rebind<const _Tp> type;
#else
# 1051 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef typename pointer_traits<_Ptr>::template rebind<const _Tp>::other type;
#endif
# 1053 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

template <class _Tp, class = void>
struct __has_void_pointer : false_type {};

template <class _Tp>
struct __has_void_pointer<_Tp,
               typename __void_t<typename _Tp::void_pointer>::type> : true_type {};

template <class _Ptr, class _Alloc, bool = __has_void_pointer<_Alloc>::value>
struct __void_pointer
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::void_pointer type;
};

template <class _Ptr, class _Alloc>
struct __void_pointer<_Ptr, _Alloc, false>
{
#ifndef _LIBCPP_CXX03_LANG
    typedef _LIBCPP_NODEBUG_TYPE typename pointer_traits<_Ptr>::template rebind<void> type;
#else
# 1074 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef _LIBCPP_NODEBUG_TYPE typename pointer_traits<_Ptr>::template rebind<void>::other type;
#endif
# 1076 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

template <class _Tp, class = void>
struct __has_const_void_pointer : false_type {};

template <class _Tp>
struct __has_const_void_pointer<_Tp,
            typename __void_t<typename _Tp::const_void_pointer>::type> : true_type {};

template <class _Ptr, class _Alloc, bool = __has_const_void_pointer<_Alloc>::value>
struct __const_void_pointer
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::const_void_pointer type;
};

template <class _Ptr, class _Alloc>
struct __const_void_pointer<_Ptr, _Alloc, false>
{
#ifndef _LIBCPP_CXX03_LANG
    typedef _LIBCPP_NODEBUG_TYPE typename pointer_traits<_Ptr>::template rebind<const void> type;
#else
# 1097 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef _LIBCPP_NODEBUG_TYPE typename pointer_traits<_Ptr>::template rebind<const void>::other type;
#endif
# 1099 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};


template <bool _UsePointerTraits> struct __to_address_helper;

template <> struct __to_address_helper<true> {
    template <class _Pointer>
    using __return_type = decltype(pointer_traits<_Pointer>::to_address(std::declval<const _Pointer&>()));

    template <class _Pointer>
    _LIBCPP_CONSTEXPR
    static __return_type<_Pointer>
    __do_it(const _Pointer &__p) _NOEXCEPT { return pointer_traits<_Pointer>::to_address(__p); }
};

template <class _Pointer, bool _Dummy = true>
using __choose_to_address = __to_address_helper<_IsValidExpansion<__to_address_helper<_Dummy>::template __return_type, _Pointer>::value>;


template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
_Tp*
__to_address(_Tp* __p) _NOEXCEPT
{
    static_assert(!is_function<_Tp>::value, "_Tp is a function type");
    return __p;
}

template <class _Pointer>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename __choose_to_address<_Pointer>::template __return_type<_Pointer>
__to_address(const _Pointer& __p) _NOEXCEPT {
  return __choose_to_address<_Pointer>::__do_it(__p);
}

template <> struct __to_address_helper<false> {
    template <class _Pointer>
    using __return_type = typename pointer_traits<_Pointer>::element_type*;

    template <class _Pointer>
    _LIBCPP_CONSTEXPR
    static __return_type<_Pointer>
    __do_it(const _Pointer &__p) _NOEXCEPT { return std::__to_address(__p.operator->()); }
};


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1146 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY constexpr
_Tp*
to_address(_Tp* __p) _NOEXCEPT
{
    static_assert(!is_function_v<_Tp>, "_Tp is a function type");
    return __p;
}

template <class _Pointer>
inline _LIBCPP_INLINE_VISIBILITY
auto
to_address(const _Pointer& __p) _NOEXCEPT
{
    return _VSTD::__to_address(__p);
}
#endif
# 1163 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Tp, class = void>
struct __has_size_type : false_type {};

template <class _Tp>
struct __has_size_type<_Tp,
               typename __void_t<typename _Tp::size_type>::type> : true_type {};

template <class _Alloc, class _DiffType, bool = __has_size_type<_Alloc>::value>
struct __size_type
{
    typedef _LIBCPP_NODEBUG_TYPE typename make_unsigned<_DiffType>::type type;
};

template <class _Alloc, class _DiffType>
struct __size_type<_Alloc, _DiffType, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::size_type type;
};

template <class _Tp, class = void>
struct __has_propagate_on_container_copy_assignment : false_type {};

template <class _Tp>
struct __has_propagate_on_container_copy_assignment<_Tp,
    typename __void_t<typename _Tp::propagate_on_container_copy_assignment>::type>
        : true_type {};

template <class _Alloc, bool = __has_propagate_on_container_copy_assignment<_Alloc>::value>
struct __propagate_on_container_copy_assignment
{
    typedef _LIBCPP_NODEBUG_TYPE false_type type;
};

template <class _Alloc>
struct __propagate_on_container_copy_assignment<_Alloc, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::propagate_on_container_copy_assignment type;
};

template <class _Tp, class = void>
struct __has_propagate_on_container_move_assignment : false_type {};

template <class _Tp>
struct __has_propagate_on_container_move_assignment<_Tp,
           typename __void_t<typename _Tp::propagate_on_container_move_assignment>::type>
               : true_type {};

template <class _Alloc, bool = __has_propagate_on_container_move_assignment<_Alloc>::value>
struct __propagate_on_container_move_assignment
{
    typedef false_type type;
};

template <class _Alloc>
struct __propagate_on_container_move_assignment<_Alloc, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::propagate_on_container_move_assignment type;
};

template <class _Tp, class = void>
struct __has_propagate_on_container_swap : false_type {};

template <class _Tp>
struct __has_propagate_on_container_swap<_Tp,
           typename __void_t<typename _Tp::propagate_on_container_swap>::type>
               : true_type {};

template <class _Alloc, bool = __has_propagate_on_container_swap<_Alloc>::value>
struct __propagate_on_container_swap
{
    typedef false_type type;
};

template <class _Alloc>
struct __propagate_on_container_swap<_Alloc, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::propagate_on_container_swap type;
};

template <class _Tp, class = void>
struct __has_is_always_equal : false_type {};

template <class _Tp>
struct __has_is_always_equal<_Tp,
           typename __void_t<typename _Tp::is_always_equal>::type>
               : true_type {};

template <class _Alloc, bool = __has_is_always_equal<_Alloc>::value>
struct __is_always_equal
{
    typedef _LIBCPP_NODEBUG_TYPE typename _VSTD::is_empty<_Alloc>::type type;
};

template <class _Alloc>
struct __is_always_equal<_Alloc, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::is_always_equal type;
};

template <class _Tp, class _Up, bool = __has_rebind<_Tp, _Up>::value>
struct __has_rebind_other
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Xp> static __two __test(...);
    template <class _Xp> static char __test(typename _Xp::template rebind<_Up>::other* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Tp, class _Up>
struct __has_rebind_other<_Tp, _Up, false>
{
    static const bool value = false;
};

template <class _Tp, class _Up, bool = __has_rebind_other<_Tp, _Up>::value>
struct __allocator_traits_rebind
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Tp::template rebind<_Up>::other type;
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <template <class, class...> class _Alloc, class _Tp, class ..._Args, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _Args...>, _Up, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc<_Tp, _Args...>::template rebind<_Up>::other type;
};

template <template <class, class...> class _Alloc, class _Tp, class ..._Args, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _Args...>, _Up, false>
{
    typedef _LIBCPP_NODEBUG_TYPE _Alloc<_Up, _Args...> type;
};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 1301 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <template <class> class _Alloc, class _Tp, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp>, _Up, true>
{
    typedef typename _Alloc<_Tp>::template rebind<_Up>::other type;
};

template <template <class> class _Alloc, class _Tp, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp>, _Up, false>
{
    typedef _Alloc<_Up> type;
};

template <template <class, class> class _Alloc, class _Tp, class _A0, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0>, _Up, true>
{
    typedef typename _Alloc<_Tp, _A0>::template rebind<_Up>::other type;
};

template <template <class, class> class _Alloc, class _Tp, class _A0, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0>, _Up, false>
{
    typedef _Alloc<_Up, _A0> type;
};

template <template <class, class, class> class _Alloc, class _Tp, class _A0,
                                         class _A1, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0, _A1>, _Up, true>
{
    typedef typename _Alloc<_Tp, _A0, _A1>::template rebind<_Up>::other type;
};

template <template <class, class, class> class _Alloc, class _Tp, class _A0,
                                         class _A1, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0, _A1>, _Up, false>
{
    typedef _Alloc<_Up, _A0, _A1> type;
};

template <template <class, class, class, class> class _Alloc, class _Tp, class _A0,
                                                class _A1, class _A2, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0, _A1, _A2>, _Up, true>
{
    typedef typename _Alloc<_Tp, _A0, _A1, _A2>::template rebind<_Up>::other type;
};

template <template <class, class, class, class> class _Alloc, class _Tp, class _A0,
                                                class _A1, class _A2, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0, _A1, _A2>, _Up, false>
{
    typedef _Alloc<_Up, _A0, _A1, _A2> type;
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1355 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

#ifndef _LIBCPP_CXX03_LANG

template <class _Alloc, class _SizeType, class _ConstVoidPtr>
auto
__has_allocate_hint_test(_Alloc&& __a, _SizeType&& __sz, _ConstVoidPtr&& __p)
    -> decltype((void)__a.allocate(__sz, __p), true_type());

template <class _Alloc, class _SizeType, class _ConstVoidPtr>
auto
__has_allocate_hint_test(const _Alloc& __a, _SizeType&& __sz, _ConstVoidPtr&& __p)
    -> false_type;

template <class _Alloc, class _SizeType, class _ConstVoidPtr>
struct __has_allocate_hint
    : integral_constant<bool,
        is_same<
            decltype(_VSTD::__has_allocate_hint_test(declval<_Alloc>(),
                                          declval<_SizeType>(),
                                          declval<_ConstVoidPtr>())),
            true_type>::value>
{
};

#else  // _LIBCPP_CXX03_LANG
# 1380 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Alloc, class _SizeType, class _ConstVoidPtr>
struct __has_allocate_hint
    : true_type
{
};

#endif  // _LIBCPP_CXX03_LANG
# 1388 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1390 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Alloc, class _Tp, class ..._Args>
decltype(_VSTD::declval<_Alloc>().construct(_VSTD::declval<_Tp*>(),
                                           _VSTD::declval<_Args>()...),
                                           true_type())
__has_construct_test(_Alloc&& __a, _Tp* __p, _Args&& ...__args);

template <class _Alloc, class _Pointer, class ..._Args>
false_type
__has_construct_test(const _Alloc& __a, _Pointer&& __p, _Args&& ...__args);

template <class _Alloc, class _Pointer, class ..._Args>
struct __has_construct
    : integral_constant<bool,
        is_same<
            decltype(_VSTD::__has_construct_test(declval<_Alloc>(),
                                          declval<_Pointer>(),
                                          declval<_Args>()...)),
            true_type>::value>
{
};

template <class _Alloc, class _Pointer>
auto
__has_destroy_test(_Alloc&& __a, _Pointer&& __p)
    -> decltype(__a.destroy(__p), true_type());

template <class _Alloc, class _Pointer>
auto
__has_destroy_test(const _Alloc& __a, _Pointer&& __p)
    -> false_type;

template <class _Alloc, class _Pointer>
struct __has_destroy
    : integral_constant<bool,
        is_same<
            decltype(_VSTD::__has_destroy_test(declval<_Alloc>(),
                                        declval<_Pointer>())),
            true_type>::value>
{
};

template <class _Alloc>
auto
__has_max_size_test(_Alloc&& __a)
    -> decltype(__a.max_size(), true_type());

template <class _Alloc>
auto
__has_max_size_test(const volatile _Alloc& __a)
    -> false_type;

template <class _Alloc>
struct __has_max_size
    : integral_constant<bool,
        is_same<
            decltype(_VSTD::__has_max_size_test(declval<_Alloc&>())),
            true_type>::value>
{
};

template <class _Alloc>
auto
__has_select_on_container_copy_construction_test(_Alloc&& __a)
    -> decltype(__a.select_on_container_copy_construction(), true_type());

template <class _Alloc>
auto
__has_select_on_container_copy_construction_test(const volatile _Alloc& __a)
    -> false_type;

template <class _Alloc>
struct __has_select_on_container_copy_construction
    : integral_constant<bool,
        is_same<
            decltype(_VSTD::__has_select_on_container_copy_construction_test(declval<_Alloc&>())),
            true_type>::value>
{
};

#else  // _LIBCPP_CXX03_LANG
# 1471 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Alloc, class _Pointer, class _Tp, class = void>
struct __has_construct : std::false_type {};

template <class _Alloc, class _Pointer, class _Tp>
struct __has_construct<_Alloc, _Pointer, _Tp, typename __void_t<
    decltype(_VSTD::declval<_Alloc>().construct(_VSTD::declval<_Pointer>(), _VSTD::declval<_Tp>()))
>::type> : std::true_type {};

template <class _Alloc, class _Pointer, class = void>
struct __has_destroy : false_type {};

template <class _Alloc, class _Pointer>
struct __has_destroy<_Alloc, _Pointer, typename __void_t<
    decltype(_VSTD::declval<_Alloc>().destroy(_VSTD::declval<_Pointer>()))
>::type> : std::true_type {};

template <class _Alloc>
struct __has_max_size
    : true_type
{
};

template <class _Alloc>
struct __has_select_on_container_copy_construction
    : false_type
{
};

#endif  // _LIBCPP_CXX03_LANG
# 1501 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Alloc, class _Ptr, bool = __has_difference_type<_Alloc>::value>
struct __alloc_traits_difference_type
{
    typedef _LIBCPP_NODEBUG_TYPE typename pointer_traits<_Ptr>::difference_type type;
};

template <class _Alloc, class _Ptr>
struct __alloc_traits_difference_type<_Alloc, _Ptr, true>
{
    typedef _LIBCPP_NODEBUG_TYPE typename _Alloc::difference_type type;
};

template <class _Tp>
struct __is_default_allocator : false_type {};

template <class _Tp>
struct __is_default_allocator<_VSTD::allocator<_Tp> > : true_type {};



template <class _Alloc,
    bool = __has_construct<_Alloc, typename _Alloc::value_type*,  typename _Alloc::value_type&&>::value && !__is_default_allocator<_Alloc>::value
    >
struct __is_cpp17_move_insertable;
template <class _Alloc>
struct __is_cpp17_move_insertable<_Alloc, true> : std::true_type {};
template <class _Alloc>
struct __is_cpp17_move_insertable<_Alloc, false> : std::is_move_constructible<typename _Alloc::value_type> {};

template <class _Alloc,
    bool = __has_construct<_Alloc, typename _Alloc::value_type*, const typename _Alloc::value_type&>::value && !__is_default_allocator<_Alloc>::value
    >
struct __is_cpp17_copy_insertable;
template <class _Alloc>
struct __is_cpp17_copy_insertable<_Alloc, true> : __is_cpp17_move_insertable<_Alloc> {};
template <class _Alloc>
struct __is_cpp17_copy_insertable<_Alloc, false> : integral_constant<bool,
    std::is_copy_constructible<typename _Alloc::value_type>::value &&
    __is_cpp17_move_insertable<_Alloc>::value>
  {};



template <class _Alloc>
struct _LIBCPP_TEMPLATE_VIS allocator_traits
{
    typedef _Alloc                              allocator_type;
    typedef typename allocator_type::value_type value_type;

    typedef typename __pointer_type<value_type, allocator_type>::type pointer;
    typedef typename __const_pointer<value_type, pointer, allocator_type>::type const_pointer;
    typedef typename __void_pointer<pointer, allocator_type>::type void_pointer;
    typedef typename __const_void_pointer<pointer, allocator_type>::type const_void_pointer;

    typedef typename __alloc_traits_difference_type<allocator_type, pointer>::type difference_type;
    typedef typename __size_type<allocator_type, difference_type>::type size_type;

    typedef typename __propagate_on_container_copy_assignment<allocator_type>::type
                     propagate_on_container_copy_assignment;
    typedef typename __propagate_on_container_move_assignment<allocator_type>::type
                     propagate_on_container_move_assignment;
    typedef typename __propagate_on_container_swap<allocator_type>::type
                     propagate_on_container_swap;
    typedef typename __is_always_equal<allocator_type>::type
                     is_always_equal;

#ifndef _LIBCPP_CXX03_LANG
    template <class _Tp> using rebind_alloc =
                  typename __allocator_traits_rebind<allocator_type, _Tp>::type;
    template <class _Tp> using rebind_traits = allocator_traits<rebind_alloc<_Tp> >;
#else  // _LIBCPP_CXX03_LANG
# 1573 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Tp> struct rebind_alloc
        {typedef typename __allocator_traits_rebind<allocator_type, _Tp>::type other;};
    template <class _Tp> struct rebind_traits
        {typedef allocator_traits<typename rebind_alloc<_Tp>::other> other;};
#endif  // _LIBCPP_CXX03_LANG
# 1578 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    static pointer allocate(allocator_type& __a, size_type __n)
        {return __a.allocate(__n);}
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    static pointer allocate(allocator_type& __a, size_type __n, const_void_pointer __hint)
        {return __allocate(__a, __n, __hint,
            __has_allocate_hint<allocator_type, size_type, const_void_pointer>());}

    _LIBCPP_INLINE_VISIBILITY
    static void deallocate(allocator_type& __a, pointer __p, size_type __n) _NOEXCEPT
        {__a.deallocate(__p, __n);}

#ifndef _LIBCPP_HAS_NO_VARIADICS
    template <class _Tp, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type& __a, _Tp* __p, _Args&&... __args)
            {__construct(__has_construct<allocator_type, _Tp*, _Args...>(),
                         __a, __p, _VSTD::forward<_Args>(__args)...);}
#else  // _LIBCPP_HAS_NO_VARIADICS
# 1598 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type&, _Tp* __p)
            {
                ::new ((void*)__p) _Tp();
            }
    template <class _Tp, class _A0>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type& __a, _Tp* __p, const _A0& __a0)
            {
                __construct(__has_construct<allocator_type, _Tp*, const _A0&>(),
                            __a, __p, __a0);
            }
    template <class _Tp, class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type&, _Tp* __p, const _A0& __a0,
                              const _A1& __a1)
            {
                ::new ((void*)__p) _Tp(__a0, __a1);
            }
    template <class _Tp, class _A0, class _A1, class _A2>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type&, _Tp* __p, const _A0& __a0,
                              const _A1& __a1, const _A2& __a2)
            {
                ::new ((void*)__p) _Tp(__a0, __a1, __a2);
            }
#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1626 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static void destroy(allocator_type& __a, _Tp* __p)
            {__destroy(__has_destroy<allocator_type, _Tp*>(), __a, __p);}

    _LIBCPP_INLINE_VISIBILITY
    static size_type max_size(const allocator_type& __a) _NOEXCEPT
        {return __max_size(__has_max_size<const allocator_type>(), __a);}

    _LIBCPP_INLINE_VISIBILITY
    static allocator_type
        select_on_container_copy_construction(const allocator_type& __a)
            {return __select_on_container_copy_construction(
                __has_select_on_container_copy_construction<const allocator_type>(),
                __a);}

    template <class _Ptr>
        _LIBCPP_INLINE_VISIBILITY
        static
        void
        __construct_forward_with_exception_guarantees(allocator_type& __a, _Ptr __begin1, _Ptr __end1, _Ptr& __begin2)
        {
            static_assert(__is_cpp17_move_insertable<allocator_type>::value,
              "The specified type does not meet the requirements of Cpp17MoveInsertible");
            for (; __begin1 != __end1; ++__begin1, (void) ++__begin2)
              construct(__a, _VSTD::__to_address(__begin2),
#ifdef _LIBCPP_NO_EXCEPTIONS
                        _VSTD::move(*__begin1)
#else
# 1656 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
                        _VSTD::move_if_noexcept(*__begin1)
#endif
# 1658 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
                        );
        }

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static
        typename enable_if
        <
            (__is_default_allocator<allocator_type>::value
                || !__has_construct<allocator_type, _Tp*, _Tp>::value) &&
             is_trivially_move_constructible<_Tp>::value,
            void
        >::type
        __construct_forward_with_exception_guarantees(allocator_type&, _Tp* __begin1, _Tp* __end1, _Tp*& __begin2)
        {
            ptrdiff_t _Np = __end1 - __begin1;
            if (_Np > 0)
            {
                _VSTD::memcpy(__begin2, __begin1, _Np * sizeof(_Tp));
                __begin2 += _Np;
            }
        }

    template <class _Iter, class _Ptr>
        _LIBCPP_INLINE_VISIBILITY
        static
        void
        __construct_range_forward(allocator_type& __a, _Iter __begin1, _Iter __end1, _Ptr& __begin2)
        {
            for (; __begin1 != __end1; ++__begin1, (void) ++__begin2)
                construct(__a, _VSTD::__to_address(__begin2), *__begin1);
        }

    template <class _SourceTp, class _DestTp,
              class _RawSourceTp = typename remove_const<_SourceTp>::type,
              class _RawDestTp = typename remove_const<_DestTp>::type>
        _LIBCPP_INLINE_VISIBILITY
        static
        typename enable_if
        <
            is_trivially_copy_constructible<_DestTp>::value &&
            is_same<_RawSourceTp, _RawDestTp>::value &&
            (__is_default_allocator<allocator_type>::value ||
             !__has_construct<allocator_type, _DestTp*, _SourceTp&>::value),
            void
        >::type
        __construct_range_forward(allocator_type&, _SourceTp* __begin1, _SourceTp* __end1, _DestTp*& __begin2)
        {
            ptrdiff_t _Np = __end1 - __begin1;
            if (_Np > 0)
            {
                _VSTD::memcpy(const_cast<_RawDestTp*>(__begin2), __begin1, _Np * sizeof(_DestTp));
                __begin2 += _Np;
            }
        }

    template <class _Ptr>
        _LIBCPP_INLINE_VISIBILITY
        static
        void
        __construct_backward_with_exception_guarantees(allocator_type& __a, _Ptr __begin1, _Ptr __end1, _Ptr& __end2)
        {
            static_assert(__is_cpp17_move_insertable<allocator_type>::value,
              "The specified type does not meet the requirements of Cpp17MoveInsertable");
            while (__end1 != __begin1)
            {
              construct(__a, _VSTD::__to_address(__end2 - 1),
#ifdef _LIBCPP_NO_EXCEPTIONS
                        _VSTD::move(*--__end1)
#else
# 1728 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
                        _VSTD::move_if_noexcept(*--__end1)
#endif
# 1730 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
                        );
              --__end2;
            }
        }

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static
        typename enable_if
        <
            (__is_default_allocator<allocator_type>::value
                || !__has_construct<allocator_type, _Tp*, _Tp>::value) &&
             is_trivially_move_constructible<_Tp>::value,
            void
        >::type
        __construct_backward_with_exception_guarantees(allocator_type&, _Tp* __begin1, _Tp* __end1, _Tp*& __end2)
        {
            ptrdiff_t _Np = __end1 - __begin1;
            __end2 -= _Np;
            if (_Np > 0)
                _VSTD::memcpy(__end2, __begin1, _Np * sizeof(_Tp));
        }

private:

    _LIBCPP_INLINE_VISIBILITY
    static pointer __allocate(allocator_type& __a, size_type __n,
        const_void_pointer __hint, true_type)
        {return __a.allocate(__n, __hint);}
    _LIBCPP_INLINE_VISIBILITY
    static pointer __allocate(allocator_type& __a, size_type __n,
        const_void_pointer, false_type)
        {return __a.allocate(__n);}

#ifndef _LIBCPP_HAS_NO_VARIADICS
    template <class _Tp, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        static void __construct(true_type, allocator_type& __a, _Tp* __p, _Args&&... __args)
            {__a.construct(__p, _VSTD::forward<_Args>(__args)...);}
    template <class _Tp, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        static void __construct(false_type, allocator_type&, _Tp* __p, _Args&&... __args)
            {
                ::new ((void*)__p) _Tp(_VSTD::forward<_Args>(__args)...);
            }
#else  // _LIBCPP_HAS_NO_VARIADICS
# 1776 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Tp, class _A0>
        _LIBCPP_INLINE_VISIBILITY
        static void __construct(true_type, allocator_type& __a, _Tp* __p,
                                const _A0& __a0)
            {__a.construct(__p, __a0);}
    template <class _Tp, class _A0>
        _LIBCPP_INLINE_VISIBILITY
        static void __construct(false_type, allocator_type&, _Tp* __p,
                                const _A0& __a0)
            {
                ::new ((void*)__p) _Tp(__a0);
            }
#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1789 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static void __destroy(true_type, allocator_type& __a, _Tp* __p)
            {__a.destroy(__p);}
    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static void __destroy(false_type, allocator_type&, _Tp* __p)
            {
                __p->~_Tp();
            }

    _LIBCPP_INLINE_VISIBILITY
    static size_type __max_size(true_type, const allocator_type& __a) _NOEXCEPT
            {return __a.max_size();}
    _LIBCPP_INLINE_VISIBILITY
    static size_type __max_size(false_type, const allocator_type&) _NOEXCEPT
            {return numeric_limits<size_type>::max() / sizeof(value_type);}

    _LIBCPP_INLINE_VISIBILITY
    static allocator_type
        __select_on_container_copy_construction(true_type, const allocator_type& __a)
            {return __a.select_on_container_copy_construction();}
    _LIBCPP_INLINE_VISIBILITY
    static allocator_type
        __select_on_container_copy_construction(false_type, const allocator_type& __a)
            {return __a;}
};

template <class _Traits, class _Tp>
struct __rebind_alloc_helper
{
#ifndef _LIBCPP_CXX03_LANG
    typedef _LIBCPP_NODEBUG_TYPE typename _Traits::template rebind_alloc<_Tp>        type;
#else
# 1824 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef typename _Traits::template rebind_alloc<_Tp>::other type;
#endif
# 1826 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

// allocator

template <class _Tp>
class _LIBCPP_TEMPLATE_VIS allocator
{
public:
    typedef size_t            size_type;
    typedef ptrdiff_t         difference_type;
    typedef _Tp*              pointer;
    typedef const _Tp*        const_pointer;
    typedef _Tp&              reference;
    typedef const _Tp&        const_reference;
    typedef _Tp               value_type;

    typedef true_type propagate_on_container_move_assignment;
    typedef true_type is_always_equal;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    allocator() _NOEXCEPT {}

    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    allocator(const allocator<_Up>&) _NOEXCEPT {}

    _LIBCPP_INLINE_VISIBILITY pointer address(reference __x) const _NOEXCEPT
        {return _VSTD::addressof(__x);}
    _LIBCPP_INLINE_VISIBILITY const_pointer address(const_reference __x) const _NOEXCEPT
        {return _VSTD::addressof(__x);}
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    pointer allocate(size_type __n, allocator<void>::const_pointer = 0)
        {
        if (__n > max_size())
            __throw_length_error("allocator<T>::allocate(size_t n)"
                                 " 'n' exceeds maximum supported size");
        return static_cast<pointer>(_VSTD::__libcpp_allocate(__n * sizeof(_Tp), _LIBCPP_ALIGNOF(_Tp)));
        }
    _LIBCPP_INLINE_VISIBILITY void deallocate(pointer __p, size_type __n) _NOEXCEPT
        {_VSTD::__libcpp_deallocate((void*)__p, __n * sizeof(_Tp), _LIBCPP_ALIGNOF(_Tp));}
    _LIBCPP_INLINE_VISIBILITY size_type max_size() const _NOEXCEPT
        {return size_type(~0) / sizeof(_Tp);}
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1871 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Up, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(_Up* __p, _Args&&... __args)
        {
            ::new((void*)__p) _Up(_VSTD::forward<_Args>(__args)...);
        }
#else  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
# 1879 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p)
        {
            ::new((void*)__p) _Tp();
        }
#if 0 /* disabled by -frewrite-includes */
# if defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1886 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0)
        {
            ::new((void*)__p) _Tp(__a0);
        }
    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0)
        {
            ::new((void*)__p) _Tp(__a0);
        }
# endif  // defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 1902 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0, _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0, _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0, const _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0, const _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
#endif  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
# 1931 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY void destroy(pointer __p) {__p->~_Tp();}
};

template <class _Tp>
class _LIBCPP_TEMPLATE_VIS allocator<const _Tp>
{
public:
    typedef size_t            size_type;
    typedef ptrdiff_t         difference_type;
    typedef const _Tp*        pointer;
    typedef const _Tp*        const_pointer;
    typedef const _Tp&        reference;
    typedef const _Tp&        const_reference;
    typedef const _Tp         value_type;

    typedef true_type propagate_on_container_move_assignment;
    typedef true_type is_always_equal;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    allocator() _NOEXCEPT {}

    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    allocator(const allocator<_Up>&) _NOEXCEPT {}

    _LIBCPP_INLINE_VISIBILITY const_pointer address(const_reference __x) const _NOEXCEPT
        {return _VSTD::addressof(__x);}
    _LIBCPP_INLINE_VISIBILITY pointer allocate(size_type __n, allocator<void>::const_pointer = 0)
    {
        if (__n > max_size())
            __throw_length_error("allocator<const T>::allocate(size_t n)"
                                 " 'n' exceeds maximum supported size");
        return static_cast<pointer>(_VSTD::__libcpp_allocate(__n * sizeof(_Tp), _LIBCPP_ALIGNOF(_Tp)));
    }
    _LIBCPP_INLINE_VISIBILITY void deallocate(pointer __p, size_type __n) _NOEXCEPT
        {_VSTD::__libcpp_deallocate((void*) const_cast<_Tp *>(__p), __n * sizeof(_Tp), _LIBCPP_ALIGNOF(_Tp));}
    _LIBCPP_INLINE_VISIBILITY size_type max_size() const _NOEXCEPT
        {return size_type(~0) / sizeof(_Tp);}
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1972 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Up, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(_Up* __p, _Args&&... __args)
        {
            ::new((void*)__p) _Up(_VSTD::forward<_Args>(__args)...);
        }
#else  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
# 1980 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p)
        {
            ::new((void*) const_cast<_Tp *>(__p)) _Tp();
        }
#if 0 /* disabled by -frewrite-includes */
# if defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1987 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0)
        {
            ::new((void*) const_cast<_Tp *>(__p)) _Tp(__a0);
        }
    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0)
        {
            ::new((void*) const_cast<_Tp *>(__p)) _Tp(__a0);
        }
# endif  // defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 2003 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0, _A1& __a1)
        {
            ::new((void*) const_cast<_Tp *>(__p)) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0, _A1& __a1)
        {
            ::new((void*) const_cast<_Tp *>(__p)) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0, const _A1& __a1)
        {
            ::new((void*) const_cast<_Tp *>(__p)) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0, const _A1& __a1)
        {
            ::new((void*) const_cast<_Tp *>(__p)) _Tp(__a0, __a1);
        }
#endif  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
# 2032 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY void destroy(pointer __p) {__p->~_Tp();}
};

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool operator==(const allocator<_Tp>&, const allocator<_Up>&) _NOEXCEPT {return true;}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool operator!=(const allocator<_Tp>&, const allocator<_Up>&) _NOEXCEPT {return false;}

template <class _OutputIterator, class _Tp>
class _LIBCPP_TEMPLATE_VIS raw_storage_iterator
    : public iterator<output_iterator_tag,
                      _Tp,                                         // purposefully not C++03
                      ptrdiff_t,                                   // purposefully not C++03
                      _Tp*,                                        // purposefully not C++03
                      raw_storage_iterator<_OutputIterator, _Tp>&> // purposefully not C++03
{
private:
    _OutputIterator __x_;
public:
    _LIBCPP_INLINE_VISIBILITY explicit raw_storage_iterator(_OutputIterator __x) : __x_(__x) {}
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator& operator*() {return *this;}
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator& operator=(const _Tp& __element)
        {::new(_VSTD::addressof(*__x_)) _Tp(__element); return *this;}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2059 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator& operator=(_Tp&& __element)
        {::new(_VSTD::addressof(*__x_)) _Tp(_VSTD::move(__element)); return *this;}
#endif
# 2062 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator& operator++() {++__x_; return *this;}
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator  operator++(int)
        {raw_storage_iterator __t(*this); ++__x_; return __t;}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2066 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY _OutputIterator base() const { return __x_; }
#endif
# 2068 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
};

template <class _Tp>
_LIBCPP_NODISCARD_EXT _LIBCPP_NO_CFI
pair<_Tp*, ptrdiff_t>
get_temporary_buffer(ptrdiff_t __n) _NOEXCEPT
{
    pair<_Tp*, ptrdiff_t> __r(0, 0);
    const ptrdiff_t __m = (~ptrdiff_t(0) ^
                           ptrdiff_t(ptrdiff_t(1) << (sizeof(ptrdiff_t) * __CHAR_BIT__ - 1)))
                           / sizeof(_Tp);
    if (__n > __m)
        __n = __m;
    while (__n > 0)
    {
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_ALIGNED_ALLOCATION)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2084 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    if (__is_overaligned_for_new(_LIBCPP_ALIGNOF(_Tp)))
        {
            std::align_val_t __al =
                std::align_val_t(std::alignment_of<_Tp>::value);
            __r.first = static_cast<_Tp*>(::operator new(
                __n * sizeof(_Tp), __al, nothrow));
        } else {
            __r.first = static_cast<_Tp*>(::operator new(
                __n * sizeof(_Tp), nothrow));
        }
#else
# 2095 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    if (__is_overaligned_for_new(_LIBCPP_ALIGNOF(_Tp)))
        {
            // Since aligned operator new is unavailable, return an empty
            // buffer rather than one with invalid alignment.
            return __r;
        }

        __r.first = static_cast<_Tp*>(::operator new(__n * sizeof(_Tp), nothrow));
#endif
# 2104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

        if (__r.first)
        {
            __r.second = __n;
            break;
        }
        __n /= 2;
    }
    return __r;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void return_temporary_buffer(_Tp* __p) _NOEXCEPT
{
  _VSTD::__libcpp_deallocate_unsized((void*)__p, _LIBCPP_ALIGNOF(_Tp));
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
template <class _Tp>
struct _LIBCPP_DEPRECATED_IN_CXX11 auto_ptr_ref
{
    _Tp* __ptr_;
};

template<class _Tp>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 auto_ptr
{
private:
    _Tp* __ptr_;
public:
    typedef _Tp element_type;

    _LIBCPP_INLINE_VISIBILITY explicit auto_ptr(_Tp* __p = 0) throw() : __ptr_(__p) {}
    _LIBCPP_INLINE_VISIBILITY auto_ptr(auto_ptr& __p) throw() : __ptr_(__p.release()) {}
    template<class _Up> _LIBCPP_INLINE_VISIBILITY auto_ptr(auto_ptr<_Up>& __p) throw()
        : __ptr_(__p.release()) {}
    _LIBCPP_INLINE_VISIBILITY auto_ptr& operator=(auto_ptr& __p) throw()
        {reset(__p.release()); return *this;}
    template<class _Up> _LIBCPP_INLINE_VISIBILITY auto_ptr& operator=(auto_ptr<_Up>& __p) throw()
        {reset(__p.release()); return *this;}
    _LIBCPP_INLINE_VISIBILITY auto_ptr& operator=(auto_ptr_ref<_Tp> __p) throw()
        {reset(__p.__ptr_); return *this;}
    _LIBCPP_INLINE_VISIBILITY ~auto_ptr() throw() {delete __ptr_;}

    _LIBCPP_INLINE_VISIBILITY _Tp& operator*() const throw()
        {return *__ptr_;}
    _LIBCPP_INLINE_VISIBILITY _Tp* operator->() const throw() {return __ptr_;}
    _LIBCPP_INLINE_VISIBILITY _Tp* get() const throw() {return __ptr_;}
    _LIBCPP_INLINE_VISIBILITY _Tp* release() throw()
    {
        _Tp* __t = __ptr_;
        __ptr_ = 0;
        return __t;
    }
    _LIBCPP_INLINE_VISIBILITY void reset(_Tp* __p = 0) throw()
    {
        if (__ptr_ != __p)
            delete __ptr_;
        __ptr_ = __p;
    }

    _LIBCPP_INLINE_VISIBILITY auto_ptr(auto_ptr_ref<_Tp> __p) throw() : __ptr_(__p.__ptr_) {}
    template<class _Up> _LIBCPP_INLINE_VISIBILITY operator auto_ptr_ref<_Up>() throw()
        {auto_ptr_ref<_Up> __t; __t.__ptr_ = release(); return __t;}
    template<class _Up> _LIBCPP_INLINE_VISIBILITY operator auto_ptr<_Up>() throw()
        {return auto_ptr<_Up>(release());}
};

template <>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 auto_ptr<void>
{
public:
    typedef void element_type;
};
#endif
# 2180 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

// Tag used to default initialize one or both of the pair's elements.
struct __default_init_tag {};
struct __value_init_tag {};

template <class _Tp, int _Idx,
          bool _CanBeEmptyBase =
              is_empty<_Tp>::value && !__libcpp_is_final<_Tp>::value>
struct __compressed_pair_elem {
  typedef _Tp _ParamT;
  typedef _Tp& reference;
  typedef const _Tp& const_reference;

  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
  __compressed_pair_elem(__default_init_tag) {}
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
  __compressed_pair_elem(__value_init_tag) : __value_() {}

  template <class _Up, class = typename enable_if<
      !is_same<__compressed_pair_elem, typename decay<_Up>::type>::value
  >::type>
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_CONSTEXPR explicit
  __compressed_pair_elem(_Up&& __u)
      : __value_(_VSTD::forward<_Up>(__u))
    {
    }


#ifndef _LIBCPP_CXX03_LANG
  template <class... _Args, size_t... _Indexes>
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
  __compressed_pair_elem(piecewise_construct_t, tuple<_Args...> __args,
                         __tuple_indices<_Indexes...>)
      : __value_(_VSTD::forward<_Args>(_VSTD::get<_Indexes>(__args))...) {}
#endif
# 2216 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3


  _LIBCPP_INLINE_VISIBILITY reference __get() _NOEXCEPT { return __value_; }
  _LIBCPP_INLINE_VISIBILITY
  const_reference __get() const _NOEXCEPT { return __value_; }

private:
  _Tp __value_;
};

template <class _Tp, int _Idx>
struct __compressed_pair_elem<_Tp, _Idx, true> : private _Tp {
  typedef _Tp _ParamT;
  typedef _Tp& reference;
  typedef const _Tp& const_reference;
  typedef _Tp __value_type;

  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR __compressed_pair_elem() = default;
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
  __compressed_pair_elem(__default_init_tag) {}
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
  __compressed_pair_elem(__value_init_tag) : __value_type() {}

  template <class _Up, class = typename enable_if<
        !is_same<__compressed_pair_elem, typename decay<_Up>::type>::value
  >::type>
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_CONSTEXPR explicit
  __compressed_pair_elem(_Up&& __u)
      : __value_type(_VSTD::forward<_Up>(__u))
  {}

#ifndef _LIBCPP_CXX03_LANG
  template <class... _Args, size_t... _Indexes>
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
  __compressed_pair_elem(piecewise_construct_t, tuple<_Args...> __args,
                         __tuple_indices<_Indexes...>)
      : __value_type(_VSTD::forward<_Args>(_VSTD::get<_Indexes>(__args))...) {}
#endif
# 2255 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

  _LIBCPP_INLINE_VISIBILITY reference __get() _NOEXCEPT { return *this; }
  _LIBCPP_INLINE_VISIBILITY
  const_reference __get() const _NOEXCEPT { return *this; }
};

template <class _T1, class _T2>
class __compressed_pair : private __compressed_pair_elem<_T1, 0>,
                          private __compressed_pair_elem<_T2, 1> {
  typedef _LIBCPP_NODEBUG_TYPE __compressed_pair_elem<_T1, 0> _Base1;
  typedef _LIBCPP_NODEBUG_TYPE __compressed_pair_elem<_T2, 1> _Base2;

  // NOTE: This static assert should never fire because __compressed_pair
  // is *almost never* used in a scenario where it's possible for T1 == T2.
  // (The exception is std::function where it is possible that the function
  //  object and the allocator have the same type).
  static_assert((!is_same<_T1, _T2>::value),
    "__compressed_pair cannot be instantated when T1 and T2 are the same type; "
    "The current implementation is NOT ABI-compatible with the previous "
    "implementation for this configuration");

public:
    template <bool _Dummy = true,
      class = typename enable_if<
          __dependent_type<is_default_constructible<_T1>, _Dummy>::value &&
          __dependent_type<is_default_constructible<_T2>, _Dummy>::value
      >::type
  >
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_CONSTEXPR __compressed_pair() : _Base1(__value_init_tag()), _Base2(__value_init_tag()) {}

  template <class _U1, class _U2>
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
  __compressed_pair(_U1&& __t1, _U2&& __t2)
      : _Base1(std::forward<_U1>(__t1)), _Base2(std::forward<_U2>(__t2)) {}

#ifndef _LIBCPP_CXX03_LANG
  template <class... _Args1, class... _Args2>
  _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
  __compressed_pair(piecewise_construct_t __pc, tuple<_Args1...> __first_args,
                    tuple<_Args2...> __second_args)
      : _Base1(__pc, _VSTD::move(__first_args),
               typename __make_tuple_indices<sizeof...(_Args1)>::type()),
        _Base2(__pc, _VSTD::move(__second_args),
               typename __make_tuple_indices<sizeof...(_Args2)>::type()) {}
#endif
# 2301 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

  _LIBCPP_INLINE_VISIBILITY
  typename _Base1::reference first() _NOEXCEPT {
    return static_cast<_Base1&>(*this).__get();
  }

  _LIBCPP_INLINE_VISIBILITY
  typename _Base1::const_reference first() const _NOEXCEPT {
    return static_cast<_Base1 const&>(*this).__get();
  }

  _LIBCPP_INLINE_VISIBILITY
  typename _Base2::reference second() _NOEXCEPT {
    return static_cast<_Base2&>(*this).__get();
  }

  _LIBCPP_INLINE_VISIBILITY
  typename _Base2::const_reference second() const _NOEXCEPT {
    return static_cast<_Base2 const&>(*this).__get();
  }

  _LIBCPP_INLINE_VISIBILITY
  void swap(__compressed_pair& __x)
    _NOEXCEPT_(__is_nothrow_swappable<_T1>::value &&
               __is_nothrow_swappable<_T2>::value)
  {
    using std::swap;
    swap(first(), __x.first());
    swap(second(), __x.second());
  }
};

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
void swap(__compressed_pair<_T1, _T2>& __x, __compressed_pair<_T1, _T2>& __y)
    _NOEXCEPT_(__is_nothrow_swappable<_T1>::value &&
               __is_nothrow_swappable<_T2>::value) {
  __x.swap(__y);
}

// default_delete

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS default_delete {
    static_assert(!is_function<_Tp>::value,
                  "default_delete cannot be instantiated for function types");
#ifndef _LIBCPP_CXX03_LANG
  _LIBCPP_INLINE_VISIBILITY constexpr default_delete() _NOEXCEPT = default;
#else
# 2350 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
  _LIBCPP_INLINE_VISIBILITY default_delete() {}
#endif
# 2352 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
  template <class _Up>
  _LIBCPP_INLINE_VISIBILITY
  default_delete(const default_delete<_Up>&,
                 typename enable_if<is_convertible<_Up*, _Tp*>::value>::type* =
                     0) _NOEXCEPT {}

  _LIBCPP_INLINE_VISIBILITY void operator()(_Tp* __ptr) const _NOEXCEPT {
    static_assert(sizeof(_Tp) > 0,
                  "default_delete can not delete incomplete type");
    static_assert(!is_void<_Tp>::value,
                  "default_delete can not delete incomplete type");
    delete __ptr;
  }
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS default_delete<_Tp[]> {
private:
  template <class _Up>
  struct _EnableIfConvertible
      : enable_if<is_convertible<_Up(*)[], _Tp(*)[]>::value> {};

public:
#ifndef _LIBCPP_CXX03_LANG
  _LIBCPP_INLINE_VISIBILITY constexpr default_delete() _NOEXCEPT = default;
#else
# 2378 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
  _LIBCPP_INLINE_VISIBILITY default_delete() {}
#endif
# 2380 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

  template <class _Up>
  _LIBCPP_INLINE_VISIBILITY
  default_delete(const default_delete<_Up[]>&,
                 typename _EnableIfConvertible<_Up>::type* = 0) _NOEXCEPT {}

  template <class _Up>
  _LIBCPP_INLINE_VISIBILITY
  typename _EnableIfConvertible<_Up>::type
  operator()(_Up* __ptr) const _NOEXCEPT {
    static_assert(sizeof(_Tp) > 0,
                  "default_delete can not delete incomplete type");
    static_assert(!is_void<_Tp>::value,
                  "default_delete can not delete void type");
    delete[] __ptr;
  }
};

template <class _Deleter>
struct __unique_ptr_deleter_sfinae {
  static_assert(!is_reference<_Deleter>::value, "incorrect specialization");
  typedef const _Deleter& __lval_ref_type;
  typedef _Deleter&& __good_rval_ref_type;
  typedef true_type __enable_rval_overload;
};

template <class _Deleter>
struct __unique_ptr_deleter_sfinae<_Deleter const&> {
  typedef const _Deleter& __lval_ref_type;
  typedef const _Deleter&& __bad_rval_ref_type;
  typedef false_type __enable_rval_overload;
};

template <class _Deleter>
struct __unique_ptr_deleter_sfinae<_Deleter&> {
  typedef _Deleter& __lval_ref_type;
  typedef _Deleter&& __bad_rval_ref_type;
  typedef false_type __enable_rval_overload;
};

template <class _Tp, class _Dp = default_delete<_Tp> >
class _LIBCPP_TEMPLATE_VIS unique_ptr {
public:
  typedef _Tp element_type;
  typedef _Dp deleter_type;
  typedef _LIBCPP_NODEBUG_TYPE typename __pointer_type<_Tp, deleter_type>::type pointer;

  static_assert(!is_rvalue_reference<deleter_type>::value,
                "the specified deleter type cannot be an rvalue reference");

private:
  __compressed_pair<pointer, deleter_type> __ptr_;

  struct __nat { int __for_bool_; };

  typedef _LIBCPP_NODEBUG_TYPE __unique_ptr_deleter_sfinae<_Dp> _DeleterSFINAE;

  template <bool _Dummy>
  using _LValRefType _LIBCPP_NODEBUG_TYPE =
      typename __dependent_type<_DeleterSFINAE, _Dummy>::__lval_ref_type;

  template <bool _Dummy>
  using _GoodRValRefType _LIBCPP_NODEBUG_TYPE =
      typename __dependent_type<_DeleterSFINAE, _Dummy>::__good_rval_ref_type;

  template <bool _Dummy>
  using _BadRValRefType _LIBCPP_NODEBUG_TYPE  =
      typename __dependent_type<_DeleterSFINAE, _Dummy>::__bad_rval_ref_type;

  template <bool _Dummy, class _Deleter = typename __dependent_type<
                             __identity<deleter_type>, _Dummy>::type>
  using _EnableIfDeleterDefaultConstructible _LIBCPP_NODEBUG_TYPE =
      typename enable_if<is_default_constructible<_Deleter>::value &&
                         !is_pointer<_Deleter>::value>::type;

  template <class _ArgType>
  using _EnableIfDeleterConstructible _LIBCPP_NODEBUG_TYPE  =
      typename enable_if<is_constructible<deleter_type, _ArgType>::value>::type;

  template <class _UPtr, class _Up>
  using _EnableIfMoveConvertible _LIBCPP_NODEBUG_TYPE  = typename enable_if<
      is_convertible<typename _UPtr::pointer, pointer>::value &&
      !is_array<_Up>::value
  >::type;

  template <class _UDel>
  using _EnableIfDeleterConvertible _LIBCPP_NODEBUG_TYPE  = typename enable_if<
      (is_reference<_Dp>::value && is_same<_Dp, _UDel>::value) ||
      (!is_reference<_Dp>::value && is_convertible<_UDel, _Dp>::value)
    >::type;

  template <class _UDel>
  using _EnableIfDeleterAssignable = typename enable_if<
      is_assignable<_Dp&, _UDel&&>::value
    >::type;

public:
  template <bool _Dummy = true,
            class = _EnableIfDeleterDefaultConstructible<_Dummy> >
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_CONSTEXPR unique_ptr() _NOEXCEPT : __ptr_(pointer(), __default_init_tag()) {}

  template <bool _Dummy = true,
            class = _EnableIfDeleterDefaultConstructible<_Dummy> >
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_CONSTEXPR unique_ptr(nullptr_t) _NOEXCEPT : __ptr_(pointer(), __default_init_tag()) {}

  template <bool _Dummy = true,
            class = _EnableIfDeleterDefaultConstructible<_Dummy> >
  _LIBCPP_INLINE_VISIBILITY
  explicit unique_ptr(pointer __p) _NOEXCEPT : __ptr_(__p, __default_init_tag()) {}

  template <bool _Dummy = true,
            class = _EnableIfDeleterConstructible<_LValRefType<_Dummy> > >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(pointer __p, _LValRefType<_Dummy> __d) _NOEXCEPT
      : __ptr_(__p, __d) {}

  template <bool _Dummy = true,
            class = _EnableIfDeleterConstructible<_GoodRValRefType<_Dummy> > >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(pointer __p, _GoodRValRefType<_Dummy> __d) _NOEXCEPT
      : __ptr_(__p, _VSTD::move(__d)) {
    static_assert(!is_reference<deleter_type>::value,
                  "rvalue deleter bound to reference");
  }

  template <bool _Dummy = true,
            class = _EnableIfDeleterConstructible<_BadRValRefType<_Dummy> > >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(pointer __p, _BadRValRefType<_Dummy> __d) = delete;

  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(unique_ptr&& __u) _NOEXCEPT
      : __ptr_(__u.release(), _VSTD::forward<deleter_type>(__u.get_deleter())) {
  }

  template <class _Up, class _Ep,
      class = _EnableIfMoveConvertible<unique_ptr<_Up, _Ep>, _Up>,
      class = _EnableIfDeleterConvertible<_Ep>
  >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(unique_ptr<_Up, _Ep>&& __u) _NOEXCEPT
      : __ptr_(__u.release(), _VSTD::forward<_Ep>(__u.get_deleter())) {}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2526 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
  template <class _Up>
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(auto_ptr<_Up>&& __p,
             typename enable_if<is_convertible<_Up*, _Tp*>::value &&
                                    is_same<_Dp, default_delete<_Tp> >::value,
                                __nat>::type = __nat()) _NOEXCEPT
      : __ptr_(__p.release(), __default_init_tag()) {}
#endif
# 2534 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

  _LIBCPP_INLINE_VISIBILITY
  unique_ptr& operator=(unique_ptr&& __u) _NOEXCEPT {
    reset(__u.release());
    __ptr_.second() = _VSTD::forward<deleter_type>(__u.get_deleter());
    return *this;
  }

  template <class _Up, class _Ep,
      class = _EnableIfMoveConvertible<unique_ptr<_Up, _Ep>, _Up>,
      class = _EnableIfDeleterAssignable<_Ep>
  >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr& operator=(unique_ptr<_Up, _Ep>&& __u) _NOEXCEPT {
    reset(__u.release());
    __ptr_.second() = _VSTD::forward<_Ep>(__u.get_deleter());
    return *this;
  }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2554 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
  template <class _Up>
  _LIBCPP_INLINE_VISIBILITY
      typename enable_if<is_convertible<_Up*, _Tp*>::value &&
                             is_same<_Dp, default_delete<_Tp> >::value,
                         unique_ptr&>::type
      operator=(auto_ptr<_Up> __p) {
    reset(__p.release());
    return *this;
  }
#endif
# 2564 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

#ifdef _LIBCPP_CXX03_LANG
  unique_ptr(unique_ptr const&) = delete;
  unique_ptr& operator=(unique_ptr const&) = delete;
#endif
# 2569 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3


  _LIBCPP_INLINE_VISIBILITY
  ~unique_ptr() { reset(); }

  _LIBCPP_INLINE_VISIBILITY
  unique_ptr& operator=(nullptr_t) _NOEXCEPT {
    reset();
    return *this;
  }

  _LIBCPP_INLINE_VISIBILITY
  typename add_lvalue_reference<_Tp>::type
  operator*() const {
    return *__ptr_.first();
  }
  _LIBCPP_INLINE_VISIBILITY
  pointer operator->() const _NOEXCEPT {
    return __ptr_.first();
  }
  _LIBCPP_INLINE_VISIBILITY
  pointer get() const _NOEXCEPT {
    return __ptr_.first();
  }
  _LIBCPP_INLINE_VISIBILITY
  deleter_type& get_deleter() _NOEXCEPT {
    return __ptr_.second();
  }
  _LIBCPP_INLINE_VISIBILITY
  const deleter_type& get_deleter() const _NOEXCEPT {
    return __ptr_.second();
  }
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT {
    return __ptr_.first() != nullptr;
  }

  _LIBCPP_INLINE_VISIBILITY
  pointer release() _NOEXCEPT {
    pointer __t = __ptr_.first();
    __ptr_.first() = pointer();
    return __t;
  }

  _LIBCPP_INLINE_VISIBILITY
  void reset(pointer __p = pointer()) _NOEXCEPT {
    pointer __tmp = __ptr_.first();
    __ptr_.first() = __p;
    if (__tmp)
      __ptr_.second()(__tmp);
  }

  _LIBCPP_INLINE_VISIBILITY
  void swap(unique_ptr& __u) _NOEXCEPT {
    __ptr_.swap(__u.__ptr_);
  }
};


template <class _Tp, class _Dp>
class _LIBCPP_TEMPLATE_VIS unique_ptr<_Tp[], _Dp> {
public:
  typedef _Tp element_type;
  typedef _Dp deleter_type;
  typedef typename __pointer_type<_Tp, deleter_type>::type pointer;

private:
  __compressed_pair<pointer, deleter_type> __ptr_;

  template <class _From>
  struct _CheckArrayPointerConversion : is_same<_From, pointer> {};

  template <class _FromElem>
  struct _CheckArrayPointerConversion<_FromElem*>
      : integral_constant<bool,
          is_same<_FromElem*, pointer>::value ||
            (is_same<pointer, element_type*>::value &&
             is_convertible<_FromElem(*)[], element_type(*)[]>::value)
      >
  {};

  typedef __unique_ptr_deleter_sfinae<_Dp> _DeleterSFINAE;

  template <bool _Dummy>
  using _LValRefType _LIBCPP_NODEBUG_TYPE =
      typename __dependent_type<_DeleterSFINAE, _Dummy>::__lval_ref_type;

  template <bool _Dummy>
  using _GoodRValRefType _LIBCPP_NODEBUG_TYPE =
      typename __dependent_type<_DeleterSFINAE, _Dummy>::__good_rval_ref_type;

  template <bool _Dummy>
  using _BadRValRefType _LIBCPP_NODEBUG_TYPE =
      typename __dependent_type<_DeleterSFINAE, _Dummy>::__bad_rval_ref_type;

  template <bool _Dummy, class _Deleter = typename __dependent_type<
                             __identity<deleter_type>, _Dummy>::type>
  using _EnableIfDeleterDefaultConstructible _LIBCPP_NODEBUG_TYPE  =
      typename enable_if<is_default_constructible<_Deleter>::value &&
                         !is_pointer<_Deleter>::value>::type;

  template <class _ArgType>
  using _EnableIfDeleterConstructible _LIBCPP_NODEBUG_TYPE  =
      typename enable_if<is_constructible<deleter_type, _ArgType>::value>::type;

  template <class _Pp>
  using _EnableIfPointerConvertible _LIBCPP_NODEBUG_TYPE  = typename enable_if<
      _CheckArrayPointerConversion<_Pp>::value
  >::type;

  template <class _UPtr, class _Up,
        class _ElemT = typename _UPtr::element_type>
  using _EnableIfMoveConvertible _LIBCPP_NODEBUG_TYPE  = typename enable_if<
      is_array<_Up>::value &&
      is_same<pointer, element_type*>::value &&
      is_same<typename _UPtr::pointer, _ElemT*>::value &&
      is_convertible<_ElemT(*)[], element_type(*)[]>::value
    >::type;

  template <class _UDel>
  using _EnableIfDeleterConvertible _LIBCPP_NODEBUG_TYPE  = typename enable_if<
      (is_reference<_Dp>::value && is_same<_Dp, _UDel>::value) ||
      (!is_reference<_Dp>::value && is_convertible<_UDel, _Dp>::value)
    >::type;

  template <class _UDel>
  using _EnableIfDeleterAssignable _LIBCPP_NODEBUG_TYPE  = typename enable_if<
      is_assignable<_Dp&, _UDel&&>::value
    >::type;

public:
  template <bool _Dummy = true,
            class = _EnableIfDeleterDefaultConstructible<_Dummy> >
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_CONSTEXPR unique_ptr() _NOEXCEPT : __ptr_(pointer(), __default_init_tag()) {}

  template <bool _Dummy = true,
            class = _EnableIfDeleterDefaultConstructible<_Dummy> >
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_CONSTEXPR unique_ptr(nullptr_t) _NOEXCEPT : __ptr_(pointer(), __default_init_tag()) {}

  template <class _Pp, bool _Dummy = true,
            class = _EnableIfDeleterDefaultConstructible<_Dummy>,
            class = _EnableIfPointerConvertible<_Pp> >
  _LIBCPP_INLINE_VISIBILITY
  explicit unique_ptr(_Pp __p) _NOEXCEPT
      : __ptr_(__p, __default_init_tag()) {}

  template <class _Pp, bool _Dummy = true,
            class = _EnableIfDeleterConstructible<_LValRefType<_Dummy> >,
            class = _EnableIfPointerConvertible<_Pp> >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(_Pp __p, _LValRefType<_Dummy> __d) _NOEXCEPT
      : __ptr_(__p, __d) {}

  template <bool _Dummy = true,
            class = _EnableIfDeleterConstructible<_LValRefType<_Dummy> > >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(nullptr_t, _LValRefType<_Dummy> __d) _NOEXCEPT
      : __ptr_(nullptr, __d) {}

  template <class _Pp, bool _Dummy = true,
            class = _EnableIfDeleterConstructible<_GoodRValRefType<_Dummy> >,
            class = _EnableIfPointerConvertible<_Pp> >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(_Pp __p, _GoodRValRefType<_Dummy> __d) _NOEXCEPT
      : __ptr_(__p, _VSTD::move(__d)) {
    static_assert(!is_reference<deleter_type>::value,
                  "rvalue deleter bound to reference");
  }

  template <bool _Dummy = true,
            class = _EnableIfDeleterConstructible<_GoodRValRefType<_Dummy> > >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(nullptr_t, _GoodRValRefType<_Dummy> __d) _NOEXCEPT
      : __ptr_(nullptr, _VSTD::move(__d)) {
    static_assert(!is_reference<deleter_type>::value,
                  "rvalue deleter bound to reference");
  }

  template <class _Pp, bool _Dummy = true,
            class = _EnableIfDeleterConstructible<_BadRValRefType<_Dummy> >,
            class = _EnableIfPointerConvertible<_Pp> >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(_Pp __p, _BadRValRefType<_Dummy> __d) = delete;

  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(unique_ptr&& __u) _NOEXCEPT
      : __ptr_(__u.release(), _VSTD::forward<deleter_type>(__u.get_deleter())) {
  }

  _LIBCPP_INLINE_VISIBILITY
  unique_ptr& operator=(unique_ptr&& __u) _NOEXCEPT {
    reset(__u.release());
    __ptr_.second() = _VSTD::forward<deleter_type>(__u.get_deleter());
    return *this;
  }

  template <class _Up, class _Ep,
      class = _EnableIfMoveConvertible<unique_ptr<_Up, _Ep>, _Up>,
      class = _EnableIfDeleterConvertible<_Ep>
  >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr(unique_ptr<_Up, _Ep>&& __u) _NOEXCEPT
      : __ptr_(__u.release(), _VSTD::forward<_Ep>(__u.get_deleter())) {
  }

  template <class _Up, class _Ep,
      class = _EnableIfMoveConvertible<unique_ptr<_Up, _Ep>, _Up>,
      class = _EnableIfDeleterAssignable<_Ep>
  >
  _LIBCPP_INLINE_VISIBILITY
  unique_ptr&
  operator=(unique_ptr<_Up, _Ep>&& __u) _NOEXCEPT {
    reset(__u.release());
    __ptr_.second() = _VSTD::forward<_Ep>(__u.get_deleter());
    return *this;
  }

#ifdef _LIBCPP_CXX03_LANG
  unique_ptr(unique_ptr const&) = delete;
  unique_ptr& operator=(unique_ptr const&) = delete;
#endif
# 2792 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

public:
  _LIBCPP_INLINE_VISIBILITY
  ~unique_ptr() { reset(); }

  _LIBCPP_INLINE_VISIBILITY
  unique_ptr& operator=(nullptr_t) _NOEXCEPT {
    reset();
    return *this;
  }

  _LIBCPP_INLINE_VISIBILITY
  typename add_lvalue_reference<_Tp>::type
  operator[](size_t __i) const {
    return __ptr_.first()[__i];
  }
  _LIBCPP_INLINE_VISIBILITY
  pointer get() const _NOEXCEPT {
    return __ptr_.first();
  }

  _LIBCPP_INLINE_VISIBILITY
  deleter_type& get_deleter() _NOEXCEPT {
    return __ptr_.second();
  }

  _LIBCPP_INLINE_VISIBILITY
  const deleter_type& get_deleter() const _NOEXCEPT {
    return __ptr_.second();
  }
  _LIBCPP_INLINE_VISIBILITY
  _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT {
    return __ptr_.first() != nullptr;
  }

  _LIBCPP_INLINE_VISIBILITY
  pointer release() _NOEXCEPT {
    pointer __t = __ptr_.first();
    __ptr_.first() = pointer();
    return __t;
  }

  template <class _Pp>
  _LIBCPP_INLINE_VISIBILITY
  typename enable_if<
      _CheckArrayPointerConversion<_Pp>::value
  >::type
  reset(_Pp __p) _NOEXCEPT {
    pointer __tmp = __ptr_.first();
    __ptr_.first() = __p;
    if (__tmp)
      __ptr_.second()(__tmp);
  }

  _LIBCPP_INLINE_VISIBILITY
  void reset(nullptr_t = nullptr) _NOEXCEPT {
    pointer __tmp = __ptr_.first();
    __ptr_.first() = nullptr;
    if (__tmp)
      __ptr_.second()(__tmp);
  }

  _LIBCPP_INLINE_VISIBILITY
  void swap(unique_ptr& __u) _NOEXCEPT {
    __ptr_.swap(__u.__ptr_);
  }

};

template <class _Tp, class _Dp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<
    __is_swappable<_Dp>::value,
    void
>::type
swap(unique_ptr<_Tp, _Dp>& __x, unique_ptr<_Tp, _Dp>& __y) _NOEXCEPT {__x.swap(__y);}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return __x.get() == __y.get();}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return !(__x == __y);}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y)
{
    typedef typename unique_ptr<_T1, _D1>::pointer _P1;
    typedef typename unique_ptr<_T2, _D2>::pointer _P2;
    typedef typename common_type<_P1, _P2>::type _Vp;
    return less<_Vp>()(__x.get(), __y.get());
}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return __y < __x;}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return !(__y < __x);}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return !(__x < __y);}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const unique_ptr<_T1, _D1>& __x, nullptr_t) _NOEXCEPT
{
    return !__x;
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(nullptr_t, const unique_ptr<_T1, _D1>& __x) _NOEXCEPT
{
    return !__x;
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const unique_ptr<_T1, _D1>& __x, nullptr_t) _NOEXCEPT
{
    return static_cast<bool>(__x);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(nullptr_t, const unique_ptr<_T1, _D1>& __x) _NOEXCEPT
{
    return static_cast<bool>(__x);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const unique_ptr<_T1, _D1>& __x, nullptr_t)
{
    typedef typename unique_ptr<_T1, _D1>::pointer _P1;
    return less<_P1>()(__x.get(), nullptr);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(nullptr_t, const unique_ptr<_T1, _D1>& __x)
{
    typedef typename unique_ptr<_T1, _D1>::pointer _P1;
    return less<_P1>()(nullptr, __x.get());
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const unique_ptr<_T1, _D1>& __x, nullptr_t)
{
    return nullptr < __x;
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(nullptr_t, const unique_ptr<_T1, _D1>& __x)
{
    return __x < nullptr;
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const unique_ptr<_T1, _D1>& __x, nullptr_t)
{
    return !(nullptr < __x);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(nullptr_t, const unique_ptr<_T1, _D1>& __x)
{
    return !(__x < nullptr);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const unique_ptr<_T1, _D1>& __x, nullptr_t)
{
    return !(__x < nullptr);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(nullptr_t, const unique_ptr<_T1, _D1>& __x)
{
    return !(nullptr < __x);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3004 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
struct __unique_if
{
    typedef unique_ptr<_Tp> __unique_single;
};

template<class _Tp>
struct __unique_if<_Tp[]>
{
    typedef unique_ptr<_Tp[]> __unique_array_unknown_bound;
};

template<class _Tp, size_t _Np>
struct __unique_if<_Tp[_Np]>
{
    typedef void __unique_array_known_bound;
};

template<class _Tp, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
typename __unique_if<_Tp>::__unique_single
make_unique(_Args&&... __args)
{
    return unique_ptr<_Tp>(new _Tp(_VSTD::forward<_Args>(__args)...));
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename __unique_if<_Tp>::__unique_array_unknown_bound
make_unique(size_t __n)
{
    typedef typename remove_extent<_Tp>::type _Up;
    return unique_ptr<_Tp>(new _Up[__n]());
}

template<class _Tp, class... _Args>
    typename __unique_if<_Tp>::__unique_array_known_bound
    make_unique(_Args&&...) = delete;

#endif  // _LIBCPP_STD_VER > 11
# 3045 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Tp, class _Dp>
#ifdef _LIBCPP_CXX03_LANG
struct _LIBCPP_TEMPLATE_VIS hash<unique_ptr<_Tp, _Dp> >
#else
# 3050 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
struct _LIBCPP_TEMPLATE_VIS hash<__enable_hash_helper<
    unique_ptr<_Tp, _Dp>, typename unique_ptr<_Tp, _Dp>::pointer> >
#endif
# 3053 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
{
    typedef unique_ptr<_Tp, _Dp> argument_type;
    typedef size_t               result_type;
    _LIBCPP_INLINE_VISIBILITY
    result_type operator()(const argument_type& __ptr) const
    {
        typedef typename argument_type::pointer pointer;
        return hash<pointer>()(__ptr.get());
    }
};

struct __destruct_n
{
private:
    size_t __size_;

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void __process(_Tp* __p, false_type) _NOEXCEPT
        {for (size_t __i = 0; __i < __size_; ++__i, ++__p) __p->~_Tp();}

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void __process(_Tp*, true_type) _NOEXCEPT
        {}

    _LIBCPP_INLINE_VISIBILITY void __incr(false_type) _NOEXCEPT
        {++__size_;}
    _LIBCPP_INLINE_VISIBILITY void __incr(true_type) _NOEXCEPT
        {}

    _LIBCPP_INLINE_VISIBILITY void __set(size_t __s, false_type) _NOEXCEPT
        {__size_ = __s;}
    _LIBCPP_INLINE_VISIBILITY void __set(size_t, true_type) _NOEXCEPT
        {}
public:
    _LIBCPP_INLINE_VISIBILITY explicit __destruct_n(size_t __s) _NOEXCEPT
        : __size_(__s) {}

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void __incr(_Tp*) _NOEXCEPT
        {__incr(integral_constant<bool, is_trivially_destructible<_Tp>::value>());}

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void __set(size_t __s, _Tp*) _NOEXCEPT
        {__set(__s, integral_constant<bool, is_trivially_destructible<_Tp>::value>());}

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void operator()(_Tp* __p) _NOEXCEPT
        {__process(__p, integral_constant<bool, is_trivially_destructible<_Tp>::value>());}
};

template <class _Alloc>
class __allocator_destructor
{
    typedef _LIBCPP_NODEBUG_TYPE allocator_traits<_Alloc> __alloc_traits;
public:
    typedef _LIBCPP_NODEBUG_TYPE typename __alloc_traits::pointer pointer;
    typedef _LIBCPP_NODEBUG_TYPE typename __alloc_traits::size_type size_type;
private:
    _Alloc& __alloc_;
    size_type __s_;
public:
    _LIBCPP_INLINE_VISIBILITY __allocator_destructor(_Alloc& __a, size_type __s)
             _NOEXCEPT
        : __alloc_(__a), __s_(__s) {}
    _LIBCPP_INLINE_VISIBILITY
    void operator()(pointer __p) _NOEXCEPT
        {__alloc_traits::deallocate(__alloc_, __p, __s_);}
};

template <class _InputIterator, class _ForwardIterator>
_ForwardIterator
uninitialized_copy(_InputIterator __f, _InputIterator __l, _ForwardIterator __r)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
#ifndef _LIBCPP_NO_EXCEPTIONS
    _ForwardIterator __s = __r;
    try
    {
#endif
# 3132 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        for (; __f != __l; ++__f, (void) ++__r)
            ::new (static_cast<void*>(_VSTD::addressof(*__r))) value_type(*__f);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        for (; __s != __r; ++__s)
            __s->~value_type();
        throw;
    }
#endif
# 3143 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __r;
}

template <class _InputIterator, class _Size, class _ForwardIterator>
_ForwardIterator
uninitialized_copy_n(_InputIterator __f, _Size __n, _ForwardIterator __r)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
#ifndef _LIBCPP_NO_EXCEPTIONS
    _ForwardIterator __s = __r;
    try
    {
#endif
# 3156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        for (; __n > 0; ++__f, (void) ++__r, (void) --__n)
            ::new (static_cast<void*>(_VSTD::addressof(*__r))) value_type(*__f);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        for (; __s != __r; ++__s)
            __s->~value_type();
        throw;
    }
#endif
# 3167 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __r;
}

template <class _ForwardIterator, class _Tp>
void
uninitialized_fill(_ForwardIterator __f, _ForwardIterator __l, const _Tp& __x)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
#ifndef _LIBCPP_NO_EXCEPTIONS
    _ForwardIterator __s = __f;
    try
    {
#endif
# 3180 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        for (; __f != __l; ++__f)
            ::new (static_cast<void*>(_VSTD::addressof(*__f))) value_type(__x);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        for (; __s != __f; ++__s)
            __s->~value_type();
        throw;
    }
#endif
# 3191 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template <class _ForwardIterator, class _Size, class _Tp>
_ForwardIterator
uninitialized_fill_n(_ForwardIterator __f, _Size __n, const _Tp& __x)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
#ifndef _LIBCPP_NO_EXCEPTIONS
    _ForwardIterator __s = __f;
    try
    {
#endif
# 3203 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        for (; __n > 0; ++__f, (void) --__n)
            ::new (static_cast<void*>(_VSTD::addressof(*__f))) value_type(__x);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        for (; __s != __f; ++__s)
            __s->~value_type();
        throw;
    }
#endif
# 3214 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __f;
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3218 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void destroy_at(_Tp* __loc) {
    _LIBCPP_ASSERT(__loc, "null pointer given to destroy_at");
    __loc->~_Tp();
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
void destroy(_ForwardIterator __first, _ForwardIterator __last) {
    for (; __first != __last; ++__first)
        _VSTD::destroy_at(_VSTD::addressof(*__first));
}

template <class _ForwardIterator, class _Size>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator destroy_n(_ForwardIterator __first, _Size __n) {
    for (; __n > 0; (void)++__first, --__n)
        _VSTD::destroy_at(_VSTD::addressof(*__first));
    return __first;
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
void uninitialized_default_construct(_ForwardIterator __first, _ForwardIterator __last) {
    using _Vt = typename iterator_traits<_ForwardIterator>::value_type;
    auto __idx = __first;
#ifndef _LIBCPP_NO_EXCEPTIONS
    try {
#endif
# 3249 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    for (; __idx != __last; ++__idx)
        ::new((void*)_VSTD::addressof(*__idx)) _Vt;
#ifndef _LIBCPP_NO_EXCEPTIONS
    } catch (...) {
        _VSTD::destroy(__first, __idx);
        throw;
    }
#endif
# 3257 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template <class _ForwardIterator, class _Size>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator uninitialized_default_construct_n(_ForwardIterator __first, _Size __n) {
    using _Vt = typename iterator_traits<_ForwardIterator>::value_type;
    auto __idx = __first;
#ifndef _LIBCPP_NO_EXCEPTIONS
    try {
#endif
# 3267 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    for (; __n > 0; (void)++__idx, --__n)
        ::new((void*)_VSTD::addressof(*__idx)) _Vt;
    return __idx;
#ifndef _LIBCPP_NO_EXCEPTIONS
    } catch (...) {
        _VSTD::destroy(__first, __idx);
        throw;
    }
#endif
# 3276 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}


template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
void uninitialized_value_construct(_ForwardIterator __first, _ForwardIterator __last) {
    using _Vt = typename iterator_traits<_ForwardIterator>::value_type;
    auto __idx = __first;
#ifndef _LIBCPP_NO_EXCEPTIONS
    try {
#endif
# 3287 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    for (; __idx != __last; ++__idx)
        ::new((void*)_VSTD::addressof(*__idx)) _Vt();
#ifndef _LIBCPP_NO_EXCEPTIONS
    } catch (...) {
        _VSTD::destroy(__first, __idx);
        throw;
    }
#endif
# 3295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template <class _ForwardIterator, class _Size>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator uninitialized_value_construct_n(_ForwardIterator __first, _Size __n) {
    using _Vt = typename iterator_traits<_ForwardIterator>::value_type;
    auto __idx = __first;
#ifndef _LIBCPP_NO_EXCEPTIONS
    try {
#endif
# 3305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    for (; __n > 0; (void)++__idx, --__n)
        ::new((void*)_VSTD::addressof(*__idx)) _Vt();
    return __idx;
#ifndef _LIBCPP_NO_EXCEPTIONS
    } catch (...) {
        _VSTD::destroy(__first, __idx);
        throw;
    }
#endif
# 3314 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}


template <class _InputIt, class _ForwardIt>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIt uninitialized_move(_InputIt __first, _InputIt __last, _ForwardIt __first_res) {
    using _Vt = typename iterator_traits<_ForwardIt>::value_type;
    auto __idx = __first_res;
#ifndef _LIBCPP_NO_EXCEPTIONS
    try {
#endif
# 3325 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    for (; __first != __last; (void)++__idx, ++__first)
        ::new((void*)_VSTD::addressof(*__idx)) _Vt(std::move(*__first));
    return __idx;
#ifndef _LIBCPP_NO_EXCEPTIONS
    } catch (...) {
        _VSTD::destroy(__first_res, __idx);
        throw;
    }
#endif
# 3334 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template <class _InputIt, class _Size, class _ForwardIt>
inline _LIBCPP_INLINE_VISIBILITY
pair<_InputIt, _ForwardIt>
uninitialized_move_n(_InputIt __first, _Size __n, _ForwardIt __first_res) {
    using _Vt = typename iterator_traits<_ForwardIt>::value_type;
    auto __idx = __first_res;
#ifndef _LIBCPP_NO_EXCEPTIONS
    try {
#endif
# 3345 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    for (; __n > 0; ++__idx, (void)++__first, --__n)
        ::new((void*)_VSTD::addressof(*__idx)) _Vt(std::move(*__first));
    return {__first, __idx};
#ifndef _LIBCPP_NO_EXCEPTIONS
    } catch (...) {
        _VSTD::destroy(__first_res, __idx);
        throw;
    }
#endif
# 3354 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}


#endif // _LIBCPP_STD_VER > 14
# 3358 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

// NOTE: Relaxed and acq/rel atomics (for increment and decrement respectively)
// should be sufficient for thread safety.
// See https://bugs.llvm.org/show_bug.cgi?id=22803
#if 0 /* disabled by -frewrite-includes */
#if defined(__clang__) && __has_builtin(__atomic_add_fetch)          \
                       && defined(__ATOMIC_RELAXED)                  \
                       && defined(__ATOMIC_ACQ_REL)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3365 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#   define _LIBCPP_HAS_BUILTIN_ATOMIC_SUPPORT
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_COMPILER_GCC)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 3367 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#   define _LIBCPP_HAS_BUILTIN_ATOMIC_SUPPORT
#endif
# 3369 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _Tp
__libcpp_atomic_refcount_increment(_Tp& __t) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_BUILTIN_ATOMIC_SUPPORT) && !defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3375 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __atomic_add_fetch(&__t, 1, __ATOMIC_RELAXED);
#else
# 3377 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __t += 1;
#endif
# 3379 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _Tp
__libcpp_atomic_refcount_decrement(_Tp& __t) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_BUILTIN_ATOMIC_SUPPORT) && !defined(_LIBCPP_HAS_NO_THREADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3386 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __atomic_add_fetch(&__t, -1, __ATOMIC_ACQ_REL);
#else
# 3388 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return __t -= 1;
#endif
# 3390 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

class _LIBCPP_EXCEPTION_ABI bad_weak_ptr
    : public std::exception
{
public:
    virtual ~bad_weak_ptr() _NOEXCEPT;
    virtual const char* what() const  _NOEXCEPT;
};

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_bad_weak_ptr()
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw bad_weak_ptr();
#else
# 3406 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _VSTD::abort();
#endif
# 3408 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template<class _Tp> class _LIBCPP_TEMPLATE_VIS weak_ptr;

class _LIBCPP_TYPE_VIS __shared_count
{
    __shared_count(const __shared_count&);
    __shared_count& operator=(const __shared_count&);

protected:
    long __shared_owners_;
    virtual ~__shared_count();
private:
    virtual void __on_zero_shared() _NOEXCEPT = 0;

public:
    _LIBCPP_INLINE_VISIBILITY
    explicit __shared_count(long __refs = 0) _NOEXCEPT
        : __shared_owners_(__refs) {}

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_BUILDING_LIBRARY) && \
    defined(_LIBCPP_DEPRECATED_ABI_LEGACY_LIBRARY_DEFINITIONS_FOR_INLINE_FUNCTIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3430 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    void __add_shared() _NOEXCEPT;
    bool __release_shared() _NOEXCEPT;
#else
# 3433 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY
    void __add_shared() _NOEXCEPT {
      __libcpp_atomic_refcount_increment(__shared_owners_);
    }
    _LIBCPP_INLINE_VISIBILITY
    bool __release_shared() _NOEXCEPT {
      if (__libcpp_atomic_refcount_decrement(__shared_owners_) == -1) {
        __on_zero_shared();
        return true;
      }
      return false;
    }
#endif
# 3446 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY
    long use_count() const _NOEXCEPT {
        return __libcpp_relaxed_load(&__shared_owners_) + 1;
    }
};

class _LIBCPP_TYPE_VIS __shared_weak_count
    : private __shared_count
{
    long __shared_weak_owners_;

public:
    _LIBCPP_INLINE_VISIBILITY
    explicit __shared_weak_count(long __refs = 0) _NOEXCEPT
        : __shared_count(__refs),
          __shared_weak_owners_(__refs) {}
protected:
    virtual ~__shared_weak_count();

public:
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_BUILDING_LIBRARY) && \
    defined(_LIBCPP_DEPRECATED_ABI_LEGACY_LIBRARY_DEFINITIONS_FOR_INLINE_FUNCTIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3468 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    void __add_shared() _NOEXCEPT;
    void __add_weak() _NOEXCEPT;
    void __release_shared() _NOEXCEPT;
#else
# 3472 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY
    void __add_shared() _NOEXCEPT {
      __shared_count::__add_shared();
    }
    _LIBCPP_INLINE_VISIBILITY
    void __add_weak() _NOEXCEPT {
      __libcpp_atomic_refcount_increment(__shared_weak_owners_);
    }
    _LIBCPP_INLINE_VISIBILITY
    void __release_shared() _NOEXCEPT {
      if (__shared_count::__release_shared())
        __release_weak();
    }
#endif
# 3486 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    void __release_weak() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    long use_count() const _NOEXCEPT {return __shared_count::use_count();}
    __shared_weak_count* lock() _NOEXCEPT;

    // Define the function out only if we build static libc++ without RTTI.
    // Otherwise we may break clients who need to compile their projects with
    // -fno-rtti and yet link against a libc++.dylib compiled
    // without -fno-rtti.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_NO_RTTI) || !defined(_LIBCPP_BUILD_STATIC)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3496 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    virtual const void* __get_deleter(const type_info&) const _NOEXCEPT;
#endif
# 3498 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
private:
    virtual void __on_zero_shared_weak() _NOEXCEPT = 0;
};

template <class _Tp, class _Dp, class _Alloc>
class __shared_ptr_pointer
    : public __shared_weak_count
{
    __compressed_pair<__compressed_pair<_Tp, _Dp>, _Alloc> __data_;
public:
    _LIBCPP_INLINE_VISIBILITY
    __shared_ptr_pointer(_Tp __p, _Dp __d, _Alloc __a)
        :  __data_(__compressed_pair<_Tp, _Dp>(__p, _VSTD::move(__d)), _VSTD::move(__a)) {}

#ifndef _LIBCPP_NO_RTTI
    virtual const void* __get_deleter(const type_info&) const _NOEXCEPT;
#endif
# 3515 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

private:
    virtual void __on_zero_shared() _NOEXCEPT;
    virtual void __on_zero_shared_weak() _NOEXCEPT;
};

#ifndef _LIBCPP_NO_RTTI

template <class _Tp, class _Dp, class _Alloc>
const void*
__shared_ptr_pointer<_Tp, _Dp, _Alloc>::__get_deleter(const type_info& __t) const _NOEXCEPT
{
    return __t == typeid(_Dp) ? _VSTD::addressof(__data_.first().second()) : nullptr;
}

#endif  // _LIBCPP_NO_RTTI
# 3531 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Tp, class _Dp, class _Alloc>
void
__shared_ptr_pointer<_Tp, _Dp, _Alloc>::__on_zero_shared() _NOEXCEPT
{
    __data_.first().second()(__data_.first().first());
    __data_.first().second().~_Dp();
}

template <class _Tp, class _Dp, class _Alloc>
void
__shared_ptr_pointer<_Tp, _Dp, _Alloc>::__on_zero_shared_weak() _NOEXCEPT
{
    typedef typename __allocator_traits_rebind<_Alloc, __shared_ptr_pointer>::type _Al;
    typedef allocator_traits<_Al> _ATraits;
    typedef pointer_traits<typename _ATraits::pointer> _PTraits;

    _Al __a(__data_.second());
    __data_.second().~_Alloc();
    __a.deallocate(_PTraits::pointer_to(*this), 1);
}

template <class _Tp, class _Alloc>
class __shared_ptr_emplace
    : public __shared_weak_count
{
    __compressed_pair<_Alloc, _Tp> __data_;
public:

    _LIBCPP_INLINE_VISIBILITY
    __shared_ptr_emplace(_Alloc __a)
        :  __data_(_VSTD::move(__a), __value_init_tag()) {}


#ifndef _LIBCPP_HAS_NO_VARIADICS
    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        __shared_ptr_emplace(_Alloc __a, _Args&& ...__args)
            :  __data_(piecewise_construct, _VSTD::forward_as_tuple(__a),
                   _VSTD::forward_as_tuple(_VSTD::forward<_Args>(__args)...)) {}
#else  // _LIBCPP_HAS_NO_VARIADICS
# 3572 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        __shared_ptr_emplace(_Alloc __a, _A0& __a0)
            :  __data_(__a, _Tp(__a0)) {}

    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        __shared_ptr_emplace(_Alloc __a, _A0& __a0, _A1& __a1)
            :  __data_(__a, _Tp(__a0, __a1)) {}

    template <class _A0, class _A1, class _A2>
        _LIBCPP_INLINE_VISIBILITY
        __shared_ptr_emplace(_Alloc __a, _A0& __a0, _A1& __a1, _A2& __a2)
            :  __data_(__a, _Tp(__a0, __a1, __a2)) {}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 3589 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

private:
    virtual void __on_zero_shared() _NOEXCEPT;
    virtual void __on_zero_shared_weak() _NOEXCEPT;
public:
    _LIBCPP_INLINE_VISIBILITY
    _Tp* get() _NOEXCEPT {return _VSTD::addressof(__data_.second());}
};

template <class _Tp, class _Alloc>
void
__shared_ptr_emplace<_Tp, _Alloc>::__on_zero_shared() _NOEXCEPT
{
    __data_.second().~_Tp();
}

template <class _Tp, class _Alloc>
void
__shared_ptr_emplace<_Tp, _Alloc>::__on_zero_shared_weak() _NOEXCEPT
{
    typedef typename __allocator_traits_rebind<_Alloc, __shared_ptr_emplace>::type _Al;
    typedef allocator_traits<_Al> _ATraits;
    typedef pointer_traits<typename _ATraits::pointer> _PTraits;
    _Al __a(__data_.first());
    __data_.first().~_Alloc();
    __a.deallocate(_PTraits::pointer_to(*this), 1);
}

struct __shared_ptr_dummy_rebind_allocator_type;
template <>
class _LIBCPP_TEMPLATE_VIS allocator<__shared_ptr_dummy_rebind_allocator_type>
{
public:
    template <class _Other>
    struct rebind
    {
        typedef allocator<_Other> other;
    };
};

template<class _Tp> class _LIBCPP_TEMPLATE_VIS enable_shared_from_this;

template<class _Tp>
class _LIBCPP_TEMPLATE_VIS shared_ptr
{
public:
    typedef _Tp element_type;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3638 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef weak_ptr<_Tp> weak_type;
#endif
# 3640 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
private:
    element_type*      __ptr_;
    __shared_weak_count* __cntrl_;

    struct __nat {int __for_bool_;};
public:
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR shared_ptr() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR shared_ptr(nullptr_t) _NOEXCEPT;
    template<class _Yp>
        explicit shared_ptr(_Yp* __p,
                            typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type = __nat());
    template<class _Yp, class _Dp>
        shared_ptr(_Yp* __p, _Dp __d,
                   typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type = __nat());
    template<class _Yp, class _Dp, class _Alloc>
        shared_ptr(_Yp* __p, _Dp __d, _Alloc __a,
                   typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type = __nat());
    template <class _Dp> shared_ptr(nullptr_t __p, _Dp __d);
    template <class _Dp, class _Alloc> shared_ptr(nullptr_t __p, _Dp __d, _Alloc __a);
    template<class _Yp> _LIBCPP_INLINE_VISIBILITY shared_ptr(const shared_ptr<_Yp>& __r, element_type* __p) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    shared_ptr(const shared_ptr& __r) _NOEXCEPT;
    template<class _Yp>
        _LIBCPP_INLINE_VISIBILITY
        shared_ptr(const shared_ptr<_Yp>& __r,
                   typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type = __nat())
                       _NOEXCEPT;
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    shared_ptr(shared_ptr&& __r) _NOEXCEPT;
    template<class _Yp> _LIBCPP_INLINE_VISIBILITY  shared_ptr(shared_ptr<_Yp>&& __r,
                   typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type = __nat())
                       _NOEXCEPT;
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3676 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template<class _Yp> explicit shared_ptr(const weak_ptr<_Yp>& __r,
                   typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type= __nat());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3679 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    template<class _Yp>
        shared_ptr(auto_ptr<_Yp>&& __r,
                   typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type = __nat());
#else
# 3684 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template<class _Yp>
        shared_ptr(auto_ptr<_Yp> __r,
                   typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type = __nat());
#endif
# 3688 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#endif
# 3689 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    template <class _Yp, class _Dp>
        shared_ptr(unique_ptr<_Yp, _Dp>&&,
                   typename enable_if
                   <
                       !is_lvalue_reference<_Dp>::value &&
                       !is_array<_Yp>::value &&
                       is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value,
                       __nat
                   >::type = __nat());
    template <class _Yp, class _Dp>
        shared_ptr(unique_ptr<_Yp, _Dp>&&,
                   typename enable_if
                   <
                       is_lvalue_reference<_Dp>::value &&
                       !is_array<_Yp>::value &&
                       is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value,
                       __nat
                   >::type = __nat());
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3709 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Yp, class _Dp>
        shared_ptr(unique_ptr<_Yp, _Dp>,
                   typename enable_if
                   <
                       !is_lvalue_reference<_Dp>::value &&
                       !is_array<_Yp>::value &&
                       is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value,
                       __nat
                   >::type = __nat());
    template <class _Yp, class _Dp>
        shared_ptr(unique_ptr<_Yp, _Dp>,
                   typename enable_if
                   <
                       is_lvalue_reference<_Dp>::value &&
                       !is_array<_Yp>::value &&
                       is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value,
                       __nat
                   >::type = __nat());
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3728 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    ~shared_ptr();

    _LIBCPP_INLINE_VISIBILITY
    shared_ptr& operator=(const shared_ptr& __r) _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            shared_ptr&
        >::type
        _LIBCPP_INLINE_VISIBILITY
        operator=(const shared_ptr<_Yp>& __r) _NOEXCEPT;
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    shared_ptr& operator=(shared_ptr&& __r) _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            shared_ptr<_Tp>&
        >::type
        _LIBCPP_INLINE_VISIBILITY
        operator=(shared_ptr<_Yp>&& __r);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3753 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template<class _Yp>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            !is_array<_Yp>::value &&
            is_convertible<_Yp*, element_type*>::value,
            shared_ptr
        >::type&
        operator=(auto_ptr<_Yp>&& __r);
#endif
# 3763 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3764 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3765 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template<class _Yp>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            !is_array<_Yp>::value &&
            is_convertible<_Yp*, element_type*>::value,
            shared_ptr&
        >::type
        operator=(auto_ptr<_Yp> __r);
#endif
# 3775 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#endif
# 3776 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    template <class _Yp, class _Dp>
        typename enable_if
        <
            !is_array<_Yp>::value &&
            is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value,
            shared_ptr&
        >::type
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
        _LIBCPP_INLINE_VISIBILITY
        operator=(unique_ptr<_Yp, _Dp>&& __r);
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3787 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        _LIBCPP_INLINE_VISIBILITY
        operator=(unique_ptr<_Yp, _Dp> __r);
#endif
# 3790 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY
    void swap(shared_ptr& __r) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    void reset() _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            void
        >::type
        _LIBCPP_INLINE_VISIBILITY
        reset(_Yp* __p);
    template<class _Yp, class _Dp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            void
        >::type
        _LIBCPP_INLINE_VISIBILITY
        reset(_Yp* __p, _Dp __d);
    template<class _Yp, class _Dp, class _Alloc>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            void
        >::type
        _LIBCPP_INLINE_VISIBILITY
        reset(_Yp* __p, _Dp __d, _Alloc __a);

    _LIBCPP_INLINE_VISIBILITY
    element_type* get() const _NOEXCEPT {return __ptr_;}
    _LIBCPP_INLINE_VISIBILITY
    typename add_lvalue_reference<element_type>::type operator*() const _NOEXCEPT
        {return *__ptr_;}
    _LIBCPP_INLINE_VISIBILITY
    element_type* operator->() const _NOEXCEPT {return __ptr_;}
    _LIBCPP_INLINE_VISIBILITY
    long use_count() const _NOEXCEPT {return __cntrl_ ? __cntrl_->use_count() : 0;}
    _LIBCPP_INLINE_VISIBILITY
    bool unique() const _NOEXCEPT {return use_count() == 1;}
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT {return get() != 0;}
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY
        bool owner_before(shared_ptr<_Up> const& __p) const _NOEXCEPT
        {return __cntrl_ < __p.__cntrl_;}
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY
        bool owner_before(weak_ptr<_Up> const& __p) const _NOEXCEPT
        {return __cntrl_ < __p.__cntrl_;}
    _LIBCPP_INLINE_VISIBILITY
    bool
    __owner_equivalent(const shared_ptr& __p) const
        {return __cntrl_ == __p.__cntrl_;}

#ifndef _LIBCPP_NO_RTTI
    template <class _Dp>
        _LIBCPP_INLINE_VISIBILITY
        _Dp* __get_deleter() const _NOEXCEPT
            {return static_cast<_Dp*>(__cntrl_
                    ? const_cast<void *>(__cntrl_->__get_deleter(typeid(_Dp)))
                      : nullptr);}
#endif  // _LIBCPP_NO_RTTI
# 3854 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    template<class _Yp, class _CntrlBlk>
    static shared_ptr<_Tp>
    __create_with_control_block(_Yp* __p, _CntrlBlk* __cntrl)
    {
        shared_ptr<_Tp> __r;
        __r.__ptr_ = __p;
        __r.__cntrl_ = __cntrl;
        __r.__enable_weak_this(__r.__ptr_, __r.__ptr_);
        return __r;
    }

    template<class _Alloc, class ..._Args>
        static
        shared_ptr<_Tp>
        allocate_shared(const _Alloc& __a, _Args&& ...__args);

private:
    template <class _Yp, bool = is_function<_Yp>::value>
        struct __shared_ptr_default_allocator
        {
            typedef allocator<_Yp> type;
        };

    template <class _Yp>
        struct __shared_ptr_default_allocator<_Yp, true>
        {
            typedef allocator<__shared_ptr_dummy_rebind_allocator_type> type;
        };

    template <class _Yp, class _OrigPtr>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if<is_convertible<_OrigPtr*,
                                          const enable_shared_from_this<_Yp>*
        >::value,
            void>::type
        __enable_weak_this(const enable_shared_from_this<_Yp>* __e,
                           _OrigPtr* __ptr) _NOEXCEPT
        {
            typedef typename remove_cv<_Yp>::type _RawYp;
            if (__e && __e->__weak_this_.expired())
            {
                __e->__weak_this_ = shared_ptr<_RawYp>(*this,
                    const_cast<_RawYp*>(static_cast<const _Yp*>(__ptr)));
            }
        }

    _LIBCPP_INLINE_VISIBILITY void __enable_weak_this(...) _NOEXCEPT {}

    template <class _Up> friend class _LIBCPP_TEMPLATE_VIS shared_ptr;
    template <class _Up> friend class _LIBCPP_TEMPLATE_VIS weak_ptr;
};


template<class _Tp>
inline
_LIBCPP_CONSTEXPR
shared_ptr<_Tp>::shared_ptr() _NOEXCEPT
    : __ptr_(0),
      __cntrl_(0)
{
}

template<class _Tp>
inline
_LIBCPP_CONSTEXPR
shared_ptr<_Tp>::shared_ptr(nullptr_t) _NOEXCEPT
    : __ptr_(0),
      __cntrl_(0)
{
}

template<class _Tp>
template<class _Yp>
shared_ptr<_Tp>::shared_ptr(_Yp* __p,
                            typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type)
    : __ptr_(__p)
{
    unique_ptr<_Yp> __hold(__p);
    typedef typename __shared_ptr_default_allocator<_Yp>::type _AllocT;
    typedef __shared_ptr_pointer<_Yp*, default_delete<_Yp>, _AllocT > _CntrlBlk;
    __cntrl_ = new _CntrlBlk(__p, default_delete<_Yp>(), _AllocT());
    __hold.release();
    __enable_weak_this(__p, __p);
}

template<class _Tp>
template<class _Yp, class _Dp>
shared_ptr<_Tp>::shared_ptr(_Yp* __p, _Dp __d,
                            typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type)
    : __ptr_(__p)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3950 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        typedef typename __shared_ptr_default_allocator<_Yp>::type _AllocT;
        typedef __shared_ptr_pointer<_Yp*, _Dp, _AllocT > _CntrlBlk;
        __cntrl_ = new _CntrlBlk(__p, __d, _AllocT());
        __enable_weak_this(__p, __p);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        __d(__p);
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3962 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template<class _Tp>
template<class _Dp>
shared_ptr<_Tp>::shared_ptr(nullptr_t __p, _Dp __d)
    : __ptr_(0)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3973 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        typedef typename __shared_ptr_default_allocator<_Tp>::type _AllocT;
        typedef __shared_ptr_pointer<nullptr_t, _Dp, _AllocT > _CntrlBlk;
        __cntrl_ = new _CntrlBlk(__p, __d, _AllocT());
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        __d(__p);
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3984 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template<class _Tp>
template<class _Yp, class _Dp, class _Alloc>
shared_ptr<_Tp>::shared_ptr(_Yp* __p, _Dp __d, _Alloc __a,
                            typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type)
    : __ptr_(__p)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3996 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        typedef __shared_ptr_pointer<_Yp*, _Dp, _Alloc> _CntrlBlk;
        typedef typename __allocator_traits_rebind<_Alloc, _CntrlBlk>::type _A2;
        typedef __allocator_destructor<_A2> _D2;
        _A2 __a2(__a);
        unique_ptr<_CntrlBlk, _D2> __hold2(__a2.allocate(1), _D2(__a2, 1));
        ::new(static_cast<void*>(_VSTD::addressof(*__hold2.get())))
            _CntrlBlk(__p, __d, __a);
        __cntrl_ = _VSTD::addressof(*__hold2.release());
        __enable_weak_this(__p, __p);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        __d(__p);
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4013 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template<class _Tp>
template<class _Dp, class _Alloc>
shared_ptr<_Tp>::shared_ptr(nullptr_t __p, _Dp __d, _Alloc __a)
    : __ptr_(0)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4024 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        typedef __shared_ptr_pointer<nullptr_t, _Dp, _Alloc> _CntrlBlk;
        typedef typename __allocator_traits_rebind<_Alloc, _CntrlBlk>::type _A2;
        typedef __allocator_destructor<_A2> _D2;
        _A2 __a2(__a);
        unique_ptr<_CntrlBlk, _D2> __hold2(__a2.allocate(1), _D2(__a2, 1));
        ::new(static_cast<void*>(_VSTD::addressof(*__hold2.get())))
            _CntrlBlk(__p, __d, __a);
        __cntrl_ = _VSTD::addressof(*__hold2.release());
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        __d(__p);
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4040 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
}

template<class _Tp>
template<class _Yp>
inline
shared_ptr<_Tp>::shared_ptr(const shared_ptr<_Yp>& __r, element_type *__p) _NOEXCEPT
    : __ptr_(__p),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_shared();
}

template<class _Tp>
inline
shared_ptr<_Tp>::shared_ptr(const shared_ptr& __r) _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_shared();
}

template<class _Tp>
template<class _Yp>
inline
shared_ptr<_Tp>::shared_ptr(const shared_ptr<_Yp>& __r,
                            typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type)
         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_shared();
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Tp>
inline
shared_ptr<_Tp>::shared_ptr(shared_ptr&& __r) _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    __r.__ptr_ = 0;
    __r.__cntrl_ = 0;
}

template<class _Tp>
template<class _Yp>
inline
shared_ptr<_Tp>::shared_ptr(shared_ptr<_Yp>&& __r,
                            typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type)
         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    __r.__ptr_ = 0;
    __r.__cntrl_ = 0;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
template<class _Tp>
template<class _Yp>
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
shared_ptr<_Tp>::shared_ptr(auto_ptr<_Yp>&& __r,
#else
# 4109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
shared_ptr<_Tp>::shared_ptr(auto_ptr<_Yp> __r,
#endif
# 4111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
                            typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type)
    : __ptr_(__r.get())
{
    typedef __shared_ptr_pointer<_Yp*, default_delete<_Yp>, allocator<_Yp> > _CntrlBlk;
    __cntrl_ = new _CntrlBlk(__r.get(), default_delete<_Yp>(), allocator<_Yp>());
    __enable_weak_this(__r.get(), __r.get());
    __r.release();
}
#endif
# 4120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
template <class _Yp, class _Dp>
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
shared_ptr<_Tp>::shared_ptr(unique_ptr<_Yp, _Dp>&& __r,
#else
# 4126 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
shared_ptr<_Tp>::shared_ptr(unique_ptr<_Yp, _Dp> __r,
#endif
# 4128 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
                            typename enable_if
                            <
                                !is_lvalue_reference<_Dp>::value &&
                                !is_array<_Yp>::value &&
                                is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value,
                                __nat
                            >::type)
    : __ptr_(__r.get())
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4138 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    if (__ptr_ == nullptr)
        __cntrl_ = nullptr;
    else
#endif
# 4142 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    {
        typedef typename __shared_ptr_default_allocator<_Yp>::type _AllocT;
        typedef __shared_ptr_pointer<_Yp*, _Dp, _AllocT > _CntrlBlk;
        __cntrl_ = new _CntrlBlk(__r.get(), __r.get_deleter(), _AllocT());
        __enable_weak_this(__r.get(), __r.get());
    }
    __r.release();
}

template<class _Tp>
template <class _Yp, class _Dp>
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
shared_ptr<_Tp>::shared_ptr(unique_ptr<_Yp, _Dp>&& __r,
#else
# 4156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
shared_ptr<_Tp>::shared_ptr(unique_ptr<_Yp, _Dp> __r,
#endif
# 4158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
                            typename enable_if
                            <
                                is_lvalue_reference<_Dp>::value &&
                                !is_array<_Yp>::value &&
                                is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value,
                                __nat
                            >::type)
    : __ptr_(__r.get())
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4168 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    if (__ptr_ == nullptr)
        __cntrl_ = nullptr;
    else
#endif
# 4172 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    {
        typedef typename __shared_ptr_default_allocator<_Yp>::type _AllocT;
        typedef __shared_ptr_pointer<_Yp*,
                                     reference_wrapper<typename remove_reference<_Dp>::type>,
                                     _AllocT > _CntrlBlk;
        __cntrl_ = new _CntrlBlk(__r.get(), ref(__r.get_deleter()), _AllocT());
        __enable_weak_this(__r.get(), __r.get());
    }
    __r.release();
}

template<class _Tp>
template<class _Alloc, class ..._Args>
shared_ptr<_Tp>
shared_ptr<_Tp>::allocate_shared(const _Alloc& __a, _Args&& ...__args)
{
    static_assert( is_constructible<_Tp, _Args...>::value, "Can't construct object in allocate_shared" );
    typedef __shared_ptr_emplace<_Tp, _Alloc> _CntrlBlk;
    typedef typename __allocator_traits_rebind<_Alloc, _CntrlBlk>::type _A2;
    typedef __allocator_destructor<_A2> _D2;
    _A2 __a2(__a);
    unique_ptr<_CntrlBlk, _D2> __hold2(__a2.allocate(1), _D2(__a2, 1));
    ::new(static_cast<void*>(_VSTD::addressof(*__hold2.get())))
        _CntrlBlk(__a, _VSTD::forward<_Args>(__args)...);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = _VSTD::addressof(*__hold2.release());
    __r.__enable_weak_this(__r.__ptr_, __r.__ptr_);
    return __r;
}

template<class _Tp>
shared_ptr<_Tp>::~shared_ptr()
{
    if (__cntrl_)
        __cntrl_->__release_shared();
}

template<class _Tp>
inline
shared_ptr<_Tp>&
shared_ptr<_Tp>::operator=(const shared_ptr& __r) _NOEXCEPT
{
    shared_ptr(__r).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline
typename enable_if
<
    is_convertible<_Yp*, typename shared_ptr<_Tp>::element_type*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(const shared_ptr<_Yp>& __r) _NOEXCEPT
{
    shared_ptr(__r).swap(*this);
    return *this;
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Tp>
inline
shared_ptr<_Tp>&
shared_ptr<_Tp>::operator=(shared_ptr&& __r) _NOEXCEPT
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline
typename enable_if
<
    is_convertible<_Yp*, typename shared_ptr<_Tp>::element_type*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(shared_ptr<_Yp>&& __r)
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4259 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
template<class _Tp>
template<class _Yp>
inline
typename enable_if
<
    !is_array<_Yp>::value &&
    is_convertible<_Yp*, typename shared_ptr<_Tp>::element_type*>::value,
    shared_ptr<_Tp>
>::type&
shared_ptr<_Tp>::operator=(auto_ptr<_Yp>&& __r)
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}
#endif
# 4274 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
template <class _Yp, class _Dp>
inline
typename enable_if
<
    !is_array<_Yp>::value &&
    is_convertible<typename unique_ptr<_Yp, _Dp>::pointer,
                   typename shared_ptr<_Tp>::element_type*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(unique_ptr<_Yp, _Dp>&& __r)
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4292 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_AUTO_PTR)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4294 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Yp>::value &&
    is_convertible<_Yp*, typename shared_ptr<_Tp>::element_type*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(auto_ptr<_Yp> __r)
{
    shared_ptr(__r).swap(*this);
    return *this;
}
#endif
# 4309 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
template <class _Yp, class _Dp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Yp>::value &&
    is_convertible<typename unique_ptr<_Yp, _Dp>::pointer,
                   typename shared_ptr<_Tp>::element_type*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(unique_ptr<_Yp, _Dp> __r)
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4327 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
inline
void
shared_ptr<_Tp>::swap(shared_ptr& __r) _NOEXCEPT
{
    _VSTD::swap(__ptr_, __r.__ptr_);
    _VSTD::swap(__cntrl_, __r.__cntrl_);
}

template<class _Tp>
inline
void
shared_ptr<_Tp>::reset() _NOEXCEPT
{
    shared_ptr().swap(*this);
}

template<class _Tp>
template<class _Yp>
inline
typename enable_if
<
    is_convertible<_Yp*, typename shared_ptr<_Tp>::element_type*>::value,
    void
>::type
shared_ptr<_Tp>::reset(_Yp* __p)
{
    shared_ptr(__p).swap(*this);
}

template<class _Tp>
template<class _Yp, class _Dp>
inline
typename enable_if
<
    is_convertible<_Yp*, typename shared_ptr<_Tp>::element_type*>::value,
    void
>::type
shared_ptr<_Tp>::reset(_Yp* __p, _Dp __d)
{
    shared_ptr(__p, __d).swap(*this);
}

template<class _Tp>
template<class _Yp, class _Dp, class _Alloc>
inline
typename enable_if
<
    is_convertible<_Yp*, typename shared_ptr<_Tp>::element_type*>::value,
    void
>::type
shared_ptr<_Tp>::reset(_Yp* __p, _Dp __d, _Alloc __a)
{
    shared_ptr(__p, __d, __a).swap(*this);
}

template<class _Tp, class ..._Args>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Tp>::value,
    shared_ptr<_Tp>
>::type
make_shared(_Args&& ...__args)
{
    static_assert(is_constructible<_Tp, _Args...>::value, "Can't construct object in make_shared");
    typedef __shared_ptr_emplace<_Tp, allocator<_Tp> > _CntrlBlk;
    typedef allocator<_CntrlBlk> _A2;
    typedef __allocator_destructor<_A2> _D2;

    _A2 __a2;
    unique_ptr<_CntrlBlk, _D2> __hold2(__a2.allocate(1), _D2(__a2, 1));
    ::new(__hold2.get()) _CntrlBlk(__a2, _VSTD::forward<_Args>(__args)...);

    _Tp *__ptr = __hold2.get()->get();
    return shared_ptr<_Tp>::__create_with_control_block(__ptr, __hold2.release());
}

template<class _Tp, class _Alloc, class ..._Args>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Tp>::value,
    shared_ptr<_Tp>
>::type
allocate_shared(const _Alloc& __a, _Args&& ...__args)
{
    return shared_ptr<_Tp>::allocate_shared(__a, _VSTD::forward<_Args>(__args)...);
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return __x.get() == __y.get();
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return !(__x == __y);
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 11
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4440 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    typedef typename common_type<_Tp*, _Up*>::type _Vp;
    return less<_Vp>()(__x.get(), __y.get());
#else
# 4443 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    return less<>()(__x.get(), __y.get());
#endif
# 4445 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return __y < __x;
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return !(__y < __x);
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return !(__x < __y);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return !__x;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return !__x;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return static_cast<bool>(__x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return static_cast<bool>(__x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return less<_Tp*>()(__x.get(), nullptr);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return less<_Tp*>()(nullptr, __x.get());
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return nullptr < __x;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return __x < nullptr;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return !(nullptr < __x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return !(__x < nullptr);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return !(__x < nullptr);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return !(nullptr < __x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(shared_ptr<_Tp>& __x, shared_ptr<_Tp>& __y) _NOEXCEPT
{
    __x.swap(__y);
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Tp>::value && !is_array<_Up>::value,
    shared_ptr<_Tp>
>::type
static_pointer_cast(const shared_ptr<_Up>& __r) _NOEXCEPT
{
    return shared_ptr<_Tp>(__r, static_cast<_Tp*>(__r.get()));
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Tp>::value && !is_array<_Up>::value,
    shared_ptr<_Tp>
>::type
dynamic_pointer_cast(const shared_ptr<_Up>& __r) _NOEXCEPT
{
    _Tp* __p = dynamic_cast<_Tp*>(__r.get());
    return __p ? shared_ptr<_Tp>(__r, __p) : shared_ptr<_Tp>();
}

template<class _Tp, class _Up>
typename enable_if
<
    is_array<_Tp>::value == is_array<_Up>::value,
    shared_ptr<_Tp>
>::type
const_pointer_cast(const shared_ptr<_Up>& __r) _NOEXCEPT
{
    typedef typename remove_extent<_Tp>::type _RTp;
    return shared_ptr<_Tp>(__r, const_cast<_RTp*>(__r.get()));
}

#ifndef _LIBCPP_NO_RTTI

template<class _Dp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Dp*
get_deleter(const shared_ptr<_Tp>& __p) _NOEXCEPT
{
    return __p.template __get_deleter<_Dp>();
}

#endif  // _LIBCPP_NO_RTTI
# 4624 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
class _LIBCPP_TEMPLATE_VIS weak_ptr
{
public:
    typedef _Tp element_type;
private:
    element_type*        __ptr_;
    __shared_weak_count* __cntrl_;

public:
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR weak_ptr() _NOEXCEPT;
    template<class _Yp> _LIBCPP_INLINE_VISIBILITY weak_ptr(shared_ptr<_Yp> const& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type = 0)
                        _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    weak_ptr(weak_ptr const& __r) _NOEXCEPT;
    template<class _Yp> _LIBCPP_INLINE_VISIBILITY weak_ptr(weak_ptr<_Yp> const& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type = 0)
                         _NOEXCEPT;

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    weak_ptr(weak_ptr&& __r) _NOEXCEPT;
    template<class _Yp> _LIBCPP_INLINE_VISIBILITY weak_ptr(weak_ptr<_Yp>&& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type = 0)
                         _NOEXCEPT;
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    ~weak_ptr();

    _LIBCPP_INLINE_VISIBILITY
    weak_ptr& operator=(weak_ptr const& __r) _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            weak_ptr&
        >::type
        _LIBCPP_INLINE_VISIBILITY
        operator=(weak_ptr<_Yp> const& __r) _NOEXCEPT;

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

    _LIBCPP_INLINE_VISIBILITY
    weak_ptr& operator=(weak_ptr&& __r) _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            weak_ptr&
        >::type
        _LIBCPP_INLINE_VISIBILITY
        operator=(weak_ptr<_Yp>&& __r) _NOEXCEPT;

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4680 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            weak_ptr&
        >::type
        _LIBCPP_INLINE_VISIBILITY
        operator=(shared_ptr<_Yp> const& __r) _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    void swap(weak_ptr& __r) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    void reset() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    long use_count() const _NOEXCEPT
        {return __cntrl_ ? __cntrl_->use_count() : 0;}
    _LIBCPP_INLINE_VISIBILITY
    bool expired() const _NOEXCEPT
        {return __cntrl_ == 0 || __cntrl_->use_count() == 0;}
    shared_ptr<_Tp> lock() const _NOEXCEPT;
    template<class _Up>
        _LIBCPP_INLINE_VISIBILITY
        bool owner_before(const shared_ptr<_Up>& __r) const _NOEXCEPT
        {return __cntrl_ < __r.__cntrl_;}
    template<class _Up>
        _LIBCPP_INLINE_VISIBILITY
        bool owner_before(const weak_ptr<_Up>& __r) const _NOEXCEPT
        {return __cntrl_ < __r.__cntrl_;}

    template <class _Up> friend class _LIBCPP_TEMPLATE_VIS weak_ptr;
    template <class _Up> friend class _LIBCPP_TEMPLATE_VIS shared_ptr;
};

template<class _Tp>
inline
_LIBCPP_CONSTEXPR
weak_ptr<_Tp>::weak_ptr() _NOEXCEPT
    : __ptr_(0),
      __cntrl_(0)
{
}

template<class _Tp>
inline
weak_ptr<_Tp>::weak_ptr(weak_ptr const& __r) _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_weak();
}

template<class _Tp>
template<class _Yp>
inline
weak_ptr<_Tp>::weak_ptr(shared_ptr<_Yp> const& __r,
                        typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type)
                         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_weak();
}

template<class _Tp>
template<class _Yp>
inline
weak_ptr<_Tp>::weak_ptr(weak_ptr<_Yp> const& __r,
                        typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type)
         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_weak();
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Tp>
inline
weak_ptr<_Tp>::weak_ptr(weak_ptr&& __r) _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    __r.__ptr_ = 0;
    __r.__cntrl_ = 0;
}

template<class _Tp>
template<class _Yp>
inline
weak_ptr<_Tp>::weak_ptr(weak_ptr<_Yp>&& __r,
                        typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type)
         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    __r.__ptr_ = 0;
    __r.__cntrl_ = 0;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4786 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
weak_ptr<_Tp>::~weak_ptr()
{
    if (__cntrl_)
        __cntrl_->__release_weak();
}

template<class _Tp>
inline
weak_ptr<_Tp>&
weak_ptr<_Tp>::operator=(weak_ptr const& __r) _NOEXCEPT
{
    weak_ptr(__r).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    weak_ptr<_Tp>&
>::type
weak_ptr<_Tp>::operator=(weak_ptr<_Yp> const& __r) _NOEXCEPT
{
    weak_ptr(__r).swap(*this);
    return *this;
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Tp>
inline
weak_ptr<_Tp>&
weak_ptr<_Tp>::operator=(weak_ptr&& __r) _NOEXCEPT
{
    weak_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    weak_ptr<_Tp>&
>::type
weak_ptr<_Tp>::operator=(weak_ptr<_Yp>&& __r) _NOEXCEPT
{
    weak_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4843 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
template<class _Yp>
inline
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    weak_ptr<_Tp>&
>::type
weak_ptr<_Tp>::operator=(shared_ptr<_Yp> const& __r) _NOEXCEPT
{
    weak_ptr(__r).swap(*this);
    return *this;
}

template<class _Tp>
inline
void
weak_ptr<_Tp>::swap(weak_ptr& __r) _NOEXCEPT
{
    _VSTD::swap(__ptr_, __r.__ptr_);
    _VSTD::swap(__cntrl_, __r.__cntrl_);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(weak_ptr<_Tp>& __x, weak_ptr<_Tp>& __y) _NOEXCEPT
{
    __x.swap(__y);
}

template<class _Tp>
inline
void
weak_ptr<_Tp>::reset() _NOEXCEPT
{
    weak_ptr().swap(*this);
}

template<class _Tp>
template<class _Yp>
shared_ptr<_Tp>::shared_ptr(const weak_ptr<_Yp>& __r,
                            typename enable_if<is_convertible<_Yp*, element_type*>::value, __nat>::type)
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_ ? __r.__cntrl_->lock() : __r.__cntrl_)
{
    if (__cntrl_ == 0)
        __throw_bad_weak_ptr();
}

template<class _Tp>
shared_ptr<_Tp>
weak_ptr<_Tp>::lock() const _NOEXCEPT
{
    shared_ptr<_Tp> __r;
    __r.__cntrl_ = __cntrl_ ? __cntrl_->lock() : __cntrl_;
    if (__r.__cntrl_)
        __r.__ptr_ = __ptr_;
    return __r;
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4906 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
template <class _Tp = void> struct owner_less;
#else
# 4908 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
template <class _Tp> struct owner_less;
#endif
# 4910 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS owner_less<shared_ptr<_Tp> >
    : binary_function<shared_ptr<_Tp>, shared_ptr<_Tp>, bool>
{
    typedef bool result_type;
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(shared_ptr<_Tp> const& __x, shared_ptr<_Tp> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(shared_ptr<_Tp> const& __x,   weak_ptr<_Tp> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(  weak_ptr<_Tp> const& __x, shared_ptr<_Tp> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS owner_less<weak_ptr<_Tp> >
    : binary_function<weak_ptr<_Tp>, weak_ptr<_Tp>, bool>
{
    typedef bool result_type;
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(  weak_ptr<_Tp> const& __x,   weak_ptr<_Tp> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(shared_ptr<_Tp> const& __x,   weak_ptr<_Tp> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(  weak_ptr<_Tp> const& __x, shared_ptr<_Tp> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4944 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
template <>
struct _LIBCPP_TEMPLATE_VIS owner_less<void>
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY
    bool operator()( shared_ptr<_Tp> const& __x, shared_ptr<_Up> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY
    bool operator()( shared_ptr<_Tp> const& __x,   weak_ptr<_Up> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(   weak_ptr<_Tp> const& __x, shared_ptr<_Up> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(   weak_ptr<_Tp> const& __x,   weak_ptr<_Up> const& __y) const _NOEXCEPT
        {return __x.owner_before(__y);}
    typedef void is_transparent;
};
#endif
# 4966 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<class _Tp>
class _LIBCPP_TEMPLATE_VIS enable_shared_from_this
{
    mutable weak_ptr<_Tp> __weak_this_;
protected:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    enable_shared_from_this() _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY
    enable_shared_from_this(enable_shared_from_this const&) _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY
    enable_shared_from_this& operator=(enable_shared_from_this const&) _NOEXCEPT
        {return *this;}
    _LIBCPP_INLINE_VISIBILITY
    ~enable_shared_from_this() {}
public:
    _LIBCPP_INLINE_VISIBILITY
    shared_ptr<_Tp> shared_from_this()
        {return shared_ptr<_Tp>(__weak_this_);}
    _LIBCPP_INLINE_VISIBILITY
    shared_ptr<_Tp const> shared_from_this() const
        {return shared_ptr<const _Tp>(__weak_this_);}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4990 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY
    weak_ptr<_Tp> weak_from_this() _NOEXCEPT
       { return __weak_this_; }

    _LIBCPP_INLINE_VISIBILITY
    weak_ptr<const _Tp> weak_from_this() const _NOEXCEPT
        { return __weak_this_; }
#endif // _LIBCPP_STD_VER > 14
# 4998 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

    template <class _Up> friend class shared_ptr;
};

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS hash<shared_ptr<_Tp> >
{
    typedef shared_ptr<_Tp>      argument_type;
    typedef size_t               result_type;

    _LIBCPP_INLINE_VISIBILITY
    result_type operator()(const argument_type& __ptr) const _NOEXCEPT
    {
        return hash<_Tp*>()(__ptr.get());
    }
};

template<class _CharT, class _Traits, class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
basic_ostream<_CharT, _Traits>&
operator<<(basic_ostream<_CharT, _Traits>& __os, shared_ptr<_Yp> const& __p);


#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_ATOMIC_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 5022 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

class _LIBCPP_TYPE_VIS __sp_mut
{
    void* __lx;
public:
    void lock() _NOEXCEPT;
    void unlock() _NOEXCEPT;

private:
    _LIBCPP_CONSTEXPR __sp_mut(void*) _NOEXCEPT;
    __sp_mut(const __sp_mut&);
    __sp_mut& operator=(const __sp_mut&);

    friend _LIBCPP_FUNC_VIS __sp_mut& __get_sp_mut(const void*);
};

_LIBCPP_FUNC_VIS _LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
__sp_mut& __get_sp_mut(const void*);

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_is_lock_free(const shared_ptr<_Tp>*)
{
    return false;
}

template <class _Tp>
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
shared_ptr<_Tp>
atomic_load(const shared_ptr<_Tp>* __p)
{
    __sp_mut& __m = __get_sp_mut(__p);
    __m.lock();
    shared_ptr<_Tp> __q = *__p;
    __m.unlock();
    return __q;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
shared_ptr<_Tp>
atomic_load_explicit(const shared_ptr<_Tp>* __p, memory_order)
{
    return atomic_load(__p);
}

template <class _Tp>
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
void
atomic_store(shared_ptr<_Tp>* __p, shared_ptr<_Tp> __r)
{
    __sp_mut& __m = __get_sp_mut(__p);
    __m.lock();
    __p->swap(__r);
    __m.unlock();
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
void
atomic_store_explicit(shared_ptr<_Tp>* __p, shared_ptr<_Tp> __r, memory_order)
{
    atomic_store(__p, __r);
}

template <class _Tp>
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
shared_ptr<_Tp>
atomic_exchange(shared_ptr<_Tp>* __p, shared_ptr<_Tp> __r)
{
    __sp_mut& __m = __get_sp_mut(__p);
    __m.lock();
    __p->swap(__r);
    __m.unlock();
    return __r;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
shared_ptr<_Tp>
atomic_exchange_explicit(shared_ptr<_Tp>* __p, shared_ptr<_Tp> __r, memory_order)
{
    return atomic_exchange(__p, __r);
}

template <class _Tp>
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
bool
atomic_compare_exchange_strong(shared_ptr<_Tp>* __p, shared_ptr<_Tp>* __v, shared_ptr<_Tp> __w)
{
    shared_ptr<_Tp> __temp;
    __sp_mut& __m = __get_sp_mut(__p);
    __m.lock();
    if (__p->__owner_equivalent(*__v))
    {
        _VSTD::swap(__temp, *__p);
        *__p = __w;
        __m.unlock();
        return true;
    }
    _VSTD::swap(__temp, *__v);
    *__v = *__p;
    __m.unlock();
    return false;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
bool
atomic_compare_exchange_weak(shared_ptr<_Tp>* __p, shared_ptr<_Tp>* __v, shared_ptr<_Tp> __w)
{
    return atomic_compare_exchange_strong(__p, __v, __w);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
bool
atomic_compare_exchange_strong_explicit(shared_ptr<_Tp>* __p, shared_ptr<_Tp>* __v,
                                        shared_ptr<_Tp> __w, memory_order, memory_order)
{
    return atomic_compare_exchange_strong(__p, __v, __w);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_AVAILABILITY_ATOMIC_SHARED_PTR
bool
atomic_compare_exchange_weak_explicit(shared_ptr<_Tp>* __p, shared_ptr<_Tp>* __v,
                                      shared_ptr<_Tp> __w, memory_order, memory_order)
{
    return atomic_compare_exchange_weak(__p, __v, __w);
}

#endif  // !defined(_LIBCPP_HAS_NO_ATOMIC_HEADER)
# 5162 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

//enum class
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_POINTER_SAFETY_ENUM_TYPE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5165 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# ifndef _LIBCPP_CXX03_LANG
enum class pointer_safety : unsigned char {
  relaxed,
  preferred,
  strict
};
# endif
# 5172 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#else
# 5173 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
struct _LIBCPP_TYPE_VIS pointer_safety
{
    enum __lx
    {
        relaxed,
        preferred,
        strict
    };

    __lx __v_;

    _LIBCPP_INLINE_VISIBILITY
    pointer_safety() : __v_() {}

    _LIBCPP_INLINE_VISIBILITY
    pointer_safety(__lx __v) : __v_(__v) {}
    _LIBCPP_INLINE_VISIBILITY
    operator int() const {return __v_;}
};
#endif
# 5193 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_ABI_POINTER_SAFETY_ENUM_TYPE) && \
    defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5196 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
_LIBCPP_FUNC_VIS pointer_safety get_pointer_safety() _NOEXCEPT;
#else
# 5198 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
// This function is only offered in C++03 under ABI v1.
#if 0 /* disabled by -frewrite-includes */
# if !defined(_LIBCPP_ABI_POINTER_SAFETY_ENUM_TYPE) || !defined(_LIBCPP_CXX03_LANG)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 5200 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
inline _LIBCPP_INLINE_VISIBILITY
pointer_safety get_pointer_safety() _NOEXCEPT {
  return pointer_safety::relaxed;
}
# endif
# 5205 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#endif
# 5206 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3


_LIBCPP_FUNC_VIS void declare_reachable(void* __p);
_LIBCPP_FUNC_VIS void declare_no_pointers(char* __p, size_t __n);
_LIBCPP_FUNC_VIS void undeclare_no_pointers(char* __p, size_t __n);
_LIBCPP_FUNC_VIS void* __undeclare_reachable(void* __p);

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Tp*
undeclare_reachable(_Tp* __p)
{
    return static_cast<_Tp*>(__undeclare_reachable(__p));
}

_LIBCPP_FUNC_VIS void* align(size_t __align, size_t __sz, void*& __ptr, size_t& __space);

// --- Helper for container swap --
template <typename _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
void __swap_allocator(_Alloc & __a1, _Alloc & __a2)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 5228 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _NOEXCEPT
#else
# 5230 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _NOEXCEPT_(__is_nothrow_swappable<_Alloc>::value)
#endif
# 5232 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
{
    __swap_allocator(__a1, __a2,
      integral_constant<bool, _VSTD::allocator_traits<_Alloc>::propagate_on_container_swap::value>());
}

template <typename _Alloc>
_LIBCPP_INLINE_VISIBILITY
void __swap_allocator(_Alloc & __a1, _Alloc & __a2, true_type)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 5241 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _NOEXCEPT
#else
# 5243 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    _NOEXCEPT_(__is_nothrow_swappable<_Alloc>::value)
#endif
# 5245 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
{
    using _VSTD::swap;
    swap(__a1, __a2);
}

template <typename _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
void __swap_allocator(_Alloc &, _Alloc &, false_type) _NOEXCEPT {}

template <typename _Alloc, typename _Traits=allocator_traits<_Alloc> >
struct __noexcept_move_assign_container : public integral_constant<bool,
    _Traits::propagate_on_container_move_assignment::value
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5258 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        || _Traits::is_always_equal::value
#else
# 5260 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
        && is_nothrow_move_assignable<_Alloc>::value
#endif
# 5262 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
    > {};


#ifndef _LIBCPP_HAS_NO_VARIADICS
template <class _Tp, class _Alloc>
struct __temp_value {
    typedef allocator_traits<_Alloc> _Traits;

    typename aligned_storage<sizeof(_Tp), _LIBCPP_ALIGNOF(_Tp)>::type __v;
    _Alloc &__a;

    _Tp *__addr() { return reinterpret_cast<_Tp *>(addressof(__v)); }
    _Tp &   get() { return *__addr(); }

    template<class... _Args>
    _LIBCPP_NO_CFI
    __temp_value(_Alloc &__alloc, _Args&& ... __args) : __a(__alloc) {
      _Traits::construct(__a, reinterpret_cast<_Tp*>(addressof(__v)),
                         _VSTD::forward<_Args>(__args)...);
    }

    ~__temp_value() { _Traits::destroy(__a, __addr()); }
    };
#endif
# 5286 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

template<typename _Alloc, typename = void, typename = void>
struct __is_allocator : false_type {};

template<typename _Alloc>
struct __is_allocator<_Alloc,
       typename __void_t<typename _Alloc::value_type>::type,
       typename __void_t<decltype(_VSTD::declval<_Alloc&>().allocate(size_t(0)))>::type
     >
   : true_type {};

// __builtin_new_allocator -- A non-templated helper for allocating and
// deallocating memory using __builtin_operator_new and
// __builtin_operator_delete. It should be used in preference to
// `std::allocator<T>` to avoid additional instantiations.
struct __builtin_new_allocator {
  struct __builtin_new_deleter {
    typedef void* pointer_type;

    _LIBCPP_CONSTEXPR explicit __builtin_new_deleter(size_t __size, size_t __align)
        : __size_(__size), __align_(__align) {}

    void operator()(void* p) const _NOEXCEPT {
        std::__libcpp_deallocate(p, __size_, __align_);
    }

   private:
    size_t __size_;
    size_t __align_;
  };

  typedef unique_ptr<void, __builtin_new_deleter> __holder_t;

  static __holder_t __allocate_bytes(size_t __s, size_t __align) {
      return __holder_t(std::__libcpp_allocate(__s, __align),
                     __builtin_new_deleter(__s, __align));
  }

  static void __deallocate_bytes(void* __p, size_t __s,
                                 size_t __align) _NOEXCEPT {
      std::__libcpp_deallocate(__p, __s, __align);
  }

  template <class _Tp>
  _LIBCPP_NODEBUG _LIBCPP_ALWAYS_INLINE
  static __holder_t __allocate_type(size_t __n) {
      return __allocate_bytes(__n * sizeof(_Tp), _LIBCPP_ALIGNOF(_Tp));
  }

  template <class _Tp>
  _LIBCPP_NODEBUG _LIBCPP_ALWAYS_INLINE
  static void __deallocate_type(void* __p, size_t __n) _NOEXCEPT {
      __deallocate_bytes(__p, __n * sizeof(_Tp), _LIBCPP_ALIGNOF(_Tp));
  }
};


_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_PARALLEL_ALGORITHMS) && _LIBCPP_STD_VER >= 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5348 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#   include <__pstl_memory>
#endif /* expanded by -frewrite-includes */
# 5348 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 5349 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
#endif
# 5350 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3

#endif  // _LIBCPP_MEMORY
# 5352 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/memory" 3
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h"

namespace llvm {

//===----------------------------------------------------------------------===//
//                          isa<x> Support Templates
//===----------------------------------------------------------------------===//

// Define a template that can be specialized by smart pointers to reflect the
// fact that they are automatically dereferenced, and are not involved with the
// template selection process...  the default implementation is a noop.
//
template<typename From> struct simplify_type {
  using SimpleType = From; // The real type this represents...

  // An accessor to get the real value...
  static SimpleType &getSimplifiedValue(From &Val) { return Val; }
};

template<typename From> struct simplify_type<const From> {
  using NonConstSimpleType = typename simplify_type<From>::SimpleType;
  using SimpleType =
      typename add_const_past_pointer<NonConstSimpleType>::type;
  using RetType =
      typename add_lvalue_reference_if_not_pointer<SimpleType>::type;

  static RetType getSimplifiedValue(const From& Val) {
    return simplify_type<From>::getSimplifiedValue(const_cast<From&>(Val));
  }
};

// The core of the implementation of isa<X> is here; To and From should be
// the names of classes.  This template can be specialized to customize the
// implementation of isa<> without rewriting it from scratch.
template <typename To, typename From, typename Enabler = void>
struct isa_impl {
  static inline bool doit(const From &Val) {
    return To::classof(&Val);
  }
};

/// Always allow upcasts, and perform no dynamic check for them.
template <typename To, typename From>
struct isa_impl<To, From, std::enable_if_t<std::is_base_of<To, From>::value>> {
  static inline bool doit(const From &) { return true; }
};

template <typename To, typename From> struct isa_impl_cl {
  static inline bool doit(const From &Val) {
    return isa_impl<To, From>::doit(Val);
  }
};

template <typename To, typename From> struct isa_impl_cl<To, const From> {
  static inline bool doit(const From &Val) {
    return isa_impl<To, From>::doit(Val);
  }
};

template <typename To, typename From>
struct isa_impl_cl<To, const std::unique_ptr<From>> {
  static inline bool doit(const std::unique_ptr<From> &Val) {
    assert(Val && "isa<> used on a null pointer");
    return isa_impl_cl<To, From>::doit(*Val);
  }
};

template <typename To, typename From> struct isa_impl_cl<To, From*> {
  static inline bool doit(const From *Val) {
    assert(Val && "isa<> used on a null pointer");
    return isa_impl<To, From>::doit(*Val);
  }
};

template <typename To, typename From> struct isa_impl_cl<To, From*const> {
  static inline bool doit(const From *Val) {
    assert(Val && "isa<> used on a null pointer");
    return isa_impl<To, From>::doit(*Val);
  }
};

template <typename To, typename From> struct isa_impl_cl<To, const From*> {
  static inline bool doit(const From *Val) {
    assert(Val && "isa<> used on a null pointer");
    return isa_impl<To, From>::doit(*Val);
  }
};

template <typename To, typename From> struct isa_impl_cl<To, const From*const> {
  static inline bool doit(const From *Val) {
    assert(Val && "isa<> used on a null pointer");
    return isa_impl<To, From>::doit(*Val);
  }
};

template<typename To, typename From, typename SimpleFrom>
struct isa_impl_wrap {
  // When From != SimplifiedType, we can simplify the type some more by using
  // the simplify_type template.
  static bool doit(const From &Val) {
    return isa_impl_wrap<To, SimpleFrom,
      typename simplify_type<SimpleFrom>::SimpleType>::doit(
                          simplify_type<const From>::getSimplifiedValue(Val));
  }
};

template<typename To, typename FromTy>
struct isa_impl_wrap<To, FromTy, FromTy> {
  // When From == SimpleType, we are as simple as we are going to get.
  static bool doit(const FromTy &Val) {
    return isa_impl_cl<To,FromTy>::doit(Val);
  }
};

// isa<X> - Return true if the parameter to the template is an instance of the
// template type argument.  Used like this:
//
//  if (isa<Type>(myVal)) { ... }
//
template <class X, class Y> LLVM_NODISCARD inline bool isa(const Y &Val) {
  return isa_impl_wrap<X, const Y,
                       typename simplify_type<const Y>::SimpleType>::doit(Val);
}

// isa_and_nonnull<X> - Functionally identical to isa, except that a null value
// is accepted.
//
template <class X, class Y>
LLVM_NODISCARD inline bool isa_and_nonnull(const Y &Val) {
  if (!Val)
    return false;
  return isa<X>(Val);
}

//===----------------------------------------------------------------------===//
//                          cast<x> Support Templates
//===----------------------------------------------------------------------===//

template<class To, class From> struct cast_retty;

// Calculate what type the 'cast' function should return, based on a requested
// type of To and a source type of From.
template<class To, class From> struct cast_retty_impl {
  using ret_type = To &;       // Normal case, return Ty&
};
template<class To, class From> struct cast_retty_impl<To, const From> {
  using ret_type = const To &; // Normal case, return Ty&
};

template<class To, class From> struct cast_retty_impl<To, From*> {
  using ret_type = To *;       // Pointer arg case, return Ty*
};

template<class To, class From> struct cast_retty_impl<To, const From*> {
  using ret_type = const To *; // Constant pointer arg case, return const Ty*
};

template<class To, class From> struct cast_retty_impl<To, const From*const> {
  using ret_type = const To *; // Constant pointer arg case, return const Ty*
};

template <class To, class From>
struct cast_retty_impl<To, std::unique_ptr<From>> {
private:
  using PointerType = typename cast_retty_impl<To, From *>::ret_type;
  using ResultType = std::remove_pointer_t<PointerType>;

public:
  using ret_type = std::unique_ptr<ResultType>;
};

template<class To, class From, class SimpleFrom>
struct cast_retty_wrap {
  // When the simplified type and the from type are not the same, use the type
  // simplifier to reduce the type, then reuse cast_retty_impl to get the
  // resultant type.
  using ret_type = typename cast_retty<To, SimpleFrom>::ret_type;
};

template<class To, class FromTy>
struct cast_retty_wrap<To, FromTy, FromTy> {
  // When the simplified type is equal to the from type, use it directly.
  using ret_type = typename cast_retty_impl<To,FromTy>::ret_type;
};

template<class To, class From>
struct cast_retty {
  using ret_type = typename cast_retty_wrap<
      To, From, typename simplify_type<From>::SimpleType>::ret_type;
};

// Ensure the non-simple values are converted using the simplify_type template
// that may be specialized by smart pointers...
//
template<class To, class From, class SimpleFrom> struct cast_convert_val {
  // This is not a simple type, use the template to simplify it...
  static typename cast_retty<To, From>::ret_type doit(From &Val) {
    return cast_convert_val<To, SimpleFrom,
      typename simplify_type<SimpleFrom>::SimpleType>::doit(
                          simplify_type<From>::getSimplifiedValue(Val));
  }
};

template<class To, class FromTy> struct cast_convert_val<To,FromTy,FromTy> {
  // This _is_ a simple type, just cast it.
  static typename cast_retty<To, FromTy>::ret_type doit(const FromTy &Val) {
    typename cast_retty<To, FromTy>::ret_type Res2
     = (typename cast_retty<To, FromTy>::ret_type)const_cast<FromTy&>(Val);
    return Res2;
  }
};

template <class X> struct is_simple_type {
  static const bool value =
      std::is_same<X, typename simplify_type<X>::SimpleType>::value;
};

// cast<X> - Return the argument parameter cast to the specified type.  This
// casting operator asserts that the type is correct, so it does not return null
// on failure.  It does not allow a null argument (use cast_or_null for that).
// It is typically used like this:
//
//  cast<Instruction>(myVal)->getParent()
//
template <class X, class Y>
inline std::enable_if_t<!is_simple_type<Y>::value,
                        typename cast_retty<X, const Y>::ret_type>
cast(const Y &Val) {
  assert(isa<X>(Val) && "cast<Ty>() argument of incompatible type!");
  return cast_convert_val<
      X, const Y, typename simplify_type<const Y>::SimpleType>::doit(Val);
}

template <class X, class Y>
inline typename cast_retty<X, Y>::ret_type cast(Y &Val) {
  assert(isa<X>(Val) && "cast<Ty>() argument of incompatible type!");
  return cast_convert_val<X, Y,
                          typename simplify_type<Y>::SimpleType>::doit(Val);
}

template <class X, class Y>
inline typename cast_retty<X, Y *>::ret_type cast(Y *Val) {
  assert(isa<X>(Val) && "cast<Ty>() argument of incompatible type!");
  return cast_convert_val<X, Y*,
                          typename simplify_type<Y*>::SimpleType>::doit(Val);
}

template <class X, class Y>
inline typename cast_retty<X, std::unique_ptr<Y>>::ret_type
cast(std::unique_ptr<Y> &&Val) {
  assert(isa<X>(Val.get()) && "cast<Ty>() argument of incompatible type!");
  using ret_type = typename cast_retty<X, std::unique_ptr<Y>>::ret_type;
  return ret_type(
      cast_convert_val<X, Y *, typename simplify_type<Y *>::SimpleType>::doit(
          Val.release()));
}

// cast_or_null<X> - Functionally identical to cast, except that a null value is
// accepted.
//
template <class X, class Y>
LLVM_NODISCARD inline std::enable_if_t<
    !is_simple_type<Y>::value, typename cast_retty<X, const Y>::ret_type>
cast_or_null(const Y &Val) {
  if (!Val)
    return nullptr;
  assert(isa<X>(Val) && "cast_or_null<Ty>() argument of incompatible type!");
  return cast<X>(Val);
}

template <class X, class Y>
LLVM_NODISCARD inline std::enable_if_t<!is_simple_type<Y>::value,
                                       typename cast_retty<X, Y>::ret_type>
cast_or_null(Y &Val) {
  if (!Val)
    return nullptr;
  assert(isa<X>(Val) && "cast_or_null<Ty>() argument of incompatible type!");
  return cast<X>(Val);
}

template <class X, class Y>
LLVM_NODISCARD inline typename cast_retty<X, Y *>::ret_type
cast_or_null(Y *Val) {
  if (!Val) return nullptr;
  assert(isa<X>(Val) && "cast_or_null<Ty>() argument of incompatible type!");
  return cast<X>(Val);
}

template <class X, class Y>
inline typename cast_retty<X, std::unique_ptr<Y>>::ret_type
cast_or_null(std::unique_ptr<Y> &&Val) {
  if (!Val)
    return nullptr;
  return cast<X>(std::move(Val));
}

// dyn_cast<X> - Return the argument parameter cast to the specified type.  This
// casting operator returns null if the argument is of the wrong type, so it can
// be used to test for a type as well as cast if successful.  This should be
// used in the context of an if statement like this:
//
//  if (const Instruction *I = dyn_cast<Instruction>(myVal)) { ... }
//

template <class X, class Y>
LLVM_NODISCARD inline std::enable_if_t<
    !is_simple_type<Y>::value, typename cast_retty<X, const Y>::ret_type>
dyn_cast(const Y &Val) {
  return isa<X>(Val) ? cast<X>(Val) : nullptr;
}

template <class X, class Y>
LLVM_NODISCARD inline typename cast_retty<X, Y>::ret_type dyn_cast(Y &Val) {
  return isa<X>(Val) ? cast<X>(Val) : nullptr;
}

template <class X, class Y>
LLVM_NODISCARD inline typename cast_retty<X, Y *>::ret_type dyn_cast(Y *Val) {
  return isa<X>(Val) ? cast<X>(Val) : nullptr;
}

// dyn_cast_or_null<X> - Functionally identical to dyn_cast, except that a null
// value is accepted.
//
template <class X, class Y>
LLVM_NODISCARD inline std::enable_if_t<
    !is_simple_type<Y>::value, typename cast_retty<X, const Y>::ret_type>
dyn_cast_or_null(const Y &Val) {
  return (Val && isa<X>(Val)) ? cast<X>(Val) : nullptr;
}

template <class X, class Y>
LLVM_NODISCARD inline std::enable_if_t<!is_simple_type<Y>::value,
                                       typename cast_retty<X, Y>::ret_type>
dyn_cast_or_null(Y &Val) {
  return (Val && isa<X>(Val)) ? cast<X>(Val) : nullptr;
}

template <class X, class Y>
LLVM_NODISCARD inline typename cast_retty<X, Y *>::ret_type
dyn_cast_or_null(Y *Val) {
  return (Val && isa<X>(Val)) ? cast<X>(Val) : nullptr;
}

// unique_dyn_cast<X> - Given a unique_ptr<Y>, try to return a unique_ptr<X>,
// taking ownership of the input pointer iff isa<X>(Val) is true.  If the
// cast is successful, From refers to nullptr on exit and the casted value
// is returned.  If the cast is unsuccessful, the function returns nullptr
// and From is unchanged.
template <class X, class Y>
LLVM_NODISCARD inline auto unique_dyn_cast(std::unique_ptr<Y> &Val)
    -> decltype(cast<X>(Val)) {
  if (!isa<X>(Val))
    return nullptr;
  return cast<X>(std::move(Val));
}

template <class X, class Y>
LLVM_NODISCARD inline auto unique_dyn_cast(std::unique_ptr<Y> &&Val) {
  return unique_dyn_cast<X, Y>(Val);
}

// dyn_cast_or_null<X> - Functionally identical to unique_dyn_cast, except that
// a null value is accepted.
template <class X, class Y>
LLVM_NODISCARD inline auto unique_dyn_cast_or_null(std::unique_ptr<Y> &Val)
    -> decltype(cast<X>(Val)) {
  if (!Val)
    return nullptr;
  return unique_dyn_cast<X, Y>(Val);
}

template <class X, class Y>
LLVM_NODISCARD inline auto unique_dyn_cast_or_null(std::unique_ptr<Y> &&Val) {
  return unique_dyn_cast_or_null<X, Y>(Val);
}

} // end namespace llvm

#endif // LLVM_SUPPORT_CASTING_H
# 401 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Casting.h"
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/LLVM.h" 2
// None.h includes an enumerator that is desired & cannot be forward declared
// without a definition of NoneType.
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/None.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/LLVM.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/None.h" 1
//===-- None.h - Simple null value for implicit construction ------*- C++ -*-=//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
//  This file provides None, an enumerator for use in implicit constructors
//  of various (usually templated) types to make such construction more
//  terse.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_NONE_H
#define LLVM_ADT_NONE_H

namespace llvm {
/// A simple null object to allow implicit construction of Optional<T>
/// and similar types without having to spell out the specialization's name.
// (constant value 1 in an attempt to workaround MSVC build issue... )
enum class NoneType { None = 1 };
const NoneType None = NoneType::None;
}

#endif
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/None.h"
# 25 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/LLVM.h" 2

namespace llvm {
  // ADT's.
  class StringRef;
  class Twine;
  class VersionTuple;
  template<typename T> class ArrayRef;
  template<typename T> class MutableArrayRef;
  template<typename T> class OwningArrayRef;
  template<unsigned InternalLen> class SmallString;
  template<typename T, unsigned N> class SmallVector;
  template<typename T> class SmallVectorImpl;
  template<typename T> class Optional;
  template <class T> class Expected;

  template<typename T>
  struct SaveAndRestore;

  // Reference counting.
  template <typename T> class IntrusiveRefCntPtr;
  template <typename T> struct IntrusiveRefCntPtrInfo;
  template <class Derived> class RefCountedBase;

  class raw_ostream;
  class raw_pwrite_stream;
  // TODO: DenseMap, ...
}


namespace clang {
  // Casting operators.
  using llvm::isa;
  using llvm::cast;
  using llvm::dyn_cast;
  using llvm::dyn_cast_or_null;
  using llvm::cast_or_null;

  // ADT's.
  using llvm::ArrayRef;
  using llvm::MutableArrayRef;
  using llvm::None;
  using llvm::Optional;
  using llvm::OwningArrayRef;
  using llvm::SaveAndRestore;
  using llvm::SmallString;
  using llvm::SmallVector;
  using llvm::SmallVectorImpl;
  using llvm::StringRef;
  using llvm::Twine;
  using llvm::VersionTuple;

  // Error handling.
  using llvm::Expected;

  // Reference counting.
  using llvm::IntrusiveRefCntPtr;
  using llvm::IntrusiveRefCntPtrInfo;
  using llvm::RefCountedBase;

  using llvm::raw_ostream;
  using llvm::raw_pwrite_stream;
} // end namespace clang.

#endif
# 89 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/LLVM.h"
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/IntrusiveRefCntPtr.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/IntrusiveRefCntPtr.h" 1
//==- llvm/ADT/IntrusiveRefCntPtr.h - Smart Refcounting Pointer --*- C++ -*-==//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the RefCountedBase, ThreadSafeRefCountedBase, and
// IntrusiveRefCntPtr classes.
//
// IntrusiveRefCntPtr is a smart pointer to an object which maintains a
// reference count.  (ThreadSafe)RefCountedBase is a mixin class that adds a
// refcount member variable and methods for updating the refcount.  An object
// that inherits from (ThreadSafe)RefCountedBase deletes itself when its
// refcount hits zero.
//
// For example:
//
//   class MyClass : public RefCountedBase<MyClass> {};
//
//   void foo() {
//     // Constructing an IntrusiveRefCntPtr increases the pointee's refcount by
//     // 1 (from 0 in this case).
//     IntrusiveRefCntPtr<MyClass> Ptr1(new MyClass());
//
//     // Copying an IntrusiveRefCntPtr increases the pointee's refcount by 1.
//     IntrusiveRefCntPtr<MyClass> Ptr2(Ptr1);
//
//     // Constructing an IntrusiveRefCntPtr has no effect on the object's
//     // refcount.  After a move, the moved-from pointer is null.
//     IntrusiveRefCntPtr<MyClass> Ptr3(std::move(Ptr1));
//     assert(Ptr1 == nullptr);
//
//     // Clearing an IntrusiveRefCntPtr decreases the pointee's refcount by 1.
//     Ptr2.reset();
//
//     // The object deletes itself when we return from the function, because
//     // Ptr3's destructor decrements its refcount to 0.
//   }
//
// You can use IntrusiveRefCntPtr with isa<T>(), dyn_cast<T>(), etc.:
//
//   IntrusiveRefCntPtr<MyClass> Ptr(new MyClass());
//   OtherClass *Other = dyn_cast<OtherClass>(Ptr);  // Ptr.get() not required
//
// IntrusiveRefCntPtr works with any class that
//
//  - inherits from (ThreadSafe)RefCountedBase,
//  - has Retain() and Release() methods, or
//  - specializes IntrusiveRefCntPtrInfo.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_INTRUSIVEREFCNTPTR_H
#define LLVM_ADT_INTRUSIVEREFCNTPTR_H

#if 0 /* expanded by -frewrite-includes */
#include <atomic>
#endif /* expanded by -frewrite-includes */
# 58 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/IntrusiveRefCntPtr.h"
# 59 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/IntrusiveRefCntPtr.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 59 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/IntrusiveRefCntPtr.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 60 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/IntrusiveRefCntPtr.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 60 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/IntrusiveRefCntPtr.h"
# 61 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/IntrusiveRefCntPtr.h"

namespace llvm {

/// A CRTP mixin class that adds reference counting to a type.
///
/// The lifetime of an object which inherits from RefCountedBase is managed by
/// calls to Release() and Retain(), which increment and decrement the object's
/// refcount, respectively.  When a Release() call decrements the refcount to 0,
/// the object deletes itself.
template <class Derived> class RefCountedBase {
  mutable unsigned RefCount = 0;

public:
  RefCountedBase() = default;
  RefCountedBase(const RefCountedBase &) {}

  void Retain() const { ++RefCount; }

  void Release() const {
    assert(RefCount > 0 && "Reference count is already zero.");
    if (--RefCount == 0)
      delete static_cast<const Derived *>(this);
  }
};

/// A thread-safe version of \c RefCountedBase.
template <class Derived> class ThreadSafeRefCountedBase {
  mutable std::atomic<int> RefCount;

protected:
  ThreadSafeRefCountedBase() : RefCount(0) {}

public:
  void Retain() const { RefCount.fetch_add(1, std::memory_order_relaxed); }

  void Release() const {
    int NewRefCount = RefCount.fetch_sub(1, std::memory_order_acq_rel) - 1;
    assert(NewRefCount >= 0 && "Reference count was already zero.");
    if (NewRefCount == 0)
      delete static_cast<const Derived *>(this);
  }
};

/// Class you can specialize to provide custom retain/release functionality for
/// a type.
///
/// Usually specializing this class is not necessary, as IntrusiveRefCntPtr
/// works with any type which defines Retain() and Release() functions -- you
/// can define those functions yourself if RefCountedBase doesn't work for you.
///
/// One case when you might want to specialize this type is if you have
///  - Foo.h defines type Foo and includes Bar.h, and
///  - Bar.h uses IntrusiveRefCntPtr<Foo> in inline functions.
///
/// Because Foo.h includes Bar.h, Bar.h can't include Foo.h in order to pull in
/// the declaration of Foo.  Without the declaration of Foo, normally Bar.h
/// wouldn't be able to use IntrusiveRefCntPtr<Foo>, which wants to call
/// T::Retain and T::Release.
///
/// To resolve this, Bar.h could include a third header, FooFwd.h, which
/// forward-declares Foo and specializes IntrusiveRefCntPtrInfo<Foo>.  Then
/// Bar.h could use IntrusiveRefCntPtr<Foo>, although it still couldn't call any
/// functions on Foo itself, because Foo would be an incomplete type.
template <typename T> struct IntrusiveRefCntPtrInfo {
  static void retain(T *obj) { obj->Retain(); }
  static void release(T *obj) { obj->Release(); }
};

/// A smart pointer to a reference-counted object that inherits from
/// RefCountedBase or ThreadSafeRefCountedBase.
///
/// This class increments its pointee's reference count when it is created, and
/// decrements its refcount when it's destroyed (or is changed to point to a
/// different object).
template <typename T> class IntrusiveRefCntPtr {
  T *Obj = nullptr;

public:
  using element_type = T;

  explicit IntrusiveRefCntPtr() = default;
  IntrusiveRefCntPtr(T *obj) : Obj(obj) { retain(); }
  IntrusiveRefCntPtr(const IntrusiveRefCntPtr &S) : Obj(S.Obj) { retain(); }
  IntrusiveRefCntPtr(IntrusiveRefCntPtr &&S) : Obj(S.Obj) { S.Obj = nullptr; }

  template <class X>
  IntrusiveRefCntPtr(IntrusiveRefCntPtr<X> &&S) : Obj(S.get()) {
    S.Obj = nullptr;
  }

  template <class X>
  IntrusiveRefCntPtr(const IntrusiveRefCntPtr<X> &S) : Obj(S.get()) {
    retain();
  }

  ~IntrusiveRefCntPtr() { release(); }

  IntrusiveRefCntPtr &operator=(IntrusiveRefCntPtr S) {
    swap(S);
    return *this;
  }

  T &operator*() const { return *Obj; }
  T *operator->() const { return Obj; }
  T *get() const { return Obj; }
  explicit operator bool() const { return Obj; }

  void swap(IntrusiveRefCntPtr &other) {
    T *tmp = other.Obj;
    other.Obj = Obj;
    Obj = tmp;
  }

  void reset() {
    release();
    Obj = nullptr;
  }

  void resetWithoutRelease() { Obj = nullptr; }

private:
  void retain() {
    if (Obj)
      IntrusiveRefCntPtrInfo<T>::retain(Obj);
  }

  void release() {
    if (Obj)
      IntrusiveRefCntPtrInfo<T>::release(Obj);
  }

  template <typename X> friend class IntrusiveRefCntPtr;
};

template <class T, class U>
inline bool operator==(const IntrusiveRefCntPtr<T> &A,
                       const IntrusiveRefCntPtr<U> &B) {
  return A.get() == B.get();
}

template <class T, class U>
inline bool operator!=(const IntrusiveRefCntPtr<T> &A,
                       const IntrusiveRefCntPtr<U> &B) {
  return A.get() != B.get();
}

template <class T, class U>
inline bool operator==(const IntrusiveRefCntPtr<T> &A, U *B) {
  return A.get() == B;
}

template <class T, class U>
inline bool operator!=(const IntrusiveRefCntPtr<T> &A, U *B) {
  return A.get() != B;
}

template <class T, class U>
inline bool operator==(T *A, const IntrusiveRefCntPtr<U> &B) {
  return A == B.get();
}

template <class T, class U>
inline bool operator!=(T *A, const IntrusiveRefCntPtr<U> &B) {
  return A != B.get();
}

template <class T>
bool operator==(std::nullptr_t A, const IntrusiveRefCntPtr<T> &B) {
  return !B;
}

template <class T>
bool operator==(const IntrusiveRefCntPtr<T> &A, std::nullptr_t B) {
  return B == A;
}

template <class T>
bool operator!=(std::nullptr_t A, const IntrusiveRefCntPtr<T> &B) {
  return !(A == B);
}

template <class T>
bool operator!=(const IntrusiveRefCntPtr<T> &A, std::nullptr_t B) {
  return !(A == B);
}

// Make IntrusiveRefCntPtr work with dyn_cast, isa, and the other idioms from
// Casting.h.
template <typename From> struct simplify_type;

template <class T> struct simplify_type<IntrusiveRefCntPtr<T>> {
  using SimpleType = T *;

  static SimpleType getSimplifiedValue(IntrusiveRefCntPtr<T> &Val) {
    return Val.get();
  }
};

template <class T> struct simplify_type<const IntrusiveRefCntPtr<T>> {
  using SimpleType = /*const*/ T *;

  static SimpleType getSimplifiedValue(const IntrusiveRefCntPtr<T> &Val) {
    return Val.get();
  }
};

} // end namespace llvm

#endif // LLVM_ADT_INTRUSIVEREFCNTPTR_H
# 270 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/IntrusiveRefCntPtr.h"
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h" 1
//===- StringRef.h - Constant String Reference Wrapper ----------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_STRINGREF_H
#define LLVM_ADT_STRINGREF_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/STLExtras.h"
#endif /* expanded by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h" 1
//===- llvm/ADT/STLExtras.h - Useful STL related functions ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file contains some templates that are useful if you are working with the
// STL at all.
//
// No library is required when using these functions.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_STLEXTRAS_H
#define LLVM_ADT_STLEXTRAS_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Optional.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h" 1
//===- Optional.h - Simple variant for passing optional values --*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
//  This file provides Optional, a template class modeled in the spirit of
//  OCaml's 'opt' variant.  The idea is to strongly type whether or not
//  a value can be optional.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_OPTIONAL_H
#define LLVM_ADT_OPTIONAL_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/None.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/type_traits.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"

namespace llvm {

class raw_ostream;

namespace optional_detail {

struct in_place_t {};

/// Storage for any type.
template <typename T, bool = is_trivially_copyable<T>::value>
class OptionalStorage {
  union {
    char empty;
    T value;
  };
  bool hasVal;

public:
  ~OptionalStorage() { reset(); }

  OptionalStorage() noexcept : empty(), hasVal(false) {}

  OptionalStorage(OptionalStorage const &other) : OptionalStorage() {
    if (other.hasValue()) {
      emplace(other.value);
    }
  }
  OptionalStorage(OptionalStorage &&other) : OptionalStorage() {
    if (other.hasValue()) {
      emplace(std::move(other.value));
    }
  }

  template <class... Args>
  explicit OptionalStorage(in_place_t, Args &&... args)
      : value(std::forward<Args>(args)...), hasVal(true) {}

  void reset() noexcept {
    if (hasVal) {
      value.~T();
      hasVal = false;
    }
  }

  bool hasValue() const noexcept { return hasVal; }

  T &getValue() LLVM_LVALUE_FUNCTION noexcept {
    assert(hasVal);
    return value;
  }
  T const &getValue() const LLVM_LVALUE_FUNCTION noexcept {
    assert(hasVal);
    return value;
  }
#if 0 /* disabled by -frewrite-includes */
#if LLVM_HAS_RVALUE_REFERENCE_THIS
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 81 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
  T &&getValue() && noexcept {
    assert(hasVal);
    return std::move(value);
  }
#endif
# 86 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"

  template <class... Args> void emplace(Args &&... args) {
    reset();
    ::new ((void *)std::addressof(value)) T(std::forward<Args>(args)...);
    hasVal = true;
  }

  OptionalStorage &operator=(T const &y) {
    if (hasValue()) {
      value = y;
    } else {
      ::new ((void *)std::addressof(value)) T(y);
      hasVal = true;
    }
    return *this;
  }
  OptionalStorage &operator=(T &&y) {
    if (hasValue()) {
      value = std::move(y);
    } else {
      ::new ((void *)std::addressof(value)) T(std::move(y));
      hasVal = true;
    }
    return *this;
  }

  OptionalStorage &operator=(OptionalStorage const &other) {
    if (other.hasValue()) {
      if (hasValue()) {
        value = other.value;
      } else {
        ::new ((void *)std::addressof(value)) T(other.value);
        hasVal = true;
      }
    } else {
      reset();
    }
    return *this;
  }

  OptionalStorage &operator=(OptionalStorage &&other) {
    if (other.hasValue()) {
      if (hasValue()) {
        value = std::move(other.value);
      } else {
        ::new ((void *)std::addressof(value)) T(std::move(other.value));
        hasVal = true;
      }
    } else {
      reset();
    }
    return *this;
  }
};

template <typename T> class OptionalStorage<T, true> {
  union {
    char empty;
    T value;
  };
  bool hasVal = false;

public:
  ~OptionalStorage() = default;

  OptionalStorage() noexcept : empty{} {}

  OptionalStorage(OptionalStorage const &other) = default;
  OptionalStorage(OptionalStorage &&other) = default;

  OptionalStorage &operator=(OptionalStorage const &other) = default;
  OptionalStorage &operator=(OptionalStorage &&other) = default;

  template <class... Args>
  explicit OptionalStorage(in_place_t, Args &&... args)
      : value(std::forward<Args>(args)...), hasVal(true) {}

  void reset() noexcept {
    if (hasVal) {
      value.~T();
      hasVal = false;
    }
  }

  bool hasValue() const noexcept { return hasVal; }

  T &getValue() LLVM_LVALUE_FUNCTION noexcept {
    assert(hasVal);
    return value;
  }
  T const &getValue() const LLVM_LVALUE_FUNCTION noexcept {
    assert(hasVal);
    return value;
  }
#if 0 /* disabled by -frewrite-includes */
#if LLVM_HAS_RVALUE_REFERENCE_THIS
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 181 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
  T &&getValue() && noexcept {
    assert(hasVal);
    return std::move(value);
  }
#endif
# 186 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"

  template <class... Args> void emplace(Args &&... args) {
    reset();
    ::new ((void *)std::addressof(value)) T(std::forward<Args>(args)...);
    hasVal = true;
  }

  OptionalStorage &operator=(T const &y) {
    if (hasValue()) {
      value = y;
    } else {
      ::new ((void *)std::addressof(value)) T(y);
      hasVal = true;
    }
    return *this;
  }
  OptionalStorage &operator=(T &&y) {
    if (hasValue()) {
      value = std::move(y);
    } else {
      ::new ((void *)std::addressof(value)) T(std::move(y));
      hasVal = true;
    }
    return *this;
  }
};

} // namespace optional_detail

template <typename T> class Optional {
  optional_detail::OptionalStorage<T> Storage;

public:
  using value_type = T;

  constexpr Optional() {}
  constexpr Optional(NoneType) {}

  Optional(const T &y) : Storage(optional_detail::in_place_t{}, y) {}
  Optional(const Optional &O) = default;

  Optional(T &&y) : Storage(optional_detail::in_place_t{}, std::move(y)) {}
  Optional(Optional &&O) = default;

  Optional &operator=(T &&y) {
    Storage = std::move(y);
    return *this;
  }
  Optional &operator=(Optional &&O) = default;

  /// Create a new object by constructing it in place with the given arguments.
  template <typename... ArgTypes> void emplace(ArgTypes &&... Args) {
    Storage.emplace(std::forward<ArgTypes>(Args)...);
  }

  static inline Optional create(const T *y) {
    return y ? Optional(*y) : Optional();
  }

  Optional &operator=(const T &y) {
    Storage = y;
    return *this;
  }
  Optional &operator=(const Optional &O) = default;

  void reset() { Storage.reset(); }

  const T *getPointer() const { return &Storage.getValue(); }
  T *getPointer() { return &Storage.getValue(); }
  const T &getValue() const LLVM_LVALUE_FUNCTION { return Storage.getValue(); }
  T &getValue() LLVM_LVALUE_FUNCTION { return Storage.getValue(); }

  explicit operator bool() const { return hasValue(); }
  bool hasValue() const { return Storage.hasValue(); }
  const T *operator->() const { return getPointer(); }
  T *operator->() { return getPointer(); }
  const T &operator*() const LLVM_LVALUE_FUNCTION { return getValue(); }
  T &operator*() LLVM_LVALUE_FUNCTION { return getValue(); }

  template <typename U>
  constexpr T getValueOr(U &&value) const LLVM_LVALUE_FUNCTION {
    return hasValue() ? getValue() : std::forward<U>(value);
  }

  /// Apply a function to the value if present; otherwise return None.
  template <class Function>
  auto map(const Function &F) const LLVM_LVALUE_FUNCTION
      -> Optional<decltype(F(getValue()))> {
    if (*this) return F(getValue());
    return None;
  }

#if 0 /* disabled by -frewrite-includes */
#if LLVM_HAS_RVALUE_REFERENCE_THIS
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 279 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
  T &&getValue() && { return std::move(Storage.getValue()); }
  T &&operator*() && { return std::move(Storage.getValue()); }

  template <typename U>
  T getValueOr(U &&value) && {
    return hasValue() ? std::move(getValue()) : std::forward<U>(value);
  }

  /// Apply a function to the value if present; otherwise return None.
  template <class Function>
  auto map(const Function &F) &&
      -> Optional<decltype(F(std::move(*this).getValue()))> {
    if (*this) return F(std::move(*this).getValue());
    return None;
  }
#endif
# 295 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
};

template <typename T, typename U>
bool operator==(const Optional<T> &X, const Optional<U> &Y) {
  if (X && Y)
    return *X == *Y;
  return X.hasValue() == Y.hasValue();
}

template <typename T, typename U>
bool operator!=(const Optional<T> &X, const Optional<U> &Y) {
  return !(X == Y);
}

template <typename T, typename U>
bool operator<(const Optional<T> &X, const Optional<U> &Y) {
  if (X && Y)
    return *X < *Y;
  return X.hasValue() < Y.hasValue();
}

template <typename T, typename U>
bool operator<=(const Optional<T> &X, const Optional<U> &Y) {
  return !(Y < X);
}

template <typename T, typename U>
bool operator>(const Optional<T> &X, const Optional<U> &Y) {
  return Y < X;
}

template <typename T, typename U>
bool operator>=(const Optional<T> &X, const Optional<U> &Y) {
  return !(X < Y);
}

template<typename T>
bool operator==(const Optional<T> &X, NoneType) {
  return !X;
}

template<typename T>
bool operator==(NoneType, const Optional<T> &X) {
  return X == None;
}

template<typename T>
bool operator!=(const Optional<T> &X, NoneType) {
  return !(X == None);
}

template<typename T>
bool operator!=(NoneType, const Optional<T> &X) {
  return X != None;
}

template <typename T> bool operator<(const Optional<T> &X, NoneType) {
  return false;
}

template <typename T> bool operator<(NoneType, const Optional<T> &X) {
  return X.hasValue();
}

template <typename T> bool operator<=(const Optional<T> &X, NoneType) {
  return !(None < X);
}

template <typename T> bool operator<=(NoneType, const Optional<T> &X) {
  return !(X < None);
}

template <typename T> bool operator>(const Optional<T> &X, NoneType) {
  return None < X;
}

template <typename T> bool operator>(NoneType, const Optional<T> &X) {
  return X < None;
}

template <typename T> bool operator>=(const Optional<T> &X, NoneType) {
  return None <= X;
}

template <typename T> bool operator>=(NoneType, const Optional<T> &X) {
  return X <= None;
}

template <typename T> bool operator==(const Optional<T> &X, const T &Y) {
  return X && *X == Y;
}

template <typename T> bool operator==(const T &X, const Optional<T> &Y) {
  return Y && X == *Y;
}

template <typename T> bool operator!=(const Optional<T> &X, const T &Y) {
  return !(X == Y);
}

template <typename T> bool operator!=(const T &X, const Optional<T> &Y) {
  return !(X == Y);
}

template <typename T> bool operator<(const Optional<T> &X, const T &Y) {
  return !X || *X < Y;
}

template <typename T> bool operator<(const T &X, const Optional<T> &Y) {
  return Y && X < *Y;
}

template <typename T> bool operator<=(const Optional<T> &X, const T &Y) {
  return !(Y < X);
}

template <typename T> bool operator<=(const T &X, const Optional<T> &Y) {
  return !(Y < X);
}

template <typename T> bool operator>(const Optional<T> &X, const T &Y) {
  return Y < X;
}

template <typename T> bool operator>(const T &X, const Optional<T> &Y) {
  return Y < X;
}

template <typename T> bool operator>=(const Optional<T> &X, const T &Y) {
  return !(X < Y);
}

template <typename T> bool operator>=(const T &X, const Optional<T> &Y) {
  return !(X < Y);
}

raw_ostream &operator<<(raw_ostream &OS, NoneType);

template <typename T, typename = decltype(std::declval<raw_ostream &>()
                                          << std::declval<const T &>())>
raw_ostream &operator<<(raw_ostream &OS, const Optional<T> &O) {
  if (O)
    OS << *O;
  else
    OS << None;
  return OS;
}

} // end namespace llvm

#endif // LLVM_ADT_OPTIONAL_H
# 446 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Optional.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h" 1
//===- iterator.h - Utilities for using and defining iterators --*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_ITERATOR_H
#define LLVM_ADT_ITERATOR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator_range.h"
#endif /* expanded by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator_range.h" 1
//===- iterator_range.h - A range adaptor for iterators ---------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
/// \file
/// This provides a very simple, boring adaptor for a begin and end iterator
/// into a range type. This should be used to build range views that work well
/// with range based for loops and range based constructors.
///
/// Note that code here follows more standards-based coding conventions as it
/// is mirroring proposed interfaces for standardization.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_ITERATOR_RANGE_H
#define LLVM_ADT_ITERATOR_RANGE_H

#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator_range.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator_range.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator_range.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator_range.h"

namespace llvm {

/// A range adaptor for a pair of iterators.
///
/// This just wraps two iterators into a range-compatible interface. Nothing
/// fancy at all.
template <typename IteratorT>
class iterator_range {
  IteratorT begin_iterator, end_iterator;

public:
  //TODO: Add SFINAE to test that the Container's iterators match the range's
  //      iterators.
  template <typename Container>
  iterator_range(Container &&c)
  //TODO: Consider ADL/non-member begin/end calls.
      : begin_iterator(c.begin()), end_iterator(c.end()) {}
  iterator_range(IteratorT begin_iterator, IteratorT end_iterator)
      : begin_iterator(std::move(begin_iterator)),
        end_iterator(std::move(end_iterator)) {}

  IteratorT begin() const { return begin_iterator; }
  IteratorT end() const { return end_iterator; }
  bool empty() const { return begin_iterator == end_iterator; }
};

/// Convenience function for iterating over sub-ranges.
///
/// This provides a bit of syntactic sugar to make using sub-ranges
/// in for loops a bit easier. Analogous to std::make_pair().
template <class T> iterator_range<T> make_range(T x, T y) {
  return iterator_range<T>(std::move(x), std::move(y));
}

template <typename T> iterator_range<T> make_range(std::pair<T, T> p) {
  return iterator_range<T>(std::move(p.first), std::move(p.second));
}

}

#endif
# 65 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator_range.h"
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 1 3
// -*- C++ -*-
//===-------------------------- algorithm ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_ALGORITHM
#define _LIBCPP_ALGORITHM

/*
    algorithm synopsis

#include <initializer_list>

namespace std
{

template <class InputIterator, class Predicate>
    constexpr bool     // constexpr in C++20
    all_of(InputIterator first, InputIterator last, Predicate pred);

template <class InputIterator, class Predicate>
    constexpr bool     // constexpr in C++20
    any_of(InputIterator first, InputIterator last, Predicate pred);

template <class InputIterator, class Predicate>
    constexpr bool     // constexpr in C++20
    none_of(InputIterator first, InputIterator last, Predicate pred);

template <class InputIterator, class Function>
    constexpr Function          // constexpr in C++20
    for_each(InputIterator first, InputIterator last, Function f);

template<class InputIterator, class Size, class Function>
    constexpr InputIterator     // constexpr in C++20
    for_each_n(InputIterator first, Size n, Function f); // C++17

template <class InputIterator, class T>
    constexpr InputIterator     // constexpr in C++20
    find(InputIterator first, InputIterator last, const T& value);

template <class InputIterator, class Predicate>
    constexpr InputIterator     // constexpr in C++20
    find_if(InputIterator first, InputIterator last, Predicate pred);

template<class InputIterator, class Predicate>
    InputIterator               // constexpr in C++20
    find_if_not(InputIterator first, InputIterator last, Predicate pred);

template <class ForwardIterator1, class ForwardIterator2>
    ForwardIterator1            // constexpr in C++20
    find_end(ForwardIterator1 first1, ForwardIterator1 last1,
             ForwardIterator2 first2, ForwardIterator2 last2);

template <class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    ForwardIterator1            // constexpr in C++20
    find_end(ForwardIterator1 first1, ForwardIterator1 last1,
             ForwardIterator2 first2, ForwardIterator2 last2, BinaryPredicate pred);

template <class ForwardIterator1, class ForwardIterator2>
    constexpr ForwardIterator1  // constexpr in C++20
    find_first_of(ForwardIterator1 first1, ForwardIterator1 last1,
                  ForwardIterator2 first2, ForwardIterator2 last2);

template <class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    constexpr ForwardIterator1  // constexpr in C++20
    find_first_of(ForwardIterator1 first1, ForwardIterator1 last1,
                  ForwardIterator2 first2, ForwardIterator2 last2, BinaryPredicate pred);

template <class ForwardIterator>
    constexpr ForwardIterator   // constexpr in C++20
    adjacent_find(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class BinaryPredicate>
    constexpr ForwardIterator   // constexpr in C++20
    adjacent_find(ForwardIterator first, ForwardIterator last, BinaryPredicate pred);

template <class InputIterator, class T>
    constexpr typename iterator_traits<InputIterator>::difference_type  // constexpr in C++20
    count(InputIterator first, InputIterator last, const T& value);

template <class InputIterator, class Predicate>
    constexpr typename iterator_traits<InputIterator>::difference_type // constexpr in C++20
    count_if(InputIterator first, InputIterator last, Predicate pred);

template <class InputIterator1, class InputIterator2>
    constexpr pair<InputIterator1, InputIterator2>   // constexpr in C++20
    mismatch(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2);

template <class InputIterator1, class InputIterator2>
    constexpr pair<InputIterator1, InputIterator2>   // constexpr in C++20
    mismatch(InputIterator1 first1, InputIterator1 last1,
             InputIterator2 first2, InputIterator2 last2); // **C++14**

template <class InputIterator1, class InputIterator2, class BinaryPredicate>
    constexpr pair<InputIterator1, InputIterator2>   // constexpr in C++20
    mismatch(InputIterator1 first1, InputIterator1 last1,
             InputIterator2 first2, BinaryPredicate pred);

template <class InputIterator1, class InputIterator2, class BinaryPredicate>
    constexpr pair<InputIterator1, InputIterator2>   // constexpr in C++20
    mismatch(InputIterator1 first1, InputIterator1 last1,
             InputIterator2 first2, InputIterator2 last2,
             BinaryPredicate pred); // **C++14**

template <class InputIterator1, class InputIterator2>
    constexpr bool      // constexpr in C++20
    equal(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2);

template <class InputIterator1, class InputIterator2>
    constexpr bool      // constexpr in C++20
    equal(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, InputIterator2 last2); // **C++14**

template <class InputIterator1, class InputIterator2, class BinaryPredicate>
    constexpr bool      // constexpr in C++20
    equal(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, BinaryPredicate pred);

template <class InputIterator1, class InputIterator2, class BinaryPredicate>
    constexpr bool      // constexpr in C++20
    equal(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, InputIterator2 last2,
          BinaryPredicate pred); // **C++14**

template<class ForwardIterator1, class ForwardIterator2>
    constexpr bool      // constexpr in C++20
    is_permutation(ForwardIterator1 first1, ForwardIterator1 last1,
                   ForwardIterator2 first2);

template<class ForwardIterator1, class ForwardIterator2>
    constexpr bool      // constexpr in C++20
    is_permutation(ForwardIterator1 first1, ForwardIterator1 last1,
                   ForwardIterator2 first2, ForwardIterator2 last2); // **C++14**

template<class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    constexpr bool      // constexpr in C++20
    is_permutation(ForwardIterator1 first1, ForwardIterator1 last1,
                   ForwardIterator2 first2, BinaryPredicate pred);

template<class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    constexpr bool      // constexpr in C++20
    is_permutation(ForwardIterator1 first1, ForwardIterator1 last1,
                   ForwardIterator2 first2, ForwardIterator2 last2,
                   BinaryPredicate pred);  // **C++14**

template <class ForwardIterator1, class ForwardIterator2>
    constexpr ForwardIterator1      // constexpr in C++20
    search(ForwardIterator1 first1, ForwardIterator1 last1,
           ForwardIterator2 first2, ForwardIterator2 last2);

template <class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    constexpr ForwardIterator1      // constexpr in C++20
    search(ForwardIterator1 first1, ForwardIterator1 last1,
           ForwardIterator2 first2, ForwardIterator2 last2, BinaryPredicate pred);

template <class ForwardIterator, class Size, class T>
    constexpr ForwardIterator       // constexpr in C++20
    search_n(ForwardIterator first, ForwardIterator last, Size count, const T& value);

template <class ForwardIterator, class Size, class T, class BinaryPredicate>
    constexpr ForwardIterator       // constexpr in C++20
    search_n(ForwardIterator first, ForwardIterator last,
             Size count, const T& value, BinaryPredicate pred);

template <class InputIterator, class OutputIterator>
    constexpr OutputIterator      // constexpr in C++20
    copy(InputIterator first, InputIterator last, OutputIterator result);

template<class InputIterator, class OutputIterator, class Predicate>
    constexpr OutputIterator      // constexpr in C++20
    copy_if(InputIterator first, InputIterator last,
            OutputIterator result, Predicate pred);

template<class InputIterator, class Size, class OutputIterator>
    constexpr OutputIterator      // constexpr in C++20
    copy_n(InputIterator first, Size n, OutputIterator result);

template <class BidirectionalIterator1, class BidirectionalIterator2>
    constexpr BidirectionalIterator2      // constexpr in C++20
    copy_backward(BidirectionalIterator1 first, BidirectionalIterator1 last,
                  BidirectionalIterator2 result);

template <class ForwardIterator1, class ForwardIterator2>
    ForwardIterator2
    swap_ranges(ForwardIterator1 first1, ForwardIterator1 last1, ForwardIterator2 first2);

template <class ForwardIterator1, class ForwardIterator2>
    void
    iter_swap(ForwardIterator1 a, ForwardIterator2 b);

template <class InputIterator, class OutputIterator, class UnaryOperation>
    constexpr OutputIterator      // constexpr in C++20
    transform(InputIterator first, InputIterator last, OutputIterator result, UnaryOperation op);

template <class InputIterator1, class InputIterator2, class OutputIterator, class BinaryOperation>
    constexpr OutputIterator      // constexpr in C++20
    transform(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2,
              OutputIterator result, BinaryOperation binary_op);

template <class ForwardIterator, class T>
    constexpr void      // constexpr in C++20
    replace(ForwardIterator first, ForwardIterator last, const T& old_value, const T& new_value);

template <class ForwardIterator, class Predicate, class T>
    constexpr void      // constexpr in C++20
    replace_if(ForwardIterator first, ForwardIterator last, Predicate pred, const T& new_value);

template <class InputIterator, class OutputIterator, class T>
    constexpr OutputIterator      // constexpr in C++20
    replace_copy(InputIterator first, InputIterator last, OutputIterator result,
                 const T& old_value, const T& new_value);

template <class InputIterator, class OutputIterator, class Predicate, class T>
    constexpr OutputIterator      // constexpr in C++20
    replace_copy_if(InputIterator first, InputIterator last, OutputIterator result, Predicate pred, const T& new_value);

template <class ForwardIterator, class T>
    constexpr void      // constexpr in C++20
    fill(ForwardIterator first, ForwardIterator last, const T& value);

template <class OutputIterator, class Size, class T>
    constexpr OutputIterator      // constexpr in C++20
    fill_n(OutputIterator first, Size n, const T& value);

template <class ForwardIterator, class Generator>
    constexpr void      // constexpr in C++20
    generate(ForwardIterator first, ForwardIterator last, Generator gen);

template <class OutputIterator, class Size, class Generator>
    constexpr OutputIterator      // constexpr in C++20
    generate_n(OutputIterator first, Size n, Generator gen);

template <class ForwardIterator, class T>
    constexpr ForwardIterator     // constexpr in C++20
    remove(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class Predicate>
    constexpr ForwardIterator     // constexpr in C++20
    remove_if(ForwardIterator first, ForwardIterator last, Predicate pred);

template <class InputIterator, class OutputIterator, class T>
    constexpr OutputIterator     // constexpr in C++20
    remove_copy(InputIterator first, InputIterator last, OutputIterator result, const T& value);

template <class InputIterator, class OutputIterator, class Predicate>
    constexpr OutputIterator     // constexpr in C++20
    remove_copy_if(InputIterator first, InputIterator last, OutputIterator result, Predicate pred);

template <class ForwardIterator>
    ForwardIterator
    unique(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class BinaryPredicate>
    ForwardIterator
    unique(ForwardIterator first, ForwardIterator last, BinaryPredicate pred);

template <class InputIterator, class OutputIterator>
    OutputIterator
    unique_copy(InputIterator first, InputIterator last, OutputIterator result);

template <class InputIterator, class OutputIterator, class BinaryPredicate>
    OutputIterator
    unique_copy(InputIterator first, InputIterator last, OutputIterator result, BinaryPredicate pred);

template <class BidirectionalIterator>
    void
    reverse(BidirectionalIterator first, BidirectionalIterator last);

template <class BidirectionalIterator, class OutputIterator>
    constexpr OutputIterator       // constexpr in C++20
    reverse_copy(BidirectionalIterator first, BidirectionalIterator last, OutputIterator result);

template <class ForwardIterator>
    ForwardIterator
    rotate(ForwardIterator first, ForwardIterator middle, ForwardIterator last);

template <class ForwardIterator, class OutputIterator>
    OutputIterator
    rotate_copy(ForwardIterator first, ForwardIterator middle, ForwardIterator last, OutputIterator result);

template <class RandomAccessIterator>
    void
    random_shuffle(RandomAccessIterator first, RandomAccessIterator last); // deprecated in C++14, removed in C++17

template <class RandomAccessIterator, class RandomNumberGenerator>
    void
    random_shuffle(RandomAccessIterator first, RandomAccessIterator last,
                   RandomNumberGenerator& rand);  // deprecated in C++14, removed in C++17

template<class PopulationIterator, class SampleIterator,
         class Distance, class UniformRandomBitGenerator>
    SampleIterator sample(PopulationIterator first, PopulationIterator last,
                          SampleIterator out, Distance n,
                          UniformRandomBitGenerator&& g); // C++17

template<class RandomAccessIterator, class UniformRandomNumberGenerator>
    void shuffle(RandomAccessIterator first, RandomAccessIterator last,
                 UniformRandomNumberGenerator&& g);

template <class InputIterator, class Predicate>
    constexpr bool  // constexpr in C++20
    is_partitioned(InputIterator first, InputIterator last, Predicate pred);

template <class ForwardIterator, class Predicate>
    ForwardIterator
    partition(ForwardIterator first, ForwardIterator last, Predicate pred);

template <class InputIterator, class OutputIterator1,
          class OutputIterator2, class Predicate>
    constexpr pair<OutputIterator1, OutputIterator2>   // constexpr in C++20
    partition_copy(InputIterator first, InputIterator last,
                   OutputIterator1 out_true, OutputIterator2 out_false,
                   Predicate pred);

template <class ForwardIterator, class Predicate>
    ForwardIterator
    stable_partition(ForwardIterator first, ForwardIterator last, Predicate pred);

template<class ForwardIterator, class Predicate>
    constexpr ForwardIterator  // constexpr in C++20
    partition_point(ForwardIterator first, ForwardIterator last, Predicate pred);

template <class ForwardIterator>
    constexpr bool  // constexpr in C++20
    is_sorted(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Compare>
    bool
    is_sorted(ForwardIterator first, ForwardIterator last, Compare comp);

template<class ForwardIterator>
    constexpr ForwardIterator    // constexpr in C++20
    is_sorted_until(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Compare>
    constexpr ForwardIterator    // constexpr in C++20
    is_sorted_until(ForwardIterator first, ForwardIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    sort(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    sort(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    stable_sort(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    stable_sort(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    partial_sort(RandomAccessIterator first, RandomAccessIterator middle, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    partial_sort(RandomAccessIterator first, RandomAccessIterator middle, RandomAccessIterator last, Compare comp);

template <class InputIterator, class RandomAccessIterator>
    RandomAccessIterator
    partial_sort_copy(InputIterator first, InputIterator last,
                      RandomAccessIterator result_first, RandomAccessIterator result_last);

template <class InputIterator, class RandomAccessIterator, class Compare>
    RandomAccessIterator
    partial_sort_copy(InputIterator first, InputIterator last,
                      RandomAccessIterator result_first, RandomAccessIterator result_last, Compare comp);

template <class RandomAccessIterator>
    void
    nth_element(RandomAccessIterator first, RandomAccessIterator nth, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    nth_element(RandomAccessIterator first, RandomAccessIterator nth, RandomAccessIterator last, Compare comp);

template <class ForwardIterator, class T>
    constexpr ForwardIterator                         // constexpr in C++20
    lower_bound(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class T, class Compare>
    constexpr ForwardIterator                         // constexpr in C++20
    lower_bound(ForwardIterator first, ForwardIterator last, const T& value, Compare comp);

template <class ForwardIterator, class T>
    constexpr ForwardIterator                         // constexpr in C++20
    upper_bound(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class T, class Compare>
    constexpr ForwardIterator                         // constexpr in C++20
    upper_bound(ForwardIterator first, ForwardIterator last, const T& value, Compare comp);

template <class ForwardIterator, class T>
    constexpr pair<ForwardIterator, ForwardIterator>  // constexpr in C++20
    equal_range(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class T, class Compare>
    constexpr pair<ForwardIterator, ForwardIterator>  // constexpr in C++20
    equal_range(ForwardIterator first, ForwardIterator last, const T& value, Compare comp);

template <class ForwardIterator, class T>
    constexpr bool                                    // constexpr in C++20
    binary_search(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class T, class Compare>
    constexpr bool                                    // constexpr in C++20
    binary_search(ForwardIterator first, ForwardIterator last, const T& value, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    merge(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    merge(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class BidirectionalIterator>
    void
    inplace_merge(BidirectionalIterator first, BidirectionalIterator middle, BidirectionalIterator last);

template <class BidirectionalIterator, class Compare>
    void
    inplace_merge(BidirectionalIterator first, BidirectionalIterator middle, BidirectionalIterator last, Compare comp);

template <class InputIterator1, class InputIterator2>
    constexpr bool                                    // constexpr in C++20
    includes(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2, InputIterator2 last2);

template <class InputIterator1, class InputIterator2, class Compare>
    constexpr bool                                    // constexpr in C++20
    includes(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2, InputIterator2 last2, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    set_union(InputIterator1 first1, InputIterator1 last1,
              InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    set_union(InputIterator1 first1, InputIterator1 last1,
              InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    constexpr OutputIterator                         // constexpr in C++20
    set_intersection(InputIterator1 first1, InputIterator1 last1,
                     InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    constexpr OutputIterator                         // constexpr in C++20
    set_intersection(InputIterator1 first1, InputIterator1 last1,
                     InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    set_difference(InputIterator1 first1, InputIterator1 last1,
                   InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    set_difference(InputIterator1 first1, InputIterator1 last1,
                   InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    set_symmetric_difference(InputIterator1 first1, InputIterator1 last1,
                             InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    set_symmetric_difference(InputIterator1 first1, InputIterator1 last1,
                             InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class RandomAccessIterator>
    void
    push_heap(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    push_heap(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    pop_heap(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    pop_heap(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    make_heap(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    make_heap(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    sort_heap(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    sort_heap(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    constexpr bool   // constexpr in C++20
    is_heap(RandomAccessIterator first, RandomAccessiterator last);

template <class RandomAccessIterator, class Compare>
    constexpr bool   // constexpr in C++20
    is_heap(RandomAccessIterator first, RandomAccessiterator last, Compare comp);

template <class RandomAccessIterator>
    constexpr RandomAccessIterator   // constexpr in C++20
    is_heap_until(RandomAccessIterator first, RandomAccessiterator last);

template <class RandomAccessIterator, class Compare>
    constexpr RandomAccessIterator   // constexpr in C++20
    is_heap_until(RandomAccessIterator first, RandomAccessiterator last, Compare comp);

template <class ForwardIterator>
    ForwardIterator
    min_element(ForwardIterator first, ForwardIterator last);  // constexpr in C++14

template <class ForwardIterator, class Compare>
    ForwardIterator
    min_element(ForwardIterator first, ForwardIterator last, Compare comp);  // constexpr in C++14

template <class T>
    const T&
    min(const T& a, const T& b);  // constexpr in C++14

template <class T, class Compare>
    const T&
    min(const T& a, const T& b, Compare comp);  // constexpr in C++14

template<class T>
    T
    min(initializer_list<T> t);  // constexpr in C++14

template<class T, class Compare>
    T
    min(initializer_list<T> t, Compare comp);  // constexpr in C++14

template<class T>
    constexpr const T& clamp( const T& v, const T& lo, const T& hi );               // C++17

template<class T, class Compare>
    constexpr const T& clamp( const T& v, const T& lo, const T& hi, Compare comp ); // C++17

template <class ForwardIterator>
    ForwardIterator
    max_element(ForwardIterator first, ForwardIterator last);  // constexpr in C++14

template <class ForwardIterator, class Compare>
    ForwardIterator
    max_element(ForwardIterator first, ForwardIterator last, Compare comp);  // constexpr in C++14

template <class T>
    const T&
    max(const T& a, const T& b); // constexpr in C++14

template <class T, class Compare>
    const T&
    max(const T& a, const T& b, Compare comp);  // constexpr in C++14

template<class T>
    T
    max(initializer_list<T> t);  // constexpr in C++14

template<class T, class Compare>
    T
    max(initializer_list<T> t, Compare comp);  // constexpr in C++14

template<class ForwardIterator>
    pair<ForwardIterator, ForwardIterator>
    minmax_element(ForwardIterator first, ForwardIterator last);   // constexpr in C++14

template<class ForwardIterator, class Compare>
    pair<ForwardIterator, ForwardIterator>
    minmax_element(ForwardIterator first, ForwardIterator last, Compare comp);   // constexpr in C++14

template<class T>
    pair<const T&, const T&>
    minmax(const T& a, const T& b);  // constexpr in C++14

template<class T, class Compare>
    pair<const T&, const T&>
    minmax(const T& a, const T& b, Compare comp);  // constexpr in C++14

template<class T>
    pair<T, T>
    minmax(initializer_list<T> t);  // constexpr in C++14

template<class T, class Compare>
    pair<T, T>
    minmax(initializer_list<T> t, Compare comp);  // constexpr in C++14

template <class InputIterator1, class InputIterator2>
    constexpr bool     // constexpr in C++20
    lexicographical_compare(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2, InputIterator2 last2);

template <class InputIterator1, class InputIterator2, class Compare>
    constexpr bool     // constexpr in C++20
    lexicographical_compare(InputIterator1 first1, InputIterator1 last1,
                            InputIterator2 first2, InputIterator2 last2, Compare comp);

template <class BidirectionalIterator>
    bool
    next_permutation(BidirectionalIterator first, BidirectionalIterator last);

template <class BidirectionalIterator, class Compare>
    bool
    next_permutation(BidirectionalIterator first, BidirectionalIterator last, Compare comp);

template <class BidirectionalIterator>
    bool
    prev_permutation(BidirectionalIterator first, BidirectionalIterator last);

template <class BidirectionalIterator, class Compare>
    bool
    prev_permutation(BidirectionalIterator first, BidirectionalIterator last, Compare comp);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 638 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 639 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 639 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 640 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 640 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 641 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 641 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 642 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility> // needed to provide swap_ranges.
#endif /* expanded by -frewrite-includes */
# 642 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 643 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 643 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 644 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <functional>
#endif /* expanded by -frewrite-includes */
# 644 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 1 3
// -*- C++ -*-
//===------------------------ functional ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_FUNCTIONAL
#define _LIBCPP_FUNCTIONAL

/*
    functional synopsis

namespace std
{

template <class Arg, class Result>
struct unary_function
{
    typedef Arg    argument_type;
    typedef Result result_type;
};

template <class Arg1, class Arg2, class Result>
struct binary_function
{
    typedef Arg1   first_argument_type;
    typedef Arg2   second_argument_type;
    typedef Result result_type;
};

template <class T>
class reference_wrapper
    : public unary_function<T1, R> // if wrapping a unary functor
    : public binary_function<T1, T2, R> // if wraping a binary functor
{
public:
    // types
    typedef T type;
    typedef see below result_type; // Not always defined

    // construct/copy/destroy
    reference_wrapper(T&) noexcept;
    reference_wrapper(T&&) = delete; // do not bind to temps
    reference_wrapper(const reference_wrapper<T>& x) noexcept;

    // assignment
    reference_wrapper& operator=(const reference_wrapper<T>& x) noexcept;

    // access
    operator T& () const noexcept;
    T& get() const noexcept;

    // invoke
    template <class... ArgTypes>
      typename result_of<T&(ArgTypes&&...)>::type
          operator() (ArgTypes&&...) const;
};

template <class T> reference_wrapper<T> ref(T& t) noexcept;
template <class T> void ref(const T&& t) = delete;
template <class T> reference_wrapper<T> ref(reference_wrapper<T>t) noexcept;

template <class T> reference_wrapper<const T> cref(const T& t) noexcept;
template <class T> void cref(const T&& t) = delete;
template <class T> reference_wrapper<const T> cref(reference_wrapper<T> t) noexcept;

template <class T> struct unwrap_reference;                                       // since C++20
template <class T> struct unwrap_ref_decay : unwrap_reference<decay_t<T>> { };    // since C++20
template <class T> using unwrap_reference_t = typename unwrap_reference<T>::type; // since C++20
template <class T> using unwrap_ref_decay_t = typename unwrap_ref_decay<T>::type; // since C++20

template <class T> // <class T=void> in C++14
struct plus : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct minus : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct multiplies : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct divides : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct modulus : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct negate : unary_function<T, T>
{
    T operator()(const T& x) const;
};

template <class T> // <class T=void> in C++14
struct equal_to : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct not_equal_to : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct greater : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct less : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct greater_equal : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct less_equal : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct logical_and : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct logical_or : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct logical_not : unary_function<T, bool>
{
    bool operator()(const T& x) const;
};

template <class T> // <class T=void> in C++14
struct bit_and : unary_function<T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct bit_or : unary_function<T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct bit_xor : unary_function<T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T=void> // C++14
struct bit_xor : unary_function<T, bool>
{
    bool operator()(const T& x) const;
};

template <class Predicate>
class unary_negate // deprecated in C++17
    : public unary_function<typename Predicate::argument_type, bool>
{
public:
    explicit unary_negate(const Predicate& pred);
    bool operator()(const typename Predicate::argument_type& x) const;
};

template <class Predicate> // deprecated in C++17
unary_negate<Predicate> not1(const Predicate& pred);

template <class Predicate>
class binary_negate // deprecated in C++17
    : public binary_function<typename Predicate::first_argument_type,
                             typename Predicate::second_argument_type,
                             bool>
{
public:
    explicit binary_negate(const Predicate& pred);
    bool operator()(const typename Predicate::first_argument_type& x,
                    const typename Predicate::second_argument_type& y) const;
};

template <class Predicate> // deprecated in C++17
binary_negate<Predicate> not2(const Predicate& pred);

template <class F> unspecified not_fn(F&& f); // C++17

template<class T> struct is_bind_expression;
template<class T> struct is_placeholder;

    // See C++14 20.9.9, Function object binders
template <class T> inline constexpr bool is_bind_expression_v
  = is_bind_expression<T>::value; // C++17
template <class T> inline constexpr int is_placeholder_v
  = is_placeholder<T>::value; // C++17


template<class Fn, class... BoundArgs>
  unspecified bind(Fn&&, BoundArgs&&...);
template<class R, class Fn, class... BoundArgs>
  unspecified bind(Fn&&, BoundArgs&&...);

template<class F, class... Args>
 invoke_result_t<F, Args...> invoke(F&& f, Args&&... args) // C++17
    noexcept(is_nothrow_invocable_v<F, Args...>);

namespace placeholders {
  // M is the implementation-defined number of placeholders
  extern unspecified _1;
  extern unspecified _2;
  .
  .
  .
  extern unspecified _Mp;
}

template <class Operation>
class binder1st     // deprecated in C++11, removed in C++17
    : public unary_function<typename Operation::second_argument_type,
                            typename Operation::result_type>
{
protected:
    Operation                               op;
    typename Operation::first_argument_type value;
public:
    binder1st(const Operation& x, const typename Operation::first_argument_type y);
    typename Operation::result_type operator()(      typename Operation::second_argument_type& x) const;
    typename Operation::result_type operator()(const typename Operation::second_argument_type& x) const;
};

template <class Operation, class T>
binder1st<Operation> bind1st(const Operation& op, const T& x);  // deprecated in C++11, removed in C++17

template <class Operation>
class binder2nd     // deprecated in C++11, removed in C++17
    : public unary_function<typename Operation::first_argument_type,
                            typename Operation::result_type>
{
protected:
    Operation                                op;
    typename Operation::second_argument_type value;
public:
    binder2nd(const Operation& x, const typename Operation::second_argument_type y);
    typename Operation::result_type operator()(      typename Operation::first_argument_type& x) const;
    typename Operation::result_type operator()(const typename Operation::first_argument_type& x) const;
};

template <class Operation, class T>
binder2nd<Operation> bind2nd(const Operation& op, const T& x);  // deprecated in C++11, removed in C++17

template <class Arg, class Result>      // deprecated in C++11, removed in C++17
class pointer_to_unary_function : public unary_function<Arg, Result>
{
public:
    explicit pointer_to_unary_function(Result (*f)(Arg));
    Result operator()(Arg x) const;
};

template <class Arg, class Result>
pointer_to_unary_function<Arg,Result> ptr_fun(Result (*f)(Arg));      // deprecated in C++11, removed in C++17

template <class Arg1, class Arg2, class Result>      // deprecated in C++11, removed in C++17
class pointer_to_binary_function : public binary_function<Arg1, Arg2, Result>
{
public:
    explicit pointer_to_binary_function(Result (*f)(Arg1, Arg2));
    Result operator()(Arg1 x, Arg2 y) const;
};

template <class Arg1, class Arg2, class Result>
pointer_to_binary_function<Arg1,Arg2,Result> ptr_fun(Result (*f)(Arg1,Arg2));      // deprecated in C++11, removed in C++17

template<class S, class T>      // deprecated in C++11, removed in C++17
class mem_fun_t : public unary_function<T*, S>
{
public:
    explicit mem_fun_t(S (T::*p)());
    S operator()(T* p) const;
};

template<class S, class T, class A>
class mem_fun1_t : public binary_function<T*, A, S>      // deprecated in C++11, removed in C++17
{
public:
    explicit mem_fun1_t(S (T::*p)(A));
    S operator()(T* p, A x) const;
};

template<class S, class T>          mem_fun_t<S,T>    mem_fun(S (T::*f)());      // deprecated in C++11, removed in C++17
template<class S, class T, class A> mem_fun1_t<S,T,A> mem_fun(S (T::*f)(A));     // deprecated in C++11, removed in C++17

template<class S, class T>
class mem_fun_ref_t : public unary_function<T, S>      // deprecated in C++11, removed in C++17
{
public:
    explicit mem_fun_ref_t(S (T::*p)());
    S operator()(T& p) const;
};

template<class S, class T, class A>
class mem_fun1_ref_t : public binary_function<T, A, S>      // deprecated in C++11, removed in C++17
{
public:
    explicit mem_fun1_ref_t(S (T::*p)(A));
    S operator()(T& p, A x) const;
};

template<class S, class T>          mem_fun_ref_t<S,T>    mem_fun_ref(S (T::*f)());      // deprecated in C++11, removed in C++17
template<class S, class T, class A> mem_fun1_ref_t<S,T,A> mem_fun_ref(S (T::*f)(A));     // deprecated in C++11, removed in C++17

template <class S, class T>
class const_mem_fun_t : public unary_function<const T*, S>      // deprecated in C++11, removed in C++17
{
public:
    explicit const_mem_fun_t(S (T::*p)() const);
    S operator()(const T* p) const;
};

template <class S, class T, class A>
class const_mem_fun1_t : public binary_function<const T*, A, S>      // deprecated in C++11, removed in C++17
{
public:
    explicit const_mem_fun1_t(S (T::*p)(A) const);
    S operator()(const T* p, A x) const;
};

template <class S, class T>          const_mem_fun_t<S,T>    mem_fun(S (T::*f)() const);      // deprecated in C++11, removed in C++17
template <class S, class T, class A> const_mem_fun1_t<S,T,A> mem_fun(S (T::*f)(A) const);     // deprecated in C++11, removed in C++17

template <class S, class T>
class const_mem_fun_ref_t : public unary_function<T, S>      // deprecated in C++11, removed in C++17
{
public:
    explicit const_mem_fun_ref_t(S (T::*p)() const);
    S operator()(const T& p) const;
};

template <class S, class T, class A>
class const_mem_fun1_ref_t : public binary_function<T, A, S>      // deprecated in C++11, removed in C++17
{
public:
    explicit const_mem_fun1_ref_t(S (T::*p)(A) const);
    S operator()(const T& p, A x) const;
};

template <class S, class T>          const_mem_fun_ref_t<S,T>    mem_fun_ref(S (T::*f)() const);   // deprecated in C++11, removed in C++17
template <class S, class T, class A> const_mem_fun1_ref_t<S,T,A> mem_fun_ref(S (T::*f)(A) const);  // deprecated in C++11, removed in C++17

template<class R, class T> unspecified mem_fn(R T::*);

class bad_function_call
    : public exception
{
};

template<class> class function; // undefined

template<class R, class... ArgTypes>
class function<R(ArgTypes...)>
  : public unary_function<T1, R>      // iff sizeof...(ArgTypes) == 1 and
                                      // ArgTypes contains T1
  : public binary_function<T1, T2, R> // iff sizeof...(ArgTypes) == 2 and
                                      // ArgTypes contains T1 and T2
{
public:
    typedef R result_type;

    // construct/copy/destroy:
    function() noexcept;
    function(nullptr_t) noexcept;
    function(const function&);
    function(function&&) noexcept;
    template<class F>
      function(F);
    template<Allocator Alloc>
      function(allocator_arg_t, const Alloc&) noexcept;            // removed in C++17
    template<Allocator Alloc>
      function(allocator_arg_t, const Alloc&, nullptr_t) noexcept; // removed in C++17
    template<Allocator Alloc>
      function(allocator_arg_t, const Alloc&, const function&);    // removed in C++17
    template<Allocator Alloc>
      function(allocator_arg_t, const Alloc&, function&&);         // removed in C++17
    template<class F, Allocator Alloc>
      function(allocator_arg_t, const Alloc&, F);                  // removed in C++17

    function& operator=(const function&);
    function& operator=(function&&) noexcept;
    function& operator=(nullptr_t) noexcept;
    template<class F>
      function& operator=(F&&);
    template<class F>
      function& operator=(reference_wrapper<F>) noexcept;

    ~function();

    // function modifiers:
    void swap(function&) noexcept;
    template<class F, class Alloc>
      void assign(F&&, const Alloc&);                 // Removed in C++17

    // function capacity:
    explicit operator bool() const noexcept;

    // function invocation:
    R operator()(ArgTypes...) const;

    // function target access:
    const std::type_info& target_type() const noexcept;
    template <typename T>       T* target() noexcept;
    template <typename T> const T* target() const noexcept;
};

// Deduction guides
template<class R, class ...Args>
function(R(*)(Args...)) -> function<R(Args...)>; // since C++17

template<class F>
function(F) -> function<see-below>; // since C++17

// Null pointer comparisons:
template <class R, class ... ArgTypes>
  bool operator==(const function<R(ArgTypes...)>&, nullptr_t) noexcept;

template <class R, class ... ArgTypes>
  bool operator==(nullptr_t, const function<R(ArgTypes...)>&) noexcept;

template <class R, class ... ArgTypes>
  bool operator!=(const function<R(ArgTypes...)>&, nullptr_t) noexcept;

template <class  R, class ... ArgTypes>
  bool operator!=(nullptr_t, const function<R(ArgTypes...)>&) noexcept;

// specialized algorithms:
template <class  R, class ... ArgTypes>
  void swap(function<R(ArgTypes...)>&, function<R(ArgTypes...)>&) noexcept;

template <class T> struct hash;

template <> struct hash<bool>;
template <> struct hash<char>;
template <> struct hash<signed char>;
template <> struct hash<unsigned char>;
template <> struct hash<char16_t>;
template <> struct hash<char32_t>;
template <> struct hash<wchar_t>;
template <> struct hash<short>;
template <> struct hash<unsigned short>;
template <> struct hash<int>;
template <> struct hash<unsigned int>;
template <> struct hash<long>;
template <> struct hash<long long>;
template <> struct hash<unsigned long>;
template <> struct hash<unsigned long long>;

template <> struct hash<float>;
template <> struct hash<double>;
template <> struct hash<long double>;

template<class T> struct hash<T*>;
template <> struct hash<nullptr_t>;  // C++17

}  // std

POLICY:  For non-variadic implementations, the number of arguments is limited
         to 3.  It is hoped that the need for non-variadic implementations
         will be minimal.

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 500 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 501 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 501 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 502 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <typeinfo>
#endif /* expanded by -frewrite-includes */
# 502 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 503 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 503 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 504 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 504 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 505 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 505 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 506 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 506 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 507 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 507 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 508 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 509 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 510 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 512 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 513 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
#endif
# 514 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

_LIBCPP_BEGIN_NAMESPACE_STD

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 518 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 520 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 522 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS plus : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x + __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 530 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS plus<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) + _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) + _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) + _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 542 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 545 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 547 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 549 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS minus : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x - __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 557 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS minus<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) - _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) - _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) - _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 569 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 572 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 574 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 576 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS multiplies : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x * __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 584 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS multiplies<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) * _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) * _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) * _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 596 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 599 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 601 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 603 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS divides : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x / __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 611 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS divides<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) / _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) / _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) / _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 623 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 626 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 628 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 630 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS modulus : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x % __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 638 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS modulus<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) % _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) % _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) % _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 650 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 655 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 657 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS negate : unary_function<_Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x) const
        {return -__x;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 665 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS negate<void>
{
    template <class _Tp>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Tp&& __x) const
    _NOEXCEPT_(noexcept(- _VSTD::forward<_Tp>(__x)))
    -> decltype        (- _VSTD::forward<_Tp>(__x))
        { return        - _VSTD::forward<_Tp>(__x); }
    typedef void is_transparent;
};
#endif
# 677 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 680 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 682 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 684 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS equal_to : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x == __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 692 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS equal_to<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) == _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) == _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) == _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 704 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 707 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 709 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 711 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS not_equal_to : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x != __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 719 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS not_equal_to<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) != _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) != _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) != _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 731 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 734 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 736 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 738 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS greater : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x > __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 746 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS greater<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) > _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) > _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) > _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 758 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


// less in <__functional_base>

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 763 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 765 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 767 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS greater_equal : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x >= __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 775 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS greater_equal<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) >= _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) >= _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) >= _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 787 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 790 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 792 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 794 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS less_equal : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x <= __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 802 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS less_equal<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) <= _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) <= _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) <= _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 814 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 817 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 819 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 821 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS logical_and : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x && __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 829 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS logical_and<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) && _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) && _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) && _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 841 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 844 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 846 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 848 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS logical_or : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x || __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 856 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS logical_or<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) || _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) || _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) || _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 868 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 871 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 873 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 875 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS logical_not : unary_function<_Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x) const
        {return !__x;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 883 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS logical_not<void>
{
    template <class _Tp>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Tp&& __x) const
    _NOEXCEPT_(noexcept(!_VSTD::forward<_Tp>(__x)))
    -> decltype        (!_VSTD::forward<_Tp>(__x))
        { return        !_VSTD::forward<_Tp>(__x); }
    typedef void is_transparent;
};
#endif
# 895 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 898 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 900 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 902 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS bit_and : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x & __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 910 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS bit_and<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) & _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) & _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) & _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 922 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 925 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 927 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 929 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS bit_or : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x | __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 937 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS bit_or<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) | _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) | _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) | _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 949 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 952 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
#else
# 954 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
#endif
# 956 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
struct _LIBCPP_TEMPLATE_VIS bit_xor : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x ^ __y;}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 964 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <>
struct _LIBCPP_TEMPLATE_VIS bit_xor<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
    _NOEXCEPT_(noexcept(_VSTD::forward<_T1>(__t) ^ _VSTD::forward<_T2>(__u)))
    -> decltype        (_VSTD::forward<_T1>(__t) ^ _VSTD::forward<_T2>(__u))
        { return        _VSTD::forward<_T1>(__t) ^ _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 976 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 979 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp = void>
struct _LIBCPP_TEMPLATE_VIS bit_not : unary_function<_Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x) const
        {return ~__x;}
};

template <>
struct _LIBCPP_TEMPLATE_VIS bit_not<void>
{
    template <class _Tp>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Tp&& __x) const
    _NOEXCEPT_(noexcept(~_VSTD::forward<_Tp>(__x)))
    -> decltype        (~_VSTD::forward<_Tp>(__x))
        { return        ~_VSTD::forward<_Tp>(__x); }
    typedef void is_transparent;
};
#endif
# 999 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template <class _Predicate>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX17 unary_negate
    : public unary_function<typename _Predicate::argument_type, bool>
{
    _Predicate __pred_;
public:
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    explicit unary_negate(const _Predicate& __pred)
        : __pred_(__pred) {}
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const typename _Predicate::argument_type& __x) const
        {return !__pred_(__x);}
};

template <class _Predicate>
_LIBCPP_DEPRECATED_IN_CXX17 inline _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
unary_negate<_Predicate>
not1(const _Predicate& __pred) {return unary_negate<_Predicate>(__pred);}

template <class _Predicate>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX17 binary_negate
    : public binary_function<typename _Predicate::first_argument_type,
                             typename _Predicate::second_argument_type,
                             bool>
{
    _Predicate __pred_;
public:
    _LIBCPP_INLINE_VISIBILITY explicit _LIBCPP_CONSTEXPR_AFTER_CXX11
    binary_negate(const _Predicate& __pred) : __pred_(__pred) {}

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const typename _Predicate::first_argument_type& __x,
                    const typename _Predicate::second_argument_type& __y) const
        {return !__pred_(__x, __y);}
};

template <class _Predicate>
_LIBCPP_DEPRECATED_IN_CXX17 inline _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
binary_negate<_Predicate>
not2(const _Predicate& __pred) {return binary_negate<_Predicate>(__pred);}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_BINDERS)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1042 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class __Operation>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 binder1st
    : public unary_function<typename __Operation::second_argument_type,
                            typename __Operation::result_type>
{
protected:
    __Operation                               op;
    typename __Operation::first_argument_type value;
public:
    _LIBCPP_INLINE_VISIBILITY binder1st(const __Operation& __x,
                               const typename __Operation::first_argument_type __y)
        : op(__x), value(__y) {}
    _LIBCPP_INLINE_VISIBILITY typename __Operation::result_type operator()
        (typename __Operation::second_argument_type& __x) const
            {return op(value, __x);}
    _LIBCPP_INLINE_VISIBILITY typename __Operation::result_type operator()
        (const typename __Operation::second_argument_type& __x) const
            {return op(value, __x);}
};

template <class __Operation, class _Tp>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
binder1st<__Operation>
bind1st(const __Operation& __op, const _Tp& __x)
    {return binder1st<__Operation>(__op, __x);}

template <class __Operation>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 binder2nd
    : public unary_function<typename __Operation::first_argument_type,
                            typename __Operation::result_type>
{
protected:
    __Operation                                op;
    typename __Operation::second_argument_type value;
public:
    _LIBCPP_INLINE_VISIBILITY
    binder2nd(const __Operation& __x, const typename __Operation::second_argument_type __y)
        : op(__x), value(__y) {}
    _LIBCPP_INLINE_VISIBILITY typename __Operation::result_type operator()
        (      typename __Operation::first_argument_type& __x) const
            {return op(__x, value);}
    _LIBCPP_INLINE_VISIBILITY typename __Operation::result_type operator()
        (const typename __Operation::first_argument_type& __x) const
            {return op(__x, value);}
};

template <class __Operation, class _Tp>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
binder2nd<__Operation>
bind2nd(const __Operation& __op, const _Tp& __x)
    {return binder2nd<__Operation>(__op, __x);}

template <class _Arg, class _Result>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 pointer_to_unary_function
    : public unary_function<_Arg, _Result>
{
    _Result (*__f_)(_Arg);
public:
    _LIBCPP_INLINE_VISIBILITY explicit pointer_to_unary_function(_Result (*__f)(_Arg))
        : __f_(__f) {}
    _LIBCPP_INLINE_VISIBILITY _Result operator()(_Arg __x) const
        {return __f_(__x);}
};

template <class _Arg, class _Result>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
pointer_to_unary_function<_Arg,_Result>
ptr_fun(_Result (*__f)(_Arg))
    {return pointer_to_unary_function<_Arg,_Result>(__f);}

template <class _Arg1, class _Arg2, class _Result>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 pointer_to_binary_function
    : public binary_function<_Arg1, _Arg2, _Result>
{
    _Result (*__f_)(_Arg1, _Arg2);
public:
    _LIBCPP_INLINE_VISIBILITY explicit pointer_to_binary_function(_Result (*__f)(_Arg1, _Arg2))
        : __f_(__f) {}
    _LIBCPP_INLINE_VISIBILITY _Result operator()(_Arg1 __x, _Arg2 __y) const
        {return __f_(__x, __y);}
};

template <class _Arg1, class _Arg2, class _Result>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
pointer_to_binary_function<_Arg1,_Arg2,_Result>
ptr_fun(_Result (*__f)(_Arg1,_Arg2))
    {return pointer_to_binary_function<_Arg1,_Arg2,_Result>(__f);}

template<class _Sp, class _Tp>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 mem_fun_t
    : public unary_function<_Tp*, _Sp>
{
    _Sp (_Tp::*__p_)();
public:
    _LIBCPP_INLINE_VISIBILITY explicit mem_fun_t(_Sp (_Tp::*__p)())
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(_Tp* __p) const
        {return (__p->*__p_)();}
};

template<class _Sp, class _Tp, class _Ap>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 mem_fun1_t
    : public binary_function<_Tp*, _Ap, _Sp>
{
    _Sp (_Tp::*__p_)(_Ap);
public:
    _LIBCPP_INLINE_VISIBILITY explicit mem_fun1_t(_Sp (_Tp::*__p)(_Ap))
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(_Tp* __p, _Ap __x) const
        {return (__p->*__p_)(__x);}
};

template<class _Sp, class _Tp>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
mem_fun_t<_Sp,_Tp>
mem_fun(_Sp (_Tp::*__f)())
    {return mem_fun_t<_Sp,_Tp>(__f);}

template<class _Sp, class _Tp, class _Ap>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
mem_fun1_t<_Sp,_Tp,_Ap>
mem_fun(_Sp (_Tp::*__f)(_Ap))
    {return mem_fun1_t<_Sp,_Tp,_Ap>(__f);}

template<class _Sp, class _Tp>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 mem_fun_ref_t
    : public unary_function<_Tp, _Sp>
{
    _Sp (_Tp::*__p_)();
public:
    _LIBCPP_INLINE_VISIBILITY explicit mem_fun_ref_t(_Sp (_Tp::*__p)())
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(_Tp& __p) const
        {return (__p.*__p_)();}
};

template<class _Sp, class _Tp, class _Ap>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 mem_fun1_ref_t
    : public binary_function<_Tp, _Ap, _Sp>
{
    _Sp (_Tp::*__p_)(_Ap);
public:
    _LIBCPP_INLINE_VISIBILITY explicit mem_fun1_ref_t(_Sp (_Tp::*__p)(_Ap))
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(_Tp& __p, _Ap __x) const
        {return (__p.*__p_)(__x);}
};

template<class _Sp, class _Tp>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
mem_fun_ref_t<_Sp,_Tp>
mem_fun_ref(_Sp (_Tp::*__f)())
    {return mem_fun_ref_t<_Sp,_Tp>(__f);}

template<class _Sp, class _Tp, class _Ap>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
mem_fun1_ref_t<_Sp,_Tp,_Ap>
mem_fun_ref(_Sp (_Tp::*__f)(_Ap))
    {return mem_fun1_ref_t<_Sp,_Tp,_Ap>(__f);}

template <class _Sp, class _Tp>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 const_mem_fun_t
    : public unary_function<const _Tp*, _Sp>
{
    _Sp (_Tp::*__p_)() const;
public:
    _LIBCPP_INLINE_VISIBILITY explicit const_mem_fun_t(_Sp (_Tp::*__p)() const)
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(const _Tp* __p) const
        {return (__p->*__p_)();}
};

template <class _Sp, class _Tp, class _Ap>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 const_mem_fun1_t
    : public binary_function<const _Tp*, _Ap, _Sp>
{
    _Sp (_Tp::*__p_)(_Ap) const;
public:
    _LIBCPP_INLINE_VISIBILITY explicit const_mem_fun1_t(_Sp (_Tp::*__p)(_Ap) const)
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(const _Tp* __p, _Ap __x) const
        {return (__p->*__p_)(__x);}
};

template <class _Sp, class _Tp>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
const_mem_fun_t<_Sp,_Tp>
mem_fun(_Sp (_Tp::*__f)() const)
    {return const_mem_fun_t<_Sp,_Tp>(__f);}

template <class _Sp, class _Tp, class _Ap>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
const_mem_fun1_t<_Sp,_Tp,_Ap>
mem_fun(_Sp (_Tp::*__f)(_Ap) const)
    {return const_mem_fun1_t<_Sp,_Tp,_Ap>(__f);}

template <class _Sp, class _Tp>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 const_mem_fun_ref_t
    : public unary_function<_Tp, _Sp>
{
    _Sp (_Tp::*__p_)() const;
public:
    _LIBCPP_INLINE_VISIBILITY explicit const_mem_fun_ref_t(_Sp (_Tp::*__p)() const)
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(const _Tp& __p) const
        {return (__p.*__p_)();}
};

template <class _Sp, class _Tp, class _Ap>
class _LIBCPP_TEMPLATE_VIS _LIBCPP_DEPRECATED_IN_CXX11 const_mem_fun1_ref_t
    : public binary_function<_Tp, _Ap, _Sp>
{
    _Sp (_Tp::*__p_)(_Ap) const;
public:
    _LIBCPP_INLINE_VISIBILITY explicit const_mem_fun1_ref_t(_Sp (_Tp::*__p)(_Ap) const)
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(const _Tp& __p, _Ap __x) const
        {return (__p.*__p_)(__x);}
};

template <class _Sp, class _Tp>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
const_mem_fun_ref_t<_Sp,_Tp>
mem_fun_ref(_Sp (_Tp::*__f)() const)
    {return const_mem_fun_ref_t<_Sp,_Tp>(__f);}

template <class _Sp, class _Tp, class _Ap>
_LIBCPP_DEPRECATED_IN_CXX11 inline _LIBCPP_INLINE_VISIBILITY
const_mem_fun1_ref_t<_Sp,_Tp,_Ap>
mem_fun_ref(_Sp (_Tp::*__f)(_Ap) const)
    {return const_mem_fun1_ref_t<_Sp,_Tp,_Ap>(__f);}
#endif
# 1274 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

////////////////////////////////////////////////////////////////////////////////
//                                MEMFUN
//==============================================================================

template <class _Tp>
class __mem_fn
    : public __weak_result_type<_Tp>
{
public:
    // types
    typedef _Tp type;
private:
    type __f_;

public:
    _LIBCPP_INLINE_VISIBILITY __mem_fn(type __f) _NOEXCEPT : __f_(__f) {}

#ifndef _LIBCPP_CXX03_LANG
    // invoke
    template <class... _ArgTypes>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return<type, _ArgTypes...>::type
    operator() (_ArgTypes&&... __args) const {
        return __invoke(__f_, _VSTD::forward<_ArgTypes>(__args)...);
    }
#else
# 1301 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

    template <class _A0>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return0<type, _A0>::type
    operator() (_A0& __a0) const {
        return __invoke(__f_, __a0);
    }

    template <class _A0>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return0<type, _A0 const>::type
    operator() (_A0 const& __a0) const {
        return __invoke(__f_, __a0);
    }

    template <class _A0, class _A1>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return1<type, _A0, _A1>::type
    operator() (_A0& __a0, _A1& __a1) const {
        return __invoke(__f_, __a0, __a1);
    }

    template <class _A0, class _A1>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return1<type, _A0 const, _A1>::type
    operator() (_A0 const& __a0, _A1& __a1) const {
        return __invoke(__f_, __a0, __a1);
    }

    template <class _A0, class _A1>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return1<type, _A0, _A1 const>::type
    operator() (_A0& __a0, _A1 const& __a1) const {
        return __invoke(__f_, __a0, __a1);
    }

    template <class _A0, class _A1>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return1<type, _A0 const, _A1 const>::type
    operator() (_A0 const& __a0, _A1 const& __a1) const {
        return __invoke(__f_, __a0, __a1);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0, _A1, _A2>::type
    operator() (_A0& __a0, _A1& __a1, _A2& __a2) const {
        return __invoke(__f_, __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0 const, _A1, _A2>::type
    operator() (_A0 const& __a0, _A1& __a1, _A2& __a2) const {
        return __invoke(__f_, __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0, _A1 const, _A2>::type
    operator() (_A0& __a0, _A1 const& __a1, _A2& __a2) const {
        return __invoke(__f_, __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0, _A1, _A2 const>::type
    operator() (_A0& __a0, _A1& __a1, _A2 const& __a2) const {
        return __invoke(__f_, __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0 const, _A1 const, _A2>::type
    operator() (_A0 const& __a0, _A1 const& __a1, _A2& __a2) const {
        return __invoke(__f_, __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0 const, _A1, _A2 const>::type
    operator() (_A0 const& __a0, _A1& __a1, _A2 const& __a2) const {
        return __invoke(__f_, __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0, _A1 const, _A2 const>::type
    operator() (_A0& __a0, _A1 const& __a1, _A2 const& __a2) const {
        return __invoke(__f_, __a0, __a1, __a2);
    }

    template <class _A0, class _A1, class _A2>
    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return2<type, _A0 const, _A1 const, _A2 const>::type
    operator() (_A0 const& __a0, _A1 const& __a1, _A2 const& __a2) const {
        return __invoke(__f_, __a0, __a1, __a2);
    }
#endif
# 1400 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
};

template<class _Rp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp _Tp::*>
mem_fn(_Rp _Tp::* __pm) _NOEXCEPT
{
    return __mem_fn<_Rp _Tp::*>(__pm);
}

////////////////////////////////////////////////////////////////////////////////
//                                FUNCTION
//==============================================================================

// bad_function_call

class _LIBCPP_EXCEPTION_ABI bad_function_call
    : public exception
{
#ifdef _LIBCPP_ABI_BAD_FUNCTION_CALL_KEY_FUNCTION
public:
    virtual ~bad_function_call() _NOEXCEPT;

    virtual const char* what() const _NOEXCEPT;
#endif
# 1425 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
};

_LIBCPP_NORETURN inline _LIBCPP_INLINE_VISIBILITY
void __throw_bad_function_call()
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw bad_function_call();
#else
# 1433 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
    _VSTD::abort();
#endif
# 1435 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
}

template<class _Fp> class _LIBCPP_TEMPLATE_VIS function; // undefined

namespace __function
{

template<class _Rp>
struct __maybe_derive_from_unary_function
{
};

template<class _Rp, class _A1>
struct __maybe_derive_from_unary_function<_Rp(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template<class _Rp>
struct __maybe_derive_from_binary_function
{
};

template<class _Rp, class _A1, class _A2>
struct __maybe_derive_from_binary_function<_Rp(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Fp>
_LIBCPP_INLINE_VISIBILITY
bool __not_null(_Fp const&) { return true; }

template <class _Fp>
_LIBCPP_INLINE_VISIBILITY
bool __not_null(_Fp* __ptr) { return __ptr; }

template <class _Ret, class _Class>
_LIBCPP_INLINE_VISIBILITY
bool __not_null(_Ret _Class::*__ptr) { return __ptr; }

template <class _Fp>
_LIBCPP_INLINE_VISIBILITY
bool __not_null(function<_Fp> const& __f) { return !!__f; }

} // namespace __function

#ifndef _LIBCPP_CXX03_LANG

namespace __function {

// __alloc_func holds a functor and an allocator.

template <class _Fp, class _Ap, class _FB> class __alloc_func;
template <class _Fp, class _FB>
class __default_alloc_func;

template <class _Fp, class _Ap, class _Rp, class... _ArgTypes>
class __alloc_func<_Fp, _Ap, _Rp(_ArgTypes...)>
{
    __compressed_pair<_Fp, _Ap> __f_;

  public:
    typedef _LIBCPP_NODEBUG_TYPE _Fp _Target;
    typedef _LIBCPP_NODEBUG_TYPE _Ap _Alloc;

    _LIBCPP_INLINE_VISIBILITY
    const _Target& __target() const { return __f_.first(); }

    // WIN32 APIs may define __allocator, so use __get_allocator instead.
    _LIBCPP_INLINE_VISIBILITY
    const _Alloc& __get_allocator() const { return __f_.second(); }

    _LIBCPP_INLINE_VISIBILITY
    explicit __alloc_func(_Target&& __f)
        : __f_(piecewise_construct, _VSTD::forward_as_tuple(_VSTD::move(__f)),
               _VSTD::forward_as_tuple())
    {
    }

    _LIBCPP_INLINE_VISIBILITY
    explicit __alloc_func(const _Target& __f, const _Alloc& __a)
        : __f_(piecewise_construct, _VSTD::forward_as_tuple(__f),
               _VSTD::forward_as_tuple(__a))
    {
    }

    _LIBCPP_INLINE_VISIBILITY
    explicit __alloc_func(const _Target& __f, _Alloc&& __a)
        : __f_(piecewise_construct, _VSTD::forward_as_tuple(__f),
               _VSTD::forward_as_tuple(_VSTD::move(__a)))
    {
    }

    _LIBCPP_INLINE_VISIBILITY
    explicit __alloc_func(_Target&& __f, _Alloc&& __a)
        : __f_(piecewise_construct, _VSTD::forward_as_tuple(_VSTD::move(__f)),
               _VSTD::forward_as_tuple(_VSTD::move(__a)))
    {
    }

    _LIBCPP_INLINE_VISIBILITY
    _Rp operator()(_ArgTypes&&... __arg)
    {
        typedef __invoke_void_return_wrapper<_Rp> _Invoker;
        return _Invoker::__call(__f_.first(),
                                _VSTD::forward<_ArgTypes>(__arg)...);
    }

    _LIBCPP_INLINE_VISIBILITY
    __alloc_func* __clone() const
    {
        typedef allocator_traits<_Alloc> __alloc_traits;
        typedef
            typename __rebind_alloc_helper<__alloc_traits, __alloc_func>::type
                _AA;
        _AA __a(__f_.second());
        typedef __allocator_destructor<_AA> _Dp;
        unique_ptr<__alloc_func, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
        ::new ((void*)__hold.get()) __alloc_func(__f_.first(), _Alloc(__a));
        return __hold.release();
    }

    _LIBCPP_INLINE_VISIBILITY
    void destroy() _NOEXCEPT { __f_.~__compressed_pair<_Target, _Alloc>(); }

    static void __destroy_and_delete(__alloc_func* __f) {
      typedef allocator_traits<_Alloc> __alloc_traits;
      typedef typename __rebind_alloc_helper<__alloc_traits, __alloc_func>::type
          _FunAlloc;
      _FunAlloc __a(__f->__get_allocator());
      __f->destroy();
      __a.deallocate(__f, 1);
    }
};

template <class _Fp, class _Rp, class... _ArgTypes>
class __default_alloc_func<_Fp, _Rp(_ArgTypes...)> {
  _Fp __f_;

public:
  typedef _LIBCPP_NODEBUG_TYPE _Fp _Target;

  _LIBCPP_INLINE_VISIBILITY
  const _Target& __target() const { return __f_; }

  _LIBCPP_INLINE_VISIBILITY
  explicit __default_alloc_func(_Target&& __f) : __f_(std::move(__f)) {}

  _LIBCPP_INLINE_VISIBILITY
  explicit __default_alloc_func(const _Target& __f) : __f_(__f) {}

  _LIBCPP_INLINE_VISIBILITY
  _Rp operator()(_ArgTypes&&... __arg) {
    typedef __invoke_void_return_wrapper<_Rp> _Invoker;
    return _Invoker::__call(__f_, _VSTD::forward<_ArgTypes>(__arg)...);
  }

  _LIBCPP_INLINE_VISIBILITY
  __default_alloc_func* __clone() const {
      __builtin_new_allocator::__holder_t __hold =
        __builtin_new_allocator::__allocate_type<__default_alloc_func>(1);
    __default_alloc_func* __res =
        ::new (__hold.get()) __default_alloc_func(__f_);
    (void)__hold.release();
    return __res;
  }

  _LIBCPP_INLINE_VISIBILITY
  void destroy() _NOEXCEPT { __f_.~_Target(); }

  static void __destroy_and_delete(__default_alloc_func* __f) {
    __f->destroy();
      __builtin_new_allocator::__deallocate_type<__default_alloc_func>(__f, 1);
  }
};

// __base provides an abstract interface for copyable functors.

template<class _Fp> class __base;

template<class _Rp, class ..._ArgTypes>
class __base<_Rp(_ArgTypes...)>
{
    __base(const __base&);
    __base& operator=(const __base&);
public:
    _LIBCPP_INLINE_VISIBILITY __base() {}
    _LIBCPP_INLINE_VISIBILITY virtual ~__base() {}
    virtual __base* __clone() const = 0;
    virtual void __clone(__base*) const = 0;
    virtual void destroy() _NOEXCEPT = 0;
    virtual void destroy_deallocate() _NOEXCEPT = 0;
    virtual _Rp operator()(_ArgTypes&& ...) = 0;
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const _NOEXCEPT = 0;
    virtual const std::type_info& target_type() const _NOEXCEPT = 0;
#endif  // _LIBCPP_NO_RTTI
# 1633 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
};

// __func implements __base for a given functor type.

template<class _FD, class _Alloc, class _FB> class __func;

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
class __func<_Fp, _Alloc, _Rp(_ArgTypes...)>
    : public  __base<_Rp(_ArgTypes...)>
{
    __alloc_func<_Fp, _Alloc, _Rp(_ArgTypes...)> __f_;
public:
    _LIBCPP_INLINE_VISIBILITY
    explicit __func(_Fp&& __f)
        : __f_(_VSTD::move(__f)) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit __func(const _Fp& __f, const _Alloc& __a)
        : __f_(__f, __a) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit __func(const _Fp& __f, _Alloc&& __a)
        : __f_(__f, _VSTD::move(__a)) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit __func(_Fp&& __f, _Alloc&& __a)
        : __f_(_VSTD::move(__f), _VSTD::move(__a)) {}

    virtual __base<_Rp(_ArgTypes...)>* __clone() const;
    virtual void __clone(__base<_Rp(_ArgTypes...)>*) const;
    virtual void destroy() _NOEXCEPT;
    virtual void destroy_deallocate() _NOEXCEPT;
    virtual _Rp operator()(_ArgTypes&&... __arg);
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const _NOEXCEPT;
    virtual const std::type_info& target_type() const _NOEXCEPT;
#endif  // _LIBCPP_NO_RTTI
# 1670 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
};

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
__base<_Rp(_ArgTypes...)>*
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::__clone() const
{
    typedef allocator_traits<_Alloc> __alloc_traits;
    typedef typename __rebind_alloc_helper<__alloc_traits, __func>::type _Ap;
    _Ap __a(__f_.__get_allocator());
    typedef __allocator_destructor<_Ap> _Dp;
    unique_ptr<__func, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
    ::new ((void*)__hold.get()) __func(__f_.__target(), _Alloc(__a));
    return __hold.release();
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
void
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::__clone(__base<_Rp(_ArgTypes...)>* __p) const
{
    ::new (__p) __func(__f_.__target(), __f_.__get_allocator());
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
void
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::destroy() _NOEXCEPT
{
    __f_.destroy();
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
void
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::destroy_deallocate() _NOEXCEPT
{
    typedef allocator_traits<_Alloc> __alloc_traits;
    typedef typename __rebind_alloc_helper<__alloc_traits, __func>::type _Ap;
    _Ap __a(__f_.__get_allocator());
    __f_.destroy();
    __a.deallocate(this, 1);
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
_Rp
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::operator()(_ArgTypes&& ... __arg)
{
    return __f_(_VSTD::forward<_ArgTypes>(__arg)...);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
const void*
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::target(const type_info& __ti) const _NOEXCEPT
{
    if (__ti == typeid(_Fp))
        return &__f_.__target();
    return (const void*)0;
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
const std::type_info&
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::target_type() const _NOEXCEPT
{
    return typeid(_Fp);
}

#endif  // _LIBCPP_NO_RTTI
# 1736 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

// __value_func creates a value-type from a __func.

template <class _Fp> class __value_func;

template <class _Rp, class... _ArgTypes> class __value_func<_Rp(_ArgTypes...)>
{
    typename aligned_storage<3 * sizeof(void*)>::type __buf_;

    typedef __base<_Rp(_ArgTypes...)> __func;
    __func* __f_;

    _LIBCPP_NO_CFI static __func* __as_base(void* p)
    {
        return reinterpret_cast<__func*>(p);
    }

  public:
    _LIBCPP_INLINE_VISIBILITY
    __value_func() _NOEXCEPT : __f_(0) {}

    template <class _Fp, class _Alloc>
    _LIBCPP_INLINE_VISIBILITY __value_func(_Fp&& __f, const _Alloc& __a)
        : __f_(0)
    {
        typedef allocator_traits<_Alloc> __alloc_traits;
        typedef __function::__func<_Fp, _Alloc, _Rp(_ArgTypes...)> _Fun;
        typedef typename __rebind_alloc_helper<__alloc_traits, _Fun>::type
            _FunAlloc;

        if (__function::__not_null(__f))
        {
            _FunAlloc __af(__a);
            if (sizeof(_Fun) <= sizeof(__buf_) &&
                is_nothrow_copy_constructible<_Fp>::value &&
                is_nothrow_copy_constructible<_FunAlloc>::value)
            {
                __f_ =
                    ::new ((void*)&__buf_) _Fun(_VSTD::move(__f), _Alloc(__af));
            }
            else
            {
                typedef __allocator_destructor<_FunAlloc> _Dp;
                unique_ptr<__func, _Dp> __hold(__af.allocate(1), _Dp(__af, 1));
                ::new ((void*)__hold.get()) _Fun(_VSTD::move(__f), _Alloc(__a));
                __f_ = __hold.release();
            }
        }
    }

    template <class _Fp,
        class = typename enable_if<!is_same<typename decay<_Fp>::type, __value_func>::value>::type>
    _LIBCPP_INLINE_VISIBILITY explicit __value_func(_Fp&& __f)
        : __value_func(std::forward<_Fp>(__f), allocator<_Fp>()) {}

    _LIBCPP_INLINE_VISIBILITY
    __value_func(const __value_func& __f)
    {
        if (__f.__f_ == 0)
            __f_ = 0;
        else if ((void*)__f.__f_ == &__f.__buf_)
        {
            __f_ = __as_base(&__buf_);
            __f.__f_->__clone(__f_);
        }
        else
            __f_ = __f.__f_->__clone();
    }

    _LIBCPP_INLINE_VISIBILITY
    __value_func(__value_func&& __f) _NOEXCEPT
    {
        if (__f.__f_ == 0)
            __f_ = 0;
        else if ((void*)__f.__f_ == &__f.__buf_)
        {
            __f_ = __as_base(&__buf_);
            __f.__f_->__clone(__f_);
        }
        else
        {
            __f_ = __f.__f_;
            __f.__f_ = 0;
        }
    }

    _LIBCPP_INLINE_VISIBILITY
    ~__value_func()
    {
        if ((void*)__f_ == &__buf_)
            __f_->destroy();
        else if (__f_)
            __f_->destroy_deallocate();
    }

    _LIBCPP_INLINE_VISIBILITY
    __value_func& operator=(__value_func&& __f)
    {
        *this = nullptr;
        if (__f.__f_ == 0)
            __f_ = 0;
        else if ((void*)__f.__f_ == &__f.__buf_)
        {
            __f_ = __as_base(&__buf_);
            __f.__f_->__clone(__f_);
        }
        else
        {
            __f_ = __f.__f_;
            __f.__f_ = 0;
        }
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __value_func& operator=(nullptr_t)
    {
        __func* __f = __f_;
        __f_ = 0;
        if ((void*)__f == &__buf_)
            __f->destroy();
        else if (__f)
            __f->destroy_deallocate();
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    _Rp operator()(_ArgTypes&&... __args) const
    {
        if (__f_ == 0)
            __throw_bad_function_call();
        return (*__f_)(_VSTD::forward<_ArgTypes>(__args)...);
    }

    _LIBCPP_INLINE_VISIBILITY
    void swap(__value_func& __f) _NOEXCEPT
    {
        if (&__f == this)
            return;
        if ((void*)__f_ == &__buf_ && (void*)__f.__f_ == &__f.__buf_)
        {
            typename aligned_storage<sizeof(__buf_)>::type __tempbuf;
            __func* __t = __as_base(&__tempbuf);
            __f_->__clone(__t);
            __f_->destroy();
            __f_ = 0;
            __f.__f_->__clone(__as_base(&__buf_));
            __f.__f_->destroy();
            __f.__f_ = 0;
            __f_ = __as_base(&__buf_);
            __t->__clone(__as_base(&__f.__buf_));
            __t->destroy();
            __f.__f_ = __as_base(&__f.__buf_);
        }
        else if ((void*)__f_ == &__buf_)
        {
            __f_->__clone(__as_base(&__f.__buf_));
            __f_->destroy();
            __f_ = __f.__f_;
            __f.__f_ = __as_base(&__f.__buf_);
        }
        else if ((void*)__f.__f_ == &__f.__buf_)
        {
            __f.__f_->__clone(__as_base(&__buf_));
            __f.__f_->destroy();
            __f.__f_ = __f_;
            __f_ = __as_base(&__buf_);
        }
        else
            _VSTD::swap(__f_, __f.__f_);
    }

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT { return __f_ != 0; }

#ifndef _LIBCPP_NO_RTTI
    _LIBCPP_INLINE_VISIBILITY
    const std::type_info& target_type() const _NOEXCEPT
    {
        if (__f_ == 0)
            return typeid(void);
        return __f_->target_type();
    }

    template <typename _Tp>
    _LIBCPP_INLINE_VISIBILITY const _Tp* target() const _NOEXCEPT
    {
        if (__f_ == 0)
            return 0;
        return (const _Tp*)__f_->target(typeid(_Tp));
    }
#endif // _LIBCPP_NO_RTTI
# 1928 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
};

// Storage for a functor object, to be used with __policy to manage copy and
// destruction.
union __policy_storage
{
    mutable char __small[sizeof(void*) * 2];
    void* __large;
};

// True if _Fun can safely be held in __policy_storage.__small.
template <typename _Fun>
struct __use_small_storage
    : public _VSTD::integral_constant<
          bool, sizeof(_Fun) <= sizeof(__policy_storage) &&
                    _LIBCPP_ALIGNOF(_Fun) <= _LIBCPP_ALIGNOF(__policy_storage) &&
                    _VSTD::is_trivially_copy_constructible<_Fun>::value &&
                    _VSTD::is_trivially_destructible<_Fun>::value> {};

// Policy contains information about how to copy, destroy, and move the
// underlying functor. You can think of it as a vtable of sorts.
struct __policy
{
    // Used to copy or destroy __large values. null for trivial objects.
    void* (*const __clone)(const void*);
    void (*const __destroy)(void*);

    // True if this is the null policy (no value).
    const bool __is_null;

    // The target type. May be null if RTTI is disabled.
    const std::type_info* const __type_info;

    // Returns a pointer to a static policy object suitable for the functor
    // type.
    template <typename _Fun>
    _LIBCPP_INLINE_VISIBILITY static const __policy* __create()
    {
        return __choose_policy<_Fun>(__use_small_storage<_Fun>());
    }

    _LIBCPP_INLINE_VISIBILITY
    static const __policy* __create_empty()
    {
        static const _LIBCPP_CONSTEXPR __policy __policy_ = {nullptr, nullptr,
                                                             true,
#ifndef _LIBCPP_NO_RTTI
                                                             &typeid(void)
#else
# 1977 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
                                                             nullptr
#endif
# 1979 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
        };
        return &__policy_;
    }

  private:
    template <typename _Fun> static void* __large_clone(const void* __s)
    {
        const _Fun* __f = static_cast<const _Fun*>(__s);
        return __f->__clone();
    }

    template <typename _Fun>
    static void __large_destroy(void* __s) {
      _Fun::__destroy_and_delete(static_cast<_Fun*>(__s));
    }

    template <typename _Fun>
    _LIBCPP_INLINE_VISIBILITY static const __policy*
    __choose_policy(/* is_small = */ false_type) {
      static const _LIBCPP_CONSTEXPR __policy __policy_ = {
          &__large_clone<_Fun>, &__large_destroy<_Fun>, false,
#ifndef _LIBCPP_NO_RTTI
          &typeid(typename _Fun::_Target)
#else
# 2003 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
          nullptr
#endif
# 2005 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
      };
        return &__policy_;
    }

    template <typename _Fun>
    _LIBCPP_INLINE_VISIBILITY static const __policy*
        __choose_policy(/* is_small = */ true_type)
    {
        static const _LIBCPP_CONSTEXPR __policy __policy_ = {
            nullptr, nullptr, false,
#ifndef _LIBCPP_NO_RTTI
            &typeid(typename _Fun::_Target)
#else
# 2018 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
            nullptr
#endif
# 2020 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
        };
        return &__policy_;
    }
};

// Used to choose between perfect forwarding or pass-by-value. Pass-by-value is
// faster for types that can be passed in registers.
template <typename _Tp>
using __fast_forward =
    typename _VSTD::conditional<_VSTD::is_scalar<_Tp>::value, _Tp, _Tp&&>::type;

// __policy_invoker calls an instance of __alloc_func held in __policy_storage.

template <class _Fp> struct __policy_invoker;

template <class _Rp, class... _ArgTypes>
struct __policy_invoker<_Rp(_ArgTypes...)>
{
    typedef _Rp (*__Call)(const __policy_storage*,
                          __fast_forward<_ArgTypes>...);

    __Call __call_;

    // Creates an invoker that throws bad_function_call.
    _LIBCPP_INLINE_VISIBILITY
    __policy_invoker() : __call_(&__call_empty) {}

    // Creates an invoker that calls the given instance of __func.
    template <typename _Fun>
    _LIBCPP_INLINE_VISIBILITY static __policy_invoker __create()
    {
        return __policy_invoker(&__call_impl<_Fun>);
    }

  private:
    _LIBCPP_INLINE_VISIBILITY
    explicit __policy_invoker(__Call __c) : __call_(__c) {}

    static _Rp __call_empty(const __policy_storage*,
                            __fast_forward<_ArgTypes>...)
    {
        __throw_bad_function_call();
    }

    template <typename _Fun>
    static _Rp __call_impl(const __policy_storage* __buf,
                           __fast_forward<_ArgTypes>... __args)
    {
        _Fun* __f = reinterpret_cast<_Fun*>(__use_small_storage<_Fun>::value
                                                ? &__buf->__small
                                                : __buf->__large);
        return (*__f)(_VSTD::forward<_ArgTypes>(__args)...);
    }
};

// __policy_func uses a __policy and __policy_invoker to create a type-erased,
// copyable functor.

template <class _Fp> class __policy_func;

template <class _Rp, class... _ArgTypes> class __policy_func<_Rp(_ArgTypes...)>
{
    // Inline storage for small objects.
    __policy_storage __buf_;

    // Calls the value stored in __buf_. This could technically be part of
    // policy, but storing it here eliminates a level of indirection inside
    // operator().
    typedef __function::__policy_invoker<_Rp(_ArgTypes...)> __invoker;
    __invoker __invoker_;

    // The policy that describes how to move / copy / destroy __buf_. Never
    // null, even if the function is empty.
    const __policy* __policy_;

  public:
    _LIBCPP_INLINE_VISIBILITY
    __policy_func() : __policy_(__policy::__create_empty()) {}

    template <class _Fp, class _Alloc>
    _LIBCPP_INLINE_VISIBILITY __policy_func(_Fp&& __f, const _Alloc& __a)
        : __policy_(__policy::__create_empty())
    {
        typedef __alloc_func<_Fp, _Alloc, _Rp(_ArgTypes...)> _Fun;
        typedef allocator_traits<_Alloc> __alloc_traits;
        typedef typename __rebind_alloc_helper<__alloc_traits, _Fun>::type
            _FunAlloc;

        if (__function::__not_null(__f))
        {
            __invoker_ = __invoker::template __create<_Fun>();
            __policy_ = __policy::__create<_Fun>();

            _FunAlloc __af(__a);
            if (__use_small_storage<_Fun>())
            {
                ::new ((void*)&__buf_.__small)
                    _Fun(_VSTD::move(__f), _Alloc(__af));
            }
            else
            {
                typedef __allocator_destructor<_FunAlloc> _Dp;
                unique_ptr<_Fun, _Dp> __hold(__af.allocate(1), _Dp(__af, 1));
                ::new ((void*)__hold.get())
                    _Fun(_VSTD::move(__f), _Alloc(__af));
                __buf_.__large = __hold.release();
            }
        }
    }

    template <class _Fp, class = typename enable_if<!is_same<typename decay<_Fp>::type, __policy_func>::value>::type>
    _LIBCPP_INLINE_VISIBILITY explicit __policy_func(_Fp&& __f)
        : __policy_(__policy::__create_empty()) {
      typedef __default_alloc_func<_Fp, _Rp(_ArgTypes...)> _Fun;

      if (__function::__not_null(__f)) {
        __invoker_ = __invoker::template __create<_Fun>();
        __policy_ = __policy::__create<_Fun>();
        if (__use_small_storage<_Fun>()) {
          ::new ((void*)&__buf_.__small) _Fun(_VSTD::move(__f));
        } else {
          __builtin_new_allocator::__holder_t __hold =
              __builtin_new_allocator::__allocate_type<_Fun>(1);
          __buf_.__large = ::new (__hold.get()) _Fun(_VSTD::move(__f));
          (void)__hold.release();
        }
      }
    }

    _LIBCPP_INLINE_VISIBILITY
    __policy_func(const __policy_func& __f)
        : __buf_(__f.__buf_), __invoker_(__f.__invoker_),
          __policy_(__f.__policy_)
    {
        if (__policy_->__clone)
            __buf_.__large = __policy_->__clone(__f.__buf_.__large);
    }

    _LIBCPP_INLINE_VISIBILITY
    __policy_func(__policy_func&& __f)
        : __buf_(__f.__buf_), __invoker_(__f.__invoker_),
          __policy_(__f.__policy_)
    {
        if (__policy_->__destroy)
        {
            __f.__policy_ = __policy::__create_empty();
            __f.__invoker_ = __invoker();
        }
    }

    _LIBCPP_INLINE_VISIBILITY
    ~__policy_func()
    {
        if (__policy_->__destroy)
            __policy_->__destroy(__buf_.__large);
    }

    _LIBCPP_INLINE_VISIBILITY
    __policy_func& operator=(__policy_func&& __f)
    {
        *this = nullptr;
        __buf_ = __f.__buf_;
        __invoker_ = __f.__invoker_;
        __policy_ = __f.__policy_;
        __f.__policy_ = __policy::__create_empty();
        __f.__invoker_ = __invoker();
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __policy_func& operator=(nullptr_t)
    {
        const __policy* __p = __policy_;
        __policy_ = __policy::__create_empty();
        __invoker_ = __invoker();
        if (__p->__destroy)
            __p->__destroy(__buf_.__large);
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    _Rp operator()(_ArgTypes&&... __args) const
    {
        return __invoker_.__call_(_VSTD::addressof(__buf_),
                                  _VSTD::forward<_ArgTypes>(__args)...);
    }

    _LIBCPP_INLINE_VISIBILITY
    void swap(__policy_func& __f)
    {
        _VSTD::swap(__invoker_, __f.__invoker_);
        _VSTD::swap(__policy_, __f.__policy_);
        _VSTD::swap(__buf_, __f.__buf_);
    }

    _LIBCPP_INLINE_VISIBILITY
    explicit operator bool() const _NOEXCEPT
    {
        return !__policy_->__is_null;
    }

#ifndef _LIBCPP_NO_RTTI
    _LIBCPP_INLINE_VISIBILITY
    const std::type_info& target_type() const _NOEXCEPT
    {
        return *__policy_->__type_info;
    }

    template <typename _Tp>
    _LIBCPP_INLINE_VISIBILITY const _Tp* target() const _NOEXCEPT
    {
        if (__policy_->__is_null || typeid(_Tp) != *__policy_->__type_info)
            return nullptr;
        if (__policy_->__clone) // Out of line storage.
            return reinterpret_cast<const _Tp*>(__buf_.__large);
        else
            return reinterpret_cast<const _Tp*>(&__buf_.__small);
    }
#endif // _LIBCPP_NO_RTTI
# 2239 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
};

}  // __function

template<class _Rp, class ..._ArgTypes>
class _LIBCPP_TEMPLATE_VIS function<_Rp(_ArgTypes...)>
    : public __function::__maybe_derive_from_unary_function<_Rp(_ArgTypes...)>,
      public __function::__maybe_derive_from_binary_function<_Rp(_ArgTypes...)>
{
#ifndef _LIBCPP_ABI_OPTIMIZED_FUNCTION
    typedef __function::__value_func<_Rp(_ArgTypes...)> __func;
#else
# 2251 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
    typedef __function::__policy_func<_Rp(_ArgTypes...)> __func;
#endif
# 2253 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

    __func __f_;

    template <class _Fp, bool = _And<
        _IsNotSame<__uncvref_t<_Fp>, function>,
        __invokable<_Fp&, _ArgTypes...>
    >::value>
    struct __callable;
    template <class _Fp>
        struct __callable<_Fp, true>
        {
            static const bool value = is_same<void, _Rp>::value ||
                is_convertible<typename __invoke_of<_Fp&, _ArgTypes...>::type,
                               _Rp>::value;
        };
    template <class _Fp>
        struct __callable<_Fp, false>
        {
            static const bool value = false;
        };

  template <class _Fp>
  using _EnableIfCallable = typename enable_if<__callable<_Fp>::value>::type;
public:
    typedef _Rp result_type;

    // construct/copy/destroy:
    _LIBCPP_INLINE_VISIBILITY
    function() _NOEXCEPT { }
    _LIBCPP_INLINE_VISIBILITY
    function(nullptr_t) _NOEXCEPT {}
    function(const function&);
    function(function&&) _NOEXCEPT;
    template<class _Fp, class = _EnableIfCallable<_Fp>>
    function(_Fp);

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2290 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&) _NOEXCEPT {}
    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&, nullptr_t) _NOEXCEPT {}
    template<class _Alloc>
      function(allocator_arg_t, const _Alloc&, const function&);
    template<class _Alloc>
      function(allocator_arg_t, const _Alloc&, function&&);
    template<class _Fp, class _Alloc, class = _EnableIfCallable<_Fp>>
      function(allocator_arg_t, const _Alloc& __a, _Fp __f);
#endif
# 2303 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

    function& operator=(const function&);
    function& operator=(function&&) _NOEXCEPT;
    function& operator=(nullptr_t) _NOEXCEPT;
    template<class _Fp, class = _EnableIfCallable<_Fp>>
    function& operator=(_Fp&&);

    ~function();

    // function modifiers:
    void swap(function&) _NOEXCEPT;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2316 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
    template<class _Fp, class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      void assign(_Fp&& __f, const _Alloc& __a)
        {function(allocator_arg, __a, _VSTD::forward<_Fp>(__f)).swap(*this);}
#endif
# 2321 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

    // function capacity:
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT {
      return static_cast<bool>(__f_);
    }

    // deleted overloads close possible hole in the type system
    template<class _R2, class... _ArgTypes2>
      bool operator==(const function<_R2(_ArgTypes2...)>&) const = delete;
    template<class _R2, class... _ArgTypes2>
      bool operator!=(const function<_R2(_ArgTypes2...)>&) const = delete;
public:
    // function invocation:
    _Rp operator()(_ArgTypes...) const;

#ifndef _LIBCPP_NO_RTTI
    // function target access:
    const std::type_info& target_type() const _NOEXCEPT;
    template <typename _Tp> _Tp* target() _NOEXCEPT;
    template <typename _Tp> const _Tp* target() const _NOEXCEPT;
#endif  // _LIBCPP_NO_RTTI
# 2343 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _Rp, class ..._Ap>
function(_Rp(*)(_Ap...)) -> function<_Rp(_Ap...)>;

template<class _Fp>
struct __strip_signature;

template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...)> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) const> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) volatile> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) const volatile> { using type = _Rp(_Ap...); };

template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) &> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) const &> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) volatile &> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) const volatile &> { using type = _Rp(_Ap...); };

template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) noexcept> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) const noexcept> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) volatile noexcept> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) const volatile noexcept> { using type = _Rp(_Ap...); };

template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) & noexcept> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) const & noexcept> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) volatile & noexcept> { using type = _Rp(_Ap...); };
template<class _Rp, class _Gp, class ..._Ap>
struct __strip_signature<_Rp (_Gp::*) (_Ap...) const volatile & noexcept> { using type = _Rp(_Ap...); };

template<class _Fp, class _Stripped = typename __strip_signature<decltype(&_Fp::operator())>::type>
function(_Fp) -> function<_Stripped>;
#endif // !_LIBCPP_HAS_NO_DEDUCTION_GUIDES
# 2391 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>::function(const function& __f) : __f_(__f.__f_) {}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2396 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template<class _Rp, class ..._ArgTypes>
template <class _Alloc>
function<_Rp(_ArgTypes...)>::function(allocator_arg_t, const _Alloc&,
                                     const function& __f) : __f_(__f.__f_) {}
#endif
# 2401 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template <class _Rp, class... _ArgTypes>
function<_Rp(_ArgTypes...)>::function(function&& __f) _NOEXCEPT
    : __f_(_VSTD::move(__f.__f_)) {}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2407 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template<class _Rp, class ..._ArgTypes>
template <class _Alloc>
function<_Rp(_ArgTypes...)>::function(allocator_arg_t, const _Alloc&,
                                      function&& __f)
    : __f_(_VSTD::move(__f.__f_)) {}
#endif
# 2413 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template <class _Rp, class... _ArgTypes>
template <class _Fp, class>
function<_Rp(_ArgTypes...)>::function(_Fp __f) : __f_(_VSTD::move(__f)) {}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2419 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Rp, class... _ArgTypes>
template <class _Fp, class _Alloc, class>
function<_Rp(_ArgTypes...)>::function(allocator_arg_t, const _Alloc& __a,
                                      _Fp __f)
    : __f_(_VSTD::move(__f), __a) {}
#endif
# 2425 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>&
function<_Rp(_ArgTypes...)>::operator=(const function& __f)
{
    function(__f).swap(*this);
    return *this;
}

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>&
function<_Rp(_ArgTypes...)>::operator=(function&& __f) _NOEXCEPT
{
    __f_ = std::move(__f.__f_);
    return *this;
}

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>&
function<_Rp(_ArgTypes...)>::operator=(nullptr_t) _NOEXCEPT
{
    __f_ = nullptr;
    return *this;
}

template<class _Rp, class ..._ArgTypes>
template <class _Fp, class>
function<_Rp(_ArgTypes...)>&
function<_Rp(_ArgTypes...)>::operator=(_Fp&& __f)
{
    function(_VSTD::forward<_Fp>(__f)).swap(*this);
    return *this;
}

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>::~function() {}

template<class _Rp, class ..._ArgTypes>
void
function<_Rp(_ArgTypes...)>::swap(function& __f) _NOEXCEPT
{
    __f_.swap(__f.__f_);
}

template<class _Rp, class ..._ArgTypes>
_Rp
function<_Rp(_ArgTypes...)>::operator()(_ArgTypes... __arg) const
{
    return __f_(_VSTD::forward<_ArgTypes>(__arg)...);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Rp, class ..._ArgTypes>
const std::type_info&
function<_Rp(_ArgTypes...)>::target_type() const _NOEXCEPT
{
    return __f_.target_type();
}

template<class _Rp, class ..._ArgTypes>
template <typename _Tp>
_Tp*
function<_Rp(_ArgTypes...)>::target() _NOEXCEPT
{
    return (_Tp*)(__f_.template target<_Tp>());
}

template<class _Rp, class ..._ArgTypes>
template <typename _Tp>
const _Tp*
function<_Rp(_ArgTypes...)>::target() const _NOEXCEPT
{
    return __f_.template target<_Tp>();
}

#endif  // _LIBCPP_NO_RTTI
# 2502 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const function<_Rp(_ArgTypes...)>& __f, nullptr_t) _NOEXCEPT {return !__f;}

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(nullptr_t, const function<_Rp(_ArgTypes...)>& __f) _NOEXCEPT {return !__f;}

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const function<_Rp(_ArgTypes...)>& __f, nullptr_t) _NOEXCEPT {return (bool)__f;}

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(nullptr_t, const function<_Rp(_ArgTypes...)>& __f) _NOEXCEPT {return (bool)__f;}

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(function<_Rp(_ArgTypes...)>& __x, function<_Rp(_ArgTypes...)>& __y) _NOEXCEPT
{return __x.swap(__y);}

#else // _LIBCPP_CXX03_LANG
# 2530 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

#if 0 /* expanded by -frewrite-includes */
#include <__functional_03>
#endif /* expanded by -frewrite-includes */
# 2531 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 2532 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

#endif
# 2534 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

////////////////////////////////////////////////////////////////////////////////
//                                  BIND
//==============================================================================

template<class _Tp> struct __is_bind_expression : public false_type {};
template<class _Tp> struct _LIBCPP_TEMPLATE_VIS is_bind_expression
    : public __is_bind_expression<typename remove_cv<_Tp>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2544 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
_LIBCPP_INLINE_VAR constexpr size_t is_bind_expression_v = is_bind_expression<_Tp>::value;
#endif
# 2547 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template<class _Tp> struct __is_placeholder : public integral_constant<int, 0> {};
template<class _Tp> struct _LIBCPP_TEMPLATE_VIS is_placeholder
    : public __is_placeholder<typename remove_cv<_Tp>::type> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2553 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
_LIBCPP_INLINE_VAR constexpr size_t is_placeholder_v = is_placeholder<_Tp>::value;
#endif
# 2556 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

namespace placeholders
{

template <int _Np> struct __ph {};

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_CXX03_LANG) || defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2563 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
_LIBCPP_FUNC_VIS extern const __ph<1>   _1;
_LIBCPP_FUNC_VIS extern const __ph<2>   _2;
_LIBCPP_FUNC_VIS extern const __ph<3>   _3;
_LIBCPP_FUNC_VIS extern const __ph<4>   _4;
_LIBCPP_FUNC_VIS extern const __ph<5>   _5;
_LIBCPP_FUNC_VIS extern const __ph<6>   _6;
_LIBCPP_FUNC_VIS extern const __ph<7>   _7;
_LIBCPP_FUNC_VIS extern const __ph<8>   _8;
_LIBCPP_FUNC_VIS extern const __ph<9>   _9;
_LIBCPP_FUNC_VIS extern const __ph<10> _10;
#else
# 2574 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
/* _LIBCPP_INLINE_VAR */ constexpr __ph<1>   _1{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<2>   _2{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<3>   _3{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<4>   _4{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<5>   _5{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<6>   _6{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<7>   _7{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<8>   _8{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<9>   _9{};
/* _LIBCPP_INLINE_VAR */ constexpr __ph<10> _10{};
#endif // defined(_LIBCPP_CXX03_LANG) || defined(_LIBCPP_BUILDING_LIBRARY)
# 2585 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

}  // placeholders

template<int _Np>
struct __is_placeholder<placeholders::__ph<_Np> >
    : public integral_constant<int, _Np> {};


#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
_Tp&
__mu(reference_wrapper<_Tp> __t, _Uj&)
{
    return __t.get();
}

template <class _Ti, class ..._Uj, size_t ..._Indx>
inline _LIBCPP_INLINE_VISIBILITY
typename __invoke_of<_Ti&, _Uj...>::type
__mu_expand(_Ti& __ti, tuple<_Uj...>& __uj, __tuple_indices<_Indx...>)
{
    return __ti(_VSTD::forward<_Uj>(_VSTD::get<_Indx>(__uj))...);
}

template <class _Ti, class ..._Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename _EnableIf
<
    is_bind_expression<_Ti>::value,
    __invoke_of<_Ti&, _Uj...>
>::type
__mu(_Ti& __ti, tuple<_Uj...>& __uj)
{
    typedef typename __make_tuple_indices<sizeof...(_Uj)>::type __indices;
    return  __mu_expand(__ti, __uj, __indices());
}

template <bool IsPh, class _Ti, class _Uj>
struct __mu_return2 {};

template <class _Ti, class _Uj>
struct __mu_return2<true, _Ti, _Uj>
{
    typedef typename tuple_element<is_placeholder<_Ti>::value - 1, _Uj>::type type;
};

template <class _Ti, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    0 < is_placeholder<_Ti>::value,
    typename __mu_return2<0 < is_placeholder<_Ti>::value, _Ti, _Uj>::type
>::type
__mu(_Ti&, _Uj& __uj)
{
    const size_t _Indx = is_placeholder<_Ti>::value - 1;
    return _VSTD::forward<typename tuple_element<_Indx, _Uj>::type>(_VSTD::get<_Indx>(__uj));
}

template <class _Ti, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_bind_expression<_Ti>::value &&
    is_placeholder<_Ti>::value == 0 &&
    !__is_reference_wrapper<_Ti>::value,
    _Ti&
>::type
__mu(_Ti& __ti, _Uj&)
{
    return __ti;
}

template <class _Ti, bool IsReferenceWrapper, bool IsBindEx, bool IsPh,
          class _TupleUj>
struct __mu_return_impl;

template <bool _Invokable, class _Ti, class ..._Uj>
struct __mu_return_invokable  // false
{
    typedef __nat type;
};

template <class _Ti, class ..._Uj>
struct __mu_return_invokable<true, _Ti, _Uj...>
{
    typedef typename __invoke_of<_Ti&, _Uj...>::type type;
};

template <class _Ti, class ..._Uj>
struct __mu_return_impl<_Ti, false, true, false, tuple<_Uj...> >
    : public __mu_return_invokable<__invokable<_Ti&, _Uj...>::value, _Ti, _Uj...>
{
};

template <class _Ti, class _TupleUj>
struct __mu_return_impl<_Ti, false, false, true, _TupleUj>
{
    typedef typename tuple_element<is_placeholder<_Ti>::value - 1,
                                   _TupleUj>::type&& type;
};

template <class _Ti, class _TupleUj>
struct __mu_return_impl<_Ti, true, false, false, _TupleUj>
{
    typedef typename _Ti::type& type;
};

template <class _Ti, class _TupleUj>
struct __mu_return_impl<_Ti, false, false, false, _TupleUj>
{
    typedef _Ti& type;
};

template <class _Ti, class _TupleUj>
struct __mu_return
    : public __mu_return_impl<_Ti,
                              __is_reference_wrapper<_Ti>::value,
                              is_bind_expression<_Ti>::value,
                              0 < is_placeholder<_Ti>::value &&
                              is_placeholder<_Ti>::value <= tuple_size<_TupleUj>::value,
                              _TupleUj>
{
};

template <class _Fp, class _BoundArgs, class _TupleUj>
struct __is_valid_bind_return
{
    static const bool value = false;
};

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct __is_valid_bind_return<_Fp, tuple<_BoundArgs...>, _TupleUj>
{
    static const bool value = __invokable<_Fp,
                    typename __mu_return<_BoundArgs, _TupleUj>::type...>::value;
};

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct __is_valid_bind_return<_Fp, const tuple<_BoundArgs...>, _TupleUj>
{
    static const bool value = __invokable<_Fp,
                    typename __mu_return<const _BoundArgs, _TupleUj>::type...>::value;
};

template <class _Fp, class _BoundArgs, class _TupleUj,
          bool = __is_valid_bind_return<_Fp, _BoundArgs, _TupleUj>::value>
struct __bind_return;

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct __bind_return<_Fp, tuple<_BoundArgs...>, _TupleUj, true>
{
    typedef typename __invoke_of
    <
        _Fp&,
        typename __mu_return
        <
            _BoundArgs,
            _TupleUj
        >::type...
    >::type type;
};

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct __bind_return<_Fp, const tuple<_BoundArgs...>, _TupleUj, true>
{
    typedef typename __invoke_of
    <
        _Fp&,
        typename __mu_return
        <
            const _BoundArgs,
            _TupleUj
        >::type...
    >::type type;
};

template <class _Fp, class _BoundArgs, size_t ..._Indx, class _Args>
inline _LIBCPP_INLINE_VISIBILITY
typename __bind_return<_Fp, _BoundArgs, _Args>::type
__apply_functor(_Fp& __f, _BoundArgs& __bound_args, __tuple_indices<_Indx...>,
                _Args&& __args)
{
    return _VSTD::__invoke(__f, _VSTD::__mu(_VSTD::get<_Indx>(__bound_args), __args)...);
}

template<class _Fp, class ..._BoundArgs>
class __bind
    : public __weak_result_type<typename decay<_Fp>::type>
{
protected:
    typedef typename decay<_Fp>::type _Fd;
    typedef tuple<typename decay<_BoundArgs>::type...> _Td;
private:
    _Fd __f_;
    _Td __bound_args_;

    typedef typename __make_tuple_indices<sizeof...(_BoundArgs)>::type __indices;
public:
    template <class _Gp, class ..._BA,
              class = typename enable_if
                               <
                                  is_constructible<_Fd, _Gp>::value &&
                                  !is_same<typename remove_reference<_Gp>::type,
                                           __bind>::value
                               >::type>
      _LIBCPP_INLINE_VISIBILITY
      explicit __bind(_Gp&& __f, _BA&& ...__bound_args)
        : __f_(_VSTD::forward<_Gp>(__f)),
          __bound_args_(_VSTD::forward<_BA>(__bound_args)...) {}

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        typename __bind_return<_Fd, _Td, tuple<_Args&&...> >::type
        operator()(_Args&& ...__args)
        {
            return _VSTD::__apply_functor(__f_, __bound_args_, __indices(),
                                  tuple<_Args&&...>(_VSTD::forward<_Args>(__args)...));
        }

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        typename __bind_return<const _Fd, const _Td, tuple<_Args&&...> >::type
        operator()(_Args&& ...__args) const
        {
            return _VSTD::__apply_functor(__f_, __bound_args_, __indices(),
                                   tuple<_Args&&...>(_VSTD::forward<_Args>(__args)...));
        }
};

template<class _Fp, class ..._BoundArgs>
struct __is_bind_expression<__bind<_Fp, _BoundArgs...> > : public true_type {};

template<class _Rp, class _Fp, class ..._BoundArgs>
class __bind_r
    : public __bind<_Fp, _BoundArgs...>
{
    typedef __bind<_Fp, _BoundArgs...> base;
    typedef typename base::_Fd _Fd;
    typedef typename base::_Td _Td;
public:
    typedef _Rp result_type;


    template <class _Gp, class ..._BA,
              class = typename enable_if
                               <
                                  is_constructible<_Fd, _Gp>::value &&
                                  !is_same<typename remove_reference<_Gp>::type,
                                           __bind_r>::value
                               >::type>
      _LIBCPP_INLINE_VISIBILITY
      explicit __bind_r(_Gp&& __f, _BA&& ...__bound_args)
        : base(_VSTD::forward<_Gp>(__f),
               _VSTD::forward<_BA>(__bound_args)...) {}

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            is_convertible<typename __bind_return<_Fd, _Td, tuple<_Args&&...> >::type,
                           result_type>::value || is_void<_Rp>::value,
            result_type
        >::type
        operator()(_Args&& ...__args)
        {
            typedef __invoke_void_return_wrapper<_Rp> _Invoker;
            return _Invoker::__call(static_cast<base&>(*this), _VSTD::forward<_Args>(__args)...);
        }

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            is_convertible<typename __bind_return<const _Fd, const _Td, tuple<_Args&&...> >::type,
                           result_type>::value || is_void<_Rp>::value,
            result_type
        >::type
        operator()(_Args&& ...__args) const
        {
            typedef __invoke_void_return_wrapper<_Rp> _Invoker;
            return _Invoker::__call(static_cast<base const&>(*this), _VSTD::forward<_Args>(__args)...);
        }
};

template<class _Rp, class _Fp, class ..._BoundArgs>
struct __is_bind_expression<__bind_r<_Rp, _Fp, _BoundArgs...> > : public true_type {};

template<class _Fp, class ..._BoundArgs>
inline _LIBCPP_INLINE_VISIBILITY
__bind<_Fp, _BoundArgs...>
bind(_Fp&& __f, _BoundArgs&&... __bound_args)
{
    typedef __bind<_Fp, _BoundArgs...> type;
    return type(_VSTD::forward<_Fp>(__f), _VSTD::forward<_BoundArgs>(__bound_args)...);
}

template<class _Rp, class _Fp, class ..._BoundArgs>
inline _LIBCPP_INLINE_VISIBILITY
__bind_r<_Rp, _Fp, _BoundArgs...>
bind(_Fp&& __f, _BoundArgs&&... __bound_args)
{
    typedef __bind_r<_Rp, _Fp, _BoundArgs...> type;
    return type(_VSTD::forward<_Fp>(__f), _VSTD::forward<_BoundArgs>(__bound_args)...);
}

#endif  // _LIBCPP_CXX03_LANG
# 2894 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2896 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template <class _Fn, class ..._Args>
invoke_result_t<_Fn, _Args...>
invoke(_Fn&& __f, _Args&&... __args)
    noexcept(is_nothrow_invocable_v<_Fn, _Args...>)
{
    return _VSTD::__invoke(_VSTD::forward<_Fn>(__f), _VSTD::forward<_Args>(__args)...);
}

template <class _DecayFunc>
class _LIBCPP_TEMPLATE_VIS __not_fn_imp {
  _DecayFunc __fd;

public:
    __not_fn_imp() = delete;

    template <class ..._Args>
    _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Args&& ...__args) &
            noexcept(noexcept(!_VSTD::invoke(__fd, _VSTD::forward<_Args>(__args)...)))
        -> decltype(          !_VSTD::invoke(__fd, _VSTD::forward<_Args>(__args)...))
        { return              !_VSTD::invoke(__fd, _VSTD::forward<_Args>(__args)...); }

    template <class ..._Args>
    _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Args&& ...__args) &&
            noexcept(noexcept(!_VSTD::invoke(_VSTD::move(__fd), _VSTD::forward<_Args>(__args)...)))
        -> decltype(          !_VSTD::invoke(_VSTD::move(__fd), _VSTD::forward<_Args>(__args)...))
        { return              !_VSTD::invoke(_VSTD::move(__fd), _VSTD::forward<_Args>(__args)...); }

    template <class ..._Args>
    _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Args&& ...__args) const&
            noexcept(noexcept(!_VSTD::invoke(__fd, _VSTD::forward<_Args>(__args)...)))
        -> decltype(          !_VSTD::invoke(__fd, _VSTD::forward<_Args>(__args)...))
        { return              !_VSTD::invoke(__fd, _VSTD::forward<_Args>(__args)...); }


    template <class ..._Args>
    _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Args&& ...__args) const&&
            noexcept(noexcept(!_VSTD::invoke(_VSTD::move(__fd), _VSTD::forward<_Args>(__args)...)))
        -> decltype(          !_VSTD::invoke(_VSTD::move(__fd), _VSTD::forward<_Args>(__args)...))
        { return              !_VSTD::invoke(_VSTD::move(__fd), _VSTD::forward<_Args>(__args)...); }

private:
    template <class _RawFunc,
              class = enable_if_t<!is_same<decay_t<_RawFunc>, __not_fn_imp>::value>>
    _LIBCPP_INLINE_VISIBILITY
    explicit __not_fn_imp(_RawFunc&& __rf)
        : __fd(_VSTD::forward<_RawFunc>(__rf)) {}

    template <class _RawFunc>
    friend inline _LIBCPP_INLINE_VISIBILITY
    __not_fn_imp<decay_t<_RawFunc>> not_fn(_RawFunc&&);
};

template <class _RawFunc>
inline _LIBCPP_INLINE_VISIBILITY
__not_fn_imp<decay_t<_RawFunc>> not_fn(_RawFunc&& __fn) {
    return __not_fn_imp<decay_t<_RawFunc>>(_VSTD::forward<_RawFunc>(__fn));
}

#endif
# 2960 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

// struct hash<T*> in <memory>

template <class _BinaryPredicate, class _ForwardIterator1, class _ForwardIterator2>
pair<_ForwardIterator1, _ForwardIterator1> _LIBCPP_CONSTEXPR_AFTER_CXX11
__search(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
         _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred,
         forward_iterator_tag, forward_iterator_tag)
{
    if (__first2 == __last2)
        return make_pair(__first1, __first1);  // Everything matches an empty sequence
    while (true)
    {
        // Find first element in sequence 1 that matchs *__first2, with a mininum of loop checks
        while (true)
        {
            if (__first1 == __last1)  // return __last1 if no element matches *__first2
                return make_pair(__last1, __last1);
            if (__pred(*__first1, *__first2))
                break;
            ++__first1;
        }
        // *__first1 matches *__first2, now match elements after here
        _ForwardIterator1 __m1 = __first1;
        _ForwardIterator2 __m2 = __first2;
        while (true)
        {
            if (++__m2 == __last2)  // If pattern exhausted, __first1 is the answer (works for 1 element pattern)
                return make_pair(__first1, __m1);
            if (++__m1 == __last1)  // Otherwise if source exhaused, pattern not found
                return make_pair(__last1, __last1);
            if (!__pred(*__m1, *__m2))  // if there is a mismatch, restart with a new __first1
            {
                ++__first1;
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _BinaryPredicate, class _RandomAccessIterator1, class _RandomAccessIterator2>
_LIBCPP_CONSTEXPR_AFTER_CXX11
pair<_RandomAccessIterator1, _RandomAccessIterator1>
__search(_RandomAccessIterator1 __first1, _RandomAccessIterator1 __last1,
         _RandomAccessIterator2 __first2, _RandomAccessIterator2 __last2, _BinaryPredicate __pred,
           random_access_iterator_tag, random_access_iterator_tag)
{
    typedef typename iterator_traits<_RandomAccessIterator1>::difference_type _D1;
    typedef typename iterator_traits<_RandomAccessIterator2>::difference_type _D2;
    // Take advantage of knowing source and pattern lengths.  Stop short when source is smaller than pattern
    const _D2 __len2 = __last2 - __first2;
    if (__len2 == 0)
        return make_pair(__first1, __first1);
    const _D1 __len1 = __last1 - __first1;
    if (__len1 < __len2)
        return make_pair(__last1, __last1);
    const _RandomAccessIterator1 __s = __last1 - (__len2 - 1);  // Start of pattern match can't go beyond here

    while (true)
    {
        while (true)
        {
            if (__first1 == __s)
                return make_pair(__last1, __last1);
            if (__pred(*__first1, *__first2))
                break;
            ++__first1;
        }

        _RandomAccessIterator1 __m1 = __first1;
        _RandomAccessIterator2 __m2 = __first2;
         while (true)
         {
             if (++__m2 == __last2)
                 return make_pair(__first1, __first1 + __len2);
             ++__m1;          // no need to check range on __m1 because __s guarantees we have enough source
             if (!__pred(*__m1, *__m2))
             {
                 ++__first1;
                 break;
             }
         }
    }
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3046 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

// default searcher
template<class _ForwardIterator, class _BinaryPredicate = equal_to<>>
class _LIBCPP_TYPE_VIS default_searcher {
public:
    _LIBCPP_INLINE_VISIBILITY
    default_searcher(_ForwardIterator __f, _ForwardIterator __l,
                       _BinaryPredicate __p = _BinaryPredicate())
        : __first_(__f), __last_(__l), __pred_(__p) {}

    template <typename _ForwardIterator2>
    _LIBCPP_INLINE_VISIBILITY
    pair<_ForwardIterator2, _ForwardIterator2>
    operator () (_ForwardIterator2 __f, _ForwardIterator2 __l) const
    {
        return _VSTD::__search(__f, __l, __first_, __last_, __pred_,
            typename _VSTD::iterator_traits<_ForwardIterator>::iterator_category(),
            typename _VSTD::iterator_traits<_ForwardIterator2>::iterator_category());
    }

private:
    _ForwardIterator __first_;
    _ForwardIterator __last_;
    _BinaryPredicate __pred_;
    };

#endif // _LIBCPP_STD_VER > 14
# 3073 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3075 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
template <class _Tp>
using unwrap_reference_t = typename unwrap_reference<_Tp>::type;

template <class _Tp>
using unwrap_ref_decay_t = typename unwrap_ref_decay<_Tp>::type;
#endif // > C++17
# 3081 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3

template <class _Container, class _Predicate>
inline void __libcpp_erase_if_container( _Container& __c, _Predicate __pred)
{
	for (typename _Container::iterator __iter = __c.begin(), __last = __c.end(); __iter != __last;)
	{
		if (__pred(*__iter))
			__iter = __c.erase(__iter);
		else
			++__iter;
	}
}

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_FUNCTIONAL
# 3097 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/functional" 3
# 645 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 645 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 646 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 646 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 647 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <bit>
#endif /* expanded by -frewrite-includes */
# 647 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 1 3
// -*- C++ -*-
//===------------------------------ bit ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===---------------------------------------------------------------------===//

#ifndef _LIBCPP_BIT
#define _LIBCPP_BIT

/*
    bit synopsis

namespace std {

  template <class T>
    constexpr bool ispow2(T x) noexcept; // C++20
  template <class T>
    constexpr T ceil2(T x);              // C++20
  template <class T>
    constexpr T floor2(T x) noexcept;    // C++20
  template <class T>
    constexpr T log2p1(T x) noexcept;    // C++20

  // 23.20.2, rotating
  template<class T>
    constexpr T rotl(T x, unsigned int s) noexcept; // C++20
  template<class T>
    constexpr T rotr(T x, unsigned int s) noexcept; // C++20

  // 23.20.3, counting
  template<class T>
    constexpr int countl_zero(T x) noexcept;  // C++20
  template<class T>
    constexpr int countl_one(T x) noexcept;   // C++20
  template<class T>
    constexpr int countr_zero(T x) noexcept;  // C++20
  template<class T>
    constexpr int countr_one(T x) noexcept;   // C++20
  template<class T>
    constexpr int popcount(T x) noexcept;     // C++20

  // 20.15.9, endian
  enum class endian {
    little = see below,        // C++20
    big = see below,           // C++20
    native = see below         // C++20
};

} // namespace std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 56 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__IBMCPP__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#if 0 /* expanded by -frewrite-includes */
#include "support/ibm/support.h"
#endif /* expanded by -frewrite-includes */
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 64 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#endif
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_COMPILER_MSVC)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 66 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#if 0 /* expanded by -frewrite-includes */
#include <intrin.h>
#endif /* expanded by -frewrite-includes */
# 66 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 67 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#endif
# 68 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 70 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 71 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
#endif
# 72 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 74 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 75 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 2 3

_LIBCPP_BEGIN_NAMESPACE_STD

#ifndef _LIBCPP_COMPILER_MSVC

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_ctz(unsigned __x)           _NOEXCEPT { return __builtin_ctz(__x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_ctz(unsigned long __x)      _NOEXCEPT { return __builtin_ctzl(__x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_ctz(unsigned long long __x) _NOEXCEPT { return __builtin_ctzll(__x); }


inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_clz(unsigned __x)           _NOEXCEPT { return __builtin_clz(__x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_clz(unsigned long __x)      _NOEXCEPT { return __builtin_clzl(__x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_clz(unsigned long long __x) _NOEXCEPT { return __builtin_clzll(__x); }


inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_popcount(unsigned __x)           _NOEXCEPT { return __builtin_popcount(__x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_popcount(unsigned long __x)      _NOEXCEPT { return __builtin_popcountl(__x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
int __libcpp_popcount(unsigned long long __x) _NOEXCEPT { return __builtin_popcountll(__x); }

#else  // _LIBCPP_COMPILER_MSVC
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3

// Precondition:  __x != 0
inline _LIBCPP_INLINE_VISIBILITY
int __libcpp_ctz(unsigned __x) {
  static_assert(sizeof(unsigned) == sizeof(unsigned long), "");
  static_assert(sizeof(unsigned long) == 4, "");
  unsigned long __where;
  if (_BitScanForward(&__where, __x))
    return static_cast<int>(__where);
  return 32;
}

inline _LIBCPP_INLINE_VISIBILITY
int __libcpp_ctz(unsigned long __x) {
    static_assert(sizeof(unsigned long) == sizeof(unsigned), "");
    return __ctz(static_cast<unsigned>(__x));
}

inline _LIBCPP_INLINE_VISIBILITY
int __libcpp_ctz(unsigned long long __x) {
    unsigned long __where;
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_BITSCAN64)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 132 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
    (defined(_M_AMD64) || defined(__x86_64__))
  if (_BitScanForward64(&__where, __x))
    return static_cast<int>(__where);
#else
# 136 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
  // Win32 doesn't have _BitScanForward64 so emulate it with two 32 bit calls.
  if (_BitScanForward(&__where, static_cast<unsigned long>(__x)))
    return static_cast<int>(__where);
  if (_BitScanForward(&__where, static_cast<unsigned long>(__x >> 32)))
    return static_cast<int>(__where + 32);
#endif
# 142 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
  return 64;
}

// Precondition:  __x != 0
inline _LIBCPP_INLINE_VISIBILITY
int __libcpp_clz(unsigned __x) {
  static_assert(sizeof(unsigned) == sizeof(unsigned long), "");
  static_assert(sizeof(unsigned long) == 4, "");
  unsigned long __where;
  if (_BitScanReverse(&__where, __x))
    return static_cast<int>(31 - __where);
  return 32; // Undefined Behavior.
}

inline _LIBCPP_INLINE_VISIBILITY
int __libcpp_clz(unsigned long __x) {
    static_assert(sizeof(unsigned) == sizeof(unsigned long), "");
    return __libcpp_clz(static_cast<unsigned>(__x));
}

inline _LIBCPP_INLINE_VISIBILITY
int __libcpp_clz(unsigned long long __x) {
  unsigned long __where;
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_BITSCAN64)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
  if (_BitScanReverse64(&__where, __x))
    return static_cast<int>(63 - __where);
#else
# 169 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
  // Win32 doesn't have _BitScanReverse64 so emulate it with two 32 bit calls.
  if (_BitScanReverse(&__where, static_cast<unsigned long>(__x >> 32)))
    return static_cast<int>(63 - (__where + 32));
  if (_BitScanReverse(&__where, static_cast<unsigned long>(__x)))
    return static_cast<int>(63 - __where);
#endif
# 175 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
  return 64; // Undefined Behavior.
}

inline _LIBCPP_INLINE_VISIBILITY int __libcpp_popcount(unsigned __x) {
  static_assert(sizeof(unsigned) == 4, "");
  return __popcnt(__x);
}

inline _LIBCPP_INLINE_VISIBILITY int __libcpp_popcount(unsigned long __x) {
  static_assert(sizeof(unsigned long) == 4, "");
  return __popcnt(__x);
}

inline _LIBCPP_INLINE_VISIBILITY int __libcpp_popcount(unsigned long long __x) {
  static_assert(sizeof(unsigned long long) == 8, "");
  return __popcnt64(__x);
}

#endif // _LIBCPP_COMPILER_MSVC
# 194 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3

template <class _Tp>
using __bitop_unsigned_integer _LIBCPP_NODEBUG_TYPE = integral_constant<bool,
         is_integral<_Tp>::value &&
         is_unsigned<_Tp>::value &&
        _IsNotSame<typename remove_cv<_Tp>::type, bool>::value &&
        _IsNotSame<typename remove_cv<_Tp>::type, signed char>::value &&
        _IsNotSame<typename remove_cv<_Tp>::type, wchar_t>::value &&
        _IsNotSame<typename remove_cv<_Tp>::type, char16_t>::value &&
        _IsNotSame<typename remove_cv<_Tp>::type, char32_t>::value
    >;


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp __rotl(_Tp __t, unsigned int __cnt) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__rotl requires unsigned");
    const unsigned int __dig = numeric_limits<_Tp>::digits;
    if ((__cnt % __dig) == 0)
        return __t;
    return (__t << (__cnt % __dig)) | (__t >> (__dig - (__cnt % __dig)));
}


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp __rotr(_Tp __t, unsigned int __cnt) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__rotr requires unsigned");
    const unsigned int __dig = numeric_limits<_Tp>::digits;
    if ((__cnt % __dig) == 0)
        return __t;
    return (__t >> (__cnt % __dig)) | (__t << (__dig - (__cnt % __dig)));
}



template<class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
int __countr_zero(_Tp __t) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__countr_zero requires unsigned");
    if (__t == 0)
        return numeric_limits<_Tp>::digits;

    if      (sizeof(_Tp) <= sizeof(unsigned int))
        return __libcpp_ctz(static_cast<unsigned int>(__t));
    else if (sizeof(_Tp) <= sizeof(unsigned long))
        return __libcpp_ctz(static_cast<unsigned long>(__t));
    else if (sizeof(_Tp) <= sizeof(unsigned long long))
        return __libcpp_ctz(static_cast<unsigned long long>(__t));
    else
    {
        int __ret = 0;
        int __iter = 0;
        const unsigned int __ulldigits = numeric_limits<unsigned long long>::digits;
        while ((__iter = __libcpp_ctz(static_cast<unsigned long long>(__t))) == __ulldigits)
        {
            __ret += __iter;
            __t >>= __ulldigits;
        }
        return __ret + __iter;
    }
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
int __countl_zero(_Tp __t) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__countl_zero requires unsigned");
    if (__t == 0)
        return numeric_limits<_Tp>::digits;

    if      (sizeof(_Tp) <= sizeof(unsigned int))
        return __libcpp_clz(static_cast<unsigned int>(__t))
              - (numeric_limits<unsigned int>::digits - numeric_limits<_Tp>::digits);
    else if (sizeof(_Tp) <= sizeof(unsigned long))
        return __libcpp_clz(static_cast<unsigned long>(__t))
              - (numeric_limits<unsigned long>::digits - numeric_limits<_Tp>::digits);
    else if (sizeof(_Tp) <= sizeof(unsigned long long))
        return __libcpp_clz(static_cast<unsigned long long>(__t))
              - (numeric_limits<unsigned long long>::digits - numeric_limits<_Tp>::digits);
    else
    {
        int __ret = 0;
        int __iter = 0;
        const unsigned int __ulldigits = numeric_limits<unsigned long long>::digits;
        while (true) {
            __t = __rotr(__t, __ulldigits);
            if ((__iter = __countl_zero(static_cast<unsigned long long>(__t))) != __ulldigits)
                break;
            __ret += __iter;
            }
        return __ret + __iter;
    }
}

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
int __countl_one(_Tp __t) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__countl_one requires unsigned");
    return __t != numeric_limits<_Tp>::max()
        ? __countl_zero(static_cast<_Tp>(~__t))
        : numeric_limits<_Tp>::digits;
}


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
int __countr_one(_Tp __t) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__countr_one requires unsigned");
    return __t != numeric_limits<_Tp>::max()
        ? __countr_zero(static_cast<_Tp>(~__t))
        : numeric_limits<_Tp>::digits;
}


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
int
__popcount(_Tp __t) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__libcpp_popcount requires unsigned");
    if      (sizeof(_Tp) <= sizeof(unsigned int))
        return __libcpp_popcount(static_cast<unsigned int>(__t));
    else if (sizeof(_Tp) <= sizeof(unsigned long))
        return __libcpp_popcount(static_cast<unsigned long>(__t));
    else if (sizeof(_Tp) <= sizeof(unsigned long long))
        return __libcpp_popcount(static_cast<unsigned long long>(__t));
    else
    {
        int __ret = 0;
        while (__t != 0)
        {
            __ret += __libcpp_popcount(static_cast<unsigned long long>(__t));
            __t >>= numeric_limits<unsigned long long>::digits;
        }
        return __ret;
    }
}


// integral log base 2
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
unsigned __bit_log2(_Tp __t) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__bit_log2 requires unsigned");
    return std::numeric_limits<_Tp>::digits - 1 - __countl_zero(__t);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
bool __ispow2(_Tp __t) _NOEXCEPT
{
    static_assert(__bitop_unsigned_integer<_Tp>::value, "__ispow2 requires unsigned");
	return __t != 0 && (((__t & (__t - 1)) == 0));
}


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 358 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3

template<class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, _Tp>
rotl(_Tp __t, unsigned int __cnt) noexcept
{
    return __rotl(__t, __cnt);
}


// rotr
template<class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, _Tp>
rotr(_Tp __t, unsigned int __cnt) noexcept
{
    return __rotr(__t, __cnt);
}


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, int>
countl_zero(_Tp __t) noexcept
{
    return __countl_zero(__t);
}


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, int>
countl_one(_Tp __t) noexcept
{
    return __countl_one(__t);
}


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, int>
countr_zero(_Tp __t) noexcept
{
	return __countr_zero(__t);
}


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, int>
countr_one(_Tp __t) noexcept
{
    return __countr_one(__t);
}


template<class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, int>
popcount(_Tp __t) noexcept
{
    return __popcount(__t);
}


template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, bool>
ispow2(_Tp __t) noexcept
{
    return __ispow2(__t);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, _Tp>
floor2(_Tp __t) noexcept
{
    return __t == 0 ? 0 : _Tp{1} << __bit_log2(__t);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, _Tp>
ceil2(_Tp __t) noexcept
{
    if (__t < 2) return 1;
    const unsigned __n = numeric_limits<_Tp>::digits - countl_zero((_Tp)(__t - 1u));
    _LIBCPP_DEBUG_ASSERT(__libcpp_is_constant_evaluated() || __n != numeric_limits<_Tp>::digits, "Bad input to ceil2");

    if constexpr (sizeof(_Tp) >= sizeof(unsigned))
        return _Tp{1} << __n;
    else
    {
        const unsigned __extra = numeric_limits<unsigned>::digits  - numeric_limits<_Tp>::digits;
        const unsigned __retVal = 1u << (__n + __extra);
        return (_Tp) (__retVal >> __extra);
    }
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
enable_if_t<__bitop_unsigned_integer<_Tp>::value, _Tp>
log2p1(_Tp __t) noexcept
{
    return __t == 0 ? 0 : __bit_log2(__t) + 1;
}


enum class endian
{
    little = 0xDEAD,
    big    = 0xFACE,
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_LITTLE_ENDIAN)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 472 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
    native = little
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_BIG_ENDIAN)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 474 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
    native = big
#else
# 476 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
    native = 0xCAFE
#endif
# 478 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
};

#endif // _LIBCPP_STD_VER > 17
# 481 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif // _LIBCPP_BIT
# 487 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/bit" 3
# 648 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 648 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 649 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 650 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 651 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 654 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#endif
# 655 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 657 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 658 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

// I'd like to replace these with _VSTD::equal_to<void>, but can't because:
//   * That only works with C++14 and later, and
//   * We haven't included <functional> here.
template <class _T1, class _T2 = _T1>
struct __equal_to
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 bool operator()(const _T1& __x, const _T1& __y) const {return __x == __y;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 bool operator()(const _T1& __x, const _T2& __y) const {return __x == __y;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 bool operator()(const _T2& __x, const _T1& __y) const {return __x == __y;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 bool operator()(const _T2& __x, const _T2& __y) const {return __x == __y;}
};

template <class _T1>
struct __equal_to<_T1, _T1>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T1& __x, const _T1& __y) const {return __x == __y;}
};

template <class _T1>
struct __equal_to<const _T1, _T1>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T1& __x, const _T1& __y) const {return __x == __y;}
};

template <class _T1>
struct __equal_to<_T1, const _T1>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T1& __x, const _T1& __y) const {return __x == __y;}
};

template <class _T1, class _T2 = _T1>
struct __less
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T1& __x, const _T1& __y) const {return __x < __y;}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T1& __x, const _T2& __y) const {return __x < __y;}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T2& __x, const _T1& __y) const {return __x < __y;}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T2& __x, const _T2& __y) const {return __x < __y;}
};

template <class _T1>
struct __less<_T1, _T1>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T1& __x, const _T1& __y) const {return __x < __y;}
};

template <class _T1>
struct __less<const _T1, _T1>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T1& __x, const _T1& __y) const {return __x < __y;}
};

template <class _T1>
struct __less<_T1, const _T1>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _T1& __x, const _T1& __y) const {return __x < __y;}
};

template <class _Predicate>
class __invert // invert the sense of a comparison
{
private:
    _Predicate __p_;
public:
    _LIBCPP_INLINE_VISIBILITY __invert() {}

    _LIBCPP_INLINE_VISIBILITY
    explicit __invert(_Predicate __p) : __p_(__p) {}

    template <class _T1>
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _T1& __x) {return !__p_(__x);}

    template <class _T1, class _T2>
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _T1& __x, const _T2& __y) {return __p_(__y, __x);}
};

// Perform division by two quickly for positive integers (llvm.org/PR39129)

template <typename _Integral>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    is_integral<_Integral>::value,
    _Integral
>::type
__half_positive(_Integral __value)
{
    return static_cast<_Integral>(static_cast<typename make_unsigned<_Integral>::type>(__value) / 2);
}

template <typename _Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    !is_integral<_Tp>::value,
    _Tp
>::type
__half_positive(_Tp __value)
{
    return __value / 2;
}

#ifdef _LIBCPP_DEBUG

template <class _Compare>
struct __debug_less
{
    _Compare &__comp_;
    _LIBCPP_CONSTEXPR_AFTER_CXX17
    __debug_less(_Compare& __c) : __comp_(__c) {}

    template <class _Tp, class _Up>
    _LIBCPP_CONSTEXPR_AFTER_CXX17
    bool operator()(const _Tp& __x,  const _Up& __y)
    {
        bool __r = __comp_(__x, __y);
        if (__r)
            __do_compare_assert(0, __y, __x);
        return __r;
    }

    template <class _Tp, class _Up>
    _LIBCPP_CONSTEXPR_AFTER_CXX17
    bool operator()(_Tp& __x,  _Up& __y)
    {
        bool __r = __comp_(__x, __y);
        if (__r)
            __do_compare_assert(0, __y, __x);
        return __r;
    }

    template <class _LHS, class _RHS>
    _LIBCPP_CONSTEXPR_AFTER_CXX17
    inline _LIBCPP_INLINE_VISIBILITY
    decltype((void)_VSTD::declval<_Compare&>()(
        _VSTD::declval<_LHS &>(), _VSTD::declval<_RHS &>()))
    __do_compare_assert(int, _LHS & __l, _RHS & __r) {
        _LIBCPP_ASSERT(!__comp_(__l, __r),
            "Comparator does not induce a strict weak ordering");
    }

    template <class _LHS, class _RHS>
    _LIBCPP_CONSTEXPR_AFTER_CXX17
    inline _LIBCPP_INLINE_VISIBILITY
    void __do_compare_assert(long, _LHS &, _RHS &) {}
};

#endif // _LIBCPP_DEBUG
# 824 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

template <class _Comp>
struct __comp_ref_type {
  // Pass the comparator by lvalue reference. Or in debug mode, using a
  // debugging wrapper that stores a reference.
#ifndef _LIBCPP_DEBUG
  typedef typename add_lvalue_reference<_Comp>::type type;
#else
# 832 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
  typedef __debug_less<_Comp> type;
#endif
# 834 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
};

// all_of

template <class _InputIterator, class _Predicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
all_of(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (!__pred(*__first))
            return false;
    return true;
}

// any_of

template <class _InputIterator, class _Predicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
any_of(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            return true;
    return false;
}

// none_of

template <class _InputIterator, class _Predicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
none_of(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            return false;
    return true;
}

// for_each

template <class _InputIterator, class _Function>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_Function
for_each(_InputIterator __first, _InputIterator __last, _Function __f)
{
    for (; __first != __last; ++__first)
        __f(*__first);
    return __f;
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 891 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
// for_each_n

template <class _InputIterator, class _Size, class _Function>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_InputIterator
for_each_n(_InputIterator __first, _Size __orig_n, _Function __f)
{
    typedef decltype(__convert_to_integral(__orig_n)) _IntegralSize;
    _IntegralSize __n = __orig_n;
    while (__n > 0)
    {
         __f(*__first);
         ++__first;
         --__n;
    }
    return __first;
}
#endif
# 909 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

// find

template <class _InputIterator, class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_InputIterator
find(_InputIterator __first, _InputIterator __last, const _Tp& __value_)
{
    for (; __first != __last; ++__first)
        if (*__first == __value_)
            break;
    return __first;
}

// find_if

template <class _InputIterator, class _Predicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_InputIterator
find_if(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            break;
    return __first;
}

// find_if_not

template<class _InputIterator, class _Predicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_InputIterator
find_if_not(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (!__pred(*__first))
            break;
    return __first;
}

// find_end

template <class _BinaryPredicate, class _ForwardIterator1, class _ForwardIterator2>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator1
__find_end(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
           _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred,
           forward_iterator_tag, forward_iterator_tag)
{
    // modeled after search algorithm
    _ForwardIterator1 __r = __last1;  // __last1 is the "default" answer
    if (__first2 == __last2)
        return __r;
    while (true)
    {
        while (true)
        {
            if (__first1 == __last1)         // if source exhausted return last correct answer
                return __r;                  //    (or __last1 if never found)
            if (__pred(*__first1, *__first2))
                break;
            ++__first1;
        }
        // *__first1 matches *__first2, now match elements after here
        _ForwardIterator1 __m1 = __first1;
        _ForwardIterator2 __m2 = __first2;
        while (true)
        {
            if (++__m2 == __last2)
            {                         // Pattern exhaused, record answer and search for another one
                __r = __first1;
                ++__first1;
                break;
            }
            if (++__m1 == __last1)     // Source exhausted, return last answer
                return __r;
            if (!__pred(*__m1, *__m2))  // mismatch, restart with a new __first
            {
                ++__first1;
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _BinaryPredicate, class _BidirectionalIterator1, class _BidirectionalIterator2>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _BidirectionalIterator1
__find_end(_BidirectionalIterator1 __first1, _BidirectionalIterator1 __last1,
           _BidirectionalIterator2 __first2, _BidirectionalIterator2 __last2, _BinaryPredicate __pred,
           bidirectional_iterator_tag, bidirectional_iterator_tag)
{
    // modeled after search algorithm (in reverse)
    if (__first2 == __last2)
        return __last1;  // Everything matches an empty sequence
    _BidirectionalIterator1 __l1 = __last1;
    _BidirectionalIterator2 __l2 = __last2;
    --__l2;
    while (true)
    {
        // Find last element in sequence 1 that matchs *(__last2-1), with a mininum of loop checks
        while (true)
        {
            if (__first1 == __l1)  // return __last1 if no element matches *__first2
                return __last1;
            if (__pred(*--__l1, *__l2))
                break;
        }
        // *__l1 matches *__l2, now match elements before here
        _BidirectionalIterator1 __m1 = __l1;
        _BidirectionalIterator2 __m2 = __l2;
        while (true)
        {
            if (__m2 == __first2)  // If pattern exhausted, __m1 is the answer (works for 1 element pattern)
                return __m1;
            if (__m1 == __first1)  // Otherwise if source exhaused, pattern not found
                return __last1;
            if (!__pred(*--__m1, *--__m2))  // if there is a mismatch, restart with a new __l1
            {
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _BinaryPredicate, class _RandomAccessIterator1, class _RandomAccessIterator2>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _RandomAccessIterator1
__find_end(_RandomAccessIterator1 __first1, _RandomAccessIterator1 __last1,
           _RandomAccessIterator2 __first2, _RandomAccessIterator2 __last2, _BinaryPredicate __pred,
           random_access_iterator_tag, random_access_iterator_tag)
{
    // Take advantage of knowing source and pattern lengths.  Stop short when source is smaller than pattern
    typename iterator_traits<_RandomAccessIterator2>::difference_type __len2 = __last2 - __first2;
    if (__len2 == 0)
        return __last1;
    typename iterator_traits<_RandomAccessIterator1>::difference_type __len1 = __last1 - __first1;
    if (__len1 < __len2)
        return __last1;
    const _RandomAccessIterator1 __s = __first1 + (__len2 - 1);  // End of pattern match can't go before here
    _RandomAccessIterator1 __l1 = __last1;
    _RandomAccessIterator2 __l2 = __last2;
    --__l2;
    while (true)
    {
        while (true)
        {
            if (__s == __l1)
                return __last1;
            if (__pred(*--__l1, *__l2))
                break;
        }
        _RandomAccessIterator1 __m1 = __l1;
        _RandomAccessIterator2 __m2 = __l2;
        while (true)
        {
            if (__m2 == __first2)
                return __m1;
                                 // no need to check range on __m1 because __s guarantees we have enough source
            if (!__pred(*--__m1, *--__m2))
            {
                break;
            }
        }
    }
}

template <class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator1
find_end(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
         _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred)
{
    return _VSTD::__find_end<typename add_lvalue_reference<_BinaryPredicate>::type>
                         (__first1, __last1, __first2, __last2, __pred,
                          typename iterator_traits<_ForwardIterator1>::iterator_category(),
                          typename iterator_traits<_ForwardIterator2>::iterator_category());
}

template <class _ForwardIterator1, class _ForwardIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator1
find_end(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
         _ForwardIterator2 __first2, _ForwardIterator2 __last2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::find_end(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>());
}

// find_first_of

template <class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _ForwardIterator1
__find_first_of_ce(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
              _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred)
{
    for (; __first1 != __last1; ++__first1)
        for (_ForwardIterator2 __j = __first2; __j != __last2; ++__j)
            if (__pred(*__first1, *__j))
                return __first1;
    return __last1;
}


template <class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator1
find_first_of(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
              _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred)
{
    return _VSTD::__find_first_of_ce(__first1, __last1, __first2, __last2, __pred);
}

template <class _ForwardIterator1, class _ForwardIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator1
find_first_of(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
              _ForwardIterator2 __first2, _ForwardIterator2 __last2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::__find_first_of_ce(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>());
}

// adjacent_find

template <class _ForwardIterator, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
adjacent_find(_ForwardIterator __first, _ForwardIterator __last, _BinaryPredicate __pred)
{
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (__pred(*__first, *__i))
                return __first;
            __first = __i;
        }
    }
    return __last;
}

template <class _ForwardIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
adjacent_find(_ForwardIterator __first, _ForwardIterator __last)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type __v;
    return _VSTD::adjacent_find(__first, __last, __equal_to<__v>());
}

// count

template <class _InputIterator, class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
typename iterator_traits<_InputIterator>::difference_type
count(_InputIterator __first, _InputIterator __last, const _Tp& __value_)
{
    typename iterator_traits<_InputIterator>::difference_type __r(0);
    for (; __first != __last; ++__first)
        if (*__first == __value_)
            ++__r;
    return __r;
}

// count_if

template <class _InputIterator, class _Predicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
typename iterator_traits<_InputIterator>::difference_type
count_if(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    typename iterator_traits<_InputIterator>::difference_type __r(0);
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            ++__r;
    return __r;
}

// mismatch

template <class _InputIterator1, class _InputIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
pair<_InputIterator1, _InputIterator2>
mismatch(_InputIterator1 __first1, _InputIterator1 __last1,
         _InputIterator2 __first2, _BinaryPredicate __pred)
{
    for (; __first1 != __last1; ++__first1, (void) ++__first2)
        if (!__pred(*__first1, *__first2))
            break;
    return pair<_InputIterator1, _InputIterator2>(__first1, __first2);
}

template <class _InputIterator1, class _InputIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
pair<_InputIterator1, _InputIterator2>
mismatch(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::mismatch(__first1, __last1, __first2, __equal_to<__v1, __v2>());
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1226 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
template <class _InputIterator1, class _InputIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
pair<_InputIterator1, _InputIterator2>
mismatch(_InputIterator1 __first1, _InputIterator1 __last1,
         _InputIterator2 __first2, _InputIterator2 __last2,
         _BinaryPredicate __pred)
{
    for (; __first1 != __last1 && __first2 != __last2; ++__first1, (void) ++__first2)
        if (!__pred(*__first1, *__first2))
            break;
    return pair<_InputIterator1, _InputIterator2>(__first1, __first2);
}

template <class _InputIterator1, class _InputIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
pair<_InputIterator1, _InputIterator2>
mismatch(_InputIterator1 __first1, _InputIterator1 __last1,
         _InputIterator2 __first2, _InputIterator2 __last2)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::mismatch(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>());
}
#endif
# 1252 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

// equal

template <class _InputIterator1, class _InputIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
equal(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2, _BinaryPredicate __pred)
{
    for (; __first1 != __last1; ++__first1, (void) ++__first2)
        if (!__pred(*__first1, *__first2))
            return false;
    return true;
}

template <class _InputIterator1, class _InputIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
equal(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::equal(__first1, __last1, __first2, __equal_to<__v1, __v2>());
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1279 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
template <class _BinaryPredicate, class _InputIterator1, class _InputIterator2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
__equal(_InputIterator1 __first1, _InputIterator1 __last1,
        _InputIterator2 __first2, _InputIterator2 __last2, _BinaryPredicate __pred,
        input_iterator_tag, input_iterator_tag )
{
    for (; __first1 != __last1 && __first2 != __last2; ++__first1, (void) ++__first2)
        if (!__pred(*__first1, *__first2))
            return false;
    return __first1 == __last1 && __first2 == __last2;
}

template <class _BinaryPredicate, class _RandomAccessIterator1, class _RandomAccessIterator2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
__equal(_RandomAccessIterator1 __first1, _RandomAccessIterator1 __last1,
        _RandomAccessIterator2 __first2, _RandomAccessIterator2 __last2, _BinaryPredicate __pred,
      random_access_iterator_tag, random_access_iterator_tag )
{
    if ( _VSTD::distance(__first1, __last1) != _VSTD::distance(__first2, __last2))
        return false;
    return _VSTD::equal<_RandomAccessIterator1, _RandomAccessIterator2,
                        typename add_lvalue_reference<_BinaryPredicate>::type>
                       (__first1, __last1, __first2, __pred );
}

template <class _InputIterator1, class _InputIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
equal(_InputIterator1 __first1, _InputIterator1 __last1,
      _InputIterator2 __first2, _InputIterator2 __last2, _BinaryPredicate __pred )
{
    return _VSTD::__equal<typename add_lvalue_reference<_BinaryPredicate>::type>
       (__first1, __last1, __first2, __last2, __pred,
        typename iterator_traits<_InputIterator1>::iterator_category(),
        typename iterator_traits<_InputIterator2>::iterator_category());
}

template <class _InputIterator1, class _InputIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
equal(_InputIterator1 __first1, _InputIterator1 __last1,
      _InputIterator2 __first2, _InputIterator2 __last2)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::__equal(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>(),
        typename iterator_traits<_InputIterator1>::iterator_category(),
        typename iterator_traits<_InputIterator2>::iterator_category());
}
#endif
# 1333 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

// is_permutation

template<class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT _LIBCPP_CONSTEXPR_AFTER_CXX17 bool
is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
               _ForwardIterator2 __first2, _BinaryPredicate __pred)
{
//  shorten sequences as much as possible by lopping of any equal prefix
    for (; __first1 != __last1; ++__first1, (void) ++__first2)
        if (!__pred(*__first1, *__first2))
            break;
    if (__first1 == __last1)
        return true;

//  __first1 != __last1 && *__first1 != *__first2
    typedef typename iterator_traits<_ForwardIterator1>::difference_type _D1;
    _D1 __l1 = _VSTD::distance(__first1, __last1);
    if (__l1 == _D1(1))
        return false;
    _ForwardIterator2 __last2 = _VSTD::next(__first2, __l1);
    // For each element in [f1, l1) see if there are the same number of
    //    equal elements in [f2, l2)
    for (_ForwardIterator1 __i = __first1; __i != __last1; ++__i)
    {
    //  Have we already counted the number of *__i in [f1, l1)?
        _ForwardIterator1 __match = __first1;
        for (; __match != __i; ++__match)
            if (__pred(*__match, *__i))
                break;
        if (__match == __i) {
            // Count number of *__i in [f2, l2)
            _D1 __c2 = 0;
            for (_ForwardIterator2 __j = __first2; __j != __last2; ++__j)
                if (__pred(*__i, *__j))
                    ++__c2;
            if (__c2 == 0)
                return false;
            // Count number of *__i in [__i, l1) (we can start with 1)
            _D1 __c1 = 1;
            for (_ForwardIterator1 __j = _VSTD::next(__i); __j != __last1; ++__j)
                if (__pred(*__i, *__j))
                    ++__c1;
            if (__c1 != __c2)
                return false;
        }
    }
    return true;
}

template<class _ForwardIterator1, class _ForwardIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
               _ForwardIterator2 __first2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::is_permutation(__first1, __last1, __first2, __equal_to<__v1, __v2>());
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1396 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
template<class _BinaryPredicate, class _ForwardIterator1, class _ForwardIterator2>
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
__is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
                 _ForwardIterator2 __first2, _ForwardIterator2 __last2,
                 _BinaryPredicate __pred,
                 forward_iterator_tag, forward_iterator_tag )
{
//  shorten sequences as much as possible by lopping of any equal prefix
    for (; __first1 != __last1 && __first2 != __last2; ++__first1, (void) ++__first2)
        if (!__pred(*__first1, *__first2))
            break;
    if (__first1 == __last1)
        return __first2 == __last2;
    else if (__first2 == __last2)
        return false;

    typedef typename iterator_traits<_ForwardIterator1>::difference_type _D1;
    _D1 __l1 = _VSTD::distance(__first1, __last1);

    typedef typename iterator_traits<_ForwardIterator2>::difference_type _D2;
    _D2 __l2 = _VSTD::distance(__first2, __last2);
    if (__l1 != __l2)
        return false;

    // For each element in [f1, l1) see if there are the same number of
    //    equal elements in [f2, l2)
    for (_ForwardIterator1 __i = __first1; __i != __last1; ++__i)
    {
    //  Have we already counted the number of *__i in [f1, l1)?
        _ForwardIterator1 __match = __first1;
        for (; __match != __i; ++__match)
            if (__pred(*__match, *__i))
                break;
        if (__match == __i) {
            // Count number of *__i in [f2, l2)
            _D1 __c2 = 0;
            for (_ForwardIterator2 __j = __first2; __j != __last2; ++__j)
                if (__pred(*__i, *__j))
                    ++__c2;
            if (__c2 == 0)
                return false;
            // Count number of *__i in [__i, l1) (we can start with 1)
            _D1 __c1 = 1;
            for (_ForwardIterator1 __j = _VSTD::next(__i); __j != __last1; ++__j)
                if (__pred(*__i, *__j))
                    ++__c1;
            if (__c1 != __c2)
                return false;
        }
    }
    return true;
}

template<class _BinaryPredicate, class _RandomAccessIterator1, class _RandomAccessIterator2>
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
__is_permutation(_RandomAccessIterator1 __first1, _RandomAccessIterator2 __last1,
               _RandomAccessIterator1 __first2, _RandomAccessIterator2 __last2,
               _BinaryPredicate __pred,
               random_access_iterator_tag, random_access_iterator_tag )
{
    if ( _VSTD::distance(__first1, __last1) != _VSTD::distance(__first2, __last2))
        return false;
    return _VSTD::is_permutation<_RandomAccessIterator1, _RandomAccessIterator2,
                                 typename add_lvalue_reference<_BinaryPredicate>::type>
                                (__first1, __last1, __first2, __pred );
}

template<class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
               _ForwardIterator2 __first2, _ForwardIterator2 __last2,
               _BinaryPredicate __pred )
{
    return _VSTD::__is_permutation<typename add_lvalue_reference<_BinaryPredicate>::type>
       (__first1, __last1, __first2, __last2, __pred,
        typename iterator_traits<_ForwardIterator1>::iterator_category(),
        typename iterator_traits<_ForwardIterator2>::iterator_category());
}

template<class _ForwardIterator1, class _ForwardIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
               _ForwardIterator2 __first2, _ForwardIterator2 __last2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::__is_permutation(__first1, __last1, __first2, __last2,
        __equal_to<__v1, __v2>(),
        typename iterator_traits<_ForwardIterator1>::iterator_category(),
        typename iterator_traits<_ForwardIterator2>::iterator_category());
}
#endif
# 1492 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

// search
// __search is in <functional>

template <class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator1
search(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
       _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred)
{
    return _VSTD::__search<typename add_lvalue_reference<_BinaryPredicate>::type>
                         (__first1, __last1, __first2, __last2, __pred,
                          typename iterator_traits<_ForwardIterator1>::iterator_category(),
                          typename iterator_traits<_ForwardIterator2>::iterator_category())
            .first;
}

template <class _ForwardIterator1, class _ForwardIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator1
search(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
       _ForwardIterator2 __first2, _ForwardIterator2 __last2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::search(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>());
}


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1524 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
template <class _ForwardIterator, class _Searcher>
_LIBCPP_NODISCARD_EXT _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator search(_ForwardIterator __f, _ForwardIterator __l, const _Searcher &__s)
{ return __s(__f, __l).first; }
#endif
# 1529 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

// search_n

template <class _BinaryPredicate, class _ForwardIterator, class _Size, class _Tp>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
__search_n(_ForwardIterator __first, _ForwardIterator __last,
           _Size __count, const _Tp& __value_, _BinaryPredicate __pred, forward_iterator_tag)
{
    if (__count <= 0)
        return __first;
    while (true)
    {
        // Find first element in sequence that matchs __value_, with a mininum of loop checks
        while (true)
        {
            if (__first == __last)  // return __last if no element matches __value_
                return __last;
            if (__pred(*__first, __value_))
                break;
            ++__first;
        }
        // *__first matches __value_, now match elements after here
        _ForwardIterator __m = __first;
        _Size __c(0);
        while (true)
        {
            if (++__c == __count)  // If pattern exhausted, __first is the answer (works for 1 element pattern)
                return __first;
            if (++__m == __last)  // Otherwise if source exhaused, pattern not found
                return __last;
            if (!__pred(*__m, __value_))  // if there is a mismatch, restart with a new __first
            {
                __first = __m;
                ++__first;
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _BinaryPredicate, class _RandomAccessIterator, class _Size, class _Tp>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _RandomAccessIterator
__search_n(_RandomAccessIterator __first, _RandomAccessIterator __last,
           _Size __count, const _Tp& __value_, _BinaryPredicate __pred, random_access_iterator_tag)
{
    if (__count <= 0)
        return __first;
    _Size __len = static_cast<_Size>(__last - __first);
    if (__len < __count)
        return __last;
    const _RandomAccessIterator __s = __last - (__count - 1);  // Start of pattern match can't go beyond here
    while (true)
    {
        // Find first element in sequence that matchs __value_, with a mininum of loop checks
        while (true)
        {
            if (__first >= __s)  // return __last if no element matches __value_
                return __last;
            if (__pred(*__first, __value_))
                break;
            ++__first;
        }
        // *__first matches __value_, now match elements after here
        _RandomAccessIterator __m = __first;
        _Size __c(0);
        while (true)
        {
            if (++__c == __count)  // If pattern exhausted, __first is the answer (works for 1 element pattern)
                return __first;
             ++__m;          // no need to check range on __m because __s guarantees we have enough source
            if (!__pred(*__m, __value_))  // if there is a mismatch, restart with a new __first
            {
                __first = __m;
                ++__first;
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _ForwardIterator, class _Size, class _Tp, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
search_n(_ForwardIterator __first, _ForwardIterator __last,
         _Size __count, const _Tp& __value_, _BinaryPredicate __pred)
{
    return _VSTD::__search_n<typename add_lvalue_reference<_BinaryPredicate>::type>
           (__first, __last, __convert_to_integral(__count), __value_, __pred,
           typename iterator_traits<_ForwardIterator>::iterator_category());
}

template <class _ForwardIterator, class _Size, class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
search_n(_ForwardIterator __first, _ForwardIterator __last, _Size __count, const _Tp& __value_)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type __v;
    return _VSTD::search_n(__first, __last, __convert_to_integral(__count),
                           __value_, __equal_to<__v, _Tp>());
}

// copy
template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_Iter
__unwrap_iter(_Iter __i)
{
    return __i;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    _Tp*
>::type
__unwrap_iter(move_iterator<_Tp*> __i)
{
    return __i.base();
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL < 2
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1654 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    _Tp*
>::type
__unwrap_iter(__wrap_iter<_Tp*> __i)
{
    return __i.base();
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    const _Tp*
>::type
__unwrap_iter(__wrap_iter<const _Tp*> __i)
{
    return __i.base();
}

#else
# 1680 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_IF_NODEBUG
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    __wrap_iter<_Tp*>
>::type
__unwrap_iter(__wrap_iter<_Tp*> __i)
{
    return __i;
}

#endif  // _LIBCPP_DEBUG_LEVEL < 2
# 1694 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
__copy_constexpr(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    for (; __first != __last; ++__first, (void) ++__result)
        *__result = *__first;
    return __result;
}

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    return __copy_constexpr(__first, __last, __result);
}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_same<typename remove_const<_Tp>::type, _Up>::value &&
    is_trivially_copy_assignable<_Up>::value,
    _Up*
>::type
__copy(_Tp* __first, _Tp* __last, _Up* __result)
{
    const size_t __n = static_cast<size_t>(__last - __first);
    if (__n > 0)
        _VSTD::memmove(__result, __first, __n * sizeof(_Up));
    return __result + __n;
}

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
_OutputIterator
copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    if (__libcpp_is_constant_evaluated()) {
        return _VSTD::__copy_constexpr(
            __unwrap_iter(__first), __unwrap_iter(__last), __unwrap_iter(__result));
    } else {
        return _VSTD::__copy(
            __unwrap_iter(__first), __unwrap_iter(__last), __unwrap_iter(__result));
    }
}

// copy_backward

template <class _BidirectionalIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
__copy_backward_constexpr(_BidirectionalIterator __first, _BidirectionalIterator __last, _OutputIterator __result)
{
    while (__first != __last)
        *--__result = *--__last;
    return __result;
}

template <class _BidirectionalIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__copy_backward(_BidirectionalIterator __first, _BidirectionalIterator __last, _OutputIterator __result)
{
    return __copy_backward_constexpr(__first, __last, __result);
}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_same<typename remove_const<_Tp>::type, _Up>::value &&
    is_trivially_copy_assignable<_Up>::value,
    _Up*
>::type
__copy_backward(_Tp* __first, _Tp* __last, _Up* __result)
{
    const size_t __n = static_cast<size_t>(__last - __first);
    if (__n > 0)
    {
        __result -= __n;
        _VSTD::memmove(__result, __first, __n * sizeof(_Up));
    }
    return __result;
}

template <class _BidirectionalIterator1, class _BidirectionalIterator2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
_BidirectionalIterator2
copy_backward(_BidirectionalIterator1 __first, _BidirectionalIterator1 __last,
              _BidirectionalIterator2 __result)
{
    if (__libcpp_is_constant_evaluated()) {
        return _VSTD::__copy_backward_constexpr(__unwrap_iter(__first),
                                                __unwrap_iter(__last),
                                                __unwrap_iter(__result));
    } else {
        return _VSTD::__copy_backward(__unwrap_iter(__first),
                                      __unwrap_iter(__last),
                                      __unwrap_iter(__result));
    }
}

// copy_if

template<class _InputIterator, class _OutputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
copy_if(_InputIterator __first, _InputIterator __last,
        _OutputIterator __result, _Predicate __pred)
{
    for (; __first != __last; ++__first)
    {
        if (__pred(*__first))
        {
            *__result = *__first;
            ++__result;
        }
    }
    return __result;
}

// copy_n

template<class _InputIterator, class _Size, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
typename enable_if
<
    __is_cpp17_input_iterator<_InputIterator>::value &&
   !__is_cpp17_random_access_iterator<_InputIterator>::value,
    _OutputIterator
>::type
copy_n(_InputIterator __first, _Size __orig_n, _OutputIterator __result)
{
    typedef decltype(__convert_to_integral(__orig_n)) _IntegralSize;
    _IntegralSize __n = __orig_n;
    if (__n > 0)
    {
        *__result = *__first;
        ++__result;
        for (--__n; __n > 0; --__n)
        {
            ++__first;
            *__result = *__first;
            ++__result;
        }
    }
    return __result;
}

template<class _InputIterator, class _Size, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
typename enable_if
<
    __is_cpp17_random_access_iterator<_InputIterator>::value,
    _OutputIterator
>::type
copy_n(_InputIterator __first, _Size __orig_n, _OutputIterator __result)
{
    typedef decltype(__convert_to_integral(__orig_n)) _IntegralSize;
    _IntegralSize __n = __orig_n;
    return _VSTD::copy(__first, __first + __n, __result);
}

// move

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__move(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    for (; __first != __last; ++__first, (void) ++__result)
        *__result = _VSTD::move(*__first);
    return __result;
}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_same<typename remove_const<_Tp>::type, _Up>::value &&
    is_trivially_copy_assignable<_Up>::value,
    _Up*
>::type
__move(_Tp* __first, _Tp* __last, _Up* __result)
{
    const size_t __n = static_cast<size_t>(__last - __first);
    if (__n > 0)
        _VSTD::memmove(__result, __first, __n * sizeof(_Up));
    return __result + __n;
}

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
move(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    return _VSTD::__move(__unwrap_iter(__first), __unwrap_iter(__last), __unwrap_iter(__result));
}

// move_backward

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__move_backward(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    while (__first != __last)
        *--__result = _VSTD::move(*--__last);
    return __result;
}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_same<typename remove_const<_Tp>::type, _Up>::value &&
    is_trivially_copy_assignable<_Up>::value,
    _Up*
>::type
__move_backward(_Tp* __first, _Tp* __last, _Up* __result)
{
    const size_t __n = static_cast<size_t>(__last - __first);
    if (__n > 0)
    {
        __result -= __n;
        _VSTD::memmove(__result, __first, __n * sizeof(_Up));
    }
    return __result;
}

template <class _BidirectionalIterator1, class _BidirectionalIterator2>
inline _LIBCPP_INLINE_VISIBILITY
_BidirectionalIterator2
move_backward(_BidirectionalIterator1 __first, _BidirectionalIterator1 __last,
              _BidirectionalIterator2 __result)
{
    return _VSTD::__move_backward(__unwrap_iter(__first), __unwrap_iter(__last), __unwrap_iter(__result));
}

// iter_swap

// moved to <type_traits> for better swap / noexcept support

// transform

template <class _InputIterator, class _OutputIterator, class _UnaryOperation>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
transform(_InputIterator __first, _InputIterator __last, _OutputIterator __result, _UnaryOperation __op)
{
    for (; __first != __last; ++__first, (void) ++__result)
        *__result = __op(*__first);
    return __result;
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _BinaryOperation>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
transform(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2,
          _OutputIterator __result, _BinaryOperation __binary_op)
{
    for (; __first1 != __last1; ++__first1, (void) ++__first2, ++__result)
        *__result = __binary_op(*__first1, *__first2);
    return __result;
}

// replace

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
void
replace(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __old_value, const _Tp& __new_value)
{
    for (; __first != __last; ++__first)
        if (*__first == __old_value)
            *__first = __new_value;
}

// replace_if

template <class _ForwardIterator, class _Predicate, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
void
replace_if(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred, const _Tp& __new_value)
{
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            *__first = __new_value;
}

// replace_copy

template <class _InputIterator, class _OutputIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
replace_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result,
             const _Tp& __old_value, const _Tp& __new_value)
{
    for (; __first != __last; ++__first, (void) ++__result)
        if (*__first == __old_value)
            *__result = __new_value;
        else
            *__result = *__first;
    return __result;
}

// replace_copy_if

template <class _InputIterator, class _OutputIterator, class _Predicate, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
replace_copy_if(_InputIterator __first, _InputIterator __last, _OutputIterator __result,
                _Predicate __pred, const _Tp& __new_value)
{
    for (; __first != __last; ++__first, (void) ++__result)
        if (__pred(*__first))
            *__result = __new_value;
        else
            *__result = *__first;
    return __result;
}

// fill_n

template <class _OutputIterator, class _Size, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
__fill_n(_OutputIterator __first, _Size __n, const _Tp& __value_)
{
    for (; __n > 0; ++__first, (void) --__n)
        *__first = __value_;
    return __first;
}

template <class _OutputIterator, class _Size, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
fill_n(_OutputIterator __first, _Size __n, const _Tp& __value_)
{
   return _VSTD::__fill_n(__first, __convert_to_integral(__n), __value_);
}

// fill

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
void
__fill(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, forward_iterator_tag)
{
    for (; __first != __last; ++__first)
        *__first = __value_;
}

template <class _RandomAccessIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
void
__fill(_RandomAccessIterator __first, _RandomAccessIterator __last, const _Tp& __value_, random_access_iterator_tag)
{
    _VSTD::fill_n(__first, __last - __first, __value_);
}

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
void
fill(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    _VSTD::__fill(__first, __last, __value_, typename iterator_traits<_ForwardIterator>::iterator_category());
}

// generate

template <class _ForwardIterator, class _Generator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
void
generate(_ForwardIterator __first, _ForwardIterator __last, _Generator __gen)
{
    for (; __first != __last; ++__first)
        *__first = __gen();
}

// generate_n

template <class _OutputIterator, class _Size, class _Generator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
generate_n(_OutputIterator __first, _Size __orig_n, _Generator __gen)
{
    typedef decltype(__convert_to_integral(__orig_n)) _IntegralSize;
    _IntegralSize __n = __orig_n;
    for (; __n > 0; ++__first, (void) --__n)
        *__first = __gen();
    return __first;
}

// remove

template <class _ForwardIterator, class _Tp>
_LIBCPP_NODISCARD_EXT _LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
remove(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    __first = _VSTD::find(__first, __last, __value_);
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (!(*__i == __value_))
            {
                *__first = _VSTD::move(*__i);
                ++__first;
            }
        }
    }
    return __first;
}

// remove_if

template <class _ForwardIterator, class _Predicate>
_LIBCPP_NODISCARD_EXT _LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
remove_if(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred)
{
    __first = _VSTD::find_if<_ForwardIterator, typename add_lvalue_reference<_Predicate>::type>
                           (__first, __last, __pred);
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (!__pred(*__i))
            {
                *__first = _VSTD::move(*__i);
                ++__first;
            }
        }
    }
    return __first;
}

// remove_copy

template <class _InputIterator, class _OutputIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
remove_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result, const _Tp& __value_)
{
    for (; __first != __last; ++__first)
    {
        if (!(*__first == __value_))
        {
            *__result = *__first;
            ++__result;
        }
    }
    return __result;
}

// remove_copy_if

template <class _InputIterator, class _OutputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
remove_copy_if(_InputIterator __first, _InputIterator __last, _OutputIterator __result, _Predicate __pred)
{
    for (; __first != __last; ++__first)
    {
        if (!__pred(*__first))
        {
            *__result = *__first;
            ++__result;
        }
    }
    return __result;
}

// unique

template <class _ForwardIterator, class _BinaryPredicate>
_LIBCPP_NODISCARD_EXT _LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
unique(_ForwardIterator __first, _ForwardIterator __last, _BinaryPredicate __pred)
{
    __first = _VSTD::adjacent_find<_ForwardIterator, typename add_lvalue_reference<_BinaryPredicate>::type>
                                 (__first, __last, __pred);
    if (__first != __last)
    {
        // ...  a  a  ?  ...
        //      f     i
        _ForwardIterator __i = __first;
        for (++__i; ++__i != __last;)
            if (!__pred(*__first, *__i))
                *++__first = _VSTD::move(*__i);
        ++__first;
    }
    return __first;
}

template <class _ForwardIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
unique(_ForwardIterator __first, _ForwardIterator __last)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type __v;
    return _VSTD::unique(__first, __last, __equal_to<__v>());
}

// unique_copy

template <class _BinaryPredicate, class _InputIterator, class _OutputIterator>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _OutputIterator
__unique_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result, _BinaryPredicate __pred,
              input_iterator_tag, output_iterator_tag)
{
    if (__first != __last)
    {
        typename iterator_traits<_InputIterator>::value_type __t(*__first);
        *__result = __t;
        ++__result;
        while (++__first != __last)
        {
            if (!__pred(__t, *__first))
            {
                __t = *__first;
                *__result = __t;
                ++__result;
            }
        }
    }
    return __result;
}

template <class _BinaryPredicate, class _ForwardIterator, class _OutputIterator>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _OutputIterator
__unique_copy(_ForwardIterator __first, _ForwardIterator __last, _OutputIterator __result, _BinaryPredicate __pred,
              forward_iterator_tag, output_iterator_tag)
{
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        *__result = *__i;
        ++__result;
        while (++__first != __last)
        {
            if (!__pred(*__i, *__first))
            {
                *__result = *__first;
                ++__result;
                __i = __first;
            }
        }
    }
    return __result;
}

template <class _BinaryPredicate, class _InputIterator, class _ForwardIterator>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
__unique_copy(_InputIterator __first, _InputIterator __last, _ForwardIterator __result, _BinaryPredicate __pred,
              input_iterator_tag, forward_iterator_tag)
{
    if (__first != __last)
    {
        *__result = *__first;
        while (++__first != __last)
            if (!__pred(*__result, *__first))
                *++__result = *__first;
        ++__result;
    }
    return __result;
}

template <class _InputIterator, class _OutputIterator, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
unique_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result, _BinaryPredicate __pred)
{
    return _VSTD::__unique_copy<typename add_lvalue_reference<_BinaryPredicate>::type>
                              (__first, __last, __result, __pred,
                               typename iterator_traits<_InputIterator>::iterator_category(),
                               typename iterator_traits<_OutputIterator>::iterator_category());
}

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
unique_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    typedef typename iterator_traits<_InputIterator>::value_type __v;
    return _VSTD::unique_copy(__first, __last, __result, __equal_to<__v>());
}

// reverse

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
__reverse(_BidirectionalIterator __first, _BidirectionalIterator __last, bidirectional_iterator_tag)
{
    while (__first != __last)
    {
        if (__first == --__last)
            break;
        _VSTD::iter_swap(__first, __last);
        ++__first;
    }
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
__reverse(_RandomAccessIterator __first, _RandomAccessIterator __last, random_access_iterator_tag)
{
    if (__first != __last)
        for (; __first < --__last; ++__first)
            _VSTD::iter_swap(__first, __last);
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
reverse(_BidirectionalIterator __first, _BidirectionalIterator __last)
{
    _VSTD::__reverse(__first, __last, typename iterator_traits<_BidirectionalIterator>::iterator_category());
}

// reverse_copy

template <class _BidirectionalIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
reverse_copy(_BidirectionalIterator __first, _BidirectionalIterator __last, _OutputIterator __result)
{
    for (; __first != __last; ++__result)
        *__result = *--__last;
    return __result;
}

// rotate

template <class _ForwardIterator>
_ForwardIterator
__rotate_left(_ForwardIterator __first, _ForwardIterator __last)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
    value_type __tmp = _VSTD::move(*__first);
    _ForwardIterator __lm1 = _VSTD::move(_VSTD::next(__first), __last, __first);
    *__lm1 = _VSTD::move(__tmp);
    return __lm1;
}

template <class _BidirectionalIterator>
_BidirectionalIterator
__rotate_right(_BidirectionalIterator __first, _BidirectionalIterator __last)
{
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    _BidirectionalIterator __lm1 = _VSTD::prev(__last);
    value_type __tmp = _VSTD::move(*__lm1);
    _BidirectionalIterator __fp1 = _VSTD::move_backward(__first, __lm1, __last);
    *__first = _VSTD::move(__tmp);
    return __fp1;
}

template <class _ForwardIterator>
_ForwardIterator
__rotate_forward(_ForwardIterator __first, _ForwardIterator __middle, _ForwardIterator __last)
{
    _ForwardIterator __i = __middle;
    while (true)
    {
        swap(*__first, *__i);
        ++__first;
        if (++__i == __last)
            break;
        if (__first == __middle)
            __middle = __i;
    }
    _ForwardIterator __r = __first;
    if (__first != __middle)
    {
        __i = __middle;
        while (true)
        {
            swap(*__first, *__i);
            ++__first;
            if (++__i == __last)
            {
                if (__first == __middle)
                    break;
                __i = __middle;
            }
            else if (__first == __middle)
                __middle = __i;
        }
    }
    return __r;
}

template<typename _Integral>
inline _LIBCPP_INLINE_VISIBILITY
_Integral
__algo_gcd(_Integral __x, _Integral __y)
{
    do
    {
        _Integral __t = __x % __y;
        __x = __y;
        __y = __t;
    } while (__y);
    return __x;
}

template<typename _RandomAccessIterator>
_RandomAccessIterator
__rotate_gcd(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;

    const difference_type __m1 = __middle - __first;
    const difference_type __m2 = __last - __middle;
    if (__m1 == __m2)
    {
        _VSTD::swap_ranges(__first, __middle, __middle);
        return __middle;
    }
    const difference_type __g = _VSTD::__algo_gcd(__m1, __m2);
    for (_RandomAccessIterator __p = __first + __g; __p != __first;)
    {
        value_type __t(_VSTD::move(*--__p));
        _RandomAccessIterator __p1 = __p;
        _RandomAccessIterator __p2 = __p1 + __m1;
        do
        {
            *__p1 = _VSTD::move(*__p2);
            __p1 = __p2;
            const difference_type __d = __last - __p2;
            if (__m1 < __d)
                __p2 += __m1;
            else
                __p2 = __first + (__m1 - __d);
        } while (__p2 != __p);
        *__p1 = _VSTD::move(__t);
    }
    return __first + __m2;
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
__rotate(_ForwardIterator __first, _ForwardIterator __middle, _ForwardIterator __last,
         _VSTD::forward_iterator_tag)
{
    typedef typename _VSTD::iterator_traits<_ForwardIterator>::value_type value_type;
    if (_VSTD::is_trivially_move_assignable<value_type>::value)
    {
        if (_VSTD::next(__first) == __middle)
            return _VSTD::__rotate_left(__first, __last);
    }
    return _VSTD::__rotate_forward(__first, __middle, __last);
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
_BidirectionalIterator
__rotate(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last,
         _VSTD::bidirectional_iterator_tag)
{
    typedef typename _VSTD::iterator_traits<_BidirectionalIterator>::value_type value_type;
    if (_VSTD::is_trivially_move_assignable<value_type>::value)
    {
        if (_VSTD::next(__first) == __middle)
            return _VSTD::__rotate_left(__first, __last);
        if (_VSTD::next(__middle) == __last)
            return _VSTD::__rotate_right(__first, __last);
    }
    return _VSTD::__rotate_forward(__first, __middle, __last);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
_RandomAccessIterator
__rotate(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last,
         _VSTD::random_access_iterator_tag)
{
    typedef typename _VSTD::iterator_traits<_RandomAccessIterator>::value_type value_type;
    if (_VSTD::is_trivially_move_assignable<value_type>::value)
    {
        if (_VSTD::next(__first) == __middle)
            return _VSTD::__rotate_left(__first, __last);
        if (_VSTD::next(__middle) == __last)
            return _VSTD::__rotate_right(__first, __last);
        return _VSTD::__rotate_gcd(__first, __middle, __last);
    }
    return _VSTD::__rotate_forward(__first, __middle, __last);
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
rotate(_ForwardIterator __first, _ForwardIterator __middle, _ForwardIterator __last)
{
    if (__first == __middle)
        return __last;
    if (__middle == __last)
        return __first;
    return _VSTD::__rotate(__first, __middle, __last,
                           typename _VSTD::iterator_traits<_ForwardIterator>::iterator_category());
}

// rotate_copy

template <class _ForwardIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
rotate_copy(_ForwardIterator __first, _ForwardIterator __middle, _ForwardIterator __last, _OutputIterator __result)
{
    return _VSTD::copy(__first, __middle, _VSTD::copy(__middle, __last, __result));
}

// min_element

template <class _ForwardIterator, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_ForwardIterator
min_element(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
    static_assert(__is_cpp17_forward_iterator<_ForwardIterator>::value,
        "std::min_element requires a ForwardIterator");
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
            if (__comp(*__i, *__first))
                __first = __i;
    }
    return __first;
}

template <class _ForwardIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_ForwardIterator
min_element(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::min_element(__first, __last,
              __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// min

template <class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&
min(const _Tp& __a, const _Tp& __b, _Compare __comp)
{
    return __comp(__b, __a) ? __b : __a;
}

template <class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&
min(const _Tp& __a, const _Tp& __b)
{
    return _VSTD::min(__a, __b, __less<_Tp>());
}

#ifndef _LIBCPP_CXX03_LANG

template<class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp
min(initializer_list<_Tp> __t, _Compare __comp)
{
    return *_VSTD::min_element(__t.begin(), __t.end(), __comp);
}

template<class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp
min(initializer_list<_Tp> __t)
{
    return *_VSTD::min_element(__t.begin(), __t.end(), __less<_Tp>());
}

#endif  // _LIBCPP_CXX03_LANG
# 2586 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

// max_element

template <class _ForwardIterator, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_ForwardIterator
max_element(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
    static_assert(__is_cpp17_forward_iterator<_ForwardIterator>::value,
        "std::max_element requires a ForwardIterator");
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
            if (__comp(*__first, *__i))
                __first = __i;
    }
    return __first;
}


template <class _ForwardIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_ForwardIterator
max_element(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::max_element(__first, __last,
              __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// max

template <class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&
max(const _Tp& __a, const _Tp& __b, _Compare __comp)
{
    return __comp(__a, __b) ? __b : __a;
}

template <class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&
max(const _Tp& __a, const _Tp& __b)
{
    return _VSTD::max(__a, __b, __less<_Tp>());
}

#ifndef _LIBCPP_CXX03_LANG

template<class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp
max(initializer_list<_Tp> __t, _Compare __comp)
{
    return *_VSTD::max_element(__t.begin(), __t.end(), __comp);
}

template<class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp
max(initializer_list<_Tp> __t)
{
    return *_VSTD::max_element(__t.begin(), __t.end(), __less<_Tp>());
}

#endif  // _LIBCPP_CXX03_LANG
# 2659 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2661 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
// clamp
template<class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
const _Tp&
clamp(const _Tp& __v, const _Tp& __lo, const _Tp& __hi, _Compare __comp)
{
    _LIBCPP_ASSERT(!__comp(__hi, __lo), "Bad bounds passed to std::clamp");
    return __comp(__v, __lo) ? __lo : __comp(__hi, __v) ? __hi : __v;

}

template<class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
const _Tp&
clamp(const _Tp& __v, const _Tp& __lo, const _Tp& __hi)
{
    return _VSTD::clamp(__v, __lo, __hi, __less<_Tp>());
}
#endif
# 2682 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

// minmax_element

template <class _ForwardIterator, class _Compare>
_LIBCPP_NODISCARD_EXT _LIBCPP_CONSTEXPR_AFTER_CXX11
std::pair<_ForwardIterator, _ForwardIterator>
minmax_element(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
  static_assert(__is_cpp17_forward_iterator<_ForwardIterator>::value,
        "std::minmax_element requires a ForwardIterator");
  std::pair<_ForwardIterator, _ForwardIterator> __result(__first, __first);
  if (__first != __last)
  {
      if (++__first != __last)
      {
          if (__comp(*__first, *__result.first))
              __result.first = __first;
          else
              __result.second = __first;
          while (++__first != __last)
          {
              _ForwardIterator __i = __first;
              if (++__first == __last)
              {
                  if (__comp(*__i, *__result.first))
                      __result.first = __i;
                  else if (!__comp(*__i, *__result.second))
                      __result.second = __i;
                  break;
              }
              else
              {
                  if (__comp(*__first, *__i))
                  {
                      if (__comp(*__first, *__result.first))
                          __result.first = __first;
                      if (!__comp(*__i, *__result.second))
                          __result.second = __i;
                  }
                  else
                  {
                      if (__comp(*__i, *__result.first))
                          __result.first = __i;
                      if (!__comp(*__first, *__result.second))
                          __result.second = __first;
                  }
              }
          }
      }
  }
  return __result;
}

template <class _ForwardIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
std::pair<_ForwardIterator, _ForwardIterator>
minmax_element(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::minmax_element(__first, __last,
              __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// minmax

template<class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
pair<const _Tp&, const _Tp&>
minmax(const _Tp& __a, const _Tp& __b, _Compare __comp)
{
    return __comp(__b, __a) ? pair<const _Tp&, const _Tp&>(__b, __a) :
                              pair<const _Tp&, const _Tp&>(__a, __b);
}

template<class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
pair<const _Tp&, const _Tp&>
minmax(const _Tp& __a, const _Tp& __b)
{
    return _VSTD::minmax(__a, __b, __less<_Tp>());
}

#ifndef _LIBCPP_CXX03_LANG

template<class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
pair<_Tp, _Tp>
minmax(initializer_list<_Tp> __t, _Compare __comp)
{
    typedef typename initializer_list<_Tp>::const_iterator _Iter;
    _Iter __first = __t.begin();
    _Iter __last  = __t.end();
    std::pair<_Tp, _Tp> __result(*__first, *__first);

    ++__first;
    if (__t.size() % 2 == 0)
    {
        if (__comp(*__first,  __result.first))
            __result.first  = *__first;
        else
            __result.second = *__first;
        ++__first;
    }

    while (__first != __last)
    {
        _Tp __prev = *__first++;
        if (__comp(*__first, __prev)) {
            if ( __comp(*__first, __result.first)) __result.first  = *__first;
            if (!__comp(__prev, __result.second))  __result.second = __prev;
            }
        else {
            if ( __comp(__prev, __result.first))    __result.first  = __prev;
            if (!__comp(*__first, __result.second)) __result.second = *__first;
            }

        __first++;
    }
    return __result;
}

template<class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
pair<_Tp, _Tp>
minmax(initializer_list<_Tp> __t)
{
    return _VSTD::minmax(__t, __less<_Tp>());
}

#endif  // _LIBCPP_CXX03_LANG
# 2816 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

// random_shuffle

// __independent_bits_engine

template <unsigned long long _Xp, size_t _Rp>
struct __log2_imp
{
    static const size_t value = _Xp & ((unsigned long long)(1) << _Rp) ? _Rp
                                           : __log2_imp<_Xp, _Rp - 1>::value;
};

template <unsigned long long _Xp>
struct __log2_imp<_Xp, 0>
{
    static const size_t value = 0;
};

template <size_t _Rp>
struct __log2_imp<0, _Rp>
{
    static const size_t value = _Rp + 1;
};

template <class _UIntType, _UIntType _Xp>
struct __log2
{
    static const size_t value = __log2_imp<_Xp,
                                         sizeof(_UIntType) * __CHAR_BIT__ - 1>::value;
};

template<class _Engine, class _UIntType>
class __independent_bits_engine
{
public:
    // types
    typedef _UIntType result_type;

private:
    typedef typename _Engine::result_type _Engine_result_type;
    typedef typename conditional
        <
            sizeof(_Engine_result_type) <= sizeof(result_type),
                result_type,
                _Engine_result_type
        >::type _Working_result_type;

    _Engine& __e_;
    size_t __w_;
    size_t __w0_;
    size_t __n_;
    size_t __n0_;
    _Working_result_type __y0_;
    _Working_result_type __y1_;
    _Engine_result_type __mask0_;
    _Engine_result_type __mask1_;

#ifdef _LIBCPP_CXX03_LANG
    static const _Working_result_type _Rp = _Engine::_Max - _Engine::_Min
                                          + _Working_result_type(1);
#else
# 2877 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
    static _LIBCPP_CONSTEXPR const _Working_result_type _Rp = _Engine::max() - _Engine::min()
                                                      + _Working_result_type(1);
#endif
# 2880 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
    static _LIBCPP_CONSTEXPR const size_t __m = __log2<_Working_result_type, _Rp>::value;
    static _LIBCPP_CONSTEXPR const size_t _WDt = numeric_limits<_Working_result_type>::digits;
    static _LIBCPP_CONSTEXPR const size_t _EDt = numeric_limits<_Engine_result_type>::digits;

public:
    // constructors and seeding functions
    __independent_bits_engine(_Engine& __e, size_t __w);

    // generating functions
    result_type operator()() {return __eval(integral_constant<bool, _Rp != 0>());}

private:
    result_type __eval(false_type);
    result_type __eval(true_type);
};

template<class _Engine, class _UIntType>
__independent_bits_engine<_Engine, _UIntType>
    ::__independent_bits_engine(_Engine& __e, size_t __w)
        : __e_(__e),
          __w_(__w)
{
    __n_ = __w_ / __m + (__w_ % __m != 0);
    __w0_ = __w_ / __n_;
    if (_Rp == 0)
        __y0_ = _Rp;
    else if (__w0_ < _WDt)
        __y0_ = (_Rp >> __w0_) << __w0_;
    else
        __y0_ = 0;
    if (_Rp - __y0_ > __y0_ / __n_)
    {
        ++__n_;
        __w0_ = __w_ / __n_;
        if (__w0_ < _WDt)
            __y0_ = (_Rp >> __w0_) << __w0_;
        else
            __y0_ = 0;
    }
    __n0_ = __n_ - __w_ % __n_;
    if (__w0_ < _WDt - 1)
        __y1_ = (_Rp >> (__w0_ + 1)) << (__w0_ + 1);
    else
        __y1_ = 0;
    __mask0_ = __w0_ > 0 ? _Engine_result_type(~0) >> (_EDt - __w0_) :
                          _Engine_result_type(0);
    __mask1_ = __w0_ < _EDt - 1 ?
                               _Engine_result_type(~0) >> (_EDt - (__w0_ + 1)) :
                               _Engine_result_type(~0);
}

template<class _Engine, class _UIntType>
inline
_UIntType
__independent_bits_engine<_Engine, _UIntType>::__eval(false_type)
{
    return static_cast<result_type>(__e_() & __mask0_);
}

template<class _Engine, class _UIntType>
_UIntType
__independent_bits_engine<_Engine, _UIntType>::__eval(true_type)
{
    const size_t _WRt = numeric_limits<result_type>::digits;
    result_type _Sp = 0;
    for (size_t __k = 0; __k < __n0_; ++__k)
    {
        _Engine_result_type __u;
        do
        {
            __u = __e_() - _Engine::min();
        } while (__u >= __y0_);
        if (__w0_ < _WRt)
            _Sp <<= __w0_;
        else
            _Sp = 0;
        _Sp += __u & __mask0_;
    }
    for (size_t __k = __n0_; __k < __n_; ++__k)
    {
        _Engine_result_type __u;
        do
        {
            __u = __e_() - _Engine::min();
        } while (__u >= __y1_);
        if (__w0_ < _WRt - 1)
            _Sp <<= __w0_ + 1;
        else
            _Sp = 0;
        _Sp += __u & __mask1_;
    }
    return _Sp;
}

// uniform_int_distribution

template<class _IntType = int>
class uniform_int_distribution
{
public:
    // types
    typedef _IntType result_type;

    class param_type
    {
        result_type __a_;
        result_type __b_;
    public:
        typedef uniform_int_distribution distribution_type;

        explicit param_type(result_type __a = 0,
                            result_type __b = numeric_limits<result_type>::max())
            : __a_(__a), __b_(__b) {}

        result_type a() const {return __a_;}
        result_type b() const {return __b_;}

        friend bool operator==(const param_type& __x, const param_type& __y)
            {return __x.__a_ == __y.__a_ && __x.__b_ == __y.__b_;}
        friend bool operator!=(const param_type& __x, const param_type& __y)
            {return !(__x == __y);}
    };

private:
    param_type __p_;

public:
    // constructors and reset functions
    explicit uniform_int_distribution(result_type __a = 0,
                                      result_type __b = numeric_limits<result_type>::max())
        : __p_(param_type(__a, __b)) {}
    explicit uniform_int_distribution(const param_type& __p) : __p_(__p) {}
    void reset() {}

    // generating functions
    template<class _URNG> result_type operator()(_URNG& __g)
        {return (*this)(__g, __p_);}
    template<class _URNG> result_type operator()(_URNG& __g, const param_type& __p);

    // property functions
    result_type a() const {return __p_.a();}
    result_type b() const {return __p_.b();}

    param_type param() const {return __p_;}
    void param(const param_type& __p) {__p_ = __p;}

    result_type min() const {return a();}
    result_type max() const {return b();}

    friend bool operator==(const uniform_int_distribution& __x,
                           const uniform_int_distribution& __y)
        {return __x.__p_ == __y.__p_;}
    friend bool operator!=(const uniform_int_distribution& __x,
                           const uniform_int_distribution& __y)
            {return !(__x == __y);}
};

template<class _IntType>
template<class _URNG>
typename uniform_int_distribution<_IntType>::result_type
uniform_int_distribution<_IntType>::operator()(_URNG& __g, const param_type& __p)
_LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
{
    typedef typename conditional<sizeof(result_type) <= sizeof(uint32_t),
                                            uint32_t, uint64_t>::type _UIntType;
    const _UIntType _Rp = _UIntType(__p.b()) - _UIntType(__p.a()) + _UIntType(1);
    if (_Rp == 1)
        return __p.a();
    const size_t _Dt = numeric_limits<_UIntType>::digits;
    typedef __independent_bits_engine<_URNG, _UIntType> _Eng;
    if (_Rp == 0)
        return static_cast<result_type>(_Eng(__g, _Dt)());
    size_t __w = _Dt - __libcpp_clz(_Rp) - 1;
    if ((_Rp & (std::numeric_limits<_UIntType>::max() >> (_Dt - __w))) != 0)
        ++__w;
    _Eng __e(__g, __w);
    _UIntType __u;
    do
    {
        __u = __e();
    } while (__u >= _Rp);
    return static_cast<result_type>(__u + __p.a());
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14 || defined(_LIBCPP_ENABLE_CXX17_REMOVED_RANDOM_SHUFFLE) \
  || defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3066 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
class _LIBCPP_TYPE_VIS __rs_default;

_LIBCPP_FUNC_VIS __rs_default __rs_get();

class _LIBCPP_TYPE_VIS __rs_default
{
    static unsigned __c_;

    __rs_default();
public:
    typedef uint_fast32_t result_type;

    static const result_type _Min = 0;
    static const result_type _Max = 0xFFFFFFFF;

    __rs_default(const __rs_default&);
    ~__rs_default();

    result_type operator()();

    static _LIBCPP_CONSTEXPR result_type min() {return _Min;}
    static _LIBCPP_CONSTEXPR result_type max() {return _Max;}

    friend _LIBCPP_FUNC_VIS __rs_default __rs_get();
};

_LIBCPP_FUNC_VIS __rs_default __rs_get();

template <class _RandomAccessIterator>
_LIBCPP_DEPRECATED_IN_CXX14 void
random_shuffle(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef uniform_int_distribution<ptrdiff_t> _Dp;
    typedef typename _Dp::param_type _Pp;
    difference_type __d = __last - __first;
    if (__d > 1)
    {
        _Dp __uid;
        __rs_default __g = __rs_get();
        for (--__last, (void) --__d; __first < __last; ++__first, (void) --__d)
        {
            difference_type __i = __uid(__g, _Pp(0, __d));
            if (__i != difference_type(0))
                swap(*__first, *(__first + __i));
        }
    }
}

template <class _RandomAccessIterator, class _RandomNumberGenerator>
_LIBCPP_DEPRECATED_IN_CXX14 void
random_shuffle(_RandomAccessIterator __first, _RandomAccessIterator __last,
#ifndef _LIBCPP_CXX03_LANG
               _RandomNumberGenerator&& __rand)
#else
# 3121 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
               _RandomNumberGenerator& __rand)
#endif
# 3123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    difference_type __d = __last - __first;
    if (__d > 1)
    {
        for (--__last; __first < __last; ++__first, (void) --__d)
        {
            difference_type __i = __rand(__d);
            if (__i != difference_type(0))
              swap(*__first, *(__first + __i));
        }
    }
}
#endif
# 3137 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

template <class _PopulationIterator, class _SampleIterator, class _Distance,
          class _UniformRandomNumberGenerator>
_LIBCPP_INLINE_VISIBILITY
_SampleIterator __sample(_PopulationIterator __first,
                         _PopulationIterator __last, _SampleIterator __output_iter,
                         _Distance __n,
                         _UniformRandomNumberGenerator & __g,
                         input_iterator_tag) {

  _Distance __k = 0;
  for (; __first != __last && __k < __n; ++__first, (void) ++__k)
    __output_iter[__k] = *__first;
  _Distance __sz = __k;
  for (; __first != __last; ++__first, (void) ++__k) {
    _Distance __r = _VSTD::uniform_int_distribution<_Distance>(0, __k)(__g);
    if (__r < __sz)
      __output_iter[__r] = *__first;
  }
  return __output_iter + _VSTD::min(__n, __k);
}

template <class _PopulationIterator, class _SampleIterator, class _Distance,
          class _UniformRandomNumberGenerator>
_LIBCPP_INLINE_VISIBILITY
_SampleIterator __sample(_PopulationIterator __first,
                         _PopulationIterator __last, _SampleIterator __output_iter,
                         _Distance __n,
                         _UniformRandomNumberGenerator& __g,
                         forward_iterator_tag) {
  _Distance __unsampled_sz = _VSTD::distance(__first, __last);
  for (__n = _VSTD::min(__n, __unsampled_sz); __n != 0; ++__first) {
    _Distance __r =
        _VSTD::uniform_int_distribution<_Distance>(0, --__unsampled_sz)(__g);
    if (__r < __n) {
      *__output_iter++ = *__first;
      --__n;
    }
  }
  return __output_iter;
}

template <class _PopulationIterator, class _SampleIterator, class _Distance,
          class _UniformRandomNumberGenerator>
_LIBCPP_INLINE_VISIBILITY
_SampleIterator __sample(_PopulationIterator __first,
                         _PopulationIterator __last, _SampleIterator __output_iter,
                         _Distance __n, _UniformRandomNumberGenerator& __g) {
  typedef typename iterator_traits<_PopulationIterator>::iterator_category
        _PopCategory;
  typedef typename iterator_traits<_PopulationIterator>::difference_type
        _Difference;
  static_assert(__is_cpp17_forward_iterator<_PopulationIterator>::value ||
                __is_cpp17_random_access_iterator<_SampleIterator>::value,
                "SampleIterator must meet the requirements of RandomAccessIterator");
  typedef typename common_type<_Distance, _Difference>::type _CommonType;
  _LIBCPP_ASSERT(__n >= 0, "N must be a positive number.");
  return _VSTD::__sample(
      __first, __last, __output_iter, _CommonType(__n),
      __g, _PopCategory());
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3200 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
template <class _PopulationIterator, class _SampleIterator, class _Distance,
          class _UniformRandomNumberGenerator>
inline _LIBCPP_INLINE_VISIBILITY
_SampleIterator sample(_PopulationIterator __first,
                       _PopulationIterator __last, _SampleIterator __output_iter,
                       _Distance __n, _UniformRandomNumberGenerator&& __g) {
    return _VSTD::__sample(__first, __last, __output_iter, __n, __g);
}
#endif // _LIBCPP_STD_VER > 14
# 3209 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

template<class _RandomAccessIterator, class _UniformRandomNumberGenerator>
    void shuffle(_RandomAccessIterator __first, _RandomAccessIterator __last,
                 _UniformRandomNumberGenerator&& __g)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef uniform_int_distribution<ptrdiff_t> _Dp;
    typedef typename _Dp::param_type _Pp;
    difference_type __d = __last - __first;
    if (__d > 1)
    {
        _Dp __uid;
        for (--__last, (void) --__d; __first < __last; ++__first, (void) --__d)
        {
            difference_type __i = __uid(__g, _Pp(0, __d));
            if (__i != difference_type(0))
                swap(*__first, *(__first + __i));
        }
    }
}

template <class _InputIterator, class _Predicate>
_LIBCPP_NODISCARD_EXT _LIBCPP_CONSTEXPR_AFTER_CXX17 bool
is_partitioned(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (!__pred(*__first))
            break;
    if ( __first == __last )
        return true;
    ++__first;
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            return false;
    return true;
}

// partition

template <class _Predicate, class _ForwardIterator>
_ForwardIterator
__partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred, forward_iterator_tag)
{
    while (true)
    {
        if (__first == __last)
            return __first;
        if (!__pred(*__first))
            break;
        ++__first;
    }
    for (_ForwardIterator __p = __first; ++__p != __last;)
    {
        if (__pred(*__p))
        {
            swap(*__first, *__p);
            ++__first;
        }
    }
    return __first;
}

template <class _Predicate, class _BidirectionalIterator>
_BidirectionalIterator
__partition(_BidirectionalIterator __first, _BidirectionalIterator __last, _Predicate __pred,
            bidirectional_iterator_tag)
{
    while (true)
    {
        while (true)
        {
            if (__first == __last)
                return __first;
            if (!__pred(*__first))
                break;
            ++__first;
        }
        do
        {
            if (__first == --__last)
                return __first;
        } while (!__pred(*__last));
        swap(*__first, *__last);
        ++__first;
    }
}

template <class _ForwardIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred)
{
    return _VSTD::__partition<typename add_lvalue_reference<_Predicate>::type>
                            (__first, __last, __pred, typename iterator_traits<_ForwardIterator>::iterator_category());
}

// partition_copy

template <class _InputIterator, class _OutputIterator1,
          class _OutputIterator2, class _Predicate>
_LIBCPP_CONSTEXPR_AFTER_CXX17 pair<_OutputIterator1, _OutputIterator2>
partition_copy(_InputIterator __first, _InputIterator __last,
               _OutputIterator1 __out_true, _OutputIterator2 __out_false,
               _Predicate __pred)
{
    for (; __first != __last; ++__first)
    {
        if (__pred(*__first))
        {
            *__out_true = *__first;
            ++__out_true;
        }
        else
        {
            *__out_false = *__first;
            ++__out_false;
        }
    }
    return pair<_OutputIterator1, _OutputIterator2>(__out_true, __out_false);
}

// partition_point

template<class _ForwardIterator, class _Predicate>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
partition_point(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred)
{
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    difference_type __len = _VSTD::distance(__first, __last);
    while (__len != 0)
    {
        difference_type __l2 = _VSTD::__half_positive(__len);
        _ForwardIterator __m = __first;
        _VSTD::advance(__m, __l2);
        if (__pred(*__m))
        {
            __first = ++__m;
            __len -= __l2 + 1;
        }
        else
            __len = __l2;
    }
    return __first;
}

// stable_partition

template <class _Predicate, class _ForwardIterator, class _Distance, class _Pair>
_ForwardIterator
__stable_partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred,
                   _Distance __len, _Pair __p, forward_iterator_tag __fit)
{
    // *__first is known to be false
    // __len >= 1
    if (__len == 1)
        return __first;
    if (__len == 2)
    {
        _ForwardIterator __m = __first;
        if (__pred(*++__m))
        {
            swap(*__first, *__m);
            return __m;
        }
        return __first;
    }
    if (__len <= __p.second)
    {   // The buffer is big enough to use
        typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h(__p.first, __d);
        // Move the falses into the temporary buffer, and the trues to the front of the line
        // Update __first to always point to the end of the trues
        value_type* __t = __p.first;
        ::new(__t) value_type(_VSTD::move(*__first));
        __d.__incr((value_type*)0);
        ++__t;
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (__pred(*__i))
            {
                *__first = _VSTD::move(*__i);
                ++__first;
            }
            else
            {
                ::new(__t) value_type(_VSTD::move(*__i));
                __d.__incr((value_type*)0);
                ++__t;
            }
        }
        // All trues now at start of range, all falses in buffer
        // Move falses back into range, but don't mess up __first which points to first false
        __i = __first;
        for (value_type* __t2 = __p.first; __t2 < __t; ++__t2, (void) ++__i)
            *__i = _VSTD::move(*__t2);
        // __h destructs moved-from values out of the temp buffer, but doesn't deallocate buffer
        return __first;
    }
    // Else not enough buffer, do in place
    // __len >= 3
    _ForwardIterator __m = __first;
    _Distance __len2 = __len / 2;  // __len2 >= 2
    _VSTD::advance(__m, __len2);
    // recurse on [__first, __m), *__first know to be false
    // F?????????????????
    // f       m         l
    typedef typename add_lvalue_reference<_Predicate>::type _PredRef;
    _ForwardIterator __first_false = __stable_partition<_PredRef>(__first, __m, __pred, __len2, __p, __fit);
    // TTTFFFFF??????????
    // f  ff   m         l
    // recurse on [__m, __last], except increase __m until *(__m) is false, *__last know to be true
    _ForwardIterator __m1 = __m;
    _ForwardIterator __second_false = __last;
    _Distance __len_half = __len - __len2;
    while (__pred(*__m1))
    {
        if (++__m1 == __last)
            goto __second_half_done;
        --__len_half;
    }
    // TTTFFFFFTTTF??????
    // f  ff   m  m1     l
    __second_false = __stable_partition<_PredRef>(__m1, __last, __pred, __len_half, __p, __fit);
__second_half_done:
    // TTTFFFFFTTTTTFFFFF
    // f  ff   m    sf   l
    return _VSTD::rotate(__first_false, __m, __second_false);
    // TTTTTTTTFFFFFFFFFF
    //         |
}

struct __return_temporary_buffer
{
    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void operator()(_Tp* __p) const {_VSTD::return_temporary_buffer(__p);}
};

template <class _Predicate, class _ForwardIterator>
_ForwardIterator
__stable_partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred,
                   forward_iterator_tag)
{
    const unsigned __alloc_limit = 3;  // might want to make this a function of trivial assignment
    // Either prove all true and return __first or point to first false
    while (true)
    {
        if (__first == __last)
            return __first;
        if (!__pred(*__first))
            break;
        ++__first;
    }
    // We now have a reduced range [__first, __last)
    // *__first is known to be false
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
    difference_type __len = _VSTD::distance(__first, __last);
    pair<value_type*, ptrdiff_t> __p(0, 0);
    unique_ptr<value_type, __return_temporary_buffer> __h;
    if (__len >= __alloc_limit)
    {
        __p = _VSTD::get_temporary_buffer<value_type>(__len);
        __h.reset(__p.first);
    }
    return __stable_partition<typename add_lvalue_reference<_Predicate>::type>
                             (__first, __last, __pred, __len, __p, forward_iterator_tag());
}

template <class _Predicate, class _BidirectionalIterator, class _Distance, class _Pair>
_BidirectionalIterator
__stable_partition(_BidirectionalIterator __first, _BidirectionalIterator __last, _Predicate __pred,
                   _Distance __len, _Pair __p, bidirectional_iterator_tag __bit)
{
    // *__first is known to be false
    // *__last is known to be true
    // __len >= 2
    if (__len == 2)
    {
        swap(*__first, *__last);
        return __last;
    }
    if (__len == 3)
    {
        _BidirectionalIterator __m = __first;
        if (__pred(*++__m))
        {
            swap(*__first, *__m);
            swap(*__m, *__last);
            return __last;
        }
        swap(*__m, *__last);
        swap(*__first, *__m);
        return __m;
    }
    if (__len <= __p.second)
    {   // The buffer is big enough to use
        typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h(__p.first, __d);
        // Move the falses into the temporary buffer, and the trues to the front of the line
        // Update __first to always point to the end of the trues
        value_type* __t = __p.first;
        ::new(__t) value_type(_VSTD::move(*__first));
        __d.__incr((value_type*)0);
        ++__t;
        _BidirectionalIterator __i = __first;
        while (++__i != __last)
        {
            if (__pred(*__i))
            {
                *__first = _VSTD::move(*__i);
                ++__first;
            }
            else
            {
                ::new(__t) value_type(_VSTD::move(*__i));
                __d.__incr((value_type*)0);
                ++__t;
            }
        }
        // move *__last, known to be true
        *__first = _VSTD::move(*__i);
        __i = ++__first;
        // All trues now at start of range, all falses in buffer
        // Move falses back into range, but don't mess up __first which points to first false
        for (value_type* __t2 = __p.first; __t2 < __t; ++__t2, (void) ++__i)
            *__i = _VSTD::move(*__t2);
        // __h destructs moved-from values out of the temp buffer, but doesn't deallocate buffer
        return __first;
    }
    // Else not enough buffer, do in place
    // __len >= 4
    _BidirectionalIterator __m = __first;
    _Distance __len2 = __len / 2;  // __len2 >= 2
    _VSTD::advance(__m, __len2);
    // recurse on [__first, __m-1], except reduce __m-1 until *(__m-1) is true, *__first know to be false
    // F????????????????T
    // f       m        l
    _BidirectionalIterator __m1 = __m;
    _BidirectionalIterator __first_false = __first;
    _Distance __len_half = __len2;
    while (!__pred(*--__m1))
    {
        if (__m1 == __first)
            goto __first_half_done;
        --__len_half;
    }
    // F???TFFF?????????T
    // f   m1  m        l
    typedef typename add_lvalue_reference<_Predicate>::type _PredRef;
    __first_false = __stable_partition<_PredRef>(__first, __m1, __pred, __len_half, __p, __bit);
__first_half_done:
    // TTTFFFFF?????????T
    // f  ff   m        l
    // recurse on [__m, __last], except increase __m until *(__m) is false, *__last know to be true
    __m1 = __m;
    _BidirectionalIterator __second_false = __last;
    ++__second_false;
    __len_half = __len - __len2;
    while (__pred(*__m1))
    {
        if (++__m1 == __last)
            goto __second_half_done;
        --__len_half;
    }
    // TTTFFFFFTTTF?????T
    // f  ff   m  m1    l
    __second_false = __stable_partition<_PredRef>(__m1, __last, __pred, __len_half, __p, __bit);
__second_half_done:
    // TTTFFFFFTTTTTFFFFF
    // f  ff   m    sf  l
    return _VSTD::rotate(__first_false, __m, __second_false);
    // TTTTTTTTFFFFFFFFFF
    //         |
}

template <class _Predicate, class _BidirectionalIterator>
_BidirectionalIterator
__stable_partition(_BidirectionalIterator __first, _BidirectionalIterator __last, _Predicate __pred,
                   bidirectional_iterator_tag)
{
    typedef typename iterator_traits<_BidirectionalIterator>::difference_type difference_type;
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    const difference_type __alloc_limit = 4;  // might want to make this a function of trivial assignment
    // Either prove all true and return __first or point to first false
    while (true)
    {
        if (__first == __last)
            return __first;
        if (!__pred(*__first))
            break;
        ++__first;
    }
    // __first points to first false, everything prior to __first is already set.
    // Either prove [__first, __last) is all false and return __first, or point __last to last true
    do
    {
        if (__first == --__last)
            return __first;
    } while (!__pred(*__last));
    // We now have a reduced range [__first, __last]
    // *__first is known to be false
    // *__last is known to be true
    // __len >= 2
    difference_type __len = _VSTD::distance(__first, __last) + 1;
    pair<value_type*, ptrdiff_t> __p(0, 0);
    unique_ptr<value_type, __return_temporary_buffer> __h;
    if (__len >= __alloc_limit)
    {
        __p = _VSTD::get_temporary_buffer<value_type>(__len);
        __h.reset(__p.first);
    }
    return __stable_partition<typename add_lvalue_reference<_Predicate>::type>
                             (__first, __last, __pred, __len, __p, bidirectional_iterator_tag());
}

template <class _ForwardIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
stable_partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred)
{
    return __stable_partition<typename add_lvalue_reference<_Predicate>::type>
                             (__first, __last, __pred, typename iterator_traits<_ForwardIterator>::iterator_category());
}

// is_sorted_until

template <class _ForwardIterator, class _Compare>
_LIBCPP_NODISCARD_EXT _LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
is_sorted_until(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (__comp(*__i, *__first))
                return __i;
            __first = __i;
        }
    }
    return __last;
}

template<class _ForwardIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
is_sorted_until(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::is_sorted_until(__first, __last, __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// is_sorted

template <class _ForwardIterator, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
is_sorted(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
    return _VSTD::is_sorted_until(__first, __last, __comp) == __last;
}

template<class _ForwardIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
is_sorted(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::is_sorted(__first, __last, __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// sort

// stable, 2-3 compares, 0-2 swaps

template <class _Compare, class _ForwardIterator>
unsigned
__sort3(_ForwardIterator __x, _ForwardIterator __y, _ForwardIterator __z, _Compare __c)
{
    unsigned __r = 0;
    if (!__c(*__y, *__x))          // if x <= y
    {
        if (!__c(*__z, *__y))      // if y <= z
            return __r;            // x <= y && y <= z
                                   // x <= y && y > z
        swap(*__y, *__z);          // x <= z && y < z
        __r = 1;
        if (__c(*__y, *__x))       // if x > y
        {
            swap(*__x, *__y);      // x < y && y <= z
            __r = 2;
        }
        return __r;                // x <= y && y < z
    }
    if (__c(*__z, *__y))           // x > y, if y > z
    {
        swap(*__x, *__z);          // x < y && y < z
        __r = 1;
        return __r;
    }
    swap(*__x, *__y);              // x > y && y <= z
    __r = 1;                       // x < y && x <= z
    if (__c(*__z, *__y))           // if y > z
    {
        swap(*__y, *__z);          // x <= y && y < z
        __r = 2;
    }
    return __r;
}                                  // x <= y && y <= z

// stable, 3-6 compares, 0-5 swaps

template <class _Compare, class _ForwardIterator>
unsigned
__sort4(_ForwardIterator __x1, _ForwardIterator __x2, _ForwardIterator __x3,
            _ForwardIterator __x4, _Compare __c)
{
    unsigned __r = __sort3<_Compare>(__x1, __x2, __x3, __c);
    if (__c(*__x4, *__x3))
    {
        swap(*__x3, *__x4);
        ++__r;
        if (__c(*__x3, *__x2))
        {
            swap(*__x2, *__x3);
            ++__r;
            if (__c(*__x2, *__x1))
            {
                swap(*__x1, *__x2);
                ++__r;
            }
        }
    }
    return __r;
}

// stable, 4-10 compares, 0-9 swaps

template <class _Compare, class _ForwardIterator>
_LIBCPP_HIDDEN
unsigned
__sort5(_ForwardIterator __x1, _ForwardIterator __x2, _ForwardIterator __x3,
            _ForwardIterator __x4, _ForwardIterator __x5, _Compare __c)
{
    unsigned __r = __sort4<_Compare>(__x1, __x2, __x3, __x4, __c);
    if (__c(*__x5, *__x4))
    {
        swap(*__x4, *__x5);
        ++__r;
        if (__c(*__x4, *__x3))
        {
            swap(*__x3, *__x4);
            ++__r;
            if (__c(*__x3, *__x2))
            {
                swap(*__x2, *__x3);
                ++__r;
                if (__c(*__x2, *__x1))
                {
                    swap(*__x1, *__x2);
                    ++__r;
                }
            }
        }
    }
    return __r;
}

// Assumes size > 0
template <class _Compare, class _BirdirectionalIterator>
void
__selection_sort(_BirdirectionalIterator __first, _BirdirectionalIterator __last, _Compare __comp)
{
    _BirdirectionalIterator __lm1 = __last;
    for (--__lm1; __first != __lm1; ++__first)
    {
        _BirdirectionalIterator __i = _VSTD::min_element<_BirdirectionalIterator,
                                                        typename add_lvalue_reference<_Compare>::type>
                                                       (__first, __last, __comp);
        if (__i != __first)
            swap(*__first, *__i);
    }
}

template <class _Compare, class _BirdirectionalIterator>
void
__insertion_sort(_BirdirectionalIterator __first, _BirdirectionalIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_BirdirectionalIterator>::value_type value_type;
    if (__first != __last)
    {
        _BirdirectionalIterator __i = __first;
        for (++__i; __i != __last; ++__i)
        {
            _BirdirectionalIterator __j = __i;
            value_type __t(_VSTD::move(*__j));
            for (_BirdirectionalIterator __k = __i; __k != __first && __comp(__t,  *--__k); --__j)
                *__j = _VSTD::move(*__k);
            *__j = _VSTD::move(__t);
        }
    }
}

template <class _Compare, class _RandomAccessIterator>
void
__insertion_sort_3(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    _RandomAccessIterator __j = __first+2;
    __sort3<_Compare>(__first, __first+1, __j, __comp);
    for (_RandomAccessIterator __i = __j+1; __i != __last; ++__i)
    {
        if (__comp(*__i, *__j))
        {
            value_type __t(_VSTD::move(*__i));
            _RandomAccessIterator __k = __j;
            __j = __i;
            do
            {
                *__j = _VSTD::move(*__k);
                __j = __k;
            } while (__j != __first && __comp(__t, *--__k));
            *__j = _VSTD::move(__t);
        }
        __j = __i;
    }
}

template <class _Compare, class _RandomAccessIterator>
bool
__insertion_sort_incomplete(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    switch (__last - __first)
    {
    case 0:
    case 1:
        return true;
    case 2:
        if (__comp(*--__last, *__first))
            swap(*__first, *__last);
        return true;
    case 3:
        _VSTD::__sort3<_Compare>(__first, __first+1, --__last, __comp);
        return true;
    case 4:
        _VSTD::__sort4<_Compare>(__first, __first+1, __first+2, --__last, __comp);
        return true;
    case 5:
        _VSTD::__sort5<_Compare>(__first, __first+1, __first+2, __first+3, --__last, __comp);
        return true;
    }
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    _RandomAccessIterator __j = __first+2;
    __sort3<_Compare>(__first, __first+1, __j, __comp);
    const unsigned __limit = 8;
    unsigned __count = 0;
    for (_RandomAccessIterator __i = __j+1; __i != __last; ++__i)
    {
        if (__comp(*__i, *__j))
        {
            value_type __t(_VSTD::move(*__i));
            _RandomAccessIterator __k = __j;
            __j = __i;
            do
            {
                *__j = _VSTD::move(*__k);
                __j = __k;
            } while (__j != __first && __comp(__t, *--__k));
            *__j = _VSTD::move(__t);
            if (++__count == __limit)
                return ++__i == __last;
        }
        __j = __i;
    }
    return true;
}

template <class _Compare, class _BirdirectionalIterator>
void
__insertion_sort_move(_BirdirectionalIterator __first1, _BirdirectionalIterator __last1,
                      typename iterator_traits<_BirdirectionalIterator>::value_type* __first2, _Compare __comp)
{
    typedef typename iterator_traits<_BirdirectionalIterator>::value_type value_type;
    if (__first1 != __last1)
    {
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h(__first2, __d);
        value_type* __last2 = __first2;
        ::new(__last2) value_type(_VSTD::move(*__first1));
        __d.__incr((value_type*)0);
        for (++__last2; ++__first1 != __last1; ++__last2)
        {
            value_type* __j2 = __last2;
            value_type* __i2 = __j2;
            if (__comp(*__first1, *--__i2))
            {
                ::new(__j2) value_type(_VSTD::move(*__i2));
                __d.__incr((value_type*)0);
                for (--__j2; __i2 != __first2 && __comp(*__first1,  *--__i2); --__j2)
                    *__j2 = _VSTD::move(*__i2);
                *__j2 = _VSTD::move(*__first1);
            }
            else
            {
                ::new(__j2) value_type(_VSTD::move(*__first1));
                __d.__incr((value_type*)0);
            }
        }
        __h.release();
    }
}

template <class _Compare, class _RandomAccessIterator>
void
__sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    // _Compare is known to be a reference type
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    const difference_type __limit = is_trivially_copy_constructible<value_type>::value &&
                                    is_trivially_copy_assignable<value_type>::value ? 30 : 6;
    while (true)
    {
    __restart:
        difference_type __len = __last - __first;
        switch (__len)
        {
        case 0:
        case 1:
            return;
        case 2:
            if (__comp(*--__last, *__first))
                swap(*__first, *__last);
            return;
        case 3:
            _VSTD::__sort3<_Compare>(__first, __first+1, --__last, __comp);
            return;
        case 4:
            _VSTD::__sort4<_Compare>(__first, __first+1, __first+2, --__last, __comp);
            return;
        case 5:
            _VSTD::__sort5<_Compare>(__first, __first+1, __first+2, __first+3, --__last, __comp);
            return;
        }
        if (__len <= __limit)
        {
            _VSTD::__insertion_sort_3<_Compare>(__first, __last, __comp);
            return;
        }
        // __len > 5
        _RandomAccessIterator __m = __first;
        _RandomAccessIterator __lm1 = __last;
        --__lm1;
        unsigned __n_swaps;
        {
        difference_type __delta;
        if (__len >= 1000)
        {
            __delta = __len/2;
            __m += __delta;
            __delta /= 2;
            __n_swaps = _VSTD::__sort5<_Compare>(__first, __first + __delta, __m, __m+__delta, __lm1, __comp);
        }
        else
        {
            __delta = __len/2;
            __m += __delta;
            __n_swaps = _VSTD::__sort3<_Compare>(__first, __m, __lm1, __comp);
        }
        }
        // *__m is median
        // partition [__first, __m) < *__m and *__m <= [__m, __last)
        // (this inhibits tossing elements equivalent to __m around unnecessarily)
        _RandomAccessIterator __i = __first;
        _RandomAccessIterator __j = __lm1;
        // j points beyond range to be tested, *__m is known to be <= *__lm1
        // The search going up is known to be guarded but the search coming down isn't.
        // Prime the downward search with a guard.
        if (!__comp(*__i, *__m))  // if *__first == *__m
        {
            // *__first == *__m, *__first doesn't go in first part
            // manually guard downward moving __j against __i
            while (true)
            {
                if (__i == --__j)
                {
                    // *__first == *__m, *__m <= all other elements
                    // Parition instead into [__first, __i) == *__first and *__first < [__i, __last)
                    ++__i;  // __first + 1
                    __j = __last;
                    if (!__comp(*__first, *--__j))  // we need a guard if *__first == *(__last-1)
                    {
                        while (true)
                        {
                            if (__i == __j)
                                return;  // [__first, __last) all equivalent elements
                            if (__comp(*__first, *__i))
                            {
                                swap(*__i, *__j);
                                ++__n_swaps;
                                ++__i;
                                break;
                            }
                            ++__i;
                        }
                    }
                    // [__first, __i) == *__first and *__first < [__j, __last) and __j == __last - 1
                    if (__i == __j)
                        return;
                    while (true)
                    {
                        while (!__comp(*__first, *__i))
                            ++__i;
                        while (__comp(*__first, *--__j))
                            ;
                        if (__i >= __j)
                            break;
                        swap(*__i, *__j);
                        ++__n_swaps;
                        ++__i;
                    }
                    // [__first, __i) == *__first and *__first < [__i, __last)
                    // The first part is sorted, sort the secod part
                    // _VSTD::__sort<_Compare>(__i, __last, __comp);
                    __first = __i;
                    goto __restart;
                }
                if (__comp(*__j, *__m))
                {
                    swap(*__i, *__j);
                    ++__n_swaps;
                    break;  // found guard for downward moving __j, now use unguarded partition
                }
            }
        }
        // It is known that *__i < *__m
        ++__i;
        // j points beyond range to be tested, *__m is known to be <= *__lm1
        // if not yet partitioned...
        if (__i < __j)
        {
            // known that *(__i - 1) < *__m
            // known that __i <= __m
            while (true)
            {
                // __m still guards upward moving __i
                while (__comp(*__i, *__m))
                    ++__i;
                // It is now known that a guard exists for downward moving __j
                while (!__comp(*--__j, *__m))
                    ;
                if (__i > __j)
                    break;
                swap(*__i, *__j);
                ++__n_swaps;
                // It is known that __m != __j
                // If __m just moved, follow it
                if (__m == __i)
                    __m = __j;
                ++__i;
            }
        }
        // [__first, __i) < *__m and *__m <= [__i, __last)
        if (__i != __m && __comp(*__m, *__i))
        {
            swap(*__i, *__m);
            ++__n_swaps;
        }
        // [__first, __i) < *__i and *__i <= [__i+1, __last)
        // If we were given a perfect partition, see if insertion sort is quick...
        if (__n_swaps == 0)
        {
            bool __fs = _VSTD::__insertion_sort_incomplete<_Compare>(__first, __i, __comp);
            if (_VSTD::__insertion_sort_incomplete<_Compare>(__i+1, __last, __comp))
            {
                if (__fs)
                    return;
                __last = __i;
                continue;
            }
            else
            {
                if (__fs)
                {
                    __first = ++__i;
                    continue;
                }
            }
        }
        // sort smaller range with recursive call and larger with tail recursion elimination
        if (__i - __first < __last - __i)
        {
            _VSTD::__sort<_Compare>(__first, __i, __comp);
            // _VSTD::__sort<_Compare>(__i+1, __last, __comp);
            __first = ++__i;
        }
        else
        {
            _VSTD::__sort<_Compare>(__i+1, __last, __comp);
            // _VSTD::__sort<_Compare>(__first, __i, __comp);
            __last = __i;
        }
    }
}

// This forwarder keeps the top call and the recursive calls using the same instantiation, forcing a reference _Compare
template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    _VSTD::__sort<_Comp_ref>(__first, __last, _Comp_ref(__comp));
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::sort(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(_Tp** __first, _Tp** __last)
{
    _VSTD::sort((size_t*)__first, (size_t*)__last, __less<size_t>());
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(__wrap_iter<_Tp*> __first, __wrap_iter<_Tp*> __last)
{
    _VSTD::sort(__first.base(), __last.base());
}

template <class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(__wrap_iter<_Tp*> __first, __wrap_iter<_Tp*> __last, _Compare __comp)
{
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    _VSTD::sort<_Tp*, _Comp_ref>(__first.base(), __last.base(), __comp);
}

_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<char>&, char*>(char*, char*, __less<char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<wchar_t>&, wchar_t*>(wchar_t*, wchar_t*, __less<wchar_t>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<signed char>&, signed char*>(signed char*, signed char*, __less<signed char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned char>&, unsigned char*>(unsigned char*, unsigned char*, __less<unsigned char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<short>&, short*>(short*, short*, __less<short>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned short>&, unsigned short*>(unsigned short*, unsigned short*, __less<unsigned short>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<int>&, int*>(int*, int*, __less<int>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned>&, unsigned*>(unsigned*, unsigned*, __less<unsigned>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<long>&, long*>(long*, long*, __less<long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned long>&, unsigned long*>(unsigned long*, unsigned long*, __less<unsigned long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<long long>&, long long*>(long long*, long long*, __less<long long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned long long>&, unsigned long long*>(unsigned long long*, unsigned long long*, __less<unsigned long long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<float>&, float*>(float*, float*, __less<float>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<double>&, double*>(double*, double*, __less<double>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<long double>&, long double*>(long double*, long double*, __less<long double>&))

_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<char>&, char*>(char*, char*, __less<char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<wchar_t>&, wchar_t*>(wchar_t*, wchar_t*, __less<wchar_t>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<signed char>&, signed char*>(signed char*, signed char*, __less<signed char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned char>&, unsigned char*>(unsigned char*, unsigned char*, __less<unsigned char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<short>&, short*>(short*, short*, __less<short>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned short>&, unsigned short*>(unsigned short*, unsigned short*, __less<unsigned short>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<int>&, int*>(int*, int*, __less<int>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned>&, unsigned*>(unsigned*, unsigned*, __less<unsigned>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<long>&, long*>(long*, long*, __less<long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned long>&, unsigned long*>(unsigned long*, unsigned long*, __less<unsigned long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<long long>&, long long*>(long long*, long long*, __less<long long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned long long>&, unsigned long long*>(unsigned long long*, unsigned long long*, __less<unsigned long long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<float>&, float*>(float*, float*, __less<float>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<double>&, double*>(double*, double*, __less<double>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<long double>&, long double*>(long double*, long double*, __less<long double>&))

_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS unsigned __sort5<__less<long double>&, long double*>(long double*, long double*, long double*, long double*, long double*, __less<long double>&))

// lower_bound

template <class _Compare, class _ForwardIterator, class _Tp>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
__lower_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    difference_type __len = _VSTD::distance(__first, __last);
    while (__len != 0)
    {
        difference_type __l2 = _VSTD::__half_positive(__len);
        _ForwardIterator __m = __first;
        _VSTD::advance(__m, __l2);
        if (__comp(*__m, __value_))
        {
            __first = ++__m;
            __len -= __l2 + 1;
        }
        else
            __len = __l2;
    }
    return __first;
}

template <class _ForwardIterator, class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
lower_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __lower_bound<_Comp_ref>(__first, __last, __value_, __comp);
}

template <class _ForwardIterator, class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
lower_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    return _VSTD::lower_bound(__first, __last, __value_,
                             __less<typename iterator_traits<_ForwardIterator>::value_type, _Tp>());
}

// upper_bound

template <class _Compare, class _ForwardIterator, class _Tp>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _ForwardIterator
__upper_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    difference_type __len = _VSTD::distance(__first, __last);
    while (__len != 0)
    {
        difference_type __l2 = _VSTD::__half_positive(__len);
        _ForwardIterator __m = __first;
        _VSTD::advance(__m, __l2);
        if (__comp(__value_, *__m))
            __len = __l2;
        else
        {
            __first = ++__m;
            __len -= __l2 + 1;
        }
    }
    return __first;
}

template <class _ForwardIterator, class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
upper_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __upper_bound<_Comp_ref>(__first, __last, __value_, __comp);
}

template <class _ForwardIterator, class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_ForwardIterator
upper_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    return _VSTD::upper_bound(__first, __last, __value_,
                             __less<_Tp, typename iterator_traits<_ForwardIterator>::value_type>());
}

// equal_range

template <class _Compare, class _ForwardIterator, class _Tp>
_LIBCPP_CONSTEXPR_AFTER_CXX17 pair<_ForwardIterator, _ForwardIterator>
__equal_range(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    difference_type __len = _VSTD::distance(__first, __last);
    while (__len != 0)
    {
        difference_type __l2 = _VSTD::__half_positive(__len);
        _ForwardIterator __m = __first;
        _VSTD::advance(__m, __l2);
        if (__comp(*__m, __value_))
        {
            __first = ++__m;
            __len -= __l2 + 1;
        }
        else if (__comp(__value_, *__m))
        {
            __last = __m;
            __len = __l2;
        }
        else
        {
            _ForwardIterator __mp1 = __m;
            return pair<_ForwardIterator, _ForwardIterator>
                   (
                      __lower_bound<_Compare>(__first, __m, __value_, __comp),
                      __upper_bound<_Compare>(++__mp1, __last, __value_, __comp)
                   );
        }
    }
    return pair<_ForwardIterator, _ForwardIterator>(__first, __first);
}

template <class _ForwardIterator, class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
pair<_ForwardIterator, _ForwardIterator>
equal_range(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __equal_range<_Comp_ref>(__first, __last, __value_, __comp);
}

template <class _ForwardIterator, class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
pair<_ForwardIterator, _ForwardIterator>
equal_range(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    return _VSTD::equal_range(__first, __last, __value_,
                             __less<typename iterator_traits<_ForwardIterator>::value_type, _Tp>());
}

// binary_search

template <class _Compare, class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
__binary_search(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    __first = __lower_bound<_Compare>(__first, __last, __value_, __comp);
    return __first != __last && !__comp(__value_, *__first);
}

template <class _ForwardIterator, class _Tp, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
binary_search(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __binary_search<_Comp_ref>(__first, __last, __value_, __comp);
}

template <class _ForwardIterator, class _Tp>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
binary_search(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    return _VSTD::binary_search(__first, __last, __value_,
                             __less<typename iterator_traits<_ForwardIterator>::value_type, _Tp>());
}

// merge

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__merge(_InputIterator1 __first1, _InputIterator1 __last1,
        _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    for (; __first1 != __last1; ++__result)
    {
        if (__first2 == __last2)
            return _VSTD::copy(__first1, __last1, __result);
        if (__comp(*__first2, *__first1))
        {
            *__result = *__first2;
            ++__first2;
        }
        else
        {
            *__result = *__first1;
            ++__first1;
        }
    }
    return _VSTD::copy(__first2, __last2, __result);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
merge(_InputIterator1 __first1, _InputIterator1 __last1,
      _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return _VSTD::__merge<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
merge(_InputIterator1 __first1, _InputIterator1 __last1,
      _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::merge(__first1, __last1, __first2, __last2, __result, __less<__v1, __v2>());
}

// inplace_merge

template <class _Compare, class _InputIterator1, class _InputIterator2,
          class _OutputIterator>
void __half_inplace_merge(_InputIterator1 __first1, _InputIterator1 __last1,
                          _InputIterator2 __first2, _InputIterator2 __last2,
                          _OutputIterator __result, _Compare __comp)
{
    for (; __first1 != __last1; ++__result)
    {
        if (__first2 == __last2)
        {
            _VSTD::move(__first1, __last1, __result);
            return;
        }

        if (__comp(*__first2, *__first1))
        {
            *__result = _VSTD::move(*__first2);
            ++__first2;
        }
        else
        {
            *__result = _VSTD::move(*__first1);
            ++__first1;
        }
    }
    // __first2 through __last2 are already in the right spot.
}

template <class _Compare, class _BidirectionalIterator>
void
__buffered_inplace_merge(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last,
                _Compare __comp, typename iterator_traits<_BidirectionalIterator>::difference_type __len1,
                                 typename iterator_traits<_BidirectionalIterator>::difference_type __len2,
                typename iterator_traits<_BidirectionalIterator>::value_type* __buff)
{
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    __destruct_n __d(0);
    unique_ptr<value_type, __destruct_n&> __h2(__buff, __d);
    if (__len1 <= __len2)
    {
        value_type* __p = __buff;
        for (_BidirectionalIterator __i = __first; __i != __middle; __d.__incr((value_type*)0), (void) ++__i, (void) ++__p)
            ::new(__p) value_type(_VSTD::move(*__i));
        __half_inplace_merge(__buff, __p, __middle, __last, __first, __comp);
    }
    else
    {
        value_type* __p = __buff;
        for (_BidirectionalIterator __i = __middle; __i != __last; __d.__incr((value_type*)0), (void) ++__i, (void) ++__p)
            ::new(__p) value_type(_VSTD::move(*__i));
        typedef reverse_iterator<_BidirectionalIterator> _RBi;
        typedef reverse_iterator<value_type*> _Rv;
        __half_inplace_merge(_Rv(__p), _Rv(__buff),
                             _RBi(__middle), _RBi(__first),
                             _RBi(__last), __invert<_Compare>(__comp));
    }
}

template <class _Compare, class _BidirectionalIterator>
void
__inplace_merge(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last,
                _Compare __comp, typename iterator_traits<_BidirectionalIterator>::difference_type __len1,
                                 typename iterator_traits<_BidirectionalIterator>::difference_type __len2,
                typename iterator_traits<_BidirectionalIterator>::value_type* __buff, ptrdiff_t __buff_size)
{
    typedef typename iterator_traits<_BidirectionalIterator>::difference_type difference_type;
    while (true)
    {
        // if __middle == __last, we're done
        if (__len2 == 0)
            return;
        if (__len1 <= __buff_size || __len2 <= __buff_size)
            return __buffered_inplace_merge<_Compare>
                   (__first, __middle, __last, __comp, __len1, __len2, __buff);
        // shrink [__first, __middle) as much as possible (with no moves), returning if it shrinks to 0
        for (; true; ++__first, (void) --__len1)
        {
            if (__len1 == 0)
                return;
            if (__comp(*__middle, *__first))
                break;
        }
        // __first < __middle < __last
        // *__first > *__middle
        // partition [__first, __m1) [__m1, __middle) [__middle, __m2) [__m2, __last) such that
        //     all elements in:
        //         [__first, __m1)  <= [__middle, __m2)
        //         [__middle, __m2) <  [__m1, __middle)
        //         [__m1, __middle) <= [__m2, __last)
        //     and __m1 or __m2 is in the middle of its range
        _BidirectionalIterator __m1;  // "median" of [__first, __middle)
        _BidirectionalIterator __m2;  // "median" of [__middle, __last)
        difference_type __len11;      // distance(__first, __m1)
        difference_type __len21;      // distance(__middle, __m2)
        // binary search smaller range
        if (__len1 < __len2)
        {   // __len >= 1, __len2 >= 2
            __len21 = __len2 / 2;
            __m2 = __middle;
            _VSTD::advance(__m2, __len21);
            __m1 = __upper_bound<_Compare>(__first, __middle, *__m2, __comp);
            __len11 = _VSTD::distance(__first, __m1);
        }
        else
        {
            if (__len1 == 1)
            {   // __len1 >= __len2 && __len2 > 0, therefore __len2 == 1
                // It is known *__first > *__middle
                swap(*__first, *__middle);
                return;
            }
            // __len1 >= 2, __len2 >= 1
            __len11 = __len1 / 2;
            __m1 = __first;
            _VSTD::advance(__m1, __len11);
            __m2 = __lower_bound<_Compare>(__middle, __last, *__m1, __comp);
            __len21 = _VSTD::distance(__middle, __m2);
        }
        difference_type __len12 = __len1 - __len11;  // distance(__m1, __middle)
        difference_type __len22 = __len2 - __len21;  // distance(__m2, __last)
        // [__first, __m1) [__m1, __middle) [__middle, __m2) [__m2, __last)
        // swap middle two partitions
        __middle = _VSTD::rotate(__m1, __middle, __m2);
        // __len12 and __len21 now have swapped meanings
        // merge smaller range with recurisve call and larger with tail recursion elimination
        if (__len11 + __len21 < __len12 + __len22)
        {
            __inplace_merge<_Compare>(__first, __m1, __middle, __comp, __len11, __len21, __buff, __buff_size);
//          __inplace_merge<_Compare>(__middle, __m2, __last, __comp, __len12, __len22, __buff, __buff_size);
            __first = __middle;
            __middle = __m2;
            __len1 = __len12;
            __len2 = __len22;
        }
        else
        {
            __inplace_merge<_Compare>(__middle, __m2, __last, __comp, __len12, __len22, __buff, __buff_size);
//          __inplace_merge<_Compare>(__first, __m1, __middle, __comp, __len11, __len21, __buff, __buff_size);
            __last = __middle;
            __middle = __m1;
            __len1 = __len11;
            __len2 = __len21;
        }
    }
}

template <class _BidirectionalIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
inplace_merge(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last,
              _Compare __comp)
{
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    typedef typename iterator_traits<_BidirectionalIterator>::difference_type difference_type;
    difference_type __len1 = _VSTD::distance(__first, __middle);
    difference_type __len2 = _VSTD::distance(__middle, __last);
    difference_type __buf_size = _VSTD::min(__len1, __len2);
    pair<value_type*, ptrdiff_t> __buf = _VSTD::get_temporary_buffer<value_type>(__buf_size);
    unique_ptr<value_type, __return_temporary_buffer> __h(__buf.first);
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return _VSTD::__inplace_merge<_Comp_ref>(__first, __middle, __last, __comp, __len1, __len2,
                                            __buf.first, __buf.second);
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
inplace_merge(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last)
{
    _VSTD::inplace_merge(__first, __middle, __last,
                        __less<typename iterator_traits<_BidirectionalIterator>::value_type>());
}

// stable_sort

template <class _Compare, class _InputIterator1, class _InputIterator2>
void
__merge_move_construct(_InputIterator1 __first1, _InputIterator1 __last1,
        _InputIterator2 __first2, _InputIterator2 __last2,
        typename iterator_traits<_InputIterator1>::value_type* __result, _Compare __comp)
{
    typedef typename iterator_traits<_InputIterator1>::value_type value_type;
    __destruct_n __d(0);
    unique_ptr<value_type, __destruct_n&> __h(__result, __d);
    for (; true; ++__result)
    {
        if (__first1 == __last1)
        {
            for (; __first2 != __last2; ++__first2, ++__result, (void) __d.__incr((value_type*)0))
                ::new (__result) value_type(_VSTD::move(*__first2));
            __h.release();
            return;
        }
        if (__first2 == __last2)
        {
            for (; __first1 != __last1; ++__first1, ++__result, (void) __d.__incr((value_type*)0))
                ::new (__result) value_type(_VSTD::move(*__first1));
            __h.release();
            return;
        }
        if (__comp(*__first2, *__first1))
        {
            ::new (__result) value_type(_VSTD::move(*__first2));
            __d.__incr((value_type*)0);
            ++__first2;
        }
        else
        {
            ::new (__result) value_type(_VSTD::move(*__first1));
            __d.__incr((value_type*)0);
            ++__first1;
        }
    }
}

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
void
__merge_move_assign(_InputIterator1 __first1, _InputIterator1 __last1,
        _InputIterator2 __first2, _InputIterator2 __last2,
        _OutputIterator __result, _Compare __comp)
{
    for (; __first1 != __last1; ++__result)
    {
        if (__first2 == __last2)
        {
            for (; __first1 != __last1; ++__first1, (void) ++__result)
                *__result = _VSTD::move(*__first1);
            return;
        }
        if (__comp(*__first2, *__first1))
        {
            *__result = _VSTD::move(*__first2);
            ++__first2;
        }
        else
        {
            *__result = _VSTD::move(*__first1);
            ++__first1;
        }
    }
    for (; __first2 != __last2; ++__first2, (void) ++__result)
        *__result = _VSTD::move(*__first2);
}

template <class _Compare, class _RandomAccessIterator>
void
__stable_sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp,
              typename iterator_traits<_RandomAccessIterator>::difference_type __len,
              typename iterator_traits<_RandomAccessIterator>::value_type* __buff, ptrdiff_t __buff_size);

template <class _Compare, class _RandomAccessIterator>
void
__stable_sort_move(_RandomAccessIterator __first1, _RandomAccessIterator __last1, _Compare __comp,
                   typename iterator_traits<_RandomAccessIterator>::difference_type __len,
                   typename iterator_traits<_RandomAccessIterator>::value_type* __first2)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    switch (__len)
    {
    case 0:
        return;
    case 1:
        ::new(__first2) value_type(_VSTD::move(*__first1));
        return;
    case 2:
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h2(__first2, __d);
        if (__comp(*--__last1, *__first1))
        {
            ::new(__first2) value_type(_VSTD::move(*__last1));
            __d.__incr((value_type*)0);
            ++__first2;
            ::new(__first2) value_type(_VSTD::move(*__first1));
        }
        else
        {
            ::new(__first2) value_type(_VSTD::move(*__first1));
            __d.__incr((value_type*)0);
            ++__first2;
            ::new(__first2) value_type(_VSTD::move(*__last1));
        }
        __h2.release();
        return;
    }
    if (__len <= 8)
    {
        __insertion_sort_move<_Compare>(__first1, __last1, __first2, __comp);
        return;
    }
    typename iterator_traits<_RandomAccessIterator>::difference_type __l2 = __len / 2;
    _RandomAccessIterator __m = __first1 + __l2;
    __stable_sort<_Compare>(__first1, __m, __comp, __l2, __first2, __l2);
    __stable_sort<_Compare>(__m, __last1, __comp, __len - __l2, __first2 + __l2, __len - __l2);
    __merge_move_construct<_Compare>(__first1, __m, __m, __last1, __first2, __comp);
}

template <class _Tp>
struct __stable_sort_switch
{
    static const unsigned value = 128*is_trivially_copy_assignable<_Tp>::value;
};

template <class _Compare, class _RandomAccessIterator>
void
__stable_sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp,
              typename iterator_traits<_RandomAccessIterator>::difference_type __len,
              typename iterator_traits<_RandomAccessIterator>::value_type* __buff, ptrdiff_t __buff_size)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    switch (__len)
    {
    case 0:
    case 1:
        return;
    case 2:
        if (__comp(*--__last, *__first))
            swap(*__first, *__last);
        return;
    }
    if (__len <= static_cast<difference_type>(__stable_sort_switch<value_type>::value))
    {
        __insertion_sort<_Compare>(__first, __last, __comp);
        return;
    }
    typename iterator_traits<_RandomAccessIterator>::difference_type __l2 = __len / 2;
    _RandomAccessIterator __m = __first + __l2;
    if (__len <= __buff_size)
    {
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h2(__buff, __d);
        __stable_sort_move<_Compare>(__first, __m, __comp, __l2, __buff);
        __d.__set(__l2, (value_type*)0);
        __stable_sort_move<_Compare>(__m, __last, __comp, __len - __l2, __buff + __l2);
        __d.__set(__len, (value_type*)0);
        __merge_move_assign<_Compare>(__buff, __buff + __l2, __buff + __l2, __buff + __len, __first, __comp);
//         __merge<_Compare>(move_iterator<value_type*>(__buff),
//                           move_iterator<value_type*>(__buff + __l2),
//                           move_iterator<_RandomAccessIterator>(__buff + __l2),
//                           move_iterator<_RandomAccessIterator>(__buff + __len),
//                           __first, __comp);
        return;
    }
    __stable_sort<_Compare>(__first, __m, __comp, __l2, __buff, __buff_size);
    __stable_sort<_Compare>(__m, __last, __comp, __len - __l2, __buff, __buff_size);
    __inplace_merge<_Compare>(__first, __m, __last, __comp, __l2, __len - __l2, __buff, __buff_size);
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
stable_sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    difference_type __len = __last - __first;
    pair<value_type*, ptrdiff_t> __buf(0, 0);
    unique_ptr<value_type, __return_temporary_buffer> __h;
    if (__len > static_cast<difference_type>(__stable_sort_switch<value_type>::value))
    {
        __buf = _VSTD::get_temporary_buffer<value_type>(__len);
        __h.reset(__buf.first);
    }
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    __stable_sort<_Comp_ref>(__first, __last, __comp, __len, __buf.first, __buf.second);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
stable_sort(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::stable_sort(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// is_heap_until

template <class _RandomAccessIterator, class _Compare>
_LIBCPP_NODISCARD_EXT _LIBCPP_CONSTEXPR_AFTER_CXX17 _RandomAccessIterator
is_heap_until(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename _VSTD::iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    difference_type __len = __last - __first;
    difference_type __p = 0;
    difference_type __c = 1;
    _RandomAccessIterator __pp = __first;
    while (__c < __len)
    {
        _RandomAccessIterator __cp = __first + __c;
        if (__comp(*__pp, *__cp))
            return __cp;
        ++__c;
        ++__cp;
        if (__c == __len)
            return __last;
        if (__comp(*__pp, *__cp))
            return __cp;
        ++__p;
        ++__pp;
        __c = 2 * __p + 1;
    }
    return __last;
}

template<class _RandomAccessIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_RandomAccessIterator
is_heap_until(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    return _VSTD::is_heap_until(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// is_heap

template <class _RandomAccessIterator, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
is_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    return _VSTD::is_heap_until(__first, __last, __comp) == __last;
}

template<class _RandomAccessIterator>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
is_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    return _VSTD::is_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// push_heap

template <class _Compare, class _RandomAccessIterator>
void
__sift_up(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp,
          typename iterator_traits<_RandomAccessIterator>::difference_type __len)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    if (__len > 1)
    {
        __len = (__len - 2) / 2;
        _RandomAccessIterator __ptr = __first + __len;
        if (__comp(*__ptr, *--__last))
        {
            value_type __t(_VSTD::move(*__last));
            do
            {
                *__last = _VSTD::move(*__ptr);
                __last = __ptr;
                if (__len == 0)
                    break;
                __len = (__len - 1) / 2;
                __ptr = __first + __len;
            } while (__comp(*__ptr, __t));
            *__last = _VSTD::move(__t);
        }
    }
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
push_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    __sift_up<_Comp_ref>(__first, __last, __comp, __last - __first);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
push_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::push_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// pop_heap

template <class _Compare, class _RandomAccessIterator>
void
__sift_down(_RandomAccessIterator __first, _RandomAccessIterator /*__last*/,
            _Compare __comp,
            typename iterator_traits<_RandomAccessIterator>::difference_type __len,
            _RandomAccessIterator __start)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    // left-child of __start is at 2 * __start + 1
    // right-child of __start is at 2 * __start + 2
    difference_type __child = __start - __first;

    if (__len < 2 || (__len - 2) / 2 < __child)
        return;

    __child = 2 * __child + 1;
    _RandomAccessIterator __child_i = __first + __child;

    if ((__child + 1) < __len && __comp(*__child_i, *(__child_i + 1))) {
        // right-child exists and is greater than left-child
        ++__child_i;
        ++__child;
    }

    // check if we are in heap-order
    if (__comp(*__child_i, *__start))
        // we are, __start is larger than it's largest child
        return;

    value_type __top(_VSTD::move(*__start));
    do
    {
        // we are not in heap-order, swap the parent with it's largest child
        *__start = _VSTD::move(*__child_i);
        __start = __child_i;

        if ((__len - 2) / 2 < __child)
            break;

        // recompute the child based off of the updated parent
        __child = 2 * __child + 1;
        __child_i = __first + __child;

        if ((__child + 1) < __len && __comp(*__child_i, *(__child_i + 1))) {
            // right-child exists and is greater than left-child
            ++__child_i;
            ++__child;
        }

        // check if we are in heap-order
    } while (!__comp(*__child_i, __top));
    *__start = _VSTD::move(__top);
}

template <class _Compare, class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
__pop_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp,
           typename iterator_traits<_RandomAccessIterator>::difference_type __len)
{
    if (__len > 1)
    {
        swap(*__first, *--__last);
        __sift_down<_Compare>(__first, __last, __comp, __len - 1, __first);
    }
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
pop_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    __pop_heap<_Comp_ref>(__first, __last, __comp, __last - __first);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
pop_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::pop_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// make_heap

template <class _Compare, class _RandomAccessIterator>
void
__make_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    difference_type __n = __last - __first;
    if (__n > 1)
    {
        // start from the first parent, there is no need to consider children
        for (difference_type __start = (__n - 2) / 2; __start >= 0; --__start)
        {
            __sift_down<_Compare>(__first, __last, __comp, __n, __first + __start);
        }
    }
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
make_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    __make_heap<_Comp_ref>(__first, __last, __comp);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
make_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::make_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// sort_heap

template <class _Compare, class _RandomAccessIterator>
void
__sort_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    for (difference_type __n = __last - __first; __n > 1; --__last, (void) --__n)
        __pop_heap<_Compare>(__first, __last, __comp, __n);
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
sort_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    __sort_heap<_Comp_ref>(__first, __last, __comp);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
sort_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::sort_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// partial_sort

template <class _Compare, class _RandomAccessIterator>
void
__partial_sort(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last,
             _Compare __comp)
{
    __make_heap<_Compare>(__first, __middle, __comp);
    typename iterator_traits<_RandomAccessIterator>::difference_type __len = __middle - __first;
    for (_RandomAccessIterator __i = __middle; __i != __last; ++__i)
    {
        if (__comp(*__i, *__first))
        {
            swap(*__i, *__first);
            __sift_down<_Compare>(__first, __middle, __comp, __len, __first);
        }
    }
    __sort_heap<_Compare>(__first, __middle, __comp);
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
partial_sort(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last,
             _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    __partial_sort<_Comp_ref>(__first, __middle, __last, __comp);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
partial_sort(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last)
{
    _VSTD::partial_sort(__first, __middle, __last,
                       __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// partial_sort_copy

template <class _Compare, class _InputIterator, class _RandomAccessIterator>
_RandomAccessIterator
__partial_sort_copy(_InputIterator __first, _InputIterator __last,
                    _RandomAccessIterator __result_first, _RandomAccessIterator __result_last, _Compare __comp)
{
    _RandomAccessIterator __r = __result_first;
    if (__r != __result_last)
    {
        for (; __first != __last && __r != __result_last; ++__first, (void) ++__r)
            *__r = *__first;
        __make_heap<_Compare>(__result_first, __r, __comp);
        typename iterator_traits<_RandomAccessIterator>::difference_type __len = __r - __result_first;
        for (; __first != __last; ++__first)
            if (__comp(*__first, *__result_first))
            {
                *__result_first = *__first;
                __sift_down<_Compare>(__result_first, __r, __comp, __len, __result_first);
            }
        __sort_heap<_Compare>(__result_first, __r, __comp);
    }
    return __r;
}

template <class _InputIterator, class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_RandomAccessIterator
partial_sort_copy(_InputIterator __first, _InputIterator __last,
                  _RandomAccessIterator __result_first, _RandomAccessIterator __result_last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __partial_sort_copy<_Comp_ref>(__first, __last, __result_first, __result_last, __comp);
}

template <class _InputIterator, class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
_RandomAccessIterator
partial_sort_copy(_InputIterator __first, _InputIterator __last,
                  _RandomAccessIterator __result_first, _RandomAccessIterator __result_last)
{
    return _VSTD::partial_sort_copy(__first, __last, __result_first, __result_last,
                                   __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// nth_element

template <class _Compare, class _RandomAccessIterator>
void
__nth_element(_RandomAccessIterator __first, _RandomAccessIterator __nth, _RandomAccessIterator __last, _Compare __comp)
{
    // _Compare is known to be a reference type
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    const difference_type __limit = 7;
    while (true)
    {
    __restart:
        if (__nth == __last)
            return;
        difference_type __len = __last - __first;
        switch (__len)
        {
        case 0:
        case 1:
            return;
        case 2:
            if (__comp(*--__last, *__first))
                swap(*__first, *__last);
            return;
        case 3:
            {
            _RandomAccessIterator __m = __first;
            _VSTD::__sort3<_Compare>(__first, ++__m, --__last, __comp);
            return;
            }
        }
        if (__len <= __limit)
        {
            __selection_sort<_Compare>(__first, __last, __comp);
            return;
        }
        // __len > __limit >= 3
        _RandomAccessIterator __m = __first + __len/2;
        _RandomAccessIterator __lm1 = __last;
        unsigned __n_swaps = _VSTD::__sort3<_Compare>(__first, __m, --__lm1, __comp);
        // *__m is median
        // partition [__first, __m) < *__m and *__m <= [__m, __last)
        // (this inhibits tossing elements equivalent to __m around unnecessarily)
        _RandomAccessIterator __i = __first;
        _RandomAccessIterator __j = __lm1;
        // j points beyond range to be tested, *__lm1 is known to be <= *__m
        // The search going up is known to be guarded but the search coming down isn't.
        // Prime the downward search with a guard.
        if (!__comp(*__i, *__m))  // if *__first == *__m
        {
            // *__first == *__m, *__first doesn't go in first part
            // manually guard downward moving __j against __i
            while (true)
            {
                if (__i == --__j)
                {
                    // *__first == *__m, *__m <= all other elements
                    // Parition instead into [__first, __i) == *__first and *__first < [__i, __last)
                    ++__i;  // __first + 1
                    __j = __last;
                    if (!__comp(*__first, *--__j))  // we need a guard if *__first == *(__last-1)
                    {
                        while (true)
                        {
                            if (__i == __j)
                                return;  // [__first, __last) all equivalent elements
                            if (__comp(*__first, *__i))
                            {
                                swap(*__i, *__j);
                                ++__n_swaps;
                                ++__i;
                                break;
                            }
                            ++__i;
                        }
                    }
                    // [__first, __i) == *__first and *__first < [__j, __last) and __j == __last - 1
                    if (__i == __j)
                        return;
                    while (true)
                    {
                        while (!__comp(*__first, *__i))
                            ++__i;
                        while (__comp(*__first, *--__j))
                            ;
                        if (__i >= __j)
                            break;
                        swap(*__i, *__j);
                        ++__n_swaps;
                        ++__i;
                    }
                    // [__first, __i) == *__first and *__first < [__i, __last)
                    // The first part is sorted,
                    if (__nth < __i)
                        return;
                    // __nth_element the secod part
                    // __nth_element<_Compare>(__i, __nth, __last, __comp);
                    __first = __i;
                    goto __restart;
                }
                if (__comp(*__j, *__m))
                {
                    swap(*__i, *__j);
                    ++__n_swaps;
                    break;  // found guard for downward moving __j, now use unguarded partition
                }
            }
        }
        ++__i;
        // j points beyond range to be tested, *__lm1 is known to be <= *__m
        // if not yet partitioned...
        if (__i < __j)
        {
            // known that *(__i - 1) < *__m
            while (true)
            {
                // __m still guards upward moving __i
                while (__comp(*__i, *__m))
                    ++__i;
                // It is now known that a guard exists for downward moving __j
                while (!__comp(*--__j, *__m))
                    ;
                if (__i >= __j)
                    break;
                swap(*__i, *__j);
                ++__n_swaps;
                // It is known that __m != __j
                // If __m just moved, follow it
                if (__m == __i)
                    __m = __j;
                ++__i;
            }
        }
        // [__first, __i) < *__m and *__m <= [__i, __last)
        if (__i != __m && __comp(*__m, *__i))
        {
            swap(*__i, *__m);
            ++__n_swaps;
        }
        // [__first, __i) < *__i and *__i <= [__i+1, __last)
        if (__nth == __i)
            return;
        if (__n_swaps == 0)
        {
            // We were given a perfectly partitioned sequence.  Coincidence?
            if (__nth < __i)
            {
                // Check for [__first, __i) already sorted
                __j = __m = __first;
                while (++__j != __i)
                {
                    if (__comp(*__j, *__m))
                        // not yet sorted, so sort
                        goto not_sorted;
                    __m = __j;
                }
                // [__first, __i) sorted
                return;
            }
            else
            {
                // Check for [__i, __last) already sorted
                __j = __m = __i;
                while (++__j != __last)
                {
                    if (__comp(*__j, *__m))
                        // not yet sorted, so sort
                        goto not_sorted;
                    __m = __j;
                }
                // [__i, __last) sorted
                return;
            }
        }
not_sorted:
        // __nth_element on range containing __nth
        if (__nth < __i)
        {
            // __nth_element<_Compare>(__first, __nth, __i, __comp);
            __last = __i;
        }
        else
        {
            // __nth_element<_Compare>(__i+1, __nth, __last, __comp);
            __first = ++__i;
        }
    }
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
nth_element(_RandomAccessIterator __first, _RandomAccessIterator __nth, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    __nth_element<_Comp_ref>(__first, __nth, __last, __comp);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
nth_element(_RandomAccessIterator __first, _RandomAccessIterator __nth, _RandomAccessIterator __last)
{
    _VSTD::nth_element(__first, __nth, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// includes

template <class _Compare, class _InputIterator1, class _InputIterator2>
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
__includes(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2, _InputIterator2 __last2,
           _Compare __comp)
{
    for (; __first2 != __last2; ++__first1)
    {
        if (__first1 == __last1 || __comp(*__first2, *__first1))
            return false;
        if (!__comp(*__first1, *__first2))
            ++__first2;
    }
    return true;
}

template <class _InputIterator1, class _InputIterator2, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
includes(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2, _InputIterator2 __last2,
         _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __includes<_Comp_ref>(__first1, __last1, __first2, __last2, __comp);
}

template <class _InputIterator1, class _InputIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
includes(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2, _InputIterator2 __last2)
{
    return _VSTD::includes(__first1, __last1, __first2, __last2,
                          __less<typename iterator_traits<_InputIterator1>::value_type,
                                 typename iterator_traits<_InputIterator2>::value_type>());
}

// set_union

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__set_union(_InputIterator1 __first1, _InputIterator1 __last1,
            _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    for (; __first1 != __last1; ++__result)
    {
        if (__first2 == __last2)
            return _VSTD::copy(__first1, __last1, __result);
        if (__comp(*__first2, *__first1))
        {
            *__result = *__first2;
            ++__first2;
        }
        else
        {
            if (!__comp(*__first1, *__first2))
                ++__first2;
            *__result = *__first1;
            ++__first1;
        }
    }
    return _VSTD::copy(__first2, __last2, __result);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_union(_InputIterator1 __first1, _InputIterator1 __last1,
          _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __set_union<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_union(_InputIterator1 __first1, _InputIterator1 __last1,
          _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    return _VSTD::set_union(__first1, __last1, __first2, __last2, __result,
                          __less<typename iterator_traits<_InputIterator1>::value_type,
                                 typename iterator_traits<_InputIterator2>::value_type>());
}

// set_intersection

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _OutputIterator
__set_intersection(_InputIterator1 __first1, _InputIterator1 __last1,
                   _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    while (__first1 != __last1 && __first2 != __last2)
    {
        if (__comp(*__first1, *__first2))
            ++__first1;
        else
        {
            if (!__comp(*__first2, *__first1))
            {
                *__result = *__first1;
                ++__result;
                ++__first1;
            }
            ++__first2;
        }
    }
    return __result;
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
set_intersection(_InputIterator1 __first1, _InputIterator1 __last1,
                 _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __set_intersection<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
_OutputIterator
set_intersection(_InputIterator1 __first1, _InputIterator1 __last1,
                 _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    return _VSTD::set_intersection(__first1, __last1, __first2, __last2, __result,
                                  __less<typename iterator_traits<_InputIterator1>::value_type,
                                         typename iterator_traits<_InputIterator2>::value_type>());
}

// set_difference

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__set_difference(_InputIterator1 __first1, _InputIterator1 __last1,
                 _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    while (__first1 != __last1)
    {
        if (__first2 == __last2)
            return _VSTD::copy(__first1, __last1, __result);
        if (__comp(*__first1, *__first2))
        {
            *__result = *__first1;
            ++__result;
            ++__first1;
        }
        else
        {
            if (!__comp(*__first2, *__first1))
                ++__first1;
            ++__first2;
        }
    }
    return __result;
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_difference(_InputIterator1 __first1, _InputIterator1 __last1,
               _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __set_difference<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_difference(_InputIterator1 __first1, _InputIterator1 __last1,
               _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    return _VSTD::set_difference(__first1, __last1, __first2, __last2, __result,
                                __less<typename iterator_traits<_InputIterator1>::value_type,
                                       typename iterator_traits<_InputIterator2>::value_type>());
}

// set_symmetric_difference

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__set_symmetric_difference(_InputIterator1 __first1, _InputIterator1 __last1,
                           _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    while (__first1 != __last1)
    {
        if (__first2 == __last2)
            return _VSTD::copy(__first1, __last1, __result);
        if (__comp(*__first1, *__first2))
        {
            *__result = *__first1;
            ++__result;
            ++__first1;
        }
        else
        {
            if (__comp(*__first2, *__first1))
            {
                *__result = *__first2;
                ++__result;
            }
            else
                ++__first1;
            ++__first2;
        }
    }
    return _VSTD::copy(__first2, __last2, __result);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_symmetric_difference(_InputIterator1 __first1, _InputIterator1 __last1,
                         _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __set_symmetric_difference<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_symmetric_difference(_InputIterator1 __first1, _InputIterator1 __last1,
                         _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    return _VSTD::set_symmetric_difference(__first1, __last1, __first2, __last2, __result,
                                          __less<typename iterator_traits<_InputIterator1>::value_type,
                                                 typename iterator_traits<_InputIterator2>::value_type>());
}

// lexicographical_compare

template <class _Compare, class _InputIterator1, class _InputIterator2>
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
__lexicographical_compare(_InputIterator1 __first1, _InputIterator1 __last1,
                          _InputIterator2 __first2, _InputIterator2 __last2, _Compare __comp)
{
    for (; __first2 != __last2; ++__first1, (void) ++__first2)
    {
        if (__first1 == __last1 || __comp(*__first1, *__first2))
            return true;
        if (__comp(*__first2, *__first1))
            return false;
    }
    return false;
}

template <class _InputIterator1, class _InputIterator2, class _Compare>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
lexicographical_compare(_InputIterator1 __first1, _InputIterator1 __last1,
                        _InputIterator2 __first2, _InputIterator2 __last2, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __lexicographical_compare<_Comp_ref>(__first1, __last1, __first2, __last2, __comp);
}

template <class _InputIterator1, class _InputIterator2>
_LIBCPP_NODISCARD_EXT inline
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
bool
lexicographical_compare(_InputIterator1 __first1, _InputIterator1 __last1,
                        _InputIterator2 __first2, _InputIterator2 __last2)
{
    return _VSTD::lexicographical_compare(__first1, __last1, __first2, __last2,
                                         __less<typename iterator_traits<_InputIterator1>::value_type,
                                                typename iterator_traits<_InputIterator2>::value_type>());
}

// next_permutation

template <class _Compare, class _BidirectionalIterator>
bool
__next_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last, _Compare __comp)
{
    _BidirectionalIterator __i = __last;
    if (__first == __last || __first == --__i)
        return false;
    while (true)
    {
        _BidirectionalIterator __ip1 = __i;
        if (__comp(*--__i, *__ip1))
        {
            _BidirectionalIterator __j = __last;
            while (!__comp(*__i, *--__j))
                ;
            swap(*__i, *__j);
            _VSTD::reverse(__ip1, __last);
            return true;
        }
        if (__i == __first)
        {
            _VSTD::reverse(__first, __last);
            return false;
        }
    }
}

template <class _BidirectionalIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
next_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __next_permutation<_Comp_ref>(__first, __last, __comp);
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
bool
next_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last)
{
    return _VSTD::next_permutation(__first, __last,
                                  __less<typename iterator_traits<_BidirectionalIterator>::value_type>());
}

// prev_permutation

template <class _Compare, class _BidirectionalIterator>
bool
__prev_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last, _Compare __comp)
{
    _BidirectionalIterator __i = __last;
    if (__first == __last || __first == --__i)
        return false;
    while (true)
    {
        _BidirectionalIterator __ip1 = __i;
        if (__comp(*__ip1, *--__i))
        {
            _BidirectionalIterator __j = __last;
            while (!__comp(*--__j, *__i))
                ;
            swap(*__i, *__j);
            _VSTD::reverse(__ip1, __last);
            return true;
        }
        if (__i == __first)
        {
            _VSTD::reverse(__first, __last);
            return false;
        }
    }
}

template <class _BidirectionalIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
prev_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last, _Compare __comp)
{
    typedef typename __comp_ref_type<_Compare>::type _Comp_ref;
    return __prev_permutation<_Comp_ref>(__first, __last, __comp);
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
bool
prev_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last)
{
    return _VSTD::prev_permutation(__first, __last,
                                  __less<typename iterator_traits<_BidirectionalIterator>::value_type>());
}

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_HAS_PARALLEL_ALGORITHMS) && _LIBCPP_STD_VER >= 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 5710 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#   include <__pstl_algorithm>
#endif /* expanded by -frewrite-includes */
# 5710 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 5711 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
#endif
# 5712 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3

#endif  // _LIBCPP_ALGORITHM
# 5714 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/algorithm" 3
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"

namespace llvm {

/// CRTP base class which implements the entire standard iterator facade
/// in terms of a minimal subset of the interface.
///
/// Use this when it is reasonable to implement most of the iterator
/// functionality in terms of a core subset. If you need special behavior or
/// there are performance implications for this, you may want to override the
/// relevant members instead.
///
/// Note, one abstraction that this does *not* provide is implementing
/// subtraction in terms of addition by negating the difference. Negation isn't
/// always information preserving, and I can see very reasonable iterator
/// designs where this doesn't work well. It doesn't really force much added
/// boilerplate anyways.
///
/// Another abstraction that this doesn't provide is implementing increment in
/// terms of addition of one. These aren't equivalent for all iterator
/// categories, and respecting that adds a lot of complexity for little gain.
///
/// Classes wishing to use `iterator_facade_base` should implement the following
/// methods:
///
/// Forward Iterators:
///   (All of the following methods)
///   - DerivedT &operator=(const DerivedT &R);
///   - bool operator==(const DerivedT &R) const;
///   - const T &operator*() const;
///   - T &operator*();
///   - DerivedT &operator++();
///
/// Bidirectional Iterators:
///   (All methods of forward iterators, plus the following)
///   - DerivedT &operator--();
///
/// Random-access Iterators:
///   (All methods of bidirectional iterators excluding the following)
///   - DerivedT &operator++();
///   - DerivedT &operator--();
///   (and plus the following)
///   - bool operator<(const DerivedT &RHS) const;
///   - DifferenceTypeT operator-(const DerivedT &R) const;
///   - DerivedT &operator+=(DifferenceTypeT N);
///   - DerivedT &operator-=(DifferenceTypeT N);
///
template <typename DerivedT, typename IteratorCategoryT, typename T,
          typename DifferenceTypeT = std::ptrdiff_t, typename PointerT = T *,
          typename ReferenceT = T &>
class iterator_facade_base
    : public std::iterator<IteratorCategoryT, T, DifferenceTypeT, PointerT,
                           ReferenceT> {
protected:
  enum {
    IsRandomAccess = std::is_base_of<std::random_access_iterator_tag,
                                     IteratorCategoryT>::value,
    IsBidirectional = std::is_base_of<std::bidirectional_iterator_tag,
                                      IteratorCategoryT>::value,
  };

  /// A proxy object for computing a reference via indirecting a copy of an
  /// iterator. This is used in APIs which need to produce a reference via
  /// indirection but for which the iterator object might be a temporary. The
  /// proxy preserves the iterator internally and exposes the indirected
  /// reference via a conversion operator.
  class ReferenceProxy {
    friend iterator_facade_base;

    DerivedT I;

    ReferenceProxy(DerivedT I) : I(std::move(I)) {}

  public:
    operator ReferenceT() const { return *I; }
  };

public:
  DerivedT operator+(DifferenceTypeT n) const {
    static_assert(std::is_base_of<iterator_facade_base, DerivedT>::value,
                  "Must pass the derived type to this template!");
    static_assert(
        IsRandomAccess,
        "The '+' operator is only defined for random access iterators.");
    DerivedT tmp = *static_cast<const DerivedT *>(this);
    tmp += n;
    return tmp;
  }
  friend DerivedT operator+(DifferenceTypeT n, const DerivedT &i) {
    static_assert(
        IsRandomAccess,
        "The '+' operator is only defined for random access iterators.");
    return i + n;
  }
  DerivedT operator-(DifferenceTypeT n) const {
    static_assert(
        IsRandomAccess,
        "The '-' operator is only defined for random access iterators.");
    DerivedT tmp = *static_cast<const DerivedT *>(this);
    tmp -= n;
    return tmp;
  }

  DerivedT &operator++() {
    static_assert(std::is_base_of<iterator_facade_base, DerivedT>::value,
                  "Must pass the derived type to this template!");
    return static_cast<DerivedT *>(this)->operator+=(1);
  }
  DerivedT operator++(int) {
    DerivedT tmp = *static_cast<DerivedT *>(this);
    ++*static_cast<DerivedT *>(this);
    return tmp;
  }
  DerivedT &operator--() {
    static_assert(
        IsBidirectional,
        "The decrement operator is only defined for bidirectional iterators.");
    return static_cast<DerivedT *>(this)->operator-=(1);
  }
  DerivedT operator--(int) {
    static_assert(
        IsBidirectional,
        "The decrement operator is only defined for bidirectional iterators.");
    DerivedT tmp = *static_cast<DerivedT *>(this);
    --*static_cast<DerivedT *>(this);
    return tmp;
  }

  bool operator!=(const DerivedT &RHS) const {
    return !static_cast<const DerivedT *>(this)->operator==(RHS);
  }

  bool operator>(const DerivedT &RHS) const {
    static_assert(
        IsRandomAccess,
        "Relational operators are only defined for random access iterators.");
    return !static_cast<const DerivedT *>(this)->operator<(RHS) &&
           !static_cast<const DerivedT *>(this)->operator==(RHS);
  }
  bool operator<=(const DerivedT &RHS) const {
    static_assert(
        IsRandomAccess,
        "Relational operators are only defined for random access iterators.");
    return !static_cast<const DerivedT *>(this)->operator>(RHS);
  }
  bool operator>=(const DerivedT &RHS) const {
    static_assert(
        IsRandomAccess,
        "Relational operators are only defined for random access iterators.");
    return !static_cast<const DerivedT *>(this)->operator<(RHS);
  }

  PointerT operator->() { return &static_cast<DerivedT *>(this)->operator*(); }
  PointerT operator->() const {
    return &static_cast<const DerivedT *>(this)->operator*();
  }
  ReferenceProxy operator[](DifferenceTypeT n) {
    static_assert(IsRandomAccess,
                  "Subscripting is only defined for random access iterators.");
    return ReferenceProxy(static_cast<DerivedT *>(this)->operator+(n));
  }
  ReferenceProxy operator[](DifferenceTypeT n) const {
    static_assert(IsRandomAccess,
                  "Subscripting is only defined for random access iterators.");
    return ReferenceProxy(static_cast<const DerivedT *>(this)->operator+(n));
  }
};

/// CRTP base class for adapting an iterator to a different type.
///
/// This class can be used through CRTP to adapt one iterator into another.
/// Typically this is done through providing in the derived class a custom \c
/// operator* implementation. Other methods can be overridden as well.
template <
    typename DerivedT, typename WrappedIteratorT,
    typename IteratorCategoryT =
        typename std::iterator_traits<WrappedIteratorT>::iterator_category,
    typename T = typename std::iterator_traits<WrappedIteratorT>::value_type,
    typename DifferenceTypeT =
        typename std::iterator_traits<WrappedIteratorT>::difference_type,
    typename PointerT = std::conditional_t<
        std::is_same<T, typename std::iterator_traits<
                            WrappedIteratorT>::value_type>::value,
        typename std::iterator_traits<WrappedIteratorT>::pointer, T *>,
    typename ReferenceT = std::conditional_t<
        std::is_same<T, typename std::iterator_traits<
                            WrappedIteratorT>::value_type>::value,
        typename std::iterator_traits<WrappedIteratorT>::reference, T &>>
class iterator_adaptor_base
    : public iterator_facade_base<DerivedT, IteratorCategoryT, T,
                                  DifferenceTypeT, PointerT, ReferenceT> {
  using BaseT = typename iterator_adaptor_base::iterator_facade_base;

protected:
  WrappedIteratorT I;

  iterator_adaptor_base() = default;

  explicit iterator_adaptor_base(WrappedIteratorT u) : I(std::move(u)) {
    static_assert(std::is_base_of<iterator_adaptor_base, DerivedT>::value,
                  "Must pass the derived type to this template!");
  }

  const WrappedIteratorT &wrapped() const { return I; }

public:
  using difference_type = DifferenceTypeT;

  DerivedT &operator+=(difference_type n) {
    static_assert(
        BaseT::IsRandomAccess,
        "The '+=' operator is only defined for random access iterators.");
    I += n;
    return *static_cast<DerivedT *>(this);
  }
  DerivedT &operator-=(difference_type n) {
    static_assert(
        BaseT::IsRandomAccess,
        "The '-=' operator is only defined for random access iterators.");
    I -= n;
    return *static_cast<DerivedT *>(this);
  }
  using BaseT::operator-;
  difference_type operator-(const DerivedT &RHS) const {
    static_assert(
        BaseT::IsRandomAccess,
        "The '-' operator is only defined for random access iterators.");
    return I - RHS.I;
  }

  // We have to explicitly provide ++ and -- rather than letting the facade
  // forward to += because WrappedIteratorT might not support +=.
  using BaseT::operator++;
  DerivedT &operator++() {
    ++I;
    return *static_cast<DerivedT *>(this);
  }
  using BaseT::operator--;
  DerivedT &operator--() {
    static_assert(
        BaseT::IsBidirectional,
        "The decrement operator is only defined for bidirectional iterators.");
    --I;
    return *static_cast<DerivedT *>(this);
  }

  bool operator==(const DerivedT &RHS) const { return I == RHS.I; }
  bool operator<(const DerivedT &RHS) const {
    static_assert(
        BaseT::IsRandomAccess,
        "Relational operators are only defined for random access iterators.");
    return I < RHS.I;
  }

  ReferenceT operator*() const { return *I; }
};

/// An iterator type that allows iterating over the pointees via some
/// other iterator.
///
/// The typical usage of this is to expose a type that iterates over Ts, but
/// which is implemented with some iterator over T*s:
///
/// \code
///   using iterator = pointee_iterator<SmallVectorImpl<T *>::iterator>;
/// \endcode
template <typename WrappedIteratorT,
          typename T = std::remove_reference_t<decltype(
              **std::declval<WrappedIteratorT>())>>
struct pointee_iterator
    : iterator_adaptor_base<
          pointee_iterator<WrappedIteratorT, T>, WrappedIteratorT,
          typename std::iterator_traits<WrappedIteratorT>::iterator_category,
          T> {
  pointee_iterator() = default;
  template <typename U>
  pointee_iterator(U &&u)
      : pointee_iterator::iterator_adaptor_base(std::forward<U &&>(u)) {}

  T &operator*() const { return **this->I; }
};

template <typename RangeT, typename WrappedIteratorT =
                               decltype(std::begin(std::declval<RangeT>()))>
iterator_range<pointee_iterator<WrappedIteratorT>>
make_pointee_range(RangeT &&Range) {
  using PointeeIteratorT = pointee_iterator<WrappedIteratorT>;
  return make_range(PointeeIteratorT(std::begin(std::forward<RangeT>(Range))),
                    PointeeIteratorT(std::end(std::forward<RangeT>(Range))));
}

template <typename WrappedIteratorT,
          typename T = decltype(&*std::declval<WrappedIteratorT>())>
class pointer_iterator
    : public iterator_adaptor_base<
          pointer_iterator<WrappedIteratorT, T>, WrappedIteratorT,
          typename std::iterator_traits<WrappedIteratorT>::iterator_category,
          T> {
  mutable T Ptr;

public:
  pointer_iterator() = default;

  explicit pointer_iterator(WrappedIteratorT u)
      : pointer_iterator::iterator_adaptor_base(std::move(u)) {}

  T &operator*() { return Ptr = &*this->I; }
  const T &operator*() const { return Ptr = &*this->I; }
};

template <typename RangeT, typename WrappedIteratorT =
                               decltype(std::begin(std::declval<RangeT>()))>
iterator_range<pointer_iterator<WrappedIteratorT>>
make_pointer_range(RangeT &&Range) {
  using PointerIteratorT = pointer_iterator<WrappedIteratorT>;
  return make_range(PointerIteratorT(std::begin(std::forward<RangeT>(Range))),
                    PointerIteratorT(std::end(std::forward<RangeT>(Range))));
}

template <typename WrappedIteratorT,
          typename T1 = std::remove_reference_t<decltype(
              **std::declval<WrappedIteratorT>())>,
          typename T2 = std::add_pointer_t<T1>>
using raw_pointer_iterator =
    pointer_iterator<pointee_iterator<WrappedIteratorT, T1>, T2>;

// Wrapper iterator over iterator ItType, adding DataRef to the type of ItType,
// to create NodeRef = std::pair<InnerTypeOfItType, DataRef>.
template <typename ItType, typename NodeRef, typename DataRef>
class WrappedPairNodeDataIterator
    : public iterator_adaptor_base<
          WrappedPairNodeDataIterator<ItType, NodeRef, DataRef>, ItType,
          typename std::iterator_traits<ItType>::iterator_category, NodeRef,
          std::ptrdiff_t, NodeRef *, NodeRef &> {
  using BaseT = iterator_adaptor_base<
      WrappedPairNodeDataIterator, ItType,
      typename std::iterator_traits<ItType>::iterator_category, NodeRef,
      std::ptrdiff_t, NodeRef *, NodeRef &>;

  const DataRef DR;
  mutable NodeRef NR;

public:
  WrappedPairNodeDataIterator(ItType Begin, const DataRef DR)
      : BaseT(Begin), DR(DR) {
    NR.first = DR;
  }

  NodeRef &operator*() const {
    NR.second = *this->I;
    return NR;
  }
};

} // end namespace llvm

#endif // LLVM_ADT_ITERATOR_H
# 374 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/iterator.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator_range.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Config/abi-breaking.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 1 "include/llvm/Config/abi-breaking.h" 1
/*===------- llvm/Config/abi-breaking.h - llvm configuration -------*- C -*-===*/
/*                                                                            */
/* Part of the LLVM Project, under the Apache License v2.0 with LLVM          */
/* Exceptions.                                                                */
/* See https://llvm.org/LICENSE.txt for license information.                  */
/* SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception                    */
/*                                                                            */
/*===----------------------------------------------------------------------===*/

/* This file controls the C++ ABI break introduced in LLVM public header. */

#ifndef LLVM_ABI_BREAKING_CHECKS_H
#define LLVM_ABI_BREAKING_CHECKS_H

/* Define to enable checks that alter the LLVM C++ ABI */
#define LLVM_ENABLE_ABI_BREAKING_CHECKS 0

/* Define to enable reverse iteration of unordered llvm containers */
#define LLVM_ENABLE_REVERSE_ITERATION 0

/* Allow selectively disabling link-time mismatch checking so that header-only
   ADT content from LLVM can be used without linking libSupport. */
#if 0 /* disabled by -frewrite-includes */
#if !LLVM_DISABLE_ABI_BREAKING_CHECKS_ENFORCING
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 24 "include/llvm/Config/abi-breaking.h"

// ABI_BREAKING_CHECKS protection: provides link-time failure when clients build
// mismatch with LLVM
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 28 "include/llvm/Config/abi-breaking.h"
// Use pragma with MSVC
#define LLVM_XSTR(s) LLVM_STR(s)
#define LLVM_STR(s) #s
#pragma detect_mismatch("LLVM_ENABLE_ABI_BREAKING_CHECKS", LLVM_XSTR(LLVM_ENABLE_ABI_BREAKING_CHECKS))
#undef LLVM_XSTR
#undef LLVM_STR
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_WIN32) || defined(__CYGWIN__) // Win32 w/o #pragma detect_mismatch
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 35 "include/llvm/Config/abi-breaking.h"
// FIXME: Implement checks without weak.
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 37 "include/llvm/Config/abi-breaking.h"
#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) && defined(__GNUC__) && !defined(__clang__))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 38 "include/llvm/Config/abi-breaking.h"
#define LLVM_HIDDEN_VISIBILITY __attribute__ ((visibility("hidden")))
#else
# 40 "include/llvm/Config/abi-breaking.h"
// GCC on AIX does not support visibility attributes. Symbols are not
// exported by default on AIX.
#define LLVM_HIDDEN_VISIBILITY
#endif
# 44 "include/llvm/Config/abi-breaking.h"
namespace llvm {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 46 "include/llvm/Config/abi-breaking.h"
extern int EnableABIBreakingChecks;
LLVM_HIDDEN_VISIBILITY
__attribute__((weak)) int *VerifyEnableABIBreakingChecks =
    &EnableABIBreakingChecks;
#else
# 51 "include/llvm/Config/abi-breaking.h"
extern int DisableABIBreakingChecks;
LLVM_HIDDEN_VISIBILITY
__attribute__((weak)) int *VerifyDisableABIBreakingChecks =
    &DisableABIBreakingChecks;
#endif
# 56 "include/llvm/Config/abi-breaking.h"
}
#undef LLVM_HIDDEN_VISIBILITY
#endif // _MSC_VER
# 59 "include/llvm/Config/abi-breaking.h"

#endif // LLVM_DISABLE_ABI_BREAKING_CHECKS_ENFORCING
# 61 "include/llvm/Config/abi-breaking.h"

#endif
# 63 "include/llvm/Config/abi-breaking.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h" 1
//===- llvm/Support/ErrorHandling.h - Fatal error handling ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines an API used to indicate fatal error conditions.  Non-fatal
// errors (most of them) should be handled through LLVMContext.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_ERRORHANDLING_H
#define LLVM_SUPPORT_ERRORHANDLING_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 1 3
// -*- C++ -*-
//===--------------------------- string -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STRING
#define _LIBCPP_STRING

/*
    string synopsis

namespace std
{

template <class stateT>
class fpos
{
private:
    stateT st;
public:
    fpos(streamoff = streamoff());

    operator streamoff() const;

    stateT state() const;
    void state(stateT);

    fpos& operator+=(streamoff);
    fpos  operator+ (streamoff) const;
    fpos& operator-=(streamoff);
    fpos  operator- (streamoff) const;
};

template <class stateT> streamoff operator-(const fpos<stateT>& x, const fpos<stateT>& y);

template <class stateT> bool operator==(const fpos<stateT>& x, const fpos<stateT>& y);
template <class stateT> bool operator!=(const fpos<stateT>& x, const fpos<stateT>& y);

template <class charT>
struct char_traits
{
    typedef charT     char_type;
    typedef ...       int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    static void assign(char_type& c1, const char_type& c2) noexcept;
    static constexpr bool eq(char_type c1, char_type c2) noexcept;
    static constexpr bool lt(char_type c1, char_type c2) noexcept;

    static int              compare(const char_type* s1, const char_type* s2, size_t n);
    static size_t           length(const char_type* s);
    static const char_type* find(const char_type* s, size_t n, const char_type& a);
    static char_type*       move(char_type* s1, const char_type* s2, size_t n);
    static char_type*       copy(char_type* s1, const char_type* s2, size_t n);
    static char_type*       assign(char_type* s, size_t n, char_type a);

    static constexpr int_type  not_eof(int_type c) noexcept;
    static constexpr char_type to_char_type(int_type c) noexcept;
    static constexpr int_type  to_int_type(char_type c) noexcept;
    static constexpr bool      eq_int_type(int_type c1, int_type c2) noexcept;
    static constexpr int_type  eof() noexcept;
};

template <> struct char_traits<char>;
template <> struct char_traits<wchar_t>;

template<class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
class basic_string
{
public:
// types:
    typedef traits traits_type;
    typedef typename traits_type::char_type value_type;
    typedef Allocator allocator_type;
    typedef typename allocator_type::size_type size_type;
    typedef typename allocator_type::difference_type difference_type;
    typedef typename allocator_type::reference reference;
    typedef typename allocator_type::const_reference const_reference;
    typedef typename allocator_type::pointer pointer;
    typedef typename allocator_type::const_pointer const_pointer;
    typedef implementation-defined iterator;
    typedef implementation-defined const_iterator;
    typedef std::reverse_iterator<iterator> reverse_iterator;
    typedef std::reverse_iterator<const_iterator> const_reverse_iterator;

    static const size_type npos = -1;

    basic_string()
        noexcept(is_nothrow_default_constructible<allocator_type>::value);
    explicit basic_string(const allocator_type& a);
    basic_string(const basic_string& str);
    basic_string(basic_string&& str)
        noexcept(is_nothrow_move_constructible<allocator_type>::value);
    basic_string(const basic_string& str, size_type pos,
                 const allocator_type& a = allocator_type());
    basic_string(const basic_string& str, size_type pos, size_type n,
                 const Allocator& a = Allocator());
    template<class T>
        basic_string(const T& t, size_type pos, size_type n, const Allocator& a = Allocator()); // C++17
    template <class T>
        explicit basic_string(const T& t, const Allocator& a = Allocator()); // C++17
    basic_string(const value_type* s, const allocator_type& a = allocator_type());
    basic_string(const value_type* s, size_type n, const allocator_type& a = allocator_type());
    basic_string(size_type n, value_type c, const allocator_type& a = allocator_type());
    template<class InputIterator>
        basic_string(InputIterator begin, InputIterator end,
                     const allocator_type& a = allocator_type());
    basic_string(initializer_list<value_type>, const Allocator& = Allocator());
    basic_string(const basic_string&, const Allocator&);
    basic_string(basic_string&&, const Allocator&);

    ~basic_string();

    operator basic_string_view<charT, traits>() const noexcept;

    basic_string& operator=(const basic_string& str);
    template <class T>
        basic_string& operator=(const T& t); // C++17
    basic_string& operator=(basic_string&& str)
        noexcept(
             allocator_type::propagate_on_container_move_assignment::value ||
             allocator_type::is_always_equal::value ); // C++17
    basic_string& operator=(const value_type* s);
    basic_string& operator=(value_type c);
    basic_string& operator=(initializer_list<value_type>);

    iterator       begin() noexcept;
    const_iterator begin() const noexcept;
    iterator       end() noexcept;
    const_iterator end() const noexcept;

    reverse_iterator       rbegin() noexcept;
    const_reverse_iterator rbegin() const noexcept;
    reverse_iterator       rend() noexcept;
    const_reverse_iterator rend() const noexcept;

    const_iterator         cbegin() const noexcept;
    const_iterator         cend() const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend() const noexcept;

    size_type size() const noexcept;
    size_type length() const noexcept;
    size_type max_size() const noexcept;
    size_type capacity() const noexcept;

    void resize(size_type n, value_type c);
    void resize(size_type n);

    void reserve(size_type res_arg = 0);
    void shrink_to_fit();
    void clear() noexcept;
    bool empty() const noexcept;

    const_reference operator[](size_type pos) const;
    reference       operator[](size_type pos);

    const_reference at(size_type n) const;
    reference       at(size_type n);

    basic_string& operator+=(const basic_string& str);
    template <class T>
        basic_string& operator+=(const T& t);              // C++17
    basic_string& operator+=(const value_type* s);
    basic_string& operator+=(value_type c);
    basic_string& operator+=(initializer_list<value_type>);

    basic_string& append(const basic_string& str);
    template <class T>
        basic_string& append(const T& t);                 // C++17
    basic_string& append(const basic_string& str, size_type pos, size_type n=npos); //C++14
    template <class T>
        basic_string& append(const T& t, size_type pos, size_type n=npos); // C++17
    basic_string& append(const value_type* s, size_type n);
    basic_string& append(const value_type* s);
    basic_string& append(size_type n, value_type c);
    template<class InputIterator>
        basic_string& append(InputIterator first, InputIterator last);
    basic_string& append(initializer_list<value_type>);

    void push_back(value_type c);
    void pop_back();
    reference       front();
    const_reference front() const;
    reference       back();
    const_reference back() const;

    basic_string& assign(const basic_string& str);
    template <class T>
        basic_string& assign(const T& t);  // C++17
    basic_string& assign(basic_string&& str);
    basic_string& assign(const basic_string& str, size_type pos, size_type n=npos); // C++14
    template <class T>
        basic_string& assign(const T& t, size_type pos, size_type n=npos); // C++17
    basic_string& assign(const value_type* s, size_type n);
    basic_string& assign(const value_type* s);
    basic_string& assign(size_type n, value_type c);
    template<class InputIterator>
        basic_string& assign(InputIterator first, InputIterator last);
    basic_string& assign(initializer_list<value_type>);

    basic_string& insert(size_type pos1, const basic_string& str);
    template <class T>
        basic_string& insert(size_type pos1, const T& t);
    basic_string& insert(size_type pos1, const basic_string& str,
                         size_type pos2, size_type n);
    template <class T>
        basic_string& insert(size_type pos1, const T& t, size_type pos2, size_type n); // C++17
    basic_string& insert(size_type pos, const value_type* s, size_type n=npos); //C++14
    basic_string& insert(size_type pos, const value_type* s);
    basic_string& insert(size_type pos, size_type n, value_type c);
    iterator      insert(const_iterator p, value_type c);
    iterator      insert(const_iterator p, size_type n, value_type c);
    template<class InputIterator>
        iterator insert(const_iterator p, InputIterator first, InputIterator last);
    iterator      insert(const_iterator p, initializer_list<value_type>);

    basic_string& erase(size_type pos = 0, size_type n = npos);
    iterator      erase(const_iterator position);
    iterator      erase(const_iterator first, const_iterator last);

    basic_string& replace(size_type pos1, size_type n1, const basic_string& str);
    template <class T>
    basic_string& replace(size_type pos1, size_type n1, const T& t);  // C++17
    basic_string& replace(size_type pos1, size_type n1, const basic_string& str,
                          size_type pos2, size_type n2=npos); // C++14
    template <class T>
        basic_string& replace(size_type pos1, size_type n1, const T& t,
                              size_type pos2, size_type n); // C++17
    basic_string& replace(size_type pos, size_type n1, const value_type* s, size_type n2);
    basic_string& replace(size_type pos, size_type n1, const value_type* s);
    basic_string& replace(size_type pos, size_type n1, size_type n2, value_type c);
    basic_string& replace(const_iterator i1, const_iterator i2, const basic_string& str);
    template <class T>
        basic_string& replace(const_iterator i1, const_iterator i2, const T& t);  // C++17
    basic_string& replace(const_iterator i1, const_iterator i2, const value_type* s, size_type n);
    basic_string& replace(const_iterator i1, const_iterator i2, const value_type* s);
    basic_string& replace(const_iterator i1, const_iterator i2, size_type n, value_type c);
    template<class InputIterator>
        basic_string& replace(const_iterator i1, const_iterator i2, InputIterator j1, InputIterator j2);
    basic_string& replace(const_iterator i1, const_iterator i2, initializer_list<value_type>);

    size_type copy(value_type* s, size_type n, size_type pos = 0) const;
    basic_string substr(size_type pos = 0, size_type n = npos) const;

    void swap(basic_string& str)
        noexcept(allocator_traits<allocator_type>::propagate_on_container_swap::value ||
                 allocator_traits<allocator_type>::is_always_equal::value);  // C++17

    const value_type* c_str() const noexcept;
    const value_type* data() const noexcept;
          value_type* data()       noexcept;   // C++17

    allocator_type get_allocator() const noexcept;

    size_type find(const basic_string& str, size_type pos = 0) const noexcept;
    template <class T>
        size_type find(const T& t, size_type pos = 0) const;  // C++17
    size_type find(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find(const value_type* s, size_type pos = 0) const noexcept;
    size_type find(value_type c, size_type pos = 0) const noexcept;

    size_type rfind(const basic_string& str, size_type pos = npos) const noexcept;
    template <class T>
        size_type rfind(const T& t, size_type pos = npos) const;  // C++17
    size_type rfind(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type rfind(const value_type* s, size_type pos = npos) const noexcept;
    size_type rfind(value_type c, size_type pos = npos) const noexcept;

    size_type find_first_of(const basic_string& str, size_type pos = 0) const noexcept;
    template <class T>
        size_type find_first_of(const T& t, size_type pos = 0) const; // C++17
    size_type find_first_of(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find_first_of(const value_type* s, size_type pos = 0) const noexcept;
    size_type find_first_of(value_type c, size_type pos = 0) const noexcept;

    size_type find_last_of(const basic_string& str, size_type pos = npos) const noexcept;
    template <class T>
        size_type find_last_of(const T& t, size_type pos = npos) const noexcept;  // C++17
    size_type find_last_of(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find_last_of(const value_type* s, size_type pos = npos) const noexcept;
    size_type find_last_of(value_type c, size_type pos = npos) const noexcept;

    size_type find_first_not_of(const basic_string& str, size_type pos = 0) const noexcept;
    template <class T>
        size_type find_first_not_of(const T& t, size_type pos = 0) const; // C++17
    size_type find_first_not_of(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find_first_not_of(const value_type* s, size_type pos = 0) const noexcept;
    size_type find_first_not_of(value_type c, size_type pos = 0) const noexcept;

    size_type find_last_not_of(const basic_string& str, size_type pos = npos) const noexcept;
    template <class T>
        size_type find_last_not_of(const T& t, size_type pos = npos) const; // C++17
    size_type find_last_not_of(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find_last_not_of(const value_type* s, size_type pos = npos) const noexcept;
    size_type find_last_not_of(value_type c, size_type pos = npos) const noexcept;

    int compare(const basic_string& str) const noexcept;
    template <class T>
        int compare(const T& t) const noexcept;  // C++17
    int compare(size_type pos1, size_type n1, const basic_string& str) const;
    template <class T>
        int compare(size_type pos1, size_type n1, const T& t) const;  // C++17
    int compare(size_type pos1, size_type n1, const basic_string& str,
                size_type pos2, size_type n2=npos) const; // C++14
    template <class T>
        int compare(size_type pos1, size_type n1, const T& t,
                    size_type pos2, size_type n2=npos) const; // C++17
    int compare(const value_type* s) const noexcept;
    int compare(size_type pos1, size_type n1, const value_type* s) const;
    int compare(size_type pos1, size_type n1, const value_type* s, size_type n2) const;

    bool starts_with(basic_string_view<charT, traits> sv) const noexcept; // C++2a
    bool starts_with(charT c) const noexcept;                             // C++2a
    bool starts_with(const charT* s) const;                               // C++2a
    bool ends_with(basic_string_view<charT, traits> sv) const noexcept;   // C++2a
    bool ends_with(charT c) const noexcept;                               // C++2a
    bool ends_with(const charT* s) const;                                 // C++2a

    bool __invariants() const;
};

template<class InputIterator,
         class Allocator = allocator<typename iterator_traits<InputIterator>::value_type>>
basic_string(InputIterator, InputIterator, Allocator = Allocator())
   -> basic_string<typename iterator_traits<InputIterator>::value_type,
                  char_traits<typename iterator_traits<InputIterator>::value_type>,
                  Allocator>;   // C++17

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(const basic_string<charT, traits, Allocator>& lhs,
          const basic_string<charT, traits, Allocator>& rhs);

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(const charT* lhs , const basic_string<charT,traits,Allocator>&rhs);

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(charT lhs, const basic_string<charT,traits,Allocator>& rhs);

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(const basic_string<charT, traits, Allocator>& lhs, const charT* rhs);

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(const basic_string<charT, traits, Allocator>& lhs, charT rhs);

template<class charT, class traits, class Allocator>
bool operator==(const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator==(const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator==(const basic_string<charT,traits,Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator!=(const basic_string<charT,traits,Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator!=(const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator!=(const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator< (const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator< (const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator< (const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator> (const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator> (const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator> (const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator<=(const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator<=(const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator<=(const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator>=(const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator>=(const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator>=(const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
void swap(basic_string<charT, traits, Allocator>& lhs,
          basic_string<charT, traits, Allocator>& rhs)
            noexcept(noexcept(lhs.swap(rhs)));

template<class charT, class traits, class Allocator>
basic_istream<charT, traits>&
operator>>(basic_istream<charT, traits>& is, basic_string<charT, traits, Allocator>& str);

template<class charT, class traits, class Allocator>
basic_ostream<charT, traits>&
operator<<(basic_ostream<charT, traits>& os, const basic_string<charT, traits, Allocator>& str);

template<class charT, class traits, class Allocator>
basic_istream<charT, traits>&
getline(basic_istream<charT, traits>& is, basic_string<charT, traits, Allocator>& str,
        charT delim);

template<class charT, class traits, class Allocator>
basic_istream<charT, traits>&
getline(basic_istream<charT, traits>& is, basic_string<charT, traits, Allocator>& str);

template<class charT, class traits, class Allocator, class U>
void erase(basic_string<charT, traits, Allocator>& c, const U& value); // C++20
template<class charT, class traits, class Allocator, class Predicate>
void erase_if(basic_string<charT, traits, Allocator>& c, Predicate pred); // C++20

typedef basic_string<char>    string;
typedef basic_string<wchar_t> wstring;
typedef basic_string<char16_t> u16string;
typedef basic_string<char32_t> u32string;

int                stoi  (const string& str, size_t* idx = 0, int base = 10);
long               stol  (const string& str, size_t* idx = 0, int base = 10);
unsigned long      stoul (const string& str, size_t* idx = 0, int base = 10);
long long          stoll (const string& str, size_t* idx = 0, int base = 10);
unsigned long long stoull(const string& str, size_t* idx = 0, int base = 10);

float       stof (const string& str, size_t* idx = 0);
double      stod (const string& str, size_t* idx = 0);
long double stold(const string& str, size_t* idx = 0);

string to_string(int val);
string to_string(unsigned val);
string to_string(long val);
string to_string(unsigned long val);
string to_string(long long val);
string to_string(unsigned long long val);
string to_string(float val);
string to_string(double val);
string to_string(long double val);

int                stoi  (const wstring& str, size_t* idx = 0, int base = 10);
long               stol  (const wstring& str, size_t* idx = 0, int base = 10);
unsigned long      stoul (const wstring& str, size_t* idx = 0, int base = 10);
long long          stoll (const wstring& str, size_t* idx = 0, int base = 10);
unsigned long long stoull(const wstring& str, size_t* idx = 0, int base = 10);

float       stof (const wstring& str, size_t* idx = 0);
double      stod (const wstring& str, size_t* idx = 0);
long double stold(const wstring& str, size_t* idx = 0);

wstring to_wstring(int val);
wstring to_wstring(unsigned val);
wstring to_wstring(long val);
wstring to_wstring(unsigned long val);
wstring to_wstring(long long val);
wstring to_wstring(unsigned long long val);
wstring to_wstring(float val);
wstring to_wstring(double val);
wstring to_wstring(long double val);

template <> struct hash<string>;
template <> struct hash<u16string>;
template <> struct hash<u32string>;
template <> struct hash<wstring>;

basic_string<char>     operator "" s( const char *str,     size_t len ); // C++14
basic_string<wchar_t>  operator "" s( const wchar_t *str,  size_t len ); // C++14
basic_string<char16_t> operator "" s( const char16_t *str, size_t len ); // C++14
basic_string<char32_t> operator "" s( const char32_t *str, size_t len ); // C++14

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 503 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 504 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <string_view>
#endif /* expanded by -frewrite-includes */
# 504 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 1 3
// -*- C++ -*-
//===------------------------ string_view ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STRING_VIEW
#define _LIBCPP_STRING_VIEW

/*
string_view synopsis

namespace std {

    // 7.2, Class template basic_string_view
    template<class charT, class traits = char_traits<charT>>
        class basic_string_view;

    // 7.9, basic_string_view non-member comparison functions
    template<class charT, class traits>
    constexpr bool operator==(basic_string_view<charT, traits> x,
                              basic_string_view<charT, traits> y) noexcept;
    template<class charT, class traits>
    constexpr bool operator!=(basic_string_view<charT, traits> x,
                              basic_string_view<charT, traits> y) noexcept;
    template<class charT, class traits>
    constexpr bool operator< (basic_string_view<charT, traits> x,
                                 basic_string_view<charT, traits> y) noexcept;
    template<class charT, class traits>
    constexpr bool operator> (basic_string_view<charT, traits> x,
                              basic_string_view<charT, traits> y) noexcept;
    template<class charT, class traits>
    constexpr bool operator<=(basic_string_view<charT, traits> x,
                                 basic_string_view<charT, traits> y) noexcept;
    template<class charT, class traits>
    constexpr bool operator>=(basic_string_view<charT, traits> x,
                              basic_string_view<charT, traits> y) noexcept;
    // see below, sufficient additional overloads of comparison functions

    // 7.10, Inserters and extractors
    template<class charT, class traits>
      basic_ostream<charT, traits>&
        operator<<(basic_ostream<charT, traits>& os,
                   basic_string_view<charT, traits> str);

    // basic_string_view typedef names
    typedef basic_string_view<char> string_view;
    typedef basic_string_view<char16_t> u16string_view;
    typedef basic_string_view<char32_t> u32string_view;
    typedef basic_string_view<wchar_t> wstring_view;

    template<class charT, class traits = char_traits<charT>>
    class basic_string_view {
      public:
      // types
      typedef traits traits_type;
      typedef charT value_type;
      typedef charT* pointer;
      typedef const charT* const_pointer;
      typedef charT& reference;
      typedef const charT& const_reference;
      typedef implementation-defined const_iterator;
      typedef const_iterator iterator;
      typedef reverse_iterator<const_iterator> const_reverse_iterator;
      typedef const_reverse_iterator reverse_iterator;
      typedef size_t size_type;
      typedef ptrdiff_t difference_type;
      static constexpr size_type npos = size_type(-1);

      // 7.3, basic_string_view constructors and assignment operators
      constexpr basic_string_view() noexcept;
      constexpr basic_string_view(const basic_string_view&) noexcept = default;
      basic_string_view& operator=(const basic_string_view&) noexcept = default;
      template<class Allocator>
      constexpr basic_string_view(const charT* str);
      constexpr basic_string_view(const charT* str, size_type len);

      // 7.4, basic_string_view iterator support
      constexpr const_iterator begin() const noexcept;
      constexpr const_iterator end() const noexcept;
      constexpr const_iterator cbegin() const noexcept;
      constexpr const_iterator cend() const noexcept;
      const_reverse_iterator rbegin() const noexcept;
      const_reverse_iterator rend() const noexcept;
      const_reverse_iterator crbegin() const noexcept;
      const_reverse_iterator crend() const noexcept;

      // 7.5, basic_string_view capacity
      constexpr size_type size() const noexcept;
      constexpr size_type length() const noexcept;
      constexpr size_type max_size() const noexcept;
      constexpr bool empty() const noexcept;

      // 7.6, basic_string_view element access
      constexpr const_reference operator[](size_type pos) const;
      constexpr const_reference at(size_type pos) const;
      constexpr const_reference front() const;
      constexpr const_reference back() const;
      constexpr const_pointer data() const noexcept;

      // 7.7, basic_string_view modifiers
      constexpr void remove_prefix(size_type n);
      constexpr void remove_suffix(size_type n);
      constexpr void swap(basic_string_view& s) noexcept;

      size_type copy(charT* s, size_type n, size_type pos = 0) const;

      constexpr basic_string_view substr(size_type pos = 0, size_type n = npos) const;
      constexpr int compare(basic_string_view s) const noexcept;
      constexpr int compare(size_type pos1, size_type n1, basic_string_view s) const;
      constexpr int compare(size_type pos1, size_type n1,
                            basic_string_view s, size_type pos2, size_type n2) const;
      constexpr int compare(const charT* s) const;
      constexpr int compare(size_type pos1, size_type n1, const charT* s) const;
      constexpr int compare(size_type pos1, size_type n1,
                            const charT* s, size_type n2) const;
      constexpr size_type find(basic_string_view s, size_type pos = 0) const noexcept;
      constexpr size_type find(charT c, size_type pos = 0) const noexcept;
      constexpr size_type find(const charT* s, size_type pos, size_type n) const;
      constexpr size_type find(const charT* s, size_type pos = 0) const;
      constexpr size_type rfind(basic_string_view s, size_type pos = npos) const noexcept;
      constexpr size_type rfind(charT c, size_type pos = npos) const noexcept;
      constexpr size_type rfind(const charT* s, size_type pos, size_type n) const;
      constexpr size_type rfind(const charT* s, size_type pos = npos) const;
      constexpr size_type find_first_of(basic_string_view s, size_type pos = 0) const noexcept;
      constexpr size_type find_first_of(charT c, size_type pos = 0) const noexcept;
      constexpr size_type find_first_of(const charT* s, size_type pos, size_type n) const;
      constexpr size_type find_first_of(const charT* s, size_type pos = 0) const;
      constexpr size_type find_last_of(basic_string_view s, size_type pos = npos) const noexcept;
      constexpr size_type find_last_of(charT c, size_type pos = npos) const noexcept;
      constexpr size_type find_last_of(const charT* s, size_type pos, size_type n) const;
      constexpr size_type find_last_of(const charT* s, size_type pos = npos) const;
      constexpr size_type find_first_not_of(basic_string_view s, size_type pos = 0) const noexcept;
      constexpr size_type find_first_not_of(charT c, size_type pos = 0) const noexcept;
      constexpr size_type find_first_not_of(const charT* s, size_type pos, size_type n) const;
      constexpr size_type find_first_not_of(const charT* s, size_type pos = 0) const;
      constexpr size_type find_last_not_of(basic_string_view s, size_type pos = npos) const noexcept;
      constexpr size_type find_last_not_of(charT c, size_type pos = npos) const noexcept;
      constexpr size_type find_last_not_of(const charT* s, size_type pos, size_type n) const;
      constexpr size_type find_last_not_of(const charT* s, size_type pos = npos) const;

      constexpr bool starts_with(basic_string_view s) const noexcept; // C++2a
      constexpr bool starts_with(charT c) const noexcept;             // C++2a
      constexpr bool starts_with(const charT* s) const;               // C++2a
      constexpr bool ends_with(basic_string_view s) const noexcept;   // C++2a
      constexpr bool ends_with(charT c) const noexcept;               // C++2a
      constexpr bool ends_with(const charT* s) const;                 // C++2a

     private:
      const_pointer data_;  // exposition only
      size_type     size_;  // exposition only
    };

  // 7.11, Hash support
  template <class T> struct hash;
  template <> struct hash<string_view>;
  template <> struct hash<u16string_view>;
  template <> struct hash<u32string_view>;
  template <> struct hash<wstring_view>;

  constexpr basic_string_view<char>     operator "" sv( const char *str,     size_t len ) noexcept;
  constexpr basic_string_view<wchar_t>  operator "" sv( const wchar_t *str,  size_t len ) noexcept;
  constexpr basic_string_view<char16_t> operator "" sv( const char16_t *str, size_t len ) noexcept;
  constexpr basic_string_view<char32_t> operator "" sv( const char32_t *str, size_t len ) noexcept;

}  // namespace std


*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 174 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 175 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#if 0 /* expanded by -frewrite-includes */
#include <__string>
#endif /* expanded by -frewrite-includes */
# 175 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 1 3
// -*- C++ -*-
//===-------------------------- __string ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___STRING
#define _LIBCPP___STRING

/*
    string synopsis

namespace std
{

template <class charT>
struct char_traits
{
    typedef charT     char_type;
    typedef ...       int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    static constexpr void assign(char_type& c1, const char_type& c2) noexcept;
    static constexpr bool eq(char_type c1, char_type c2) noexcept;
    static constexpr bool lt(char_type c1, char_type c2) noexcept;

    static constexpr int    compare(const char_type* s1, const char_type* s2, size_t n);
    static constexpr size_t length(const char_type* s);
    static constexpr const char_type*
                            find(const char_type* s, size_t n, const char_type& a);

    static constexpr char_type* move(char_type* s1, const char_type* s2, size_t n); // constexpr in C++20
    static constexpr char_type* copy(char_type* s1, const char_type* s2, size_t n); // constexpr in C++20
    static constexpr char_type* assign(char_type* s, size_t n, char_type a);        // constexpr in C++20

    static constexpr int_type  not_eof(int_type c) noexcept;
    static constexpr char_type to_char_type(int_type c) noexcept;
    static constexpr int_type  to_int_type(char_type c) noexcept;
    static constexpr bool      eq_int_type(int_type c1, int_type c2) noexcept;
    static constexpr int_type  eof() noexcept;
};

template <> struct char_traits<char>;
template <> struct char_traits<wchar_t>;
template <> struct char_traits<char8_t>;  // c++20

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 56 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>  // for search and min
#endif /* expanded by -frewrite-includes */
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdio>     // For EOF.
#endif /* expanded by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 1 3
// -*- C++ -*-
//===---------------------------- cstdio ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDIO
#define _LIBCPP_CSTDIO

/*
    cstdio synopsis

Macros:

    BUFSIZ
    EOF
    FILENAME_MAX
    FOPEN_MAX
    L_tmpnam
    NULL
    SEEK_CUR
    SEEK_END
    SEEK_SET
    TMP_MAX
    _IOFBF
    _IOLBF
    _IONBF
    stderr
    stdin
    stdout

namespace std
{

Types:

FILE
fpos_t
size_t

int remove(const char* filename);
int rename(const char* old, const char* new);
FILE* tmpfile(void);
char* tmpnam(char* s);
int fclose(FILE* stream);
int fflush(FILE* stream);
FILE* fopen(const char* restrict filename, const char* restrict mode);
FILE* freopen(const char* restrict filename, const char * restrict mode,
              FILE * restrict stream);
void setbuf(FILE* restrict stream, char* restrict buf);
int setvbuf(FILE* restrict stream, char* restrict buf, int mode, size_t size);
int fprintf(FILE* restrict stream, const char* restrict format, ...);
int fscanf(FILE* restrict stream, const char * restrict format, ...);
int printf(const char* restrict format, ...);
int scanf(const char* restrict format, ...);
int snprintf(char* restrict s, size_t n, const char* restrict format, ...);    // C99
int sprintf(char* restrict s, const char* restrict format, ...);
int sscanf(const char* restrict s, const char* restrict format, ...);
int vfprintf(FILE* restrict stream, const char* restrict format, va_list arg);
int vfscanf(FILE* restrict stream, const char* restrict format, va_list arg);  // C99
int vprintf(const char* restrict format, va_list arg);
int vscanf(const char* restrict format, va_list arg);                          // C99
int vsnprintf(char* restrict s, size_t n, const char* restrict format,         // C99
              va_list arg);
int vsprintf(char* restrict s, const char* restrict format, va_list arg);
int vsscanf(const char* restrict s, const char* restrict format, va_list arg); // C99
int fgetc(FILE* stream);
char* fgets(char* restrict s, int n, FILE* restrict stream);
int fputc(int c, FILE* stream);
int fputs(const char* restrict s, FILE* restrict stream);
int getc(FILE* stream);
int getchar(void);
char* gets(char* s);  // removed in C++14
int putc(int c, FILE* stream);
int putchar(int c);
int puts(const char* s);
int ungetc(int c, FILE* stream);
size_t fread(void* restrict ptr, size_t size, size_t nmemb,
             FILE* restrict stream);
size_t fwrite(const void* restrict ptr, size_t size, size_t nmemb,
              FILE* restrict stream);
int fgetpos(FILE* restrict stream, fpos_t* restrict pos);
int fseek(FILE* stream, long offset, int whence);
int fsetpos(FILE*stream, const fpos_t* pos);
long ftell(FILE* stream);
void rewind(FILE* stream);
void clearerr(FILE* stream);
int feof(FILE* stream);
int ferror(FILE* stream);
void perror(const char* s);

}  // std
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3
# 99 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdio.h>
#endif /* expanded by -frewrite-includes */
# 99 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 1 3
// -*- C++ -*-
//===---------------------------- stdio.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_FILE) || defined(__need___FILE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdio.h>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDIO_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
#define _LIBCPP_STDIO_H

/*
    stdio.h synopsis

Macros:

    BUFSIZ
    EOF
    FILENAME_MAX
    FOPEN_MAX
    L_tmpnam
    NULL
    SEEK_CUR
    SEEK_END
    SEEK_SET
    TMP_MAX
    _IOFBF
    _IOLBF
    _IONBF
    stderr
    stdin
    stdout

Types:

FILE
fpos_t
size_t

int remove(const char* filename);
int rename(const char* old, const char* new);
FILE* tmpfile(void);
char* tmpnam(char* s);
int fclose(FILE* stream);
int fflush(FILE* stream);
FILE* fopen(const char* restrict filename, const char* restrict mode);
FILE* freopen(const char* restrict filename, const char * restrict mode,
              FILE * restrict stream);
void setbuf(FILE* restrict stream, char* restrict buf);
int setvbuf(FILE* restrict stream, char* restrict buf, int mode, size_t size);
int fprintf(FILE* restrict stream, const char* restrict format, ...);
int fscanf(FILE* restrict stream, const char * restrict format, ...);
int printf(const char* restrict format, ...);
int scanf(const char* restrict format, ...);
int snprintf(char* restrict s, size_t n, const char* restrict format, ...);    // C99
int sprintf(char* restrict s, const char* restrict format, ...);
int sscanf(const char* restrict s, const char* restrict format, ...);
int vfprintf(FILE* restrict stream, const char* restrict format, va_list arg);
int vfscanf(FILE* restrict stream, const char* restrict format, va_list arg);  // C99
int vprintf(const char* restrict format, va_list arg);
int vscanf(const char* restrict format, va_list arg);                          // C99
int vsnprintf(char* restrict s, size_t n, const char* restrict format,         // C99
              va_list arg);
int vsprintf(char* restrict s, const char* restrict format, va_list arg);
int vsscanf(const char* restrict s, const char* restrict format, va_list arg); // C99
int fgetc(FILE* stream);
char* fgets(char* restrict s, int n, FILE* restrict stream);
int fputc(int c, FILE* stream);
int fputs(const char* restrict s, FILE* restrict stream);
int getc(FILE* stream);
int getchar(void);
char* gets(char* s);  // removed in C++14
int putc(int c, FILE* stream);
int putchar(int c);
int puts(const char* s);
int ungetc(int c, FILE* stream);
size_t fread(void* restrict ptr, size_t size, size_t nmemb,
             FILE* restrict stream);
size_t fwrite(const void* restrict ptr, size_t size, size_t nmemb,
              FILE* restrict stream);
int fgetpos(FILE* restrict stream, fpos_t* restrict pos);
int fseek(FILE* stream, long offset, int whence);
int fsetpos(FILE*stream, const fpos_t* pos);
long ftell(FILE* stream);
void rewind(FILE* stream);
void clearerr(FILE* stream);
int feof(FILE* stream);
int ferror(FILE* stream);
void perror(const char* s);
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
#endif
# 106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdio.h>
#endif /* expanded by -frewrite-includes */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#ifdef __cplusplus

#undef getc
#undef putc
#undef clearerr
#undef feof
#undef ferror

#endif
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3

#endif  // _LIBCPP_STDIO_H
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdio.h" 3
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 103 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3
#endif
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::FILE;
using ::fpos_t;
using ::size_t;

using ::fclose;
using ::fflush;
using ::setbuf;
using ::setvbuf;
using ::fprintf;
using ::fscanf;
using ::snprintf;
using ::sprintf;
using ::sscanf;
using ::vfprintf;
using ::vfscanf;
using ::vsscanf;
using ::vsnprintf;
using ::vsprintf;
using ::fgetc;
using ::fgets;
using ::fputc;
using ::fputs;
using ::getc;
using ::putc;
using ::ungetc;
using ::fread;
using ::fwrite;
using ::fgetpos;
using ::fseek;
using ::fsetpos;
using ::ftell;
using ::rewind;
using ::clearerr;
using ::feof;
using ::ferror;
using ::perror;

#ifndef _LIBCPP_HAS_NO_GLOBAL_FILESYSTEM_NAMESPACE
using ::fopen;
using ::freopen;
using ::remove;
using ::rename;
using ::tmpfile;
using ::tmpnam;
#endif
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3

#ifndef _LIBCPP_HAS_NO_STDIN
using ::getchar;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 11 && !defined(_LIBCPP_C_HAS_NO_GETS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3
using ::gets;
#endif
# 158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3
using ::scanf;
using ::vscanf;
#endif
# 161 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3

#ifndef _LIBCPP_HAS_NO_STDOUT
using ::printf;
using ::putchar;
using ::puts;
using ::vprintf;
#endif
# 168 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTDIO
# 172 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cstdio" 3
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>     // for __murmur2_or_cityhash
#endif /* expanded by -frewrite-includes */
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3

#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 64 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
#endif
# 66 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 68 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

// The the extern template ABI lists are kept outside of <string> to improve the
// readability of that header.
#define _LIBCPP_STRING_EXTERN_TEMPLATE_LIST(_Func, _CharType) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::replace(size_type, size_type, value_type const*, size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::rfind(value_type const*, size_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS void basic_string<_CharType>::__init(value_type const*, size_type, size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::basic_string(basic_string const&)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::replace(size_type, size_type, value_type const*)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::basic_string(basic_string const&, std::allocator<_CharType> const&)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::find_last_not_of(value_type const*, size_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::~basic_string()) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::find_first_not_of(value_type const*, size_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::insert(size_type, size_type, value_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::operator=(value_type)) \
  _Func(_LIBCPP_FUNC_VIS void basic_string<_CharType>::__init(value_type const*, size_type)) \
  _Func(_LIBCPP_FUNC_VIS const _CharType& basic_string<_CharType>::at(size_type) const) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::insert(size_type, value_type const*, size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::find_first_of(value_type const*, size_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::replace(size_type, size_type, size_type, value_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::assign(value_type const*, size_type)) \
  _Func(_LIBCPP_FUNC_VIS void basic_string<_CharType>::reserve(size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::append(value_type const*, size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::assign(basic_string const&, size_type, size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::copy(value_type*, size_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::basic_string(basic_string const&, size_type, size_type, std::allocator<_CharType> const&)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::find(value_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS void basic_string<_CharType>::__init(size_type, value_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::insert(size_type, value_type const*)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::find_last_of(value_type const*, size_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS void basic_string<_CharType>::__grow_by(size_type, size_type, size_type, size_type, size_type, size_type)) \
  _Func(_LIBCPP_FUNC_VIS void basic_string<_CharType>::__grow_by_and_replace(size_type, size_type, size_type, size_type, size_type, size_type, value_type const*)) \
  _Func(_LIBCPP_FUNC_VIS void basic_string<_CharType>::push_back(value_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::append(size_type, value_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::rfind(value_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS const basic_string<_CharType>::size_type basic_string<_CharType>::npos) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::assign(size_type, value_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::erase(size_type, size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::append(basic_string const&, size_type, size_type)) \
  _Func(_LIBCPP_FUNC_VIS int basic_string<_CharType>::compare(value_type const*) const) \
  _Func(_LIBCPP_FUNC_VIS int basic_string<_CharType>::compare(size_type, size_type, value_type const*) const) \
  _Func(_LIBCPP_FUNC_VIS _CharType& basic_string<_CharType>::at(size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::assign(value_type const*)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::size_type basic_string<_CharType>::find(value_type const*, size_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS int basic_string<_CharType>::compare(size_type, size_type, basic_string const&, size_type, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS int basic_string<_CharType>::compare(size_type, size_type, value_type const*, size_type) const) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::operator=(basic_string const&)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::append(value_type const*)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::replace(size_type, size_type, basic_string const&, size_type, size_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>::iterator basic_string<_CharType>::insert(basic_string::const_iterator, value_type)) \
  _Func(_LIBCPP_FUNC_VIS void basic_string<_CharType>::resize(size_type, value_type)) \
  _Func(_LIBCPP_FUNC_VIS basic_string<_CharType>& basic_string<_CharType>::insert(size_type, basic_string const&, size_type, size_type))


// char_traits

template <class _CharT>
struct _LIBCPP_TEMPLATE_VIS char_traits
{
    typedef _CharT    char_type;
    typedef int       int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    static inline void _LIBCPP_CONSTEXPR_AFTER_CXX14
        assign(char_type& __c1, const char_type& __c2) _NOEXCEPT {__c1 = __c2;}
    static inline _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 < __c2;}

    static _LIBCPP_CONSTEXPR_AFTER_CXX14
    int compare(const char_type* __s1, const char_type* __s2, size_t __n);
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR_AFTER_CXX14
    size_t length(const char_type* __s);
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR_AFTER_CXX14
    const char_type* find(const char_type* __s, size_t __n, const char_type& __a);
    static _LIBCPP_CONSTEXPR_AFTER_CXX17
    char_type*       move(char_type* __s1, const char_type* __s2, size_t __n);
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR_AFTER_CXX17
    char_type*       copy(char_type* __s1, const char_type* __s2, size_t __n);
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR_AFTER_CXX17
    char_type*       assign(char_type* __s, size_t __n, char_type __a);

    static inline _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    static inline _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    static inline _LIBCPP_CONSTEXPR int_type  to_int_type(char_type __c) _NOEXCEPT
        {return int_type(__c);}
    static inline _LIBCPP_CONSTEXPR bool      eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR int_type  eof() _NOEXCEPT
        {return int_type(EOF);}
};

template <class _CharT>
_LIBCPP_CONSTEXPR_AFTER_CXX14 int
char_traits<_CharT>::compare(const char_type* __s1, const char_type* __s2, size_t __n)
{
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
}

template <class _CharT>
inline
_LIBCPP_CONSTEXPR_AFTER_CXX14 size_t
char_traits<_CharT>::length(const char_type* __s)
{
    size_t __len = 0;
    for (; !eq(*__s, char_type(0)); ++__s)
        ++__len;
    return __len;
}

template <class _CharT>
inline
_LIBCPP_CONSTEXPR_AFTER_CXX14 const _CharT*
char_traits<_CharT>::find(const char_type* __s, size_t __n, const char_type& __a)
{
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return 0;
}

template <class _CharT>
_LIBCPP_CONSTEXPR_AFTER_CXX17 _CharT*
char_traits<_CharT>::move(char_type* __s1, const char_type* __s2, size_t __n)
{
    if (__n == 0) return __s1;
    char_type* __r = __s1;
    if (__s1 < __s2)
    {
        for (; __n; --__n, ++__s1, ++__s2)
            assign(*__s1, *__s2);
    }
    else if (__s2 < __s1)
    {
        __s1 += __n;
        __s2 += __n;
        for (; __n; --__n)
            assign(*--__s1, *--__s2);
    }
    return __r;
}

template <class _CharT>
inline _LIBCPP_CONSTEXPR_AFTER_CXX17
_CharT*
char_traits<_CharT>::copy(char_type* __s1, const char_type* __s2, size_t __n)
{
    _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
    char_type* __r = __s1;
    for (; __n; --__n, ++__s1, ++__s2)
        assign(*__s1, *__s2);
    return __r;
}

template <class _CharT>
inline _LIBCPP_CONSTEXPR_AFTER_CXX17
_CharT*
char_traits<_CharT>::assign(char_type* __s, size_t __n, char_type __a)
{
    char_type* __r = __s;
    for (; __n; --__n, ++__s)
        assign(*__s, __a);
    return __r;
}

// constexpr versions of move/copy/assign.

template <class _CharT>
static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
_CharT* __move_constexpr(_CharT* __s1, const _CharT* __s2, size_t __n) _NOEXCEPT
{
    if (__n == 0) return __s1;
    if (__s1 < __s2) {
      _VSTD::copy(__s2, __s2 + __n, __s1);
    } else if (__s2 < __s1) {
      _VSTD::copy_backward(__s2, __s2 + __n, __s1 + __n);
    }
    return __s1;
}

template <class _CharT>
static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
_CharT* __copy_constexpr(_CharT* __s1, const _CharT* __s2, size_t __n) _NOEXCEPT
{
    _VSTD::copy_n(__s2, __n, __s1);
    return __s1;
}

template <class _CharT>
static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
_CharT* __assign_constexpr(_CharT* __s, size_t __n, _CharT __a) _NOEXCEPT
{
     _VSTD::fill_n(__s, __n, __a);
     return __s;
}

// char_traits<char>

template <>
struct _LIBCPP_TEMPLATE_VIS char_traits<char>
{
    typedef char      char_type;
    typedef int       int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    static inline _LIBCPP_CONSTEXPR_AFTER_CXX14
    void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT {__c1 = __c2;}
    static inline _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
            {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return (unsigned char)__c1 < (unsigned char)__c2;}

    static _LIBCPP_CONSTEXPR_AFTER_CXX14
    int compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;
    static inline size_t _LIBCPP_CONSTEXPR_AFTER_CXX14
    length(const char_type* __s)  _NOEXCEPT {return __builtin_strlen(__s);}
    static _LIBCPP_CONSTEXPR_AFTER_CXX14
    const char_type* find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT;
    static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type* move(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
        {
            return __libcpp_is_constant_evaluated()
                       ? __move_constexpr(__s1, __s2, __n)
                       : __n == 0 ? __s1 : (char_type*)memmove(__s1, __s2, __n);
        }
    static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type* copy(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
        {
            _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
            return __libcpp_is_constant_evaluated()
                       ? __copy_constexpr(__s1, __s2, __n)
                       : __n == 0 ? __s1 : (char_type*)memcpy(__s1, __s2, __n);
        }
    static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type* assign(char_type* __s, size_t __n, char_type __a) _NOEXCEPT
        {
            return __libcpp_is_constant_evaluated()
                       ? __assign_constexpr(__s, __n, __a)
                       : __n == 0 ? __s : (char_type*)memset(__s, to_int_type(__a), __n);
        }

    static inline _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    static inline _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    static inline _LIBCPP_CONSTEXPR int_type to_int_type(char_type __c) _NOEXCEPT
        {return int_type((unsigned char)__c);}
    static inline _LIBCPP_CONSTEXPR bool eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR int_type  eof() _NOEXCEPT
        {return int_type(EOF);}
};

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
int
char_traits<char>::compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
    if (__n == 0)
        return 0;
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_constexpr_string_builtins)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 351 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return __builtin_memcmp(__s1, __s2, __n);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 353 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return memcmp(__s1, __s2, __n);
#else
# 355 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
#endif
# 364 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
const char*
char_traits<char>::find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT
{
    if (__n == 0)
        return nullptr;
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_constexpr_string_builtins)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 373 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return __builtin_char_memchr(__s, to_int_type(__a), __n);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 375 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return (const char_type*) memchr(__s, to_int_type(__a), __n);
#else
# 377 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return nullptr;
#endif
# 385 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
}


// char_traits<wchar_t>

template <>
struct _LIBCPP_TEMPLATE_VIS char_traits<wchar_t>
{
    typedef wchar_t   char_type;
    typedef wint_t    int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    static inline _LIBCPP_CONSTEXPR_AFTER_CXX14
    void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT {__c1 = __c2;}
    static inline _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 < __c2;}

    static _LIBCPP_CONSTEXPR_AFTER_CXX14
    int compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;
    static _LIBCPP_CONSTEXPR_AFTER_CXX14
    size_t length(const char_type* __s) _NOEXCEPT;
    static _LIBCPP_CONSTEXPR_AFTER_CXX14
    const char_type* find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT;
    static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type* move(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
        {
            return __libcpp_is_constant_evaluated()
                       ? __move_constexpr(__s1, __s2, __n)
                       : __n == 0 ? __s1 : wmemmove(__s1, __s2, __n);
        }
    static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type* copy(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
        {
            _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
            return __libcpp_is_constant_evaluated()
                       ? __copy_constexpr(__s1, __s2, __n)
                       : __n == 0 ? __s1 : wmemcpy(__s1, __s2, __n);
        }
    static inline _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type* assign(char_type* __s, size_t __n, char_type __a) _NOEXCEPT
        {
            return __libcpp_is_constant_evaluated()
                       ? __assign_constexpr(__s, __n, __a)
                       : __n == 0 ? __s : wmemset(__s, __a, __n);
        }
    static inline _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    static inline _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    static inline _LIBCPP_CONSTEXPR int_type to_int_type(char_type __c) _NOEXCEPT
        {return int_type(__c);}
    static inline _LIBCPP_CONSTEXPR bool eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR int_type eof() _NOEXCEPT
        {return int_type(WEOF);}
};

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
int
char_traits<wchar_t>::compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
    if (__n == 0)
        return 0;
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_constexpr_string_builtins)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 453 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return __builtin_wmemcmp(__s1, __s2, __n);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 455 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return wmemcmp(__s1, __s2, __n);
#else
# 457 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
#endif
# 466 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
}


template <class _Traits>
_LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
inline size_t __char_traits_length_checked(const typename _Traits::char_type* __s) _NOEXCEPT {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 474 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
  return __s ? _Traits::length(__s) : (_VSTD::__libcpp_debug_function(_VSTD::__libcpp_debug_info(__FILE__, __LINE__, "p == nullptr", "null pointer pass to non-null argument of char_traits<...>::length")), 0);
#else
# 476 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
  return _Traits::length(__s);
#endif
# 478 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
size_t
char_traits<wchar_t>::length(const char_type* __s) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_constexpr_string_builtins)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 485 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return __builtin_wcslen(__s);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 487 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return wcslen(__s);
#else
# 489 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    size_t __len = 0;
    for (; !eq(*__s, char_type(0)); ++__s)
        ++__len;
    return __len;
#endif
# 494 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
const wchar_t*
char_traits<wchar_t>::find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT
{
    if (__n == 0)
        return nullptr;
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_constexpr_string_builtins)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 503 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return __builtin_wmemchr(__s, __a, __n);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 505 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return wmemchr(__s, __a, __n);
#else
# 507 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return nullptr;
#endif
# 515 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
}


#ifndef _LIBCPP_NO_HAS_CHAR8_T

template <>
struct _LIBCPP_TEMPLATE_VIS char_traits<char8_t>
{
    typedef char8_t        char_type;
    typedef unsigned int   int_type;
    typedef streamoff      off_type;
    typedef u8streampos    pos_type;
    typedef mbstate_t      state_type;

    static inline constexpr void assign(char_type& __c1, const char_type& __c2) noexcept
        {__c1 = __c2;}
    static inline constexpr bool eq(char_type __c1, char_type __c2) noexcept
        {return __c1 == __c2;}
    static inline constexpr bool lt(char_type __c1, char_type __c2) noexcept
        {return __c1 < __c2;}

    static constexpr
    int              compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;

    static constexpr
    size_t           length(const char_type* __s) _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY static constexpr
    const char_type* find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT;

    static _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type*       move(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
        {
            return __libcpp_is_constant_evaluated()
                       ? __move_constexpr(__s1, __s2, __n)
                       : __n == 0 ? __s1 : (char_type*)memmove(__s1, __s2, __n);
        }

    static _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type*       copy(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
       {
            _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
            return __libcpp_is_constant_evaluated()
                       ? __copy_constexpr(__s1, __s2, __n)
                       : __n == 0 ? __s1 : (char_type*)memcpy(__s1, __s2, __n);
        }

    static _LIBCPP_CONSTEXPR_AFTER_CXX17_WITH_IS_CONSTANT_EVALUATED
    char_type*       assign(char_type* __s, size_t __n, char_type __a) _NOEXCEPT
        {
            return __libcpp_is_constant_evaluated()
                       ? __assign_constexpr(__s, __n, __a)
                       : __n == 0 ? __s : (char_type*)memset(__s, to_int_type(__a), __n);
        }

    static inline constexpr int_type  not_eof(int_type __c) noexcept
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    static inline constexpr char_type to_char_type(int_type __c) noexcept
        {return char_type(__c);}
    static inline constexpr int_type to_int_type(char_type __c) noexcept
        {return int_type(__c);}
    static inline constexpr bool eq_int_type(int_type __c1, int_type __c2) noexcept
        {return __c1 == __c2;}
    static inline constexpr int_type eof() noexcept
        {return int_type(EOF);}
};

// TODO use '__builtin_strlen' if it ever supports char8_t ??
inline constexpr
size_t
char_traits<char8_t>::length(const char_type* __s) _NOEXCEPT
{
    size_t __len = 0;
    for (; !eq(*__s, char_type(0)); ++__s)
        ++__len;
    return __len;
}

inline constexpr
int
char_traits<char8_t>::compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if __has_feature(cxx_constexpr_string_builtins)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 598 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    return __builtin_memcmp(__s1, __s2, __n);
#else
# 600 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
#endif
# 609 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
}

// TODO use '__builtin_char_memchr' if it ever supports char8_t ??
inline constexpr
const char8_t*
char_traits<char8_t>::find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT
{
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return 0;
}

#endif // #_LIBCPP_NO_HAS_CHAR8_T
# 626 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3

#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS

template <>
struct _LIBCPP_TEMPLATE_VIS char_traits<char16_t>
{
    typedef char16_t       char_type;
    typedef uint_least16_t int_type;
    typedef streamoff      off_type;
    typedef u16streampos   pos_type;
    typedef mbstate_t      state_type;

    static inline _LIBCPP_CONSTEXPR_AFTER_CXX14
    void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT {__c1 = __c2;}
    static inline _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 < __c2;}

    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR_AFTER_CXX14
    int              compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR_AFTER_CXX14
    size_t           length(const char_type* __s) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR_AFTER_CXX14
    const char_type* find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    static char_type*       move(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    static char_type*       copy(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    static char_type*       assign(char_type* __s, size_t __n, char_type __a) _NOEXCEPT;

    static inline _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    static inline _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    static inline _LIBCPP_CONSTEXPR int_type to_int_type(char_type __c) _NOEXCEPT
        {return int_type(__c);}
    static inline _LIBCPP_CONSTEXPR bool eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR int_type eof() _NOEXCEPT
        {return int_type(0xFFFF);}
};

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
int
char_traits<char16_t>::compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
size_t
char_traits<char16_t>::length(const char_type* __s) _NOEXCEPT
{
    size_t __len = 0;
    for (; !eq(*__s, char_type(0)); ++__s)
        ++__len;
    return __len;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
const char16_t*
char_traits<char16_t>::find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT
{
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return 0;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX17
char16_t*
char_traits<char16_t>::move(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
    if (__n == 0) return __s1;
    char_type* __r = __s1;
    if (__s1 < __s2)
    {
        for (; __n; --__n, ++__s1, ++__s2)
            assign(*__s1, *__s2);
    }
    else if (__s2 < __s1)
    {
        __s1 += __n;
        __s2 += __n;
        for (; __n; --__n)
            assign(*--__s1, *--__s2);
    }
    return __r;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX17
char16_t*
char_traits<char16_t>::copy(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
    _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
    char_type* __r = __s1;
    for (; __n; --__n, ++__s1, ++__s2)
        assign(*__s1, *__s2);
    return __r;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX17
char16_t*
char_traits<char16_t>::assign(char_type* __s, size_t __n, char_type __a) _NOEXCEPT
{
    char_type* __r = __s;
    for (; __n; --__n, ++__s)
        assign(*__s, __a);
    return __r;
}

template <>
struct _LIBCPP_TEMPLATE_VIS char_traits<char32_t>
{
    typedef char32_t       char_type;
    typedef uint_least32_t int_type;
    typedef streamoff      off_type;
    typedef u32streampos   pos_type;
    typedef mbstate_t      state_type;

    static inline _LIBCPP_CONSTEXPR_AFTER_CXX14
    void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT {__c1 = __c2;}
    static inline _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 < __c2;}

    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR_AFTER_CXX14
    int              compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR_AFTER_CXX14
    size_t           length(const char_type* __s) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR_AFTER_CXX14
    const char_type* find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    static char_type*       move(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    static char_type*       copy(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX17
    static char_type*       assign(char_type* __s, size_t __n, char_type __a) _NOEXCEPT;

    static inline _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    static inline _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    static inline _LIBCPP_CONSTEXPR int_type to_int_type(char_type __c) _NOEXCEPT
        {return int_type(__c);}
    static inline _LIBCPP_CONSTEXPR bool eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    static inline _LIBCPP_CONSTEXPR int_type eof() _NOEXCEPT
        {return int_type(0xFFFFFFFF);}
};

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
int
char_traits<char32_t>::compare(const char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
size_t
char_traits<char32_t>::length(const char_type* __s) _NOEXCEPT
{
    size_t __len = 0;
    for (; !eq(*__s, char_type(0)); ++__s)
        ++__len;
    return __len;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX14
const char32_t*
char_traits<char32_t>::find(const char_type* __s, size_t __n, const char_type& __a) _NOEXCEPT
{
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return 0;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX17
char32_t*
char_traits<char32_t>::move(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
    if (__n == 0) return __s1;
    char_type* __r = __s1;
    if (__s1 < __s2)
    {
        for (; __n; --__n, ++__s1, ++__s2)
            assign(*__s1, *__s2);
    }
    else if (__s2 < __s1)
    {
        __s1 += __n;
        __s2 += __n;
        for (; __n; --__n)
            assign(*--__s1, *--__s2);
    }
    return __r;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX17
char32_t*
char_traits<char32_t>::copy(char_type* __s1, const char_type* __s2, size_t __n) _NOEXCEPT
{
    _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
    char_type* __r = __s1;
    for (; __n; --__n, ++__s1, ++__s2)
        assign(*__s1, *__s2);
    return __r;
}

inline _LIBCPP_CONSTEXPR_AFTER_CXX17
char32_t*
char_traits<char32_t>::assign(char_type* __s, size_t __n, char_type __a) _NOEXCEPT
{
    char_type* __r = __s;
    for (; __n; --__n, ++__s)
        assign(*__s, __a);
    return __r;
}

#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 870 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3

// helper fns for basic_string and string_view

// __str_find
template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_find(const _CharT *__p, _SizeT __sz,
             _CharT __c, _SizeT __pos) _NOEXCEPT
{
    if (__pos >= __sz)
        return __npos;
    const _CharT* __r = _Traits::find(__p + __pos, __sz - __pos, __c);
    if (__r == 0)
        return __npos;
    return static_cast<_SizeT>(__r - __p);
}

template <class _CharT, class _Traits>
inline _LIBCPP_CONSTEXPR_AFTER_CXX11 const _CharT *
__search_substring(const _CharT *__first1, const _CharT *__last1,
                   const _CharT *__first2, const _CharT *__last2) {
  // Take advantage of knowing source and pattern lengths.
  // Stop short when source is smaller than pattern.
  const ptrdiff_t __len2 = __last2 - __first2;
  if (__len2 == 0)
    return __first1;

  ptrdiff_t __len1 = __last1 - __first1;
  if (__len1 < __len2)
    return __last1;

  // First element of __first2 is loop invariant.
  _CharT __f2 = *__first2;
  while (true) {
    __len1 = __last1 - __first1;
    // Check whether __first1 still has at least __len2 bytes.
    if (__len1 < __len2)
      return __last1;

    // Find __f2 the first byte matching in __first1.
    __first1 = _Traits::find(__first1, __len1 - __len2 + 1, __f2);
    if (__first1 == 0)
      return __last1;

    // It is faster to compare from the first byte of __first1 even if we
    // already know that it matches the first byte of __first2: this is because
    // __first2 is most likely aligned, as it is user's "pattern" string, and
    // __first1 + 1 is most likely not aligned, as the match is in the middle of
    // the string.
    if (_Traits::compare(__first1, __first2, __len2) == 0)
      return __first1;

    ++__first1;
  }
}

template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_find(const _CharT *__p, _SizeT __sz,
       const _CharT* __s, _SizeT __pos, _SizeT __n) _NOEXCEPT
{
    if (__pos > __sz)
        return __npos;

    if (__n == 0) // There is nothing to search, just return __pos.
        return __pos;

    const _CharT *__r = __search_substring<_CharT, _Traits>(
        __p + __pos, __p + __sz, __s, __s + __n);

    if (__r == __p + __sz)
        return __npos;
    return static_cast<_SizeT>(__r - __p);
}


// __str_rfind

template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_rfind(const _CharT *__p, _SizeT __sz,
              _CharT __c, _SizeT __pos) _NOEXCEPT
{
    if (__sz < 1)
        return __npos;
    if (__pos < __sz)
        ++__pos;
    else
        __pos = __sz;
    for (const _CharT* __ps = __p + __pos; __ps != __p;)
    {
        if (_Traits::eq(*--__ps, __c))
            return static_cast<_SizeT>(__ps - __p);
    }
    return __npos;
}

template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_rfind(const _CharT *__p, _SizeT __sz,
        const _CharT* __s, _SizeT __pos, _SizeT __n) _NOEXCEPT
{
    __pos = _VSTD::min(__pos, __sz);
    if (__n < __sz - __pos)
        __pos += __n;
    else
        __pos = __sz;
    const _CharT* __r = _VSTD::__find_end(
                  __p, __p + __pos, __s, __s + __n, _Traits::eq,
                        random_access_iterator_tag(), random_access_iterator_tag());
    if (__n > 0 && __r == __p + __pos)
        return __npos;
    return static_cast<_SizeT>(__r - __p);
}

// __str_find_first_of
template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_find_first_of(const _CharT *__p, _SizeT __sz,
                const _CharT* __s, _SizeT __pos, _SizeT __n) _NOEXCEPT
{
    if (__pos >= __sz || __n == 0)
        return __npos;
    const _CharT* __r = _VSTD::__find_first_of_ce
        (__p + __pos, __p + __sz, __s, __s + __n, _Traits::eq );
    if (__r == __p + __sz)
        return __npos;
    return static_cast<_SizeT>(__r - __p);
}


// __str_find_last_of
template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_find_last_of(const _CharT *__p, _SizeT __sz,
               const _CharT* __s, _SizeT __pos, _SizeT __n) _NOEXCEPT
    {
    if (__n != 0)
    {
        if (__pos < __sz)
            ++__pos;
        else
            __pos = __sz;
        for (const _CharT* __ps = __p + __pos; __ps != __p;)
        {
            const _CharT* __r = _Traits::find(__s, __n, *--__ps);
            if (__r)
                return static_cast<_SizeT>(__ps - __p);
        }
    }
    return __npos;
}


// __str_find_first_not_of
template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_find_first_not_of(const _CharT *__p, _SizeT __sz,
                    const _CharT* __s, _SizeT __pos, _SizeT __n) _NOEXCEPT
{
    if (__pos < __sz)
    {
        const _CharT* __pe = __p + __sz;
        for (const _CharT* __ps = __p + __pos; __ps != __pe; ++__ps)
            if (_Traits::find(__s, __n, *__ps) == 0)
                return static_cast<_SizeT>(__ps - __p);
    }
    return __npos;
}


template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_find_first_not_of(const _CharT *__p, _SizeT __sz,
                          _CharT __c, _SizeT __pos) _NOEXCEPT
{
    if (__pos < __sz)
    {
        const _CharT* __pe = __p + __sz;
        for (const _CharT* __ps = __p + __pos; __ps != __pe; ++__ps)
            if (!_Traits::eq(*__ps, __c))
                return static_cast<_SizeT>(__ps - __p);
    }
    return __npos;
}


// __str_find_last_not_of
template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_find_last_not_of(const _CharT *__p, _SizeT __sz,
                   const _CharT* __s, _SizeT __pos, _SizeT __n) _NOEXCEPT
{
    if (__pos < __sz)
        ++__pos;
    else
        __pos = __sz;
    for (const _CharT* __ps = __p + __pos; __ps != __p;)
        if (_Traits::find(__s, __n, *--__ps) == 0)
            return static_cast<_SizeT>(__ps - __p);
    return __npos;
}


template<class _CharT, class _SizeT, class _Traits, _SizeT __npos>
inline _SizeT _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
__str_find_last_not_of(const _CharT *__p, _SizeT __sz,
                         _CharT __c, _SizeT __pos) _NOEXCEPT
{
    if (__pos < __sz)
        ++__pos;
    else
        __pos = __sz;
    for (const _CharT* __ps = __p + __pos; __ps != __p;)
        if (!_Traits::eq(*--__ps, __c))
            return static_cast<_SizeT>(__ps - __p);
    return __npos;
}

template<class _Ptr>
inline _LIBCPP_INLINE_VISIBILITY
size_t __do_string_hash(_Ptr __p, _Ptr __e)
{
    typedef typename iterator_traits<_Ptr>::value_type value_type;
    return __murmur2_or_cityhash<size_t>()(__p, (__e-__p)*sizeof(value_type));
}

template <class _CharT, class _Iter, class _Traits=char_traits<_CharT> >
struct __quoted_output_proxy
{
    _Iter  __first;
    _Iter  __last;
    _CharT  __delim;
    _CharT  __escape;

    __quoted_output_proxy(_Iter __f, _Iter __l, _CharT __d, _CharT __e)
    : __first(__f), __last(__l), __delim(__d), __escape(__e) {}
    //  This would be a nice place for a string_ref
};

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP___STRING
# 1115 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__string" 3
# 176 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 176 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 177 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 177 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 178 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 178 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 179 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 179 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 180 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 180 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 182 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 182 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 183 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 185 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 186 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
#endif
# 187 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 189 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 190 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

template<class _CharT, class _Traits = char_traits<_CharT> >
class _LIBCPP_TEMPLATE_VIS basic_string_view {
public:
    // types
    typedef _Traits                                    traits_type;
    typedef _CharT                                     value_type;
    typedef _CharT*                                    pointer;
    typedef const _CharT*                              const_pointer;
    typedef _CharT&                                    reference;
    typedef const _CharT&                              const_reference;
    typedef const_pointer                              const_iterator; // See [string.view.iterators]
    typedef const_iterator                             iterator;
    typedef _VSTD::reverse_iterator<const_iterator>    const_reverse_iterator;
    typedef const_reverse_iterator                     reverse_iterator;
    typedef size_t                                     size_type;
    typedef ptrdiff_t                                  difference_type;
    static _LIBCPP_CONSTEXPR const size_type npos = -1; // size_type(-1);

    static_assert((!is_array<value_type>::value), "Character type of basic_string_view must not be an array");
    static_assert(( is_standard_layout<value_type>::value), "Character type of basic_string_view must be standard-layout");
    static_assert(( is_trivial<value_type>::value), "Character type of basic_string_view must be trivial");
    static_assert((is_same<_CharT, typename traits_type::char_type>::value),
                  "traits_type::char_type must be the same type as CharT");

    // [string.view.cons], construct/copy
    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    basic_string_view() _NOEXCEPT : __data (nullptr), __size(0) {}

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    basic_string_view(const basic_string_view&) _NOEXCEPT = default;

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    basic_string_view& operator=(const basic_string_view&) _NOEXCEPT = default;

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    basic_string_view(const _CharT* __s, size_type __len) _NOEXCEPT
        : __data(__s), __size(__len)
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 233 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
    _LIBCPP_ASSERT(__len == 0 || __s != nullptr, "string_view::string_view(_CharT *, size_t): received nullptr");
#endif
# 235 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
    }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    basic_string_view(const _CharT* __s)
        : __data(__s), __size(std::__char_traits_length_checked<_Traits>(__s)) {}

    // [string.view.iterators], iterators
    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_iterator begin()  const _NOEXCEPT { return cbegin(); }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_iterator end()    const _NOEXCEPT { return cend(); }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_iterator cbegin() const _NOEXCEPT { return __data; }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_iterator cend()   const _NOEXCEPT { return __data + __size; }

    _LIBCPP_CONSTEXPR_AFTER_CXX14 _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin()   const _NOEXCEPT { return const_reverse_iterator(cend()); }

    _LIBCPP_CONSTEXPR_AFTER_CXX14 _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend()     const _NOEXCEPT { return const_reverse_iterator(cbegin()); }

    _LIBCPP_CONSTEXPR_AFTER_CXX14 _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin()  const _NOEXCEPT { return const_reverse_iterator(cend()); }

    _LIBCPP_CONSTEXPR_AFTER_CXX14 _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend()    const _NOEXCEPT { return const_reverse_iterator(cbegin()); }

    // [string.view.capacity], capacity
    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    size_type size()     const _NOEXCEPT { return __size; }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    size_type length()   const _NOEXCEPT { return __size; }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    size_type max_size() const _NOEXCEPT { return numeric_limits<size_type>::max(); }

    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool empty()         const _NOEXCEPT { return __size == 0; }

    // [string.view.access], element access
    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_reference operator[](size_type __pos) const _NOEXCEPT { return __data[__pos]; }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_reference at(size_type __pos) const
    {
        return __pos >= size()
            ? (__throw_out_of_range("string_view::at"), __data[0])
            : __data[__pos];
    }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_reference front() const _NOEXCEPT
    {
        return _LIBCPP_ASSERT(!empty(), "string_view::front(): string is empty"), __data[0];
    }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_reference back() const _NOEXCEPT
    {
        return _LIBCPP_ASSERT(!empty(), "string_view::back(): string is empty"), __data[__size-1];
    }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    const_pointer data() const _NOEXCEPT { return __data; }

    // [string.view.modifiers], modifiers:
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    void remove_prefix(size_type __n) _NOEXCEPT
    {
        _LIBCPP_ASSERT(__n <= size(), "remove_prefix() can't remove more than size()");
        __data += __n;
        __size -= __n;
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    void remove_suffix(size_type __n) _NOEXCEPT
    {
        _LIBCPP_ASSERT(__n <= size(), "remove_suffix() can't remove more than size()");
        __size -= __n;
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    void swap(basic_string_view& __other) _NOEXCEPT
    {
        const value_type *__p = __data;
        __data = __other.__data;
        __other.__data = __p;

        size_type __sz = __size;
        __size = __other.__size;
        __other.__size = __sz;
    }

    _LIBCPP_INLINE_VISIBILITY
    size_type copy(_CharT* __s, size_type __n, size_type __pos = 0) const
    {
        if (__pos > size())
            __throw_out_of_range("string_view::copy");
        size_type __rlen = _VSTD::min(__n, size() - __pos);
        _Traits::copy(__s, data() + __pos, __rlen);
        return __rlen;
    }

    _LIBCPP_CONSTEXPR _LIBCPP_INLINE_VISIBILITY
    basic_string_view substr(size_type __pos = 0, size_type __n = npos) const
    {
        return __pos > size()
            ? (__throw_out_of_range("string_view::substr"), basic_string_view())
            : basic_string_view(data() + __pos, _VSTD::min(__n, size() - __pos));
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 int compare(basic_string_view __sv) const _NOEXCEPT
    {
        size_type __rlen = _VSTD::min( size(), __sv.size());
        int __retval = _Traits::compare(data(), __sv.data(), __rlen);
        if ( __retval == 0 ) // first __rlen chars matched
            __retval = size() == __sv.size() ? 0 : ( size() < __sv.size() ? -1 : 1 );
        return __retval;
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    int compare(size_type __pos1, size_type __n1, basic_string_view __sv) const
    {
        return substr(__pos1, __n1).compare(__sv);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    int compare(                       size_type __pos1, size_type __n1,
                basic_string_view __sv, size_type __pos2, size_type __n2) const
    {
        return substr(__pos1, __n1).compare(__sv.substr(__pos2, __n2));
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    int compare(const _CharT* __s) const _NOEXCEPT
    {
        return compare(basic_string_view(__s));
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    int compare(size_type __pos1, size_type __n1, const _CharT* __s) const
    {
        return substr(__pos1, __n1).compare(basic_string_view(__s));
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    int compare(size_type __pos1, size_type __n1, const _CharT* __s, size_type __n2) const
    {
        return substr(__pos1, __n1).compare(basic_string_view(__s, __n2));
    }

    // find
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find(basic_string_view __s, size_type __pos = 0) const _NOEXCEPT
    {
        _LIBCPP_ASSERT(__s.size() == 0 || __s.data() != nullptr, "string_view::find(): received nullptr");
        return __str_find<value_type, size_type, traits_type, npos>
            (data(), size(), __s.data(), __pos, __s.size());
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find(_CharT __c, size_type __pos = 0) const _NOEXCEPT
    {
        return __str_find<value_type, size_type, traits_type, npos>
            (data(), size(), __c, __pos);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find(const _CharT* __s, size_type __pos, size_type __n) const
    {
        _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string_view::find(): received nullptr");
        return __str_find<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, __n);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find(const _CharT* __s, size_type __pos = 0) const
    {
        _LIBCPP_ASSERT(__s != nullptr, "string_view::find(): received nullptr");
        return __str_find<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, traits_type::length(__s));
    }

    // rfind
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type rfind(basic_string_view __s, size_type __pos = npos) const _NOEXCEPT
    {
        _LIBCPP_ASSERT(__s.size() == 0 || __s.data() != nullptr, "string_view::find(): received nullptr");
        return __str_rfind<value_type, size_type, traits_type, npos>
            (data(), size(), __s.data(), __pos, __s.size());
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type rfind(_CharT __c, size_type __pos = npos) const _NOEXCEPT
    {
        return __str_rfind<value_type, size_type, traits_type, npos>
            (data(), size(), __c, __pos);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type rfind(const _CharT* __s, size_type __pos, size_type __n) const
    {
        _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string_view::rfind(): received nullptr");
        return __str_rfind<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, __n);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type rfind(const _CharT* __s, size_type __pos=npos) const
    {
        _LIBCPP_ASSERT(__s != nullptr, "string_view::rfind(): received nullptr");
        return __str_rfind<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, traits_type::length(__s));
    }

    // find_first_of
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(basic_string_view __s, size_type __pos = 0) const _NOEXCEPT
    {
        _LIBCPP_ASSERT(__s.size() == 0 || __s.data() != nullptr, "string_view::find_first_of(): received nullptr");
        return __str_find_first_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s.data(), __pos, __s.size());
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(_CharT __c, size_type __pos = 0) const _NOEXCEPT
    { return find(__c, __pos); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(const _CharT* __s, size_type __pos, size_type __n) const
    {
        _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string_view::find_first_of(): received nullptr");
        return __str_find_first_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, __n);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(const _CharT* __s, size_type __pos=0) const
    {
        _LIBCPP_ASSERT(__s != nullptr, "string_view::find_first_of(): received nullptr");
        return __str_find_first_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, traits_type::length(__s));
    }

    // find_last_of
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(basic_string_view __s, size_type __pos=npos) const _NOEXCEPT
    {
        _LIBCPP_ASSERT(__s.size() == 0 || __s.data() != nullptr, "string_view::find_last_of(): received nullptr");
        return __str_find_last_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s.data(), __pos, __s.size());
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(_CharT __c, size_type __pos = npos) const _NOEXCEPT
    { return rfind(__c, __pos); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(const _CharT* __s, size_type __pos, size_type __n) const
    {
        _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string_view::find_last_of(): received nullptr");
        return __str_find_last_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, __n);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(const _CharT* __s, size_type __pos=npos) const
    {
        _LIBCPP_ASSERT(__s != nullptr, "string_view::find_last_of(): received nullptr");
        return __str_find_last_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, traits_type::length(__s));
    }

    // find_first_not_of
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(basic_string_view __s, size_type __pos=0) const _NOEXCEPT
    {
        _LIBCPP_ASSERT(__s.size() == 0 || __s.data() != nullptr, "string_view::find_first_not_of(): received nullptr");
        return __str_find_first_not_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s.data(), __pos, __s.size());
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(_CharT __c, size_type __pos=0) const _NOEXCEPT
    {
        return __str_find_first_not_of<value_type, size_type, traits_type, npos>
            (data(), size(), __c, __pos);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(const _CharT* __s, size_type __pos, size_type __n) const
    {
        _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string_view::find_first_not_of(): received nullptr");
        return __str_find_first_not_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, __n);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(const _CharT* __s, size_type __pos=0) const
    {
        _LIBCPP_ASSERT(__s != nullptr, "string_view::find_first_not_of(): received nullptr");
        return __str_find_first_not_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, traits_type::length(__s));
    }

    // find_last_not_of
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(basic_string_view __s, size_type __pos=npos) const _NOEXCEPT
    {
        _LIBCPP_ASSERT(__s.size() == 0 || __s.data() != nullptr, "string_view::find_last_not_of(): received nullptr");
        return __str_find_last_not_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s.data(), __pos, __s.size());
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(_CharT __c, size_type __pos=npos) const _NOEXCEPT
    {
        return __str_find_last_not_of<value_type, size_type, traits_type, npos>
            (data(), size(), __c, __pos);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(const _CharT* __s, size_type __pos, size_type __n) const
    {
        _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string_view::find_last_not_of(): received nullptr");
        return __str_find_last_not_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, __n);
    }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(const _CharT* __s, size_type __pos=npos) const
    {
        _LIBCPP_ASSERT(__s != nullptr, "string_view::find_last_not_of(): received nullptr");
        return __str_find_last_not_of<value_type, size_type, traits_type, npos>
            (data(), size(), __s, __pos, traits_type::length(__s));
    }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 579 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool starts_with(basic_string_view __s) const _NOEXCEPT
    { return size() >= __s.size() && compare(0, __s.size(), __s) == 0; }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool starts_with(value_type __c) const _NOEXCEPT
    { return !empty() && _Traits::eq(front(), __c); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool starts_with(const value_type* __s) const _NOEXCEPT
    { return starts_with(basic_string_view(__s)); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool ends_with(basic_string_view __s) const _NOEXCEPT
    { return size() >= __s.size() && compare(size() - __s.size(), npos, __s) == 0; }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool ends_with(value_type __c) const _NOEXCEPT
    { return !empty() && _Traits::eq(back(), __c); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool ends_with(const value_type* __s) const _NOEXCEPT
    { return ends_with(basic_string_view(__s)); }
#endif
# 603 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3

private:
    const   value_type* __data;
    size_type           __size;
};


// [string.view.comparison]
// operator ==
template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator==(basic_string_view<_CharT, _Traits> __lhs,
                basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    if ( __lhs.size() != __rhs.size()) return false;
    return __lhs.compare(__rhs) == 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator==(basic_string_view<_CharT, _Traits> __lhs,
                typename common_type<basic_string_view<_CharT, _Traits> >::type __rhs) _NOEXCEPT
{
    if ( __lhs.size() != __rhs.size()) return false;
    return __lhs.compare(__rhs) == 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator==(typename common_type<basic_string_view<_CharT, _Traits> >::type __lhs,
                basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    if ( __lhs.size() != __rhs.size()) return false;
    return __lhs.compare(__rhs) == 0;
}


// operator !=
template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator!=(basic_string_view<_CharT, _Traits> __lhs, basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    if ( __lhs.size() != __rhs.size())
        return true;
    return __lhs.compare(__rhs) != 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator!=(basic_string_view<_CharT, _Traits> __lhs,
                typename common_type<basic_string_view<_CharT, _Traits> >::type __rhs) _NOEXCEPT
{
    if ( __lhs.size() != __rhs.size())
        return true;
    return __lhs.compare(__rhs) != 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator!=(typename common_type<basic_string_view<_CharT, _Traits> >::type __lhs,
                basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    if ( __lhs.size() != __rhs.size())
        return true;
    return __lhs.compare(__rhs) != 0;
}


// operator <
template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator<(basic_string_view<_CharT, _Traits> __lhs, basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) < 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator<(basic_string_view<_CharT, _Traits> __lhs,
                typename common_type<basic_string_view<_CharT, _Traits> >::type __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) < 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator<(typename common_type<basic_string_view<_CharT, _Traits> >::type __lhs,
                basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) < 0;
}


// operator >
template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator> (basic_string_view<_CharT, _Traits> __lhs, basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) > 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator>(basic_string_view<_CharT, _Traits> __lhs,
                typename common_type<basic_string_view<_CharT, _Traits> >::type __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) > 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator>(typename common_type<basic_string_view<_CharT, _Traits> >::type __lhs,
                basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) > 0;
}


// operator <=
template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator<=(basic_string_view<_CharT, _Traits> __lhs, basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) <= 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator<=(basic_string_view<_CharT, _Traits> __lhs,
                typename common_type<basic_string_view<_CharT, _Traits> >::type __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) <= 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator<=(typename common_type<basic_string_view<_CharT, _Traits> >::type __lhs,
                basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) <= 0;
}


// operator >=
template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator>=(basic_string_view<_CharT, _Traits> __lhs, basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) >= 0;
}


template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator>=(basic_string_view<_CharT, _Traits> __lhs,
                typename common_type<basic_string_view<_CharT, _Traits> >::type __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) >= 0;
}

template<class _CharT, class _Traits>
_LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
bool operator>=(typename common_type<basic_string_view<_CharT, _Traits> >::type __lhs,
                basic_string_view<_CharT, _Traits> __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) >= 0;
}


template<class _CharT, class _Traits>
basic_ostream<_CharT, _Traits>&
operator<<(basic_ostream<_CharT, _Traits>& __os,
           basic_string_view<_CharT, _Traits> __str);

typedef basic_string_view<char>     string_view;
#ifndef _LIBCPP_NO_HAS_CHAR8_T
typedef basic_string_view<char8_t>  u8string_view;
#endif
# 781 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
typedef basic_string_view<char16_t> u16string_view;
typedef basic_string_view<char32_t> u32string_view;
typedef basic_string_view<wchar_t>  wstring_view;

// [string.view.hash]
template<class _CharT>
struct _LIBCPP_TEMPLATE_VIS hash<basic_string_view<_CharT, char_traits<_CharT> > >
    : public unary_function<basic_string_view<_CharT, char_traits<_CharT> >, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(const basic_string_view<_CharT, char_traits<_CharT> > __val) const _NOEXCEPT {
        return __do_string_hash(__val.data(), __val.data() + __val.size());
    }
};


#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 798 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
inline namespace literals
{
  inline namespace string_view_literals
  {
    inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    basic_string_view<char> operator "" sv(const char *__str, size_t __len) _NOEXCEPT
    {
        return basic_string_view<char> (__str, __len);
    }

    inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    basic_string_view<wchar_t> operator "" sv(const wchar_t *__str, size_t __len) _NOEXCEPT
    {
        return basic_string_view<wchar_t> (__str, __len);
    }

#ifndef _LIBCPP_NO_HAS_CHAR8_T
    inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    basic_string_view<char8_t> operator "" sv(const char8_t *__str, size_t __len) _NOEXCEPT
    {
        return basic_string_view<char8_t> (__str, __len);
    }
#endif
# 821 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3

    inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    basic_string_view<char16_t> operator "" sv(const char16_t *__str, size_t __len) _NOEXCEPT
    {
        return basic_string_view<char16_t> (__str, __len);
    }

    inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    basic_string_view<char32_t> operator "" sv(const char32_t *__str, size_t __len) _NOEXCEPT
    {
        return basic_string_view<char32_t> (__str, __len);
    }
  }
}
#endif
# 836 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif // _LIBCPP_STRING_VIEW
# 841 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string_view" 3
# 505 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 505 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 506 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 506 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 507 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdio>  // For EOF.
#endif /* expanded by -frewrite-includes */
# 507 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 508 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <cwchar>
#endif /* expanded by -frewrite-includes */
# 508 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 1 3
// -*- C++ -*-
//===--------------------------- cwchar -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CWCHAR
#define _LIBCPP_CWCHAR

/*
    cwchar synopsis

Macros:

    NULL
    WCHAR_MAX
    WCHAR_MIN
    WEOF

namespace std
{

Types:

    mbstate_t
    size_t
    tm
    wint_t

int fwprintf(FILE* restrict stream, const wchar_t* restrict format, ...);
int fwscanf(FILE* restrict stream, const wchar_t* restrict format, ...);
int swprintf(wchar_t* restrict s, size_t n, const wchar_t* restrict format, ...);
int swscanf(const wchar_t* restrict s, const wchar_t* restrict format, ...);
int vfwprintf(FILE* restrict stream, const wchar_t* restrict format, va_list arg);
int vfwscanf(FILE* restrict stream, const wchar_t* restrict format, va_list arg);  // C99
int vswprintf(wchar_t* restrict s, size_t n, const wchar_t* restrict format, va_list arg);
int vswscanf(const wchar_t* restrict s, const wchar_t* restrict format, va_list arg);  // C99
int vwprintf(const wchar_t* restrict format, va_list arg);
int vwscanf(const wchar_t* restrict format, va_list arg);  // C99
int wprintf(const wchar_t* restrict format, ...);
int wscanf(const wchar_t* restrict format, ...);
wint_t fgetwc(FILE* stream);
wchar_t* fgetws(wchar_t* restrict s, int n, FILE* restrict stream);
wint_t fputwc(wchar_t c, FILE* stream);
int fputws(const wchar_t* restrict s, FILE* restrict stream);
int fwide(FILE* stream, int mode);
wint_t getwc(FILE* stream);
wint_t getwchar();
wint_t putwc(wchar_t c, FILE* stream);
wint_t putwchar(wchar_t c);
wint_t ungetwc(wint_t c, FILE* stream);
double wcstod(const wchar_t* restrict nptr, wchar_t** restrict endptr);
float wcstof(const wchar_t* restrict nptr, wchar_t** restrict endptr);         // C99
long double wcstold(const wchar_t* restrict nptr, wchar_t** restrict endptr);  // C99
long wcstol(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
long long wcstoll(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);  // C99
unsigned long wcstoul(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
unsigned long long wcstoull(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);  // C99
wchar_t* wcscpy(wchar_t* restrict s1, const wchar_t* restrict s2);
wchar_t* wcsncpy(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wcscat(wchar_t* restrict s1, const wchar_t* restrict s2);
wchar_t* wcsncat(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
int wcscmp(const wchar_t* s1, const wchar_t* s2);
int wcscoll(const wchar_t* s1, const wchar_t* s2);
int wcsncmp(const wchar_t* s1, const wchar_t* s2, size_t n);
size_t wcsxfrm(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
const wchar_t* wcschr(const wchar_t* s, wchar_t c);
      wchar_t* wcschr(      wchar_t* s, wchar_t c);
size_t wcscspn(const wchar_t* s1, const wchar_t* s2);
size_t wcslen(const wchar_t* s);
const wchar_t* wcspbrk(const wchar_t* s1, const wchar_t* s2);
      wchar_t* wcspbrk(      wchar_t* s1, const wchar_t* s2);
const wchar_t* wcsrchr(const wchar_t* s, wchar_t c);
      wchar_t* wcsrchr(      wchar_t* s, wchar_t c);
size_t wcsspn(const wchar_t* s1, const wchar_t* s2);
const wchar_t* wcsstr(const wchar_t* s1, const wchar_t* s2);
      wchar_t* wcsstr(      wchar_t* s1, const wchar_t* s2);
wchar_t* wcstok(wchar_t* restrict s1, const wchar_t* restrict s2, wchar_t** restrict ptr);
const wchar_t* wmemchr(const wchar_t* s, wchar_t c, size_t n);
      wchar_t* wmemchr(      wchar_t* s, wchar_t c, size_t n);
int wmemcmp(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wmemcpy(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wmemmove(wchar_t* s1, const wchar_t* s2, size_t n);
wchar_t* wmemset(wchar_t* s, wchar_t c, size_t n);
size_t wcsftime(wchar_t* restrict s, size_t maxsize, const wchar_t* restrict format,
                const tm* restrict timeptr);
wint_t btowc(int c);
int wctob(wint_t c);
int mbsinit(const mbstate_t* ps);
size_t mbrlen(const char* restrict s, size_t n, mbstate_t* restrict ps);
size_t mbrtowc(wchar_t* restrict pwc, const char* restrict s, size_t n, mbstate_t* restrict ps);
size_t wcrtomb(char* restrict s, wchar_t wc, mbstate_t* restrict ps);
size_t mbsrtowcs(wchar_t* restrict dst, const char** restrict src, size_t len,
                 mbstate_t* restrict ps);
size_t wcsrtombs(char* restrict dst, const wchar_t** restrict src, size_t len,
                 mbstate_t* restrict ps);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
# 106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
#if 0 /* expanded by -frewrite-includes */
#include <cwctype>
#endif /* expanded by -frewrite-includes */
# 106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 1 3
// -*- C++ -*-
//===--------------------------- cwctype ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CWCTYPE
#define _LIBCPP_CWCTYPE

/*
    cwctype synopsis

Macros:

    WEOF

namespace std
{

Types:

    wint_t
    wctrans_t
    wctype_t

int iswalnum(wint_t wc);
int iswalpha(wint_t wc);
int iswblank(wint_t wc);  // C99
int iswcntrl(wint_t wc);
int iswdigit(wint_t wc);
int iswgraph(wint_t wc);
int iswlower(wint_t wc);
int iswprint(wint_t wc);
int iswpunct(wint_t wc);
int iswspace(wint_t wc);
int iswupper(wint_t wc);
int iswxdigit(wint_t wc);
int iswctype(wint_t wc, wctype_t desc);
wctype_t wctype(const char* property);
wint_t towlower(wint_t wc);
wint_t towupper(wint_t wc);
wint_t towctrans(wint_t wc, wctrans_t desc);
wctrans_t wctrans(const char* property);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 52 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 3
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 3
#if 0 /* expanded by -frewrite-includes */
#include <cctype>
#endif /* expanded by -frewrite-includes */
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 1 3
// -*- C++ -*-
//===---------------------------- cctype ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CCTYPE
#define _LIBCPP_CCTYPE

/*
    cctype synopsis

namespace std
{

int isalnum(int c);
int isalpha(int c);
int isblank(int c);  // C99
int iscntrl(int c);
int isdigit(int c);
int isgraph(int c);
int islower(int c);
int isprint(int c);
int ispunct(int c);
int isspace(int c);
int isupper(int c);
int isxdigit(int c);
int tolower(int c);
int toupper(int c);

}  // std
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 37 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3
# 38 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3
#if 0 /* expanded by -frewrite-includes */
#include <ctype.h>
#endif /* expanded by -frewrite-includes */
# 38 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3
# 39 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 41 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 42 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3
#endif
# 43 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

_LIBCPP_BEGIN_NAMESPACE_STD

#ifdef isalnum
#undef isalnum
#endif
# 49 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef isalpha
#undef isalpha
#endif
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef isblank
#undef isblank
#endif
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef iscntrl
#undef iscntrl
#endif
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef isdigit
#undef isdigit
#endif
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef isgraph
#undef isgraph
#endif
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef islower
#undef islower
#endif
# 73 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef isprint
#undef isprint
#endif
# 77 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef ispunct
#undef ispunct
#endif
# 81 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef isspace
#undef isspace
#endif
# 85 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef isupper
#undef isupper
#endif
# 89 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef isxdigit
#undef isxdigit
#endif
# 93 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef tolower
#undef tolower
#endif
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3

#ifdef toupper
#undef toupper
#endif
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3


using ::isalnum;
using ::isalpha;
using ::isblank;
using ::iscntrl;
using ::isdigit;
using ::isgraph;
using ::islower;
using ::isprint;
using ::ispunct;
using ::isspace;
using ::isupper;
using ::isxdigit;
using ::tolower;
using ::toupper;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CCTYPE
# 121 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cctype" 3
# 54 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <wctype.h>
#endif /* expanded by -frewrite-includes */
# 54 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 1 3
// -*- C++ -*-
//===--------------------------- wctype.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_WCTYPE_H
#define _LIBCPP_WCTYPE_H

/*
    wctype.h synopsis

Macros:

    WEOF

Types:

    wint_t
    wctrans_t
    wctype_t

int iswalnum(wint_t wc);
int iswalpha(wint_t wc);
int iswblank(wint_t wc);  // C99
int iswcntrl(wint_t wc);
int iswdigit(wint_t wc);
int iswgraph(wint_t wc);
int iswlower(wint_t wc);
int iswprint(wint_t wc);
int iswpunct(wint_t wc);
int iswspace(wint_t wc);
int iswupper(wint_t wc);
int iswxdigit(wint_t wc);
int iswctype(wint_t wc, wctype_t desc);
wctype_t wctype(const char* property);
wint_t towlower(wint_t wc);
wint_t towupper(wint_t wc);
wint_t towctrans(wint_t wc, wctrans_t desc);
wctrans_t wctrans(const char* property);

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 47 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 3
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 51 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 3
#endif
# 52 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <wctype.h>
#endif /* expanded by -frewrite-includes */
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 1 3 4
/*-
 * Copyright (c)1999 Citrus Project,
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	citrus Id: wctype.h,v 1.4 2000/12/21 01:50:21 itojun Exp
 *	$NetBSD: wctype.h,v 1.3 2000/12/22 14:16:16 itojun Exp $
 * $FreeBSD: /repoman/r/ncvs/src/include/wctype.h,v 1.10 2002/08/21 16:19:55 mike Exp $
 */

#ifndef _WCTYPE_H_
#define	_WCTYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 35 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_types/_wctrans_t.h>
#endif /* expanded by -frewrite-includes */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_wctrans_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _WCTRANS_T 
#define _WCTRANS_T 
#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_wctrans_t.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_wctrans_t.h" 3 4
typedef	__darwin_wctrans_t wctrans_t;
#endif /* _WCTRANS_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/_types/_wctrans_t.h" 3 4
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 2 3 4

#define __DARWIN_WCTYPE_TOP_inline	__header_inline

#if 0 /* expanded by -frewrite-includes */
#include <_wctype.h>
#endif /* expanded by -frewrite-includes */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <ctype.h>
#endif /* expanded by -frewrite-includes */
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4

/*
 * Use inline functions if we are allowed to and the compiler supports them.
 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_DONT_USE_CTYPE_INLINE_) && \
    (defined(_USE_CTYPE_INLINE_) || defined(__GNUC__) || defined(__cplusplus))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 48 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4

__DARWIN_WCTYPE_TOP_inline int
iswblank(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_B));
}

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 56 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
__DARWIN_WCTYPE_TOP_inline int
iswascii(wint_t _wc)
{
	return ((_wc & ~0x7F) == 0);
}

__DARWIN_WCTYPE_TOP_inline int
iswhexnumber(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_X));
}

__DARWIN_WCTYPE_TOP_inline int
iswideogram(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_I));
}

__DARWIN_WCTYPE_TOP_inline int
iswnumber(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_D));
}

__DARWIN_WCTYPE_TOP_inline int
iswphonogram(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_Q));
}

__DARWIN_WCTYPE_TOP_inline int
iswrune(wint_t _wc)
{
	return (__istype(_wc, 0xFFFFFFF0L));
}

__DARWIN_WCTYPE_TOP_inline int
iswspecial(wint_t _wc)
{
	return (__istype(_wc, _CTYPE_T));
}
#endif /* !_ANSI_SOURCE */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4

#else /* not using inlines */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4

__BEGIN_DECLS
int	iswblank(wint_t);

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
wint_t	iswascii(wint_t);
wint_t	iswhexnumber(wint_t);
wint_t	iswideogram(wint_t);
wint_t	iswnumber(wint_t);
wint_t	iswphonogram(wint_t);
wint_t	iswrune(wint_t);
wint_t	iswspecial(wint_t);
#endif
# 113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
__END_DECLS

#endif /* using inlines */
# 116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4

__BEGIN_DECLS
#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
wint_t	nextwctype(wint_t, wctype_t);
#endif
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
wint_t	towctrans(wint_t, wctrans_t);
wctrans_t
	wctrans(const char *);
__END_DECLS

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_wctype.h>
#endif /* expanded by -frewrite-includes */
# 127 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
# 128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4

#endif		/* _WCTYPE_H_ */
# 131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/wctype.h" 3 4
# 54 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 2 3

#ifdef __cplusplus

#undef iswalnum
#undef iswalpha
#undef iswblank
#undef iswcntrl
#undef iswdigit
#undef iswgraph
#undef iswlower
#undef iswprint
#undef iswpunct
#undef iswspace
#undef iswupper
#undef iswxdigit
#undef iswctype
#undef wctype
#undef towlower
#undef towupper
#undef towctrans
#undef wctrans

#endif  // __cplusplus
# 77 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 3

#endif  // _LIBCPP_WCTYPE_H
# 79 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wctype.h" 3
# 55 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 3
#endif
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::wint_t;
using ::wctrans_t;
using ::wctype_t;
using ::iswalnum;
using ::iswalpha;
using ::iswblank;
using ::iswcntrl;
using ::iswdigit;
using ::iswgraph;
using ::iswlower;
using ::iswprint;
using ::iswpunct;
using ::iswspace;
using ::iswupper;
using ::iswxdigit;
using ::iswctype;
using ::wctype;
using ::towlower;
using ::towupper;
using ::towctrans;
using ::wctrans;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CWCTYPE
# 87 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwctype" 3
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <wchar.h>
#endif /* expanded by -frewrite-includes */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 1 3
// -*- C++ -*-
//===--------------------------- wchar.h ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_wint_t) || defined(__need_mbstate_t)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <wchar.h>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_WCHAR_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#define _LIBCPP_WCHAR_H

/*
    wchar.h synopsis

Macros:

    NULL
    WCHAR_MAX
    WCHAR_MIN
    WEOF

Types:

    mbstate_t
    size_t
    tm
    wint_t

int fwprintf(FILE* restrict stream, const wchar_t* restrict format, ...);
int fwscanf(FILE* restrict stream, const wchar_t* restrict format, ...);
int swprintf(wchar_t* restrict s, size_t n, const wchar_t* restrict format, ...);
int swscanf(const wchar_t* restrict s, const wchar_t* restrict format, ...);
int vfwprintf(FILE* restrict stream, const wchar_t* restrict format, va_list arg);
int vfwscanf(FILE* restrict stream, const wchar_t* restrict format, va_list arg);  // C99
int vswprintf(wchar_t* restrict s, size_t n, const wchar_t* restrict format, va_list arg);
int vswscanf(const wchar_t* restrict s, const wchar_t* restrict format, va_list arg);  // C99
int vwprintf(const wchar_t* restrict format, va_list arg);
int vwscanf(const wchar_t* restrict format, va_list arg);  // C99
int wprintf(const wchar_t* restrict format, ...);
int wscanf(const wchar_t* restrict format, ...);
wint_t fgetwc(FILE* stream);
wchar_t* fgetws(wchar_t* restrict s, int n, FILE* restrict stream);
wint_t fputwc(wchar_t c, FILE* stream);
int fputws(const wchar_t* restrict s, FILE* restrict stream);
int fwide(FILE* stream, int mode);
wint_t getwc(FILE* stream);
wint_t getwchar();
wint_t putwc(wchar_t c, FILE* stream);
wint_t putwchar(wchar_t c);
wint_t ungetwc(wint_t c, FILE* stream);
double wcstod(const wchar_t* restrict nptr, wchar_t** restrict endptr);
float wcstof(const wchar_t* restrict nptr, wchar_t** restrict endptr);         // C99
long double wcstold(const wchar_t* restrict nptr, wchar_t** restrict endptr);  // C99
long wcstol(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
long long wcstoll(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);  // C99
unsigned long wcstoul(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
unsigned long long wcstoull(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);  // C99
wchar_t* wcscpy(wchar_t* restrict s1, const wchar_t* restrict s2);
wchar_t* wcsncpy(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wcscat(wchar_t* restrict s1, const wchar_t* restrict s2);
wchar_t* wcsncat(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
int wcscmp(const wchar_t* s1, const wchar_t* s2);
int wcscoll(const wchar_t* s1, const wchar_t* s2);
int wcsncmp(const wchar_t* s1, const wchar_t* s2, size_t n);
size_t wcsxfrm(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
const wchar_t* wcschr(const wchar_t* s, wchar_t c);
      wchar_t* wcschr(      wchar_t* s, wchar_t c);
size_t wcscspn(const wchar_t* s1, const wchar_t* s2);
size_t wcslen(const wchar_t* s);
const wchar_t* wcspbrk(const wchar_t* s1, const wchar_t* s2);
      wchar_t* wcspbrk(      wchar_t* s1, const wchar_t* s2);
const wchar_t* wcsrchr(const wchar_t* s, wchar_t c);
      wchar_t* wcsrchr(      wchar_t* s, wchar_t c);
size_t wcsspn(const wchar_t* s1, const wchar_t* s2);
const wchar_t* wcsstr(const wchar_t* s1, const wchar_t* s2);
      wchar_t* wcsstr(      wchar_t* s1, const wchar_t* s2);
wchar_t* wcstok(wchar_t* restrict s1, const wchar_t* restrict s2, wchar_t** restrict ptr);
const wchar_t* wmemchr(const wchar_t* s, wchar_t c, size_t n);
      wchar_t* wmemchr(      wchar_t* s, wchar_t c, size_t n);
int wmemcmp(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wmemcpy(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wmemmove(wchar_t* s1, const wchar_t* s2, size_t n);
wchar_t* wmemset(wchar_t* s, wchar_t c, size_t n);
size_t wcsftime(wchar_t* restrict s, size_t maxsize, const wchar_t* restrict format,
                const tm* restrict timeptr);
wint_t btowc(int c);
int wctob(wint_t c);
int mbsinit(const mbstate_t* ps);
size_t mbrlen(const char* restrict s, size_t n, mbstate_t* restrict ps);
size_t mbrtowc(wchar_t* restrict pwc, const char* restrict s, size_t n, mbstate_t* restrict ps);
size_t wcrtomb(char* restrict s, wchar_t wc, mbstate_t* restrict ps);
size_t mbsrtowcs(wchar_t* restrict dst, const char** restrict src, size_t len,
                 mbstate_t* restrict ps);
size_t wcsrtombs(char* restrict dst, const wchar_t** restrict src, size_t len,
                 mbstate_t* restrict ps);

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
# 109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#endif
# 113 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#ifdef __cplusplus
#define __CORRECT_ISO_CPP_WCHAR_H_PROTO
#endif
# 117 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <wchar.h>
#endif /* expanded by -frewrite-includes */
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
# 119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

// Determine whether we have const-correct overloads for wcschr and friends.
#if 0 /* disabled by -frewrite-includes */
#if defined(_WCHAR_H_CPLUSPLUS_98_CONFORMANCE_)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#  define _LIBCPP_WCHAR_H_HAS_CONST_OVERLOADS 1
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__GLIBC_PREREQ)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 124 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* disabled by -frewrite-includes */
#  if __GLIBC_PREREQ(2, 10)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 125 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#    define _LIBCPP_WCHAR_H_HAS_CONST_OVERLOADS 1
#  endif
# 127 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_MSVCRT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 128 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#if 0 /* disabled by -frewrite-includes */
#  if defined(_CRT_CONST_CORRECT_OVERLOADS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 129 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#    define _LIBCPP_WCHAR_H_HAS_CONST_OVERLOADS 1
#  endif
# 131 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
#endif
# 132 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && !defined(_LIBCPP_WCHAR_H_HAS_CONST_OVERLOADS) && defined(_LIBCPP_PREFERRED_OVERLOAD)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 134 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
extern "C++" {
inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wcschr(const wchar_t* __s, wchar_t __c) {return (wchar_t*)wcschr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wcschr(const wchar_t* __s, wchar_t __c) {return __libcpp_wcschr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wcschr(      wchar_t* __s, wchar_t __c) {return __libcpp_wcschr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wcspbrk(const wchar_t* __s1, const wchar_t* __s2) {return (wchar_t*)wcspbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wcspbrk(const wchar_t* __s1, const wchar_t* __s2) {return __libcpp_wcspbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wcspbrk(      wchar_t* __s1, const wchar_t* __s2) {return __libcpp_wcspbrk(__s1, __s2);}

inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wcsrchr(const wchar_t* __s, wchar_t __c) {return (wchar_t*)wcsrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wcsrchr(const wchar_t* __s, wchar_t __c) {return __libcpp_wcsrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wcsrchr(      wchar_t* __s, wchar_t __c) {return __libcpp_wcsrchr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wcsstr(const wchar_t* __s1, const wchar_t* __s2) {return (wchar_t*)wcsstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wcsstr(const wchar_t* __s1, const wchar_t* __s2) {return __libcpp_wcsstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wcsstr(      wchar_t* __s1, const wchar_t* __s2) {return __libcpp_wcsstr(__s1, __s2);}

inline _LIBCPP_INLINE_VISIBILITY
wchar_t* __libcpp_wmemchr(const wchar_t* __s, wchar_t __c, size_t __n) {return (wchar_t*)wmemchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
const wchar_t* wmemchr(const wchar_t* __s, wchar_t __c, size_t __n) {return __libcpp_wmemchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
      wchar_t* wmemchr(      wchar_t* __s, wchar_t __c, size_t __n) {return __libcpp_wmemchr(__s, __c, __n);}
}
#endif
# 171 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && defined(_LIBCPP_MSVCRT_LIKE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 173 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
extern "C" {
size_t mbsnrtowcs(wchar_t *__restrict dst, const char **__restrict src,
                  size_t nmc, size_t len, mbstate_t *__restrict ps);
size_t wcsnrtombs(char *__restrict dst, const wchar_t **__restrict src,
                  size_t nwc, size_t len, mbstate_t *__restrict ps);
}  // extern "C++"
#endif  // __cplusplus && _LIBCPP_MSVCRT
# 180 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3

#endif  // _LIBCPP_WCHAR_H
# 182 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/wchar.h" 3
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
#endif
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::mbstate_t;
using ::size_t;
using ::tm;
using ::wint_t;
using ::FILE;
using ::fwprintf;
using ::fwscanf;
using ::swprintf;
using ::vfwprintf;
using ::vswprintf;
using ::swscanf;
using ::vfwscanf;
using ::vswscanf;
using ::fgetwc;
using ::fgetws;
using ::fputwc;
using ::fputws;
using ::fwide;
using ::getwc;
using ::putwc;
using ::ungetwc;
using ::wcstod;
using ::wcstof;
using ::wcstold;
using ::wcstol;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::wcstoll;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 143 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
using ::wcstoul;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::wcstoull;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 147 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
using ::wcscpy;
using ::wcsncpy;
using ::wcscat;
using ::wcsncat;
using ::wcscmp;
using ::wcscoll;
using ::wcsncmp;
using ::wcsxfrm;
using ::wcschr;
using ::wcspbrk;
using ::wcsrchr;
using ::wcsstr;
using ::wmemchr;
using ::wcscspn;
using ::wcslen;
using ::wcsspn;
using ::wcstok;
using ::wmemcmp;
using ::wmemcpy;
using ::wmemmove;
using ::wmemset;
using ::wcsftime;
using ::btowc;
using ::wctob;
using ::mbsinit;
using ::mbrlen;
using ::mbrtowc;
using ::wcrtomb;
using ::mbsrtowcs;
using ::wcsrtombs;

#ifndef _LIBCPP_HAS_NO_STDIN
using ::getwchar;
using ::vwscanf;
using ::wscanf;
#endif
# 183 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3

#ifndef _LIBCPP_HAS_NO_STDOUT
using ::putwchar;
using ::vwprintf;
using ::wprintf;
#endif
# 189 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CWCHAR
# 193 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cwchar" 3
# 509 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 509 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 510 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 510 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 511 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 511 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 512 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 512 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 513 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 513 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 514 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 514 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 515 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 515 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 516 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 516 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 517 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 517 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 518 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 519 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 520 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#endif
# 521 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 522 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 523 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 525 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 526 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#endif
# 527 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 529 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 530 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

// fpos

template <class _StateT>
class _LIBCPP_TEMPLATE_VIS fpos
{
private:
    _StateT __st_;
    streamoff __off_;
public:
    _LIBCPP_INLINE_VISIBILITY fpos(streamoff __off = streamoff()) : __st_(), __off_(__off) {}

    _LIBCPP_INLINE_VISIBILITY operator streamoff() const {return __off_;}

    _LIBCPP_INLINE_VISIBILITY _StateT state() const {return __st_;}
    _LIBCPP_INLINE_VISIBILITY void state(_StateT __st) {__st_ = __st;}

    _LIBCPP_INLINE_VISIBILITY fpos& operator+=(streamoff __off) {__off_ += __off; return *this;}
    _LIBCPP_INLINE_VISIBILITY fpos  operator+ (streamoff __off) const {fpos __t(*this); __t += __off; return __t;}
    _LIBCPP_INLINE_VISIBILITY fpos& operator-=(streamoff __off) {__off_ -= __off; return *this;}
    _LIBCPP_INLINE_VISIBILITY fpos  operator- (streamoff __off) const {fpos __t(*this); __t -= __off; return __t;}
};

template <class _StateT>
inline _LIBCPP_INLINE_VISIBILITY
streamoff operator-(const fpos<_StateT>& __x, const fpos<_StateT>& __y)
    {return streamoff(__x) - streamoff(__y);}

template <class _StateT>
inline _LIBCPP_INLINE_VISIBILITY
bool operator==(const fpos<_StateT>& __x, const fpos<_StateT>& __y)
    {return streamoff(__x) == streamoff(__y);}

template <class _StateT>
inline _LIBCPP_INLINE_VISIBILITY
bool operator!=(const fpos<_StateT>& __x, const fpos<_StateT>& __y)
    {return streamoff(__x) != streamoff(__y);}

// basic_string

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __x,
          const basic_string<_CharT, _Traits, _Allocator>& __y);

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const _CharT* __x, const basic_string<_CharT,_Traits,_Allocator>& __y);

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(_CharT __x, const basic_string<_CharT,_Traits,_Allocator>& __y);

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __x, const _CharT* __y);

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __x, _CharT __y);

_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS string operator+<char, char_traits<char>, allocator<char> >(char const*, string const&))

template <bool>
class _LIBCPP_TEMPLATE_VIS __basic_string_common
{
protected:
    _LIBCPP_NORETURN void __throw_length_error() const;
    _LIBCPP_NORETURN void __throw_out_of_range() const;
};

template <bool __b>
void
__basic_string_common<__b>::__throw_length_error() const
{
    _VSTD::__throw_length_error("basic_string");
}

template <bool __b>
void
__basic_string_common<__b>::__throw_out_of_range() const
{
    _VSTD::__throw_out_of_range("basic_string");
}

_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS __basic_string_common<true>)

#ifdef _LIBCPP_NO_EXCEPTIONS
template <class _Iter>
struct __libcpp_string_gets_noexcept_iterator_impl : public true_type {};
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_HAS_NO_NOEXCEPT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 625 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
template <class _Iter>
struct __libcpp_string_gets_noexcept_iterator_impl : public false_type {};
#else
# 628 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
template <class _Iter, bool = __is_cpp17_forward_iterator<_Iter>::value>
struct __libcpp_string_gets_noexcept_iterator_impl : public _LIBCPP_BOOL_CONSTANT((
    noexcept(++(declval<_Iter&>())) &&
    is_nothrow_assignable<_Iter&, _Iter>::value &&
    noexcept(declval<_Iter>() == declval<_Iter>()) &&
    noexcept(*declval<_Iter>())
)) {};

template <class _Iter>
struct __libcpp_string_gets_noexcept_iterator_impl<_Iter, false> : public false_type {};
#endif
# 639 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3


template <class _Iter>
struct __libcpp_string_gets_noexcept_iterator
    : public _LIBCPP_BOOL_CONSTANT(__libcpp_is_trivial_iterator<_Iter>::value || __libcpp_string_gets_noexcept_iterator_impl<_Iter>::value) {};

template <class _CharT, class _Traits, class _Tp>
struct __can_be_converted_to_string_view : public _BoolConstant<
      is_convertible<const _Tp&, basic_string_view<_CharT, _Traits> >::value &&
     !is_convertible<const _Tp&, const _CharT*>::value
    > {};

#ifdef _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT

template <class _CharT, size_t = sizeof(_CharT)>
struct __padding
{
    unsigned char __xx[sizeof(_CharT)-1];
};

template <class _CharT>
struct __padding<_CharT, 1>
{
};

#endif  // _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT
# 665 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

template<class _CharT, class _Traits, class _Allocator>
class _LIBCPP_TEMPLATE_VIS basic_string
    : private __basic_string_common<true>
{
public:
    typedef basic_string                                 __self;
    typedef basic_string_view<_CharT, _Traits>           __self_view;
    typedef _Traits                                      traits_type;
    typedef _CharT                                       value_type;
    typedef _Allocator                                   allocator_type;
    typedef allocator_traits<allocator_type>             __alloc_traits;
    typedef typename __alloc_traits::size_type           size_type;
    typedef typename __alloc_traits::difference_type     difference_type;
    typedef value_type&                                  reference;
    typedef const value_type&                            const_reference;
    typedef typename __alloc_traits::pointer             pointer;
    typedef typename __alloc_traits::const_pointer       const_pointer;

    static_assert((!is_array<value_type>::value), "Character type of basic_string must not be an array");
    static_assert(( is_standard_layout<value_type>::value), "Character type of basic_string must be standard-layout");
    static_assert(( is_trivial<value_type>::value), "Character type of basic_string must be trivial");
    static_assert(( is_same<_CharT, typename traits_type::char_type>::value),
                  "traits_type::char_type must be the same type as CharT");
    static_assert(( is_same<typename allocator_type::value_type, value_type>::value),
                  "Allocator::value_type must be same type as value_type");

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_RAW_ITERATORS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 693 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    typedef pointer                                      iterator;
    typedef const_pointer                                const_iterator;
#else  // defined(_LIBCPP_RAW_ITERATORS)
# 696 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    typedef __wrap_iter<pointer>                         iterator;
    typedef __wrap_iter<const_pointer>                   const_iterator;
#endif  // defined(_LIBCPP_RAW_ITERATORS)
# 699 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    typedef _VSTD::reverse_iterator<iterator>             reverse_iterator;
    typedef _VSTD::reverse_iterator<const_iterator>       const_reverse_iterator;

private:

#ifdef _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT

    struct __long
    {
        pointer   __data_;
        size_type __size_;
        size_type __cap_;
    };

#ifdef _LIBCPP_BIG_ENDIAN
    static const size_type __short_mask = 0x01;
    static const size_type __long_mask  = 0x1ul;
#else  // _LIBCPP_BIG_ENDIAN
# 717 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    static const size_type __short_mask = 0x80;
    static const size_type __long_mask  = ~(size_type(~0) >> 1);
#endif  // _LIBCPP_BIG_ENDIAN
# 720 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    enum {__min_cap = (sizeof(__long) - 1)/sizeof(value_type) > 2 ?
                      (sizeof(__long) - 1)/sizeof(value_type) : 2};

    struct __short
    {
        value_type __data_[__min_cap];
        struct
            : __padding<value_type>
        {
            unsigned char __size_;
        };
    };

#else
# 735 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    struct __long
    {
        size_type __cap_;
        size_type __size_;
        pointer   __data_;
    };

#ifdef _LIBCPP_BIG_ENDIAN
    static const size_type __short_mask = 0x80;
    static const size_type __long_mask  = ~(size_type(~0) >> 1);
#else  // _LIBCPP_BIG_ENDIAN
# 747 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    static const size_type __short_mask = 0x01;
    static const size_type __long_mask  = 0x1ul;
#endif  // _LIBCPP_BIG_ENDIAN
# 750 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    enum {__min_cap = (sizeof(__long) - 1)/sizeof(value_type) > 2 ?
                      (sizeof(__long) - 1)/sizeof(value_type) : 2};

    struct __short
    {
        union
        {
            unsigned char __size_;
            value_type __lx;
        };
        value_type __data_[__min_cap];
    };

#endif  // _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT
# 765 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    union __ulx{__long __lx; __short __lxx;};

    enum {__n_words = sizeof(__ulx) / sizeof(size_type)};

    struct __raw
    {
        size_type __words[__n_words];
    };

    struct __rep
    {
        union
        {
            __long  __l;
            __short __s;
            __raw   __r;
        };
    };

    __compressed_pair<__rep, allocator_type> __r_;

public:
    _LIBCPP_FUNC_VIS
    static const size_type npos = -1;

    _LIBCPP_INLINE_VISIBILITY basic_string()
        _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value);

    _LIBCPP_INLINE_VISIBILITY explicit basic_string(const allocator_type& __a)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 796 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT_(is_nothrow_copy_constructible<allocator_type>::value);
#else
# 798 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT;
#endif
# 800 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    basic_string(const basic_string& __str);
    basic_string(const basic_string& __str, const allocator_type& __a);

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    basic_string(basic_string&& __str)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 808 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value);
#else
# 810 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT;
#endif
# 812 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    basic_string(basic_string&& __str, const allocator_type& __a);
#endif  // _LIBCPP_CXX03_LANG
# 816 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    template <class = _EnableIf<__is_allocator<_Allocator>::value, nullptr_t> >
    _LIBCPP_INLINE_VISIBILITY
    basic_string(const _CharT* __s) : __r_(__default_init_tag(), __default_init_tag()) {
      _LIBCPP_ASSERT(__s != nullptr, "basic_string(const char*) detected nullptr");
      __init(__s, traits_type::length(__s));
#if 0 /* disabled by -frewrite-includes */
#   if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 823 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
      __get_db()->__insert_c(this);
#   endif
# 825 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    }

    template <class = _EnableIf<__is_allocator<_Allocator>::value, nullptr_t> >
        _LIBCPP_INLINE_VISIBILITY
        basic_string(const _CharT* __s, const _Allocator& __a);

    _LIBCPP_INLINE_VISIBILITY
    basic_string(const _CharT* __s, size_type __n);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(const _CharT* __s, size_type __n, const _Allocator& __a);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(size_type __n, _CharT __c);

    template <class = _EnableIf<__is_allocator<_Allocator>::value, nullptr_t> >
        _LIBCPP_INLINE_VISIBILITY
        basic_string(size_type __n, _CharT __c, const _Allocator& __a);

    basic_string(const basic_string& __str, size_type __pos, size_type __n,
                 const _Allocator& __a = _Allocator());
    _LIBCPP_INLINE_VISIBILITY
    basic_string(const basic_string& __str, size_type __pos,
                 const _Allocator& __a = _Allocator());

    template<class _Tp, class = _EnableIf<__can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value && !__is_same_uncvref<_Tp, basic_string>::value> >
        _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
        basic_string(const _Tp& __t, size_type __pos, size_type __n,
                     const allocator_type& __a = allocator_type());

    template<class _Tp, class = _EnableIf<__can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value &&
                                          !__is_same_uncvref<_Tp, basic_string>::value> >
        _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
        explicit basic_string(const _Tp& __t);

    template<class _Tp, class = _EnableIf<__can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value && !__is_same_uncvref<_Tp, basic_string>::value> >
        _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
        explicit basic_string(const _Tp& __t, const allocator_type& __a);

    template<class _InputIterator, class = _EnableIf<__is_cpp17_input_iterator<_InputIterator>::value> >
        _LIBCPP_INLINE_VISIBILITY
        basic_string(_InputIterator __first, _InputIterator __last);
    template<class _InputIterator, class = _EnableIf<__is_cpp17_input_iterator<_InputIterator>::value> >
        _LIBCPP_INLINE_VISIBILITY
        basic_string(_InputIterator __first, _InputIterator __last, const allocator_type& __a);
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    basic_string(initializer_list<_CharT> __il);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(initializer_list<_CharT> __il, const _Allocator& __a);
#endif  // _LIBCPP_CXX03_LANG
# 874 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    inline ~basic_string();

    _LIBCPP_INLINE_VISIBILITY
    operator __self_view() const _NOEXCEPT { return __self_view(data(), size()); }

    basic_string& operator=(const basic_string& __str);

    template <class _Tp, class = _EnableIf<__can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value && !__is_same_uncvref<_Tp, basic_string>::value> >
    basic_string& operator=(const _Tp& __t)
        {__self_view __sv = __t; return assign(__sv);}

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    basic_string& operator=(basic_string&& __str)
        _NOEXCEPT_((__noexcept_move_assign_container<_Allocator, __alloc_traits>::value));
     _LIBCPP_INLINE_VISIBILITY
    basic_string& operator=(initializer_list<value_type> __il) {return assign(__il.begin(), __il.size());}
#endif
# 893 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY basic_string& operator=(const value_type* __s) {return assign(__s);}
    basic_string& operator=(value_type __c);

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 897 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY
    iterator begin() _NOEXCEPT
        {return iterator(this, __get_pointer());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT
        {return const_iterator(this, __get_pointer());}
    _LIBCPP_INLINE_VISIBILITY
    iterator end() _NOEXCEPT
        {return iterator(this, __get_pointer() + size());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT
        {return const_iterator(this, __get_pointer() + size());}
#else
# 910 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY
    iterator begin() _NOEXCEPT
        {return iterator(__get_pointer());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT
        {return const_iterator(__get_pointer());}
    _LIBCPP_INLINE_VISIBILITY
    iterator end() _NOEXCEPT
        {return iterator(__get_pointer() + size());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT
        {return const_iterator(__get_pointer() + size());}
#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 923 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator rbegin() _NOEXCEPT
        {return reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin() const _NOEXCEPT
        {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator rend() _NOEXCEPT
        {return reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend() const _NOEXCEPT
        {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY
    const_iterator cbegin() const _NOEXCEPT
        {return begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator cend() const _NOEXCEPT
        {return end();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT
        {return rbegin();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend() const _NOEXCEPT
        {return rend();}

    _LIBCPP_INLINE_VISIBILITY size_type size() const _NOEXCEPT
        {return __is_long() ? __get_long_size() : __get_short_size();}
    _LIBCPP_INLINE_VISIBILITY size_type length() const _NOEXCEPT {return size();}
    _LIBCPP_INLINE_VISIBILITY size_type max_size() const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY size_type capacity() const _NOEXCEPT
        {return (__is_long() ? __get_long_cap()
                             : static_cast<size_type>(__min_cap)) - 1;}

    void resize(size_type __n, value_type __c);
    _LIBCPP_INLINE_VISIBILITY void resize(size_type __n) {resize(__n, value_type());}

    void reserve(size_type __res_arg);
    _LIBCPP_INLINE_VISIBILITY void __resize_default_init(size_type __n);

    _LIBCPP_INLINE_VISIBILITY
    void reserve() _NOEXCEPT {reserve(0);}
    _LIBCPP_INLINE_VISIBILITY
    void shrink_to_fit() _NOEXCEPT {reserve();}
    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT;
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool empty() const _NOEXCEPT {return size() == 0;}

    _LIBCPP_INLINE_VISIBILITY const_reference operator[](size_type __pos) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY reference       operator[](size_type __pos)       _NOEXCEPT;

    const_reference at(size_type __n) const;
    reference       at(size_type __n);

    _LIBCPP_INLINE_VISIBILITY basic_string& operator+=(const basic_string& __str) {return append(__str);}

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value
            && !__is_same_uncvref<_Tp, basic_string >::value,
            basic_string&
        >
                                            operator+=(const _Tp& __t)            {__self_view __sv = __t; return append(__sv);}
    _LIBCPP_INLINE_VISIBILITY basic_string& operator+=(const value_type* __s)     {return append(__s);}
    _LIBCPP_INLINE_VISIBILITY basic_string& operator+=(value_type __c)            {push_back(__c); return *this;}
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY basic_string& operator+=(initializer_list<value_type> __il) {return append(__il);}
#endif  // _LIBCPP_CXX03_LANG
# 994 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    basic_string& append(const basic_string& __str);

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf<
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value
            && !__is_same_uncvref<_Tp, basic_string>::value,
            basic_string&
        >
                  append(const _Tp& __t) { __self_view __sv = __t; return append(__sv.data(), __sv.size()); }
    basic_string& append(const basic_string& __str, size_type __pos, size_type __n=npos);

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value
            && !__is_same_uncvref<_Tp, basic_string>::value,
            basic_string&
        >
                  append(const _Tp& __t, size_type __pos, size_type __n=npos);
    basic_string& append(const value_type* __s, size_type __n);
    basic_string& append(const value_type* __s);
    basic_string& append(size_type __n, value_type __c);

    _LIBCPP_INLINE_VISIBILITY
    void __append_default_init(size_type __n);

    template <class _ForwardIterator>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    basic_string& __append_forward_unsafe(_ForwardIterator, _ForwardIterator);
    template<class _InputIterator>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __is_exactly_cpp17_input_iterator<_InputIterator>::value
                || !__libcpp_string_gets_noexcept_iterator<_InputIterator>::value,
            basic_string&
        >
    _LIBCPP_INLINE_VISIBILITY
    append(_InputIterator __first, _InputIterator __last) {
      const basic_string __temp (__first, __last, __alloc());
      append(__temp.data(), __temp.size());
      return *this;
    }
    template<class _ForwardIterator>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value
                && __libcpp_string_gets_noexcept_iterator<_ForwardIterator>::value,
            basic_string&
        >
    _LIBCPP_INLINE_VISIBILITY
    append(_ForwardIterator __first, _ForwardIterator __last) {
      return __append_forward_unsafe(__first, __last);
    }

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    basic_string& append(initializer_list<value_type> __il) {return append(__il.begin(), __il.size());}
#endif  // _LIBCPP_CXX03_LANG
# 1058 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    void push_back(value_type __c);
    _LIBCPP_INLINE_VISIBILITY
    void pop_back();
    _LIBCPP_INLINE_VISIBILITY reference       front() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY const_reference front() const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY reference       back() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY const_reference back() const _NOEXCEPT;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            basic_string&
        >
                 assign(const _Tp & __t) { __self_view __sv = __t; return assign(__sv.data(), __sv.size()); }
    _LIBCPP_INLINE_VISIBILITY
    basic_string& assign(const basic_string& __str) { return *this = __str; }
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    basic_string& assign(basic_string&& __str)
        _NOEXCEPT_((__noexcept_move_assign_container<_Allocator, __alloc_traits>::value))
        {*this = _VSTD::move(__str); return *this;}
#endif
# 1083 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    basic_string& assign(const basic_string& __str, size_type __pos, size_type __n=npos);
    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value
            && !__is_same_uncvref<_Tp, basic_string>::value,
            basic_string&
        >
                  assign(const _Tp & __t, size_type __pos, size_type __n=npos);
    basic_string& assign(const value_type* __s, size_type __n);
    basic_string& assign(const value_type* __s);
    basic_string& assign(size_type __n, value_type __c);
    template<class _InputIterator>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
           __is_exactly_cpp17_input_iterator<_InputIterator>::value
                || !__libcpp_string_gets_noexcept_iterator<_InputIterator>::value,
            basic_string&
        >
        assign(_InputIterator __first, _InputIterator __last);
    template<class _ForwardIterator>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value
                 && __libcpp_string_gets_noexcept_iterator<_ForwardIterator>::value,
            basic_string&
        >
        assign(_ForwardIterator __first, _ForwardIterator __last);
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    basic_string& assign(initializer_list<value_type> __il) {return assign(__il.begin(), __il.size());}
#endif  // _LIBCPP_CXX03_LANG
# 1118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    basic_string& insert(size_type __pos1, const basic_string& __str);

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            basic_string&
        >
                 insert(size_type __pos1, const _Tp& __t)
    { __self_view __sv = __t; return insert(__pos1, __sv.data(), __sv.size()); }

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value && !__is_same_uncvref<_Tp, basic_string>::value,
            basic_string&
        >
                  insert(size_type __pos1, const _Tp& __t, size_type __pos2, size_type __n=npos);
    basic_string& insert(size_type __pos1, const basic_string& __str, size_type __pos2, size_type __n=npos);
    basic_string& insert(size_type __pos, const value_type* __s, size_type __n);
    basic_string& insert(size_type __pos, const value_type* __s);
    basic_string& insert(size_type __pos, size_type __n, value_type __c);
    iterator      insert(const_iterator __pos, value_type __c);
    _LIBCPP_INLINE_VISIBILITY
    iterator      insert(const_iterator __pos, size_type __n, value_type __c);
    template<class _InputIterator>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
           __is_exactly_cpp17_input_iterator<_InputIterator>::value
                || !__libcpp_string_gets_noexcept_iterator<_InputIterator>::value,
            iterator
        >
        insert(const_iterator __pos, _InputIterator __first, _InputIterator __last);
    template<class _ForwardIterator>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value
                 && __libcpp_string_gets_noexcept_iterator<_ForwardIterator>::value,
            iterator
        >
        insert(const_iterator __pos, _ForwardIterator __first, _ForwardIterator __last);
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __pos, initializer_list<value_type> __il)
                    {return insert(__pos, __il.begin(), __il.end());}
#endif  // _LIBCPP_CXX03_LANG
# 1170 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    basic_string& erase(size_type __pos = 0, size_type __n = npos);
    _LIBCPP_INLINE_VISIBILITY
    iterator      erase(const_iterator __pos);
    _LIBCPP_INLINE_VISIBILITY
    iterator      erase(const_iterator __first, const_iterator __last);

    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(size_type __pos1, size_type __n1, const basic_string& __str);

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            basic_string&
        >
                  replace(size_type __pos1, size_type __n1, const _Tp& __t) { __self_view __sv = __t; return replace(__pos1, __n1, __sv.data(), __sv.size()); }
    basic_string& replace(size_type __pos1, size_type __n1, const basic_string& __str, size_type __pos2, size_type __n2=npos);
    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value  && !__is_same_uncvref<_Tp, basic_string>::value,
            basic_string&
        >
                  replace(size_type __pos1, size_type __n1, const _Tp& __t, size_type __pos2, size_type __n2=npos);
    basic_string& replace(size_type __pos, size_type __n1, const value_type* __s, size_type __n2);
    basic_string& replace(size_type __pos, size_type __n1, const value_type* __s);
    basic_string& replace(size_type __pos, size_type __n1, size_type __n2, value_type __c);
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, const basic_string& __str);

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            basic_string&
        >
                  replace(const_iterator __i1, const_iterator __i2, const _Tp& __t) { __self_view __sv = __t; return replace(__i1 - begin(), __i2 - __i1, __sv); }

    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, const value_type* __s, size_type __n);
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, const value_type* __s);
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, size_type __n, value_type __c);
    template<class _InputIterator>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __is_cpp17_input_iterator<_InputIterator>::value,
            basic_string&
        >
        replace(const_iterator __i1, const_iterator __i2, _InputIterator __j1, _InputIterator __j2);
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, initializer_list<value_type> __il)
        {return replace(__i1, __i2, __il.begin(), __il.end());}
#endif  // _LIBCPP_CXX03_LANG
# 1231 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    size_type copy(value_type* __s, size_type __n, size_type __pos = 0) const;
    _LIBCPP_INLINE_VISIBILITY
    basic_string substr(size_type __pos = 0, size_type __n = npos) const;

    _LIBCPP_INLINE_VISIBILITY
    void swap(basic_string& __str)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1239 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT;
#else
# 1241 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value);
#endif
# 1244 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    const value_type* c_str() const _NOEXCEPT {return data();}
    _LIBCPP_INLINE_VISIBILITY
    const value_type* data() const _NOEXCEPT  {return _VSTD::__to_address(__get_pointer());}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 || defined(_LIBCPP_BUILDING_LIBRARY)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1250 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY
    value_type* data()             _NOEXCEPT  {return _VSTD::__to_address(__get_pointer());}
#endif
# 1253 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    allocator_type get_allocator() const _NOEXCEPT {return __alloc();}

    _LIBCPP_INLINE_VISIBILITY
    size_type find(const basic_string& __str, size_type __pos = 0) const _NOEXCEPT;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            size_type
        >
              find(const _Tp& __t, size_type __pos = 0) const;
    size_type find(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find(const value_type* __s, size_type __pos = 0) const _NOEXCEPT;
    size_type find(value_type __c, size_type __pos = 0) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type rfind(const basic_string& __str, size_type __pos = npos) const _NOEXCEPT;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            size_type
        >
              rfind(const _Tp& __t, size_type __pos = npos) const;
    size_type rfind(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type rfind(const value_type* __s, size_type __pos = npos) const _NOEXCEPT;
    size_type rfind(value_type __c, size_type __pos = npos) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(const basic_string& __str, size_type __pos = 0) const _NOEXCEPT;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            size_type
        >
              find_first_of(const _Tp& __t, size_type __pos = 0) const;
    size_type find_first_of(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(const value_type* __s, size_type __pos = 0) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(value_type __c, size_type __pos = 0) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(const basic_string& __str, size_type __pos = npos) const _NOEXCEPT;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            size_type
        >
              find_last_of(const _Tp& __t, size_type __pos = npos) const;
    size_type find_last_of(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(const value_type* __s, size_type __pos = npos) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(value_type __c, size_type __pos = npos) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(const basic_string& __str, size_type __pos = 0) const _NOEXCEPT;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            size_type
        >
              find_first_not_of(const _Tp &__t, size_type __pos = 0) const;
    size_type find_first_not_of(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(const value_type* __s, size_type __pos = 0) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(value_type __c, size_type __pos = 0) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(const basic_string& __str, size_type __pos = npos) const _NOEXCEPT;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            size_type
        >
              find_last_not_of(const _Tp& __t, size_type __pos = npos) const;
    size_type find_last_not_of(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(const value_type* __s, size_type __pos = npos) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(value_type __c, size_type __pos = npos) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    int compare(const basic_string& __str) const _NOEXCEPT;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            int
        >
        compare(const _Tp &__t) const;

    template <class _Tp>
    _LIBCPP_METHOD_TEMPLATE_IMPLICIT_INSTANTIATION_VIS
    _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
            int
        >
         compare(size_type __pos1, size_type __n1, const _Tp& __t) const;

    _LIBCPP_INLINE_VISIBILITY
    int compare(size_type __pos1, size_type __n1, const basic_string& __str) const;
    int compare(size_type __pos1, size_type __n1, const basic_string& __str, size_type __pos2, size_type __n2=npos) const;

    template <class _Tp>
    inline _LIBCPP_INLINE_VISIBILITY
        _EnableIf
        <
            __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value  && !__is_same_uncvref<_Tp, basic_string>::value,
            int
        >
        compare(size_type __pos1, size_type __n1, const _Tp& __t, size_type __pos2, size_type __n2=npos) const;
    int compare(const value_type* __s) const _NOEXCEPT;
    int compare(size_type __pos1, size_type __n1, const value_type* __s) const;
    int compare(size_type __pos1, size_type __n1, const value_type* __s, size_type __n2) const;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1395 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool starts_with(__self_view __sv) const _NOEXCEPT
    { return __self_view(data(), size()).starts_with(__sv); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool starts_with(value_type __c) const _NOEXCEPT
    { return !empty() && _Traits::eq(front(), __c); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool starts_with(const value_type* __s) const _NOEXCEPT
    { return starts_with(__self_view(__s)); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool ends_with(__self_view __sv) const _NOEXCEPT
    { return __self_view(data(), size()).ends_with( __sv); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool ends_with(value_type __c) const _NOEXCEPT
    { return !empty() && _Traits::eq(back(), __c); }

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool ends_with(const value_type* __s) const _NOEXCEPT
    { return ends_with(__self_view(__s)); }
#endif
# 1419 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY bool __invariants() const;

    _LIBCPP_INLINE_VISIBILITY void __clear_and_shrink() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    bool __is_long() const _NOEXCEPT
        {return bool(__r_.first().__s.__size_ & __short_mask);}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1429 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    bool __dereferenceable(const const_iterator* __i) const;
    bool __decrementable(const const_iterator* __i) const;
    bool __addable(const const_iterator* __i, ptrdiff_t __n) const;
    bool __subscriptable(const const_iterator* __i, ptrdiff_t __n) const;

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 1436 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

private:
    _LIBCPP_INLINE_VISIBILITY
    allocator_type& __alloc() _NOEXCEPT
        {return __r_.second();}
    _LIBCPP_INLINE_VISIBILITY
    const allocator_type& __alloc() const _NOEXCEPT
        {return __r_.second();}

#ifdef _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT

    _LIBCPP_INLINE_VISIBILITY
    void __set_short_size(size_type __s) _NOEXCEPT
#   ifdef _LIBCPP_BIG_ENDIAN
        {__r_.first().__s.__size_ = (unsigned char)(__s << 1);}
#   else
# 1452 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        {__r_.first().__s.__size_ = (unsigned char)(__s);}
#   endif
# 1454 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    size_type __get_short_size() const _NOEXCEPT
#   ifdef _LIBCPP_BIG_ENDIAN
        {return __r_.first().__s.__size_ >> 1;}
#   else
# 1460 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        {return __r_.first().__s.__size_;}
#   endif
# 1462 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

#else  // _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT
# 1464 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    void __set_short_size(size_type __s) _NOEXCEPT
#   ifdef _LIBCPP_BIG_ENDIAN
        {__r_.first().__s.__size_ = (unsigned char)(__s);}
#   else
# 1470 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        {__r_.first().__s.__size_ = (unsigned char)(__s << 1);}
#   endif
# 1472 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    size_type __get_short_size() const _NOEXCEPT
#   ifdef _LIBCPP_BIG_ENDIAN
        {return __r_.first().__s.__size_;}
#   else
# 1478 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        {return __r_.first().__s.__size_ >> 1;}
#   endif
# 1480 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

#endif  // _LIBCPP_ABI_ALTERNATE_STRING_LAYOUT
# 1482 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    void __set_long_size(size_type __s) _NOEXCEPT
        {__r_.first().__l.__size_ = __s;}
    _LIBCPP_INLINE_VISIBILITY
    size_type __get_long_size() const _NOEXCEPT
        {return __r_.first().__l.__size_;}
    _LIBCPP_INLINE_VISIBILITY
    void __set_size(size_type __s) _NOEXCEPT
        {if (__is_long()) __set_long_size(__s); else __set_short_size(__s);}

    _LIBCPP_INLINE_VISIBILITY
    void __set_long_cap(size_type __s) _NOEXCEPT
        {__r_.first().__l.__cap_  = __long_mask | __s;}
    _LIBCPP_INLINE_VISIBILITY
    size_type __get_long_cap() const _NOEXCEPT
        {return __r_.first().__l.__cap_ & size_type(~__long_mask);}

    _LIBCPP_INLINE_VISIBILITY
    void __set_long_pointer(pointer __p) _NOEXCEPT
        {__r_.first().__l.__data_ = __p;}
    _LIBCPP_INLINE_VISIBILITY
    pointer __get_long_pointer() _NOEXCEPT
        {return __r_.first().__l.__data_;}
    _LIBCPP_INLINE_VISIBILITY
    const_pointer __get_long_pointer() const _NOEXCEPT
        {return __r_.first().__l.__data_;}
    _LIBCPP_INLINE_VISIBILITY
    pointer __get_short_pointer() _NOEXCEPT
        {return pointer_traits<pointer>::pointer_to(__r_.first().__s.__data_[0]);}
    _LIBCPP_INLINE_VISIBILITY
    const_pointer __get_short_pointer() const _NOEXCEPT
        {return pointer_traits<const_pointer>::pointer_to(__r_.first().__s.__data_[0]);}
    _LIBCPP_INLINE_VISIBILITY
    pointer __get_pointer() _NOEXCEPT
        {return __is_long() ? __get_long_pointer() : __get_short_pointer();}
    _LIBCPP_INLINE_VISIBILITY
    const_pointer __get_pointer() const _NOEXCEPT
        {return __is_long() ? __get_long_pointer() : __get_short_pointer();}

    _LIBCPP_INLINE_VISIBILITY
    void __zero() _NOEXCEPT
        {
            size_type (&__a)[__n_words] = __r_.first().__r.__words;
            for (unsigned __i = 0; __i < __n_words; ++__i)
                __a[__i] = 0;
        }

    template <size_type __a> static
        _LIBCPP_INLINE_VISIBILITY
        size_type __align_it(size_type __s) _NOEXCEPT
            {return (__s + (__a-1)) & ~(__a-1);}
    enum {__alignment = 16};
    static _LIBCPP_INLINE_VISIBILITY
    size_type __recommend(size_type __s) _NOEXCEPT
        {
        if (__s < __min_cap) return static_cast<size_type>(__min_cap) - 1;
        size_type __guess = __align_it<sizeof(value_type) < __alignment ?
                     __alignment/sizeof(value_type) : 1 > (__s+1) - 1;
        if (__guess == __min_cap) ++__guess;
        return __guess;
        }

    inline
    void __init(const value_type* __s, size_type __sz, size_type __reserve);
    inline
    void __init(const value_type* __s, size_type __sz);
    inline
    void __init(size_type __n, value_type __c);

    template <class _InputIterator>
    inline
    _EnableIf
    <
        __is_exactly_cpp17_input_iterator<_InputIterator>::value
    >
    __init(_InputIterator __first, _InputIterator __last);

    template <class _ForwardIterator>
    inline
    _EnableIf
    <
        __is_cpp17_forward_iterator<_ForwardIterator>::value
    >
    __init(_ForwardIterator __first, _ForwardIterator __last);

    void __grow_by(size_type __old_cap, size_type __delta_cap, size_type __old_sz,
                   size_type __n_copy,  size_type __n_del,     size_type __n_add = 0);
    void __grow_by_and_replace(size_type __old_cap, size_type __delta_cap, size_type __old_sz,
                               size_type __n_copy,  size_type __n_del,
                               size_type __n_add, const value_type* __p_new_stuff);

    _LIBCPP_INLINE_VISIBILITY
    void __erase_to_end(size_type __pos);

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const basic_string& __str)
        {__copy_assign_alloc(__str, integral_constant<bool,
                      __alloc_traits::propagate_on_container_copy_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const basic_string& __str, true_type)
        {
            if (__alloc() == __str.__alloc())
                __alloc() = __str.__alloc();
            else
            {
                if (!__str.__is_long())
                {
                    __clear_and_shrink();
                    __alloc() = __str.__alloc();
                }
                else
                {
                    allocator_type __a = __str.__alloc();
                    pointer __p = __alloc_traits::allocate(__a, __str.__get_long_cap());
                    __clear_and_shrink();
                    __alloc() = _VSTD::move(__a);
                    __set_long_pointer(__p);
                    __set_long_cap(__str.__get_long_cap());
                    __set_long_size(__str.size());
                }
            }
        }

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const basic_string&, false_type) _NOEXCEPT
        {}

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign(basic_string& __str, false_type)
        _NOEXCEPT_(__alloc_traits::is_always_equal::value);
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign(basic_string& __str, true_type)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1618 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT;
#else
# 1620 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value);
#endif
# 1622 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
#endif
# 1623 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    void
    __move_assign_alloc(basic_string& __str)
        _NOEXCEPT_(
            !__alloc_traits::propagate_on_container_move_assignment::value ||
            is_nothrow_move_assignable<allocator_type>::value)
    {__move_assign_alloc(__str, integral_constant<bool,
                      __alloc_traits::propagate_on_container_move_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(basic_string& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
        {
            __alloc() = _VSTD::move(__c.__alloc());
        }

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(basic_string&, false_type)
        _NOEXCEPT
        {}

    _LIBCPP_INLINE_VISIBILITY void __invalidate_all_iterators();
    _LIBCPP_INLINE_VISIBILITY void __invalidate_iterators_past(size_type);

    friend basic_string operator+<>(const basic_string&, const basic_string&);
    friend basic_string operator+<>(const value_type*, const basic_string&);
    friend basic_string operator+<>(value_type, const basic_string&);
    friend basic_string operator+<>(const basic_string&, const value_type*);
    friend basic_string operator+<>(const basic_string&, value_type);
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _InputIterator,
         class _CharT = typename iterator_traits<_InputIterator>::value_type,
         class _Allocator = allocator<_CharT>,
         class = _EnableIf<__is_cpp17_input_iterator<_InputIterator>::value>,
         class = _EnableIf<__is_allocator<_Allocator>::value>
         >
basic_string(_InputIterator, _InputIterator, _Allocator = _Allocator())
  -> basic_string<_CharT, char_traits<_CharT>, _Allocator>;

template<class _CharT,
         class _Traits,
         class _Allocator = allocator<_CharT>,
         class = _EnableIf<__is_allocator<_Allocator>::value>
         >
explicit basic_string(basic_string_view<_CharT, _Traits>, const _Allocator& = _Allocator())
  -> basic_string<_CharT, _Traits, _Allocator>;

template<class _CharT,
         class _Traits,
         class _Allocator = allocator<_CharT>,
         class = _EnableIf<__is_allocator<_Allocator>::value>,
         class _Sz = typename allocator_traits<_Allocator>::size_type
         >
basic_string(basic_string_view<_CharT, _Traits>, _Sz, _Sz, const _Allocator& = _Allocator())
  -> basic_string<_CharT, _Traits, _Allocator>;
#endif
# 1682 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

template <class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::__invalidate_all_iterators()
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1689 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__invalidate_all(this);
#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 1691 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::__invalidate_iterators_past(size_type
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1698 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
                                                                        __pos
#endif
# 1700 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
                                                                      )
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1703 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __c_node* __c = __get_db()->__find_c_and_lock(this);
    if (__c)
    {
        const_pointer __new_last = __get_pointer() + __pos;
        for (__i_node** __p = __c->end_; __p != __c->beg_; )
        {
            --__p;
            const_iterator* __i = static_cast<const_iterator*>((*__p)->__i_);
            if (__i->base() > __new_last)
            {
                (*__p)->__c_ = nullptr;
                if (--__c->end_ != __p)
                    memmove(__p, __p+1, (__c->end_ - __p)*sizeof(__i_node*));
            }
        }
        __get_db()->unlock();
    }
#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 1721 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string()
    _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value)
     : __r_(__default_init_tag(), __default_init_tag())
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1730 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1732 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __zero();
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(const allocator_type& __a)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1739 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT_(is_nothrow_copy_constructible<allocator_type>::value)
#else
# 1741 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT
#endif
# 1743 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
: __r_(__default_init_tag(), __a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1746 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1748 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __zero();
}

template <class _CharT, class _Traits, class _Allocator>
void basic_string<_CharT, _Traits, _Allocator>::__init(const value_type* __s,
                                                       size_type __sz,
                                                       size_type __reserve)
{
    if (__reserve > max_size())
        this->__throw_length_error();
    pointer __p;
    if (__reserve < __min_cap)
    {
        __set_short_size(__sz);
        __p = __get_short_pointer();
    }
    else
    {
        size_type __cap = __recommend(__reserve);
        __p = __alloc_traits::allocate(__alloc(), __cap+1);
        __set_long_pointer(__p);
        __set_long_cap(__cap+1);
        __set_long_size(__sz);
    }
    traits_type::copy(_VSTD::__to_address(__p), __s, __sz);
    traits_type::assign(__p[__sz], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__init(const value_type* __s, size_type __sz)
{
    if (__sz > max_size())
        this->__throw_length_error();
    pointer __p;
    if (__sz < __min_cap)
    {
        __set_short_size(__sz);
        __p = __get_short_pointer();
    }
    else
    {
        size_type __cap = __recommend(__sz);
        __p = __alloc_traits::allocate(__alloc(), __cap+1);
        __set_long_pointer(__p);
        __set_long_cap(__cap+1);
        __set_long_size(__sz);
    }
    traits_type::copy(_VSTD::__to_address(__p), __s, __sz);
    traits_type::assign(__p[__sz], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
template <class>
basic_string<_CharT, _Traits, _Allocator>::basic_string(const _CharT* __s, const _Allocator& __a)
    : __r_(__default_init_tag(), __a)
{
    _LIBCPP_ASSERT(__s != nullptr, "basic_string(const char*, allocator) detected nullptr");
    __init(__s, traits_type::length(__s));
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1808 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1810 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(const _CharT* __s, size_type __n)
     : __r_(__default_init_tag(), __default_init_tag())
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "basic_string(const char*, n) detected nullptr");
    __init(__s, __n);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1820 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1822 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(const _CharT* __s, size_type __n, const _Allocator& __a)
    : __r_(__default_init_tag(), __a)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "basic_string(const char*, n, allocator) detected nullptr");
    __init(__s, __n);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1832 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1834 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>::basic_string(const basic_string& __str)
    : __r_(__default_init_tag(), __alloc_traits::select_on_container_copy_construction(__str.__alloc()))
{
    if (!__str.__is_long())
        __r_.first().__r = __str.__r_.first().__r;
    else
        __init(_VSTD::__to_address(__str.__get_long_pointer()), __str.__get_long_size());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1845 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1847 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>::basic_string(
    const basic_string& __str, const allocator_type& __a)
    : __r_(__default_init_tag(), __a)
{
    if (!__str.__is_long())
        __r_.first().__r = __str.__r_.first().__r;
    else
        __init(_VSTD::__to_address(__str.__get_long_pointer()), __str.__get_long_size());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1859 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1861 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

#ifndef _LIBCPP_CXX03_LANG

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(basic_string&& __str)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1869 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value)
#else
# 1871 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT
#endif
# 1873 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    : __r_(_VSTD::move(__str.__r_))
{
    __str.__zero();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1877 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
    if (__is_long())
        __get_db()->swap(this, &__str);
#endif
# 1881 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(basic_string&& __str, const allocator_type& __a)
    : __r_(__default_init_tag(), __a)
{
    if (__str.__is_long() && __a != __str.__alloc()) // copy, not move
        __init(_VSTD::__to_address(__str.__get_long_pointer()), __str.__get_long_size());
    else
    {
        __r_.first().__r = __str.__r_.first().__r;
        __str.__zero();
    }
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1896 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
    if (__is_long())
        __get_db()->swap(this, &__str);
#endif
# 1900 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

#endif  // _LIBCPP_CXX03_LANG
# 1903 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__init(size_type __n, value_type __c)
{
    if (__n > max_size())
        this->__throw_length_error();
    pointer __p;
    if (__n < __min_cap)
    {
        __set_short_size(__n);
        __p = __get_short_pointer();
    }
    else
    {
        size_type __cap = __recommend(__n);
        __p = __alloc_traits::allocate(__alloc(), __cap+1);
        __set_long_pointer(__p);
        __set_long_cap(__cap+1);
        __set_long_size(__n);
    }
    traits_type::assign(_VSTD::__to_address(__p), __n, __c);
    traits_type::assign(__p[__n], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(size_type __n, _CharT __c)
     : __r_(__default_init_tag(), __default_init_tag())
{
    __init(__n, __c);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1935 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1937 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template <class>
basic_string<_CharT, _Traits, _Allocator>::basic_string(size_type __n, _CharT __c, const _Allocator& __a)
    : __r_(__default_init_tag(), __a)
{
    __init(__n, __c);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1946 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1948 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>::basic_string(const basic_string& __str,
                                                        size_type __pos, size_type __n,
                                                        const _Allocator& __a)
    : __r_(__default_init_tag(), __a)
{
    size_type __str_sz = __str.size();
    if (__pos > __str_sz)
        this->__throw_out_of_range();
    __init(__str.data() + __pos, _VSTD::min(__n, __str_sz - __pos));
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1961 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1963 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(const basic_string& __str, size_type __pos,
                                                        const _Allocator& __a)
    : __r_(__default_init_tag(), __a)
{
    size_type __str_sz = __str.size();
    if (__pos > __str_sz)
        this->__throw_out_of_range();
    __init(__str.data() + __pos, __str_sz - __pos);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1976 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1978 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp, class>
basic_string<_CharT, _Traits, _Allocator>::basic_string(
             const _Tp& __t, size_type __pos, size_type __n, const allocator_type& __a)
    : __r_(__default_init_tag(), __a)
{
    __self_view __sv0 = __t;
    __self_view __sv = __sv0.substr(__pos, __n);
    __init(__sv.data(), __sv.size());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1990 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 1992 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp, class>
basic_string<_CharT, _Traits, _Allocator>::basic_string(const _Tp & __t)
     : __r_(__default_init_tag(), __default_init_tag())
{
    __self_view __sv = __t;
    __init(__sv.data(), __sv.size());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2002 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 2004 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp, class>
basic_string<_CharT, _Traits, _Allocator>::basic_string(const _Tp & __t, const _Allocator& __a)
    : __r_(__default_init_tag(), __a)
{
    __self_view __sv = __t;
    __init(__sv.data(), __sv.size());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2014 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 2016 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template <class _InputIterator>
_EnableIf
<
    __is_exactly_cpp17_input_iterator<_InputIterator>::value
>
basic_string<_CharT, _Traits, _Allocator>::__init(_InputIterator __first, _InputIterator __last)
{
    __zero();
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2031 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    for (; __first != __last; ++__first)
        push_back(*__first);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        if (__is_long())
            __alloc_traits::deallocate(__alloc(), __get_long_pointer(), __get_long_cap());
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2042 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template <class _ForwardIterator>
_EnableIf
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value
>
basic_string<_CharT, _Traits, _Allocator>::__init(_ForwardIterator __first, _ForwardIterator __last)
{
    size_type __sz = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__sz > max_size())
        this->__throw_length_error();
    pointer __p;
    if (__sz < __min_cap)
    {
        __set_short_size(__sz);
        __p = __get_short_pointer();
    }
    else
    {
        size_type __cap = __recommend(__sz);
        __p = __alloc_traits::allocate(__alloc(), __cap+1);
        __set_long_pointer(__p);
        __set_long_cap(__cap+1);
        __set_long_size(__sz);
    }
    for (; __first != __last; ++__first, (void) ++__p)
        traits_type::assign(*__p, *__first);
    traits_type::assign(*__p, value_type());
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator, class>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(_InputIterator __first, _InputIterator __last)
     : __r_(__default_init_tag(), __default_init_tag())
{
    __init(__first, __last);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2082 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 2084 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator, class>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(_InputIterator __first, _InputIterator __last,
                                                        const allocator_type& __a)
    : __r_(__default_init_tag(), __a)
{
    __init(__first, __last);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2095 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 2097 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

#ifndef _LIBCPP_CXX03_LANG

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>::basic_string(
    initializer_list<_CharT> __il)
     : __r_(__default_init_tag(), __default_init_tag())
{
    __init(__il.begin(), __il.end());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 2111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline

basic_string<_CharT, _Traits, _Allocator>::basic_string(
    initializer_list<_CharT> __il, const _Allocator& __a)
    : __r_(__default_init_tag(), __a)
{
    __init(__il.begin(), __il.end());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2122 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__insert_c(this);
#endif
# 2124 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

#endif  // _LIBCPP_CXX03_LANG
# 2127 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>::~basic_string()
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2132 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    __get_db()->__erase_c(this);
#endif
# 2134 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    if (__is_long())
        __alloc_traits::deallocate(__alloc(), __get_long_pointer(), __get_long_cap());
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__grow_by_and_replace
    (size_type __old_cap, size_type __delta_cap, size_type __old_sz,
     size_type __n_copy,  size_type __n_del,     size_type __n_add, const value_type* __p_new_stuff)
{
    size_type __ms = max_size();
    if (__delta_cap > __ms - __old_cap - 1)
        this->__throw_length_error();
    pointer __old_p = __get_pointer();
    size_type __cap = __old_cap < __ms / 2 - __alignment ?
                          __recommend(_VSTD::max(__old_cap + __delta_cap, 2 * __old_cap)) :
                          __ms - 1;
    pointer __p = __alloc_traits::allocate(__alloc(), __cap+1);
    __invalidate_all_iterators();
    if (__n_copy != 0)
        traits_type::copy(_VSTD::__to_address(__p),
                          _VSTD::__to_address(__old_p), __n_copy);
    if (__n_add != 0)
        traits_type::copy(_VSTD::__to_address(__p) + __n_copy, __p_new_stuff, __n_add);
    size_type __sec_cp_sz = __old_sz - __n_del - __n_copy;
    if (__sec_cp_sz != 0)
        traits_type::copy(_VSTD::__to_address(__p) + __n_copy + __n_add,
                          _VSTD::__to_address(__old_p) + __n_copy + __n_del, __sec_cp_sz);
    if (__old_cap+1 != __min_cap)
        __alloc_traits::deallocate(__alloc(), __old_p, __old_cap+1);
    __set_long_pointer(__p);
    __set_long_cap(__cap+1);
    __old_sz = __n_copy + __n_add + __sec_cp_sz;
    __set_long_size(__old_sz);
    traits_type::assign(__p[__old_sz], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__grow_by(size_type __old_cap, size_type __delta_cap, size_type __old_sz,
                                                     size_type __n_copy,  size_type __n_del,     size_type __n_add)
{
    size_type __ms = max_size();
    if (__delta_cap > __ms - __old_cap)
        this->__throw_length_error();
    pointer __old_p = __get_pointer();
    size_type __cap = __old_cap < __ms / 2 - __alignment ?
                          __recommend(_VSTD::max(__old_cap + __delta_cap, 2 * __old_cap)) :
                          __ms - 1;
    pointer __p = __alloc_traits::allocate(__alloc(), __cap+1);
    __invalidate_all_iterators();
    if (__n_copy != 0)
        traits_type::copy(_VSTD::__to_address(__p),
                          _VSTD::__to_address(__old_p), __n_copy);
    size_type __sec_cp_sz = __old_sz - __n_del - __n_copy;
    if (__sec_cp_sz != 0)
        traits_type::copy(_VSTD::__to_address(__p) + __n_copy + __n_add,
                          _VSTD::__to_address(__old_p) + __n_copy + __n_del,
                          __sec_cp_sz);
    if (__old_cap+1 != __min_cap)
        __alloc_traits::deallocate(__alloc(), __old_p, __old_cap+1);
    __set_long_pointer(__p);
    __set_long_cap(__cap+1);
}

// assign

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(const value_type* __s, size_type __n)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::assign received nullptr");
    size_type __cap = capacity();
    if (__cap >= __n)
    {
        value_type* __p = _VSTD::__to_address(__get_pointer());
        traits_type::move(__p, __s, __n);
        traits_type::assign(__p[__n], value_type());
        __set_size(__n);
        __invalidate_iterators_past(__n);
    }
    else
    {
        size_type __sz = size();
        __grow_by_and_replace(__cap, __n - __cap, __sz, 0, __sz, __n, __s);
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(size_type __n, value_type __c)
{
    size_type __cap = capacity();
    if (__cap < __n)
    {
        size_type __sz = size();
        __grow_by(__cap, __n - __cap, __sz, 0, __sz);
    }
    else
        __invalidate_iterators_past(__n);
    value_type* __p = _VSTD::__to_address(__get_pointer());
    traits_type::assign(__p, __n, __c);
    traits_type::assign(__p[__n], value_type());
    __set_size(__n);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::operator=(value_type __c)
{
    pointer __p;
    if (__is_long())
    {
        __p = __get_long_pointer();
        __set_long_size(1);
    }
    else
    {
        __p = __get_short_pointer();
        __set_short_size(1);
    }
    traits_type::assign(*__p, __c);
    traits_type::assign(*++__p, value_type());
    __invalidate_iterators_past(1);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::operator=(const basic_string& __str)
{
    if (this != &__str)
    {
        __copy_assign_alloc(__str);
        const bool __str_is_long = __str.__is_long(); // Force single branch
        if (__is_long() || __str_is_long) {
          return assign(__str.data(), __str.size());
        }
        __r_.first().__r = __str.__r_.first().__r;
    }
    return *this;
}

#ifndef _LIBCPP_CXX03_LANG

template <class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::__move_assign(basic_string& __str, false_type)
    _NOEXCEPT_(__alloc_traits::is_always_equal::value)
{
    if (__alloc() != __str.__alloc())
        assign(__str);
    else
        __move_assign(__str, true_type());
}

template <class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::__move_assign(basic_string& __str, true_type)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2298 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _NOEXCEPT
#else
# 2300 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
#endif
# 2302 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
{
  if (__is_long()) {
    __alloc_traits::deallocate(__alloc(), __get_long_pointer(),
                               __get_long_cap());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2307 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    if (!is_nothrow_move_assignable<allocator_type>::value) {
      __set_short_size(0);
      traits_type::assign(__get_short_pointer()[0], value_type());
    }
#endif
# 2312 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
  }
  __move_assign_alloc(__str);
  __r_.first() = __str.__r_.first();
  __str.__set_short_size(0);
  traits_type::assign(__str.__get_short_pointer()[0], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::operator=(basic_string&& __str)
    _NOEXCEPT_((__noexcept_move_assign_container<_Allocator, __alloc_traits>::value))
{
    __move_assign(__str, integral_constant<bool,
          __alloc_traits::propagate_on_container_move_assignment::value>());
    return *this;
}

#endif
# 2331 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
_EnableIf
<
     __is_exactly_cpp17_input_iterator <_InputIterator>::value
          || !__libcpp_string_gets_noexcept_iterator<_InputIterator>::value,
    basic_string<_CharT, _Traits, _Allocator>&
>
basic_string<_CharT, _Traits, _Allocator>::assign(_InputIterator __first, _InputIterator __last)
{
    const basic_string __temp(__first, __last, __alloc());
    assign(__temp.data(), __temp.size());
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
template<class _ForwardIterator>
_EnableIf
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value
         && __libcpp_string_gets_noexcept_iterator<_ForwardIterator>::value,
    basic_string<_CharT, _Traits, _Allocator>&
>
basic_string<_CharT, _Traits, _Allocator>::assign(_ForwardIterator __first, _ForwardIterator __last)
{
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    size_type __cap = capacity();
    if (__cap < __n)
    {
        size_type __sz = size();
        __grow_by(__cap, __n - __cap, __sz, 0, __sz);
    }
    else
        __invalidate_iterators_past(__n);
    pointer __p = __get_pointer();
    for (; __first != __last; ++__first, ++__p)
        traits_type::assign(*__p, *__first);
    traits_type::assign(*__p, value_type());
    __set_size(__n);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(const basic_string& __str, size_type __pos, size_type __n)
{
    size_type __sz = __str.size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    return assign(__str.data() + __pos, _VSTD::min(__n, __sz - __pos));
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value
    && !__is_same_uncvref<_Tp, basic_string<_CharT, _Traits, _Allocator> >::value,
    basic_string<_CharT, _Traits, _Allocator>&
>
basic_string<_CharT, _Traits, _Allocator>::assign(const _Tp & __t, size_type __pos, size_type __n)
{
    __self_view __sv = __t;
    size_type __sz = __sv.size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    return assign(__sv.data() + __pos, _VSTD::min(__n, __sz - __pos));
}


template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "string::assign received nullptr");
    return assign(__s, traits_type::length(__s));
}

// append

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(const value_type* __s, size_type __n)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::append received nullptr");
    size_type __cap = capacity();
    size_type __sz = size();
    if (__cap - __sz >= __n)
    {
        if (__n)
        {
            value_type* __p = _VSTD::__to_address(__get_pointer());
            traits_type::copy(__p + __sz, __s, __n);
            __sz += __n;
            __set_size(__sz);
            traits_type::assign(__p[__sz], value_type());
        }
    }
    else
        __grow_by_and_replace(__cap, __sz + __n - __cap, __sz, __sz, 0, __n, __s);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(size_type __n, value_type __c)
{
    if (__n)
    {
        size_type __cap = capacity();
        size_type __sz = size();
        if (__cap - __sz < __n)
            __grow_by(__cap, __sz + __n - __cap, __sz, __sz, 0);
        pointer __p = __get_pointer();
        traits_type::assign(_VSTD::__to_address(__p) + __sz, __n, __c);
        __sz += __n;
        __set_size(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
inline void
basic_string<_CharT, _Traits, _Allocator>::__append_default_init(size_type __n)
{
    if (__n)
    {
        size_type __cap = capacity();
        size_type __sz = size();
        if (__cap - __sz < __n)
            __grow_by(__cap, __sz + __n - __cap, __sz, __sz, 0);
        pointer __p = __get_pointer();
        __sz += __n;
        __set_size(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::push_back(value_type __c)
{
    bool __is_short = !__is_long();
    size_type __cap;
    size_type __sz;
    if (__is_short)
    {
        __cap = __min_cap - 1;
        __sz = __get_short_size();
    }
    else
    {
        __cap = __get_long_cap() - 1;
        __sz = __get_long_size();
    }
    if (__sz == __cap)
    {
        __grow_by(__cap, 1, __sz, __sz, 0);
        __is_short = !__is_long();
    }
    pointer __p;
    if (__is_short)
    {
        __p = __get_short_pointer() + __sz;
        __set_short_size(__sz+1);
    }
    else
    {
        __p = __get_long_pointer() + __sz;
        __set_long_size(__sz+1);
    }
    traits_type::assign(*__p, __c);
    traits_type::assign(*++__p, value_type());
}

template <class _Tp>
bool __ptr_in_range (const _Tp* __p, const _Tp* __first, const _Tp* __last)
{
    return __first <= __p && __p < __last;
}

template <class _Tp1, class _Tp2>
bool __ptr_in_range (const _Tp1*, const _Tp2*, const _Tp2*)
{
    return false;
}

template <class _CharT, class _Traits, class _Allocator>
template<class _ForwardIterator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::__append_forward_unsafe(
    _ForwardIterator __first, _ForwardIterator __last)
{
    static_assert(__is_cpp17_forward_iterator<_ForwardIterator>::value,
                  "function requires a ForwardIterator");
    size_type __sz = size();
    size_type __cap = capacity();
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__n)
    {
        typedef typename iterator_traits<_ForwardIterator>::reference _CharRef;
        _CharRef __tmp_ref = *__first;
        if (__ptr_in_range(_VSTD::addressof(__tmp_ref), data(), data() + size()))
        {
            const basic_string __temp (__first, __last, __alloc());
            append(__temp.data(), __temp.size());
        }
        else
        {
            if (__cap - __sz < __n)
                __grow_by(__cap, __sz + __n - __cap, __sz, __sz, 0);
            pointer __p = __get_pointer() + __sz;
            for (; __first != __last; ++__p, ++__first)
                traits_type::assign(*__p, *__first);
            traits_type::assign(*__p, value_type());
            __set_size(__sz + __n);
        }
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(const basic_string& __str)
{
    return append(__str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(const basic_string& __str, size_type __pos, size_type __n)
{
    size_type __sz = __str.size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    return append(__str.data() + __pos, _VSTD::min(__n, __sz - __pos));
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp>
    _EnableIf
    <
        __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value  && !__is_same_uncvref<_Tp, basic_string<_CharT, _Traits, _Allocator> >::value,
        basic_string<_CharT, _Traits, _Allocator>&
    >
basic_string<_CharT, _Traits, _Allocator>::append(const _Tp & __t, size_type __pos, size_type __n)
{
    __self_view __sv = __t;
    size_type __sz = __sv.size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    return append(__sv.data() + __pos, _VSTD::min(__n, __sz - __pos));
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "string::append received nullptr");
    return append(__s, traits_type::length(__s));
}

// insert

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos, const value_type* __s, size_type __n)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::insert received nullptr");
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    size_type __cap = capacity();
    if (__cap - __sz >= __n)
    {
        if (__n)
        {
            value_type* __p = _VSTD::__to_address(__get_pointer());
            size_type __n_move = __sz - __pos;
            if (__n_move != 0)
            {
                if (__p + __pos <= __s && __s < __p + __sz)
                    __s += __n;
                traits_type::move(__p + __pos + __n, __p + __pos, __n_move);
            }
            traits_type::move(__p + __pos, __s, __n);
            __sz += __n;
            __set_size(__sz);
            traits_type::assign(__p[__sz], value_type());
        }
    }
    else
        __grow_by_and_replace(__cap, __sz + __n - __cap, __sz, __pos, 0, __n, __s);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos, size_type __n, value_type __c)
{
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    if (__n)
    {
        size_type __cap = capacity();
        value_type* __p;
        if (__cap - __sz >= __n)
        {
            __p = _VSTD::__to_address(__get_pointer());
            size_type __n_move = __sz - __pos;
            if (__n_move != 0)
                traits_type::move(__p + __pos + __n, __p + __pos, __n_move);
        }
        else
        {
            __grow_by(__cap, __sz + __n - __cap, __sz, __pos, 0, __n);
            __p = _VSTD::__to_address(__get_long_pointer());
        }
        traits_type::assign(__p + __pos, __n, __c);
        __sz += __n;
        __set_size(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
_EnableIf
<
   __is_exactly_cpp17_input_iterator<_InputIterator>::value
        || !__libcpp_string_gets_noexcept_iterator<_InputIterator>::value,
   typename basic_string<_CharT, _Traits, _Allocator>::iterator
>
basic_string<_CharT, _Traits, _Allocator>::insert(const_iterator __pos, _InputIterator __first, _InputIterator __last)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2672 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__pos) == this,
        "string::insert(iterator, range) called with an iterator not"
        " referring to this string");
#endif
# 2676 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    const basic_string __temp(__first, __last, __alloc());
    return insert(__pos, __temp.data(), __temp.data() + __temp.size());
}

template <class _CharT, class _Traits, class _Allocator>
template<class _ForwardIterator>
_EnableIf
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value
        && __libcpp_string_gets_noexcept_iterator<_ForwardIterator>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::iterator
>
basic_string<_CharT, _Traits, _Allocator>::insert(const_iterator __pos, _ForwardIterator __first, _ForwardIterator __last)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2691 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__pos) == this,
        "string::insert(iterator, range) called with an iterator not"
        " referring to this string");
#endif
# 2695 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    size_type __ip = static_cast<size_type>(__pos - begin());
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__n)
    {
        typedef typename iterator_traits<_ForwardIterator>::reference _CharRef;
        _CharRef __tmp_char = *__first;
        if (__ptr_in_range(_VSTD::addressof(__tmp_char), data(), data() + size()))
        {
            const basic_string __temp(__first, __last, __alloc());
            return insert(__pos, __temp.data(), __temp.data() + __temp.size());
        }

        size_type __sz = size();
        size_type __cap = capacity();
        value_type* __p;
        if (__cap - __sz >= __n)
        {
            __p = _VSTD::__to_address(__get_pointer());
            size_type __n_move = __sz - __ip;
            if (__n_move != 0)
                traits_type::move(__p + __ip + __n, __p + __ip, __n_move);
        }
        else
        {
            __grow_by(__cap, __sz + __n - __cap, __sz, __ip, 0, __n);
            __p = _VSTD::__to_address(__get_long_pointer());
        }
        __sz += __n;
        __set_size(__sz);
        traits_type::assign(__p[__sz], value_type());
        for (__p += __ip; __first != __last; ++__p, ++__first)
            traits_type::assign(*__p, *__first);
    }
    return begin() + __ip;
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos1, const basic_string& __str)
{
    return insert(__pos1, __str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos1, const basic_string& __str,
                                                  size_type __pos2, size_type __n)
{
    size_type __str_sz = __str.size();
    if (__pos2 > __str_sz)
        this->__throw_out_of_range();
    return insert(__pos1, __str.data() + __pos2, _VSTD::min(__n, __str_sz - __pos2));
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value  && !__is_same_uncvref<_Tp, basic_string<_CharT, _Traits, _Allocator> >::value,
    basic_string<_CharT, _Traits, _Allocator>&
>
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos1, const _Tp& __t,
                                                  size_type __pos2, size_type __n)
{
    __self_view __sv = __t;
    size_type __str_sz = __sv.size();
    if (__pos2 > __str_sz)
        this->__throw_out_of_range();
    return insert(__pos1, __sv.data() + __pos2, _VSTD::min(__n, __str_sz - __pos2));
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos, const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "string::insert received nullptr");
    return insert(__pos, __s, traits_type::length(__s));
}

template <class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::iterator
basic_string<_CharT, _Traits, _Allocator>::insert(const_iterator __pos, value_type __c)
{
    size_type __ip = static_cast<size_type>(__pos - begin());
    size_type __sz = size();
    size_type __cap = capacity();
    value_type* __p;
    if (__cap == __sz)
    {
        __grow_by(__cap, 1, __sz, __ip, 0, 1);
        __p = _VSTD::__to_address(__get_long_pointer());
    }
    else
    {
        __p = _VSTD::__to_address(__get_pointer());
        size_type __n_move = __sz - __ip;
        if (__n_move != 0)
            traits_type::move(__p + __ip + 1, __p + __ip, __n_move);
    }
    traits_type::assign(__p[__ip], __c);
    traits_type::assign(__p[++__sz], value_type());
    __set_size(__sz);
    return begin() + static_cast<difference_type>(__ip);
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::iterator
basic_string<_CharT, _Traits, _Allocator>::insert(const_iterator __pos, size_type __n, value_type __c)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2807 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__pos) == this,
        "string::insert(iterator, n, value) called with an iterator not"
        " referring to this string");
#endif
# 2811 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    difference_type __p = __pos - begin();
    insert(static_cast<size_type>(__p), __n, __c);
    return begin() + __p;
}

// replace

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos, size_type __n1, const value_type* __s, size_type __n2)
    _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
{
    _LIBCPP_ASSERT(__n2 == 0 || __s != nullptr, "string::replace received nullptr");
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    __n1 = _VSTD::min(__n1, __sz - __pos);
    size_type __cap = capacity();
    if (__cap - __sz + __n1 >= __n2)
    {
        value_type* __p = _VSTD::__to_address(__get_pointer());
        if (__n1 != __n2)
        {
            size_type __n_move = __sz - __pos - __n1;
            if (__n_move != 0)
            {
                if (__n1 > __n2)
                {
                    traits_type::move(__p + __pos, __s, __n2);
                    traits_type::move(__p + __pos + __n2, __p + __pos + __n1, __n_move);
                    goto __finish;
                }
                if (__p + __pos < __s && __s < __p + __sz)
                {
                    if (__p + __pos + __n1 <= __s)
                        __s += __n2 - __n1;
                    else // __p + __pos < __s < __p + __pos + __n1
                    {
                        traits_type::move(__p + __pos, __s, __n1);
                        __pos += __n1;
                        __s += __n2;
                        __n2 -= __n1;
                        __n1 = 0;
                    }
                }
                traits_type::move(__p + __pos + __n2, __p + __pos + __n1, __n_move);
            }
        }
        traits_type::move(__p + __pos, __s, __n2);
__finish:
// __sz += __n2 - __n1; in this and the below function below can cause unsigned
// integer overflow, but this is a safe operation, so we disable the check.
        __sz += __n2 - __n1;
        __set_size(__sz);
        __invalidate_iterators_past(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
    else
        __grow_by_and_replace(__cap, __sz - __n1 + __n2 - __cap, __sz, __pos, __n1, __n2, __s);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos, size_type __n1, size_type __n2, value_type __c)
    _LIBCPP_DISABLE_UBSAN_UNSIGNED_INTEGER_CHECK
{
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    __n1 = _VSTD::min(__n1, __sz - __pos);
    size_type __cap = capacity();
    value_type* __p;
    if (__cap - __sz + __n1 >= __n2)
    {
        __p = _VSTD::__to_address(__get_pointer());
        if (__n1 != __n2)
        {
            size_type __n_move = __sz - __pos - __n1;
            if (__n_move != 0)
                traits_type::move(__p + __pos + __n2, __p + __pos + __n1, __n_move);
        }
    }
    else
    {
        __grow_by(__cap, __sz - __n1 + __n2 - __cap, __sz, __pos, __n1, __n2);
        __p = _VSTD::__to_address(__get_long_pointer());
    }
    traits_type::assign(__p + __pos, __n2, __c);
    __sz += __n2 - __n1;
    __set_size(__sz);
    __invalidate_iterators_past(__sz);
    traits_type::assign(__p[__sz], value_type());
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
_EnableIf
<
    __is_cpp17_input_iterator<_InputIterator>::value,
    basic_string<_CharT, _Traits, _Allocator>&
>
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2,
                                                   _InputIterator __j1, _InputIterator __j2)
{
    const basic_string __temp(__j1, __j2, __alloc());
    return this->replace(__i1, __i2, __temp);
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos1, size_type __n1, const basic_string& __str)
{
    return replace(__pos1, __n1, __str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos1, size_type __n1, const basic_string& __str,
                                                   size_type __pos2, size_type __n2)
{
    size_type __str_sz = __str.size();
    if (__pos2 > __str_sz)
        this->__throw_out_of_range();
    return replace(__pos1, __n1, __str.data() + __pos2, _VSTD::min(__n2, __str_sz - __pos2));
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value && !__is_same_uncvref<_Tp, basic_string<_CharT, _Traits, _Allocator> >::value,
    basic_string<_CharT, _Traits, _Allocator>&
>
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos1, size_type __n1, const _Tp& __t,
                                                   size_type __pos2, size_type __n2)
{
    __self_view __sv = __t;
    size_type __str_sz = __sv.size();
    if (__pos2 > __str_sz)
        this->__throw_out_of_range();
    return replace(__pos1, __n1, __sv.data() + __pos2, _VSTD::min(__n2, __str_sz - __pos2));
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos, size_type __n1, const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "string::replace received nullptr");
    return replace(__pos, __n1, __s, traits_type::length(__s));
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2, const basic_string& __str)
{
    return replace(static_cast<size_type>(__i1 - begin()), static_cast<size_type>(__i2 - __i1),
                   __str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2, const value_type* __s, size_type __n)
{
    return replace(static_cast<size_type>(__i1 - begin()), static_cast<size_type>(__i2 - __i1), __s, __n);
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2, const value_type* __s)
{
    return replace(static_cast<size_type>(__i1 - begin()), static_cast<size_type>(__i2 - __i1), __s);
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2, size_type __n, value_type __c)
{
    return replace(static_cast<size_type>(__i1 - begin()), static_cast<size_type>(__i2 - __i1), __n, __c);
}

// erase

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::erase(size_type __pos, size_type __n)
{
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    if (__n)
    {
        value_type* __p = _VSTD::__to_address(__get_pointer());
        __n = _VSTD::min(__n, __sz - __pos);
        size_type __n_move = __sz - __pos - __n;
        if (__n_move != 0)
            traits_type::move(__p + __pos, __p + __pos + __n, __n_move);
        __sz -= __n;
        __set_size(__sz);
        __invalidate_iterators_past(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::iterator
basic_string<_CharT, _Traits, _Allocator>::erase(const_iterator __pos)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3028 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__pos) == this,
        "string::erase(iterator) called with an iterator not"
        " referring to this string");
#endif
# 3032 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_ASSERT(__pos != end(),
        "string::erase(iterator) called with a non-dereferenceable iterator");
    iterator __b = begin();
    size_type __r = static_cast<size_type>(__pos - __b);
    erase(__r, 1);
    return __b + static_cast<difference_type>(__r);
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::iterator
basic_string<_CharT, _Traits, _Allocator>::erase(const_iterator __first, const_iterator __last)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3046 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__first) == this,
        "string::erase(iterator,  iterator) called with an iterator not"
        " referring to this string");
#endif
# 3050 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_ASSERT(__first <= __last, "string::erase(first, last) called with invalid range");
    iterator __b = begin();
    size_type __r = static_cast<size_type>(__first - __b);
    erase(__r, static_cast<size_type>(__last - __first));
    return __b + static_cast<difference_type>(__r);
}

template <class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::pop_back()
{
    _LIBCPP_ASSERT(!empty(), "string::pop_back(): string is already empty");
    size_type __sz;
    if (__is_long())
    {
        __sz = __get_long_size() - 1;
        __set_long_size(__sz);
        traits_type::assign(*(__get_long_pointer() + __sz), value_type());
    }
    else
    {
        __sz = __get_short_size() - 1;
        __set_short_size(__sz);
        traits_type::assign(*(__get_short_pointer() + __sz), value_type());
    }
    __invalidate_iterators_past(__sz);
}

template <class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::clear() _NOEXCEPT
{
    __invalidate_all_iterators();
    if (__is_long())
    {
        traits_type::assign(*__get_long_pointer(), value_type());
        __set_long_size(0);
    }
    else
    {
        traits_type::assign(*__get_short_pointer(), value_type());
        __set_short_size(0);
    }
}

template <class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::__erase_to_end(size_type __pos)
{
    if (__is_long())
    {
        traits_type::assign(*(__get_long_pointer() + __pos), value_type());
        __set_long_size(__pos);
    }
    else
    {
        traits_type::assign(*(__get_short_pointer() + __pos), value_type());
        __set_short_size(__pos);
    }
    __invalidate_iterators_past(__pos);
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::resize(size_type __n, value_type __c)
{
    size_type __sz = size();
    if (__n > __sz)
        append(__n - __sz, __c);
    else
        __erase_to_end(__n);
}

template <class _CharT, class _Traits, class _Allocator>
inline void
basic_string<_CharT, _Traits, _Allocator>::__resize_default_init(size_type __n)
{
    size_type __sz = size();
    if (__n > __sz) {
       __append_default_init(__n - __sz);
    } else
        __erase_to_end(__n);
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::max_size() const _NOEXCEPT
{
    size_type __m = __alloc_traits::max_size(__alloc());
#ifdef _LIBCPP_BIG_ENDIAN
    return (__m <= ~__long_mask ? __m : __m/2) - __alignment;
#else
# 3146 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    return __m - __alignment;
#endif
# 3148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::reserve(size_type __res_arg)
{
    if (__res_arg > max_size())
        this->__throw_length_error();
    size_type __cap = capacity();
    size_type __sz = size();
    __res_arg = _VSTD::max(__res_arg, __sz);
    __res_arg = __recommend(__res_arg);
    if (__res_arg != __cap)
    {
        pointer __new_data, __p;
        bool __was_long, __now_long;
        if (__res_arg == __min_cap - 1)
        {
            __was_long = true;
            __now_long = false;
            __new_data = __get_short_pointer();
            __p = __get_long_pointer();
        }
        else
        {
            if (__res_arg > __cap)
                __new_data = __alloc_traits::allocate(__alloc(), __res_arg+1);
            else
            {
            #ifndef _LIBCPP_NO_EXCEPTIONS
                try
                {
            #endif  // _LIBCPP_NO_EXCEPTIONS
# 3181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
                    __new_data = __alloc_traits::allocate(__alloc(), __res_arg+1);
            #ifndef _LIBCPP_NO_EXCEPTIONS
                }
                catch (...)
                {
                    return;
                }
            #else  // _LIBCPP_NO_EXCEPTIONS
# 3189 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
                if (__new_data == nullptr)
                    return;
            #endif  // _LIBCPP_NO_EXCEPTIONS
# 3192 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
            }
            __now_long = true;
            __was_long = __is_long();
            __p = __get_pointer();
        }
        traits_type::copy(_VSTD::__to_address(__new_data),
                          _VSTD::__to_address(__p), size()+1);
        if (__was_long)
            __alloc_traits::deallocate(__alloc(), __p, __cap+1);
        if (__now_long)
        {
            __set_long_cap(__res_arg+1);
            __set_long_size(__sz);
            __set_long_pointer(__new_data);
        }
        else
            __set_short_size(__sz);
        __invalidate_all_iterators();
    }
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::const_reference
basic_string<_CharT, _Traits, _Allocator>::operator[](size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__pos <= size(), "string index out of bounds");
    return *(data() + __pos);
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::reference
basic_string<_CharT, _Traits, _Allocator>::operator[](size_type __pos) _NOEXCEPT
{
    _LIBCPP_ASSERT(__pos <= size(), "string index out of bounds");
    return *(__get_pointer() + __pos);
}

template <class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::const_reference
basic_string<_CharT, _Traits, _Allocator>::at(size_type __n) const
{
    if (__n >= size())
        this->__throw_out_of_range();
    return (*this)[__n];
}

template <class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::reference
basic_string<_CharT, _Traits, _Allocator>::at(size_type __n)
{
    if (__n >= size())
        this->__throw_out_of_range();
    return (*this)[__n];
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::reference
basic_string<_CharT, _Traits, _Allocator>::front() _NOEXCEPT
{
    _LIBCPP_ASSERT(!empty(), "string::front(): string is empty");
    return *__get_pointer();
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::const_reference
basic_string<_CharT, _Traits, _Allocator>::front() const _NOEXCEPT
{
    _LIBCPP_ASSERT(!empty(), "string::front(): string is empty");
    return *data();
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::reference
basic_string<_CharT, _Traits, _Allocator>::back() _NOEXCEPT
{
    _LIBCPP_ASSERT(!empty(), "string::back(): string is empty");
    return *(__get_pointer() + size() - 1);
}

template <class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::const_reference
basic_string<_CharT, _Traits, _Allocator>::back() const _NOEXCEPT
{
    _LIBCPP_ASSERT(!empty(), "string::back(): string is empty");
    return *(data() + size() - 1);
}

template <class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::copy(value_type* __s, size_type __n, size_type __pos) const
{
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    size_type __rlen = _VSTD::min(__n, __sz - __pos);
    traits_type::copy(__s, data() + __pos, __rlen);
    return __rlen;
}

template <class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>
basic_string<_CharT, _Traits, _Allocator>::substr(size_type __pos, size_type __n) const
{
    return basic_string(*this, __pos, __n, __alloc());
}

template <class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::swap(basic_string& __str)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3310 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT
#else
# 3312 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value)
#endif
# 3315 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3317 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    if (!__is_long())
        __get_db()->__invalidate_all(this);
    if (!__str.__is_long())
        __get_db()->__invalidate_all(&__str);
    __get_db()->swap(this, &__str);
#endif
# 3323 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
    _LIBCPP_ASSERT(
        __alloc_traits::propagate_on_container_swap::value ||
        __alloc_traits::is_always_equal::value ||
        __alloc() == __str.__alloc(), "swapping non-equal allocators");
    _VSTD::swap(__r_.first(), __str.__r_.first());
    __swap_allocator(__alloc(), __str.__alloc());
}

// find

template <class _Traits>
struct _LIBCPP_HIDDEN __traits_eq
{
    typedef typename _Traits::char_type char_type;
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const char_type& __x, const char_type& __y) _NOEXCEPT
        {return _Traits::eq(__x, __y);}
};

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find(const value_type* __s,
                                                size_type __pos,
                                                size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find(): received nullptr");
    return __str_find<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, __n);
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find(const basic_string& __str,
                                                size_type __pos) const _NOEXCEPT
{
    return __str_find<value_type, size_type, traits_type, npos>
        (data(), size(), __str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::size_type
>
basic_string<_CharT, _Traits, _Allocator>::find(const _Tp &__t,
                                                size_type __pos) const
{
    __self_view __sv = __t;
    return __str_find<value_type, size_type, traits_type, npos>
        (data(), size(), __sv.data(), __pos, __sv.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find(const value_type* __s,
                                                size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find(): received nullptr");
    return __str_find<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find(value_type __c,
                                                size_type __pos) const _NOEXCEPT
{
    return __str_find<value_type, size_type, traits_type, npos>
        (data(), size(), __c, __pos);
}

// rfind

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::rfind(const value_type* __s,
                                                 size_type __pos,
                                                 size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::rfind(): received nullptr");
    return __str_rfind<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, __n);
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::rfind(const basic_string& __str,
                                                 size_type __pos) const _NOEXCEPT
{
    return __str_rfind<value_type, size_type, traits_type, npos>
        (data(), size(), __str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::size_type
>
basic_string<_CharT, _Traits, _Allocator>::rfind(const _Tp& __t,
                                                size_type __pos) const
{
    __self_view __sv = __t;
    return __str_rfind<value_type, size_type, traits_type, npos>
        (data(), size(), __sv.data(), __pos, __sv.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::rfind(const value_type* __s,
                                                 size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::rfind(): received nullptr");
    return __str_rfind<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::rfind(value_type __c,
                                                 size_type __pos) const _NOEXCEPT
{
    return __str_rfind<value_type, size_type, traits_type, npos>
        (data(), size(), __c, __pos);
}

// find_first_of

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_of(const value_type* __s,
                                                         size_type __pos,
                                                         size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find_first_of(): received nullptr");
    return __str_find_first_of<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, __n);
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_of(const basic_string& __str,
                                                         size_type __pos) const _NOEXCEPT
{
    return __str_find_first_of<value_type, size_type, traits_type, npos>
        (data(), size(), __str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::size_type
>
basic_string<_CharT, _Traits, _Allocator>::find_first_of(const _Tp& __t,
                                                size_type __pos) const
{
    __self_view __sv = __t;
    return __str_find_first_of<value_type, size_type, traits_type, npos>
        (data(), size(), __sv.data(), __pos, __sv.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_of(const value_type* __s,
                                                         size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find_first_of(): received nullptr");
    return __str_find_first_of<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_of(value_type __c,
                                                         size_type __pos) const _NOEXCEPT
{
    return find(__c, __pos);
}

// find_last_of

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_of(const value_type* __s,
                                                        size_type __pos,
                                                        size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find_last_of(): received nullptr");
    return __str_find_last_of<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, __n);
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_of(const basic_string& __str,
                                                        size_type __pos) const _NOEXCEPT
{
    return __str_find_last_of<value_type, size_type, traits_type, npos>
        (data(), size(), __str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::size_type
>
basic_string<_CharT, _Traits, _Allocator>::find_last_of(const _Tp& __t,
                                                size_type __pos) const
{
    __self_view __sv = __t;
    return __str_find_last_of<value_type, size_type, traits_type, npos>
        (data(), size(), __sv.data(), __pos, __sv.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_of(const value_type* __s,
                                                        size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find_last_of(): received nullptr");
    return __str_find_last_of<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_of(value_type __c,
                                                        size_type __pos) const _NOEXCEPT
{
    return rfind(__c, __pos);
}

// find_first_not_of

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(const value_type* __s,
                                                             size_type __pos,
                                                             size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find_first_not_of(): received nullptr");
    return __str_find_first_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, __n);
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(const basic_string& __str,
                                                             size_type __pos) const _NOEXCEPT
{
    return __str_find_first_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::size_type
>
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(const _Tp& __t,
                                                size_type __pos) const
{
    __self_view __sv = __t;
    return __str_find_first_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __sv.data(), __pos, __sv.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(const value_type* __s,
                                                             size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find_first_not_of(): received nullptr");
    return __str_find_first_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(value_type __c,
                                                             size_type __pos) const _NOEXCEPT
{
    return __str_find_first_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __c, __pos);
}

// find_last_not_of

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(const value_type* __s,
                                                            size_type __pos,
                                                            size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find_last_not_of(): received nullptr");
    return __str_find_last_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, __n);
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(const basic_string& __str,
                                                            size_type __pos) const _NOEXCEPT
{
    return __str_find_last_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::size_type
>
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(const _Tp& __t,
                                                size_type __pos) const
{
    __self_view __sv = __t;
    return __str_find_last_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __sv.data(), __pos, __sv.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(const value_type* __s,
                                                            size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find_last_not_of(): received nullptr");
    return __str_find_last_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
inline
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(value_type __c,
                                                            size_type __pos) const _NOEXCEPT
{
    return __str_find_last_not_of<value_type, size_type, traits_type, npos>
        (data(), size(), __c, __pos);
}

// compare

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
    int
>
basic_string<_CharT, _Traits, _Allocator>::compare(const _Tp& __t) const
{
    __self_view __sv = __t;
    size_t __lhs_sz = size();
    size_t __rhs_sz = __sv.size();
    int __result = traits_type::compare(data(), __sv.data(),
                                        _VSTD::min(__lhs_sz, __rhs_sz));
    if (__result != 0)
        return __result;
    if (__lhs_sz < __rhs_sz)
        return -1;
    if (__lhs_sz > __rhs_sz)
        return 1;
    return 0;
}

template <class _CharT, class _Traits, class _Allocator>
inline
int
basic_string<_CharT, _Traits, _Allocator>::compare(const basic_string& __str) const _NOEXCEPT
{
    return compare(__self_view(__str));
}

template <class _CharT, class _Traits, class _Allocator>
int
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const value_type* __s,
                                                   size_type __n2) const
{
    _LIBCPP_ASSERT(__n2 == 0 || __s != nullptr, "string::compare(): received nullptr");
    size_type __sz = size();
    if (__pos1 > __sz || __n2 == npos)
        this->__throw_out_of_range();
    size_type __rlen = _VSTD::min(__n1, __sz - __pos1);
    int __r = traits_type::compare(data() + __pos1, __s, _VSTD::min(__rlen, __n2));
    if (__r == 0)
    {
        if (__rlen < __n2)
            __r = -1;
        else if (__rlen > __n2)
            __r = 1;
    }
    return __r;
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value,
    int
>
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const _Tp& __t) const
{
    __self_view __sv = __t;
    return compare(__pos1, __n1, __sv.data(), __sv.size());
}

template <class _CharT, class _Traits, class _Allocator>
inline
int
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const basic_string& __str) const
{
    return compare(__pos1, __n1, __str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
template <class _Tp>
_EnableIf
<
    __can_be_converted_to_string_view<_CharT, _Traits, _Tp>::value
    && !__is_same_uncvref<_Tp, basic_string<_CharT, _Traits, _Allocator> >::value,
    int
>
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const _Tp& __t,
                                                   size_type __pos2,
                                                   size_type __n2) const
{
    __self_view __sv = __t;
    return __self_view(*this).substr(__pos1, __n1).compare(__sv.substr(__pos2, __n2));
}

template <class _CharT, class _Traits, class _Allocator>
int
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const basic_string& __str,
                                                   size_type __pos2,
                                                   size_type __n2) const
{
        return compare(__pos1, __n1, __self_view(__str), __pos2, __n2);
}

template <class _CharT, class _Traits, class _Allocator>
int
basic_string<_CharT, _Traits, _Allocator>::compare(const value_type* __s) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::compare(): received nullptr");
    return compare(0, npos, __s, traits_type::length(__s));
}

template <class _CharT, class _Traits, class _Allocator>
int
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const value_type* __s) const
{
    _LIBCPP_ASSERT(__s != nullptr, "string::compare(): received nullptr");
    return compare(__pos1, __n1, __s, traits_type::length(__s));
}

// __invariants

template<class _CharT, class _Traits, class _Allocator>
inline
bool
basic_string<_CharT, _Traits, _Allocator>::__invariants() const
{
    if (size() > capacity())
        return false;
    if (capacity() < __min_cap - 1)
        return false;
    if (data() == 0)
        return false;
    if (data()[size()] != value_type(0))
        return false;
    return true;
}

// __clear_and_shrink

template<class _CharT, class _Traits, class _Allocator>
inline
void
basic_string<_CharT, _Traits, _Allocator>::__clear_and_shrink() _NOEXCEPT
{
    clear();
    if(__is_long())
    {
        __alloc_traits::deallocate(__alloc(), __get_long_pointer(), capacity() + 1);
        __set_long_cap(0);
        __set_short_size(0);
    }
}

// operator==

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    size_t __lhs_sz = __lhs.size();
    return __lhs_sz == __rhs.size() && _Traits::compare(__lhs.data(),
                                                        __rhs.data(),
                                                        __lhs_sz) == 0;
}

template<class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const basic_string<char, char_traits<char>, _Allocator>& __lhs,
           const basic_string<char, char_traits<char>, _Allocator>& __rhs) _NOEXCEPT
{
    size_t __lhs_sz = __lhs.size();
    if (__lhs_sz != __rhs.size())
        return false;
    const char* __lp = __lhs.data();
    const char* __rp = __rhs.data();
    if (__lhs.__is_long())
        return char_traits<char>::compare(__lp, __rp, __lhs_sz) == 0;
    for (; __lhs_sz != 0; --__lhs_sz, ++__lp, ++__rp)
        if (*__lp != *__rp)
            return false;
    return true;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    typedef basic_string<_CharT, _Traits, _Allocator> _String;
    _LIBCPP_ASSERT(__lhs != nullptr, "operator==(char*, basic_string): received nullptr");
    size_t __lhs_len = _Traits::length(__lhs);
    if (__lhs_len != __rhs.size()) return false;
    return __rhs.compare(0, _String::npos, __lhs, __lhs_len) == 0;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const basic_string<_CharT,_Traits,_Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    typedef basic_string<_CharT, _Traits, _Allocator> _String;
    _LIBCPP_ASSERT(__rhs != nullptr, "operator==(basic_string, char*): received nullptr");
    size_t __rhs_len = _Traits::length(__rhs);
    if (__rhs_len != __lhs.size()) return false;
    return __lhs.compare(0, _String::npos, __rhs, __rhs_len) == 0;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const basic_string<_CharT,_Traits,_Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__lhs == __rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__lhs == __rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return !(__lhs == __rhs);
}

// operator<

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) < 0;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) < 0;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __rhs.compare(__lhs) > 0;
}

// operator>

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __rhs < __lhs;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return __rhs < __lhs;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __rhs < __lhs;
}

// operator<=

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__rhs < __lhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return !(__rhs < __lhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__rhs < __lhs);
}

// operator>=

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__lhs < __rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return !(__lhs < __rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__lhs < __rhs);
}

// operator +

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
          const basic_string<_CharT, _Traits, _Allocator>& __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__lhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __lhs_sz = __lhs.size();
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __rhs_sz = __rhs.size();
    __r.__init(__lhs.data(), __lhs_sz, __lhs_sz + __rhs_sz);
    __r.append(__rhs.data(), __rhs_sz);
    return __r;
}

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const _CharT* __lhs , const basic_string<_CharT,_Traits,_Allocator>& __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__rhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __lhs_sz = _Traits::length(__lhs);
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __rhs_sz = __rhs.size();
    __r.__init(__lhs, __lhs_sz, __lhs_sz + __rhs_sz);
    __r.append(__rhs.data(), __rhs_sz);
    return __r;
}

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(_CharT __lhs, const basic_string<_CharT,_Traits,_Allocator>& __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__rhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __rhs_sz = __rhs.size();
    __r.__init(&__lhs, 1, 1 + __rhs_sz);
    __r.append(__rhs.data(), __rhs_sz);
    return __r;
}

template<class _CharT, class _Traits, class _Allocator>
inline
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __lhs, const _CharT* __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__lhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __lhs_sz = __lhs.size();
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __rhs_sz = _Traits::length(__rhs);
    __r.__init(__lhs.data(), __lhs_sz, __lhs_sz + __rhs_sz);
    __r.append(__rhs, __rhs_sz);
    return __r;
}

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __lhs, _CharT __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__lhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __lhs_sz = __lhs.size();
    __r.__init(__lhs.data(), __lhs_sz, __lhs_sz + 1);
    __r.push_back(__rhs);
    return __r;
}

#ifndef _LIBCPP_CXX03_LANG

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(basic_string<_CharT, _Traits, _Allocator>&& __lhs, const basic_string<_CharT, _Traits, _Allocator>& __rhs)
{
    return _VSTD::move(__lhs.append(__rhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __lhs, basic_string<_CharT, _Traits, _Allocator>&& __rhs)
{
    return _VSTD::move(__rhs.insert(0, __lhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(basic_string<_CharT, _Traits, _Allocator>&& __lhs, basic_string<_CharT, _Traits, _Allocator>&& __rhs)
{
    return _VSTD::move(__lhs.append(__rhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(const _CharT* __lhs , basic_string<_CharT,_Traits,_Allocator>&& __rhs)
{
    return _VSTD::move(__rhs.insert(0, __lhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(_CharT __lhs, basic_string<_CharT,_Traits,_Allocator>&& __rhs)
{
    __rhs.insert(__rhs.begin(), __lhs);
    return _VSTD::move(__rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(basic_string<_CharT, _Traits, _Allocator>&& __lhs, const _CharT* __rhs)
{
    return _VSTD::move(__lhs.append(__rhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(basic_string<_CharT, _Traits, _Allocator>&& __lhs, _CharT __rhs)
{
    __lhs.push_back(__rhs);
    return _VSTD::move(__lhs);
}

#endif  // _LIBCPP_CXX03_LANG
# 4177 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

// swap

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(basic_string<_CharT, _Traits, _Allocator>& __lhs,
     basic_string<_CharT, _Traits, _Allocator>& __rhs)
     _NOEXCEPT_(_NOEXCEPT_(__lhs.swap(__rhs)))
{
    __lhs.swap(__rhs);
}

#ifndef _LIBCPP_NO_HAS_CHAR8_T
typedef basic_string<char8_t> u8string;
#endif
# 4193 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
typedef basic_string<char16_t> u16string;
typedef basic_string<char32_t> u32string;
#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 4198 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

_LIBCPP_FUNC_VIS int                stoi  (const string& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS long               stol  (const string& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS unsigned long      stoul (const string& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS long long          stoll (const string& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS unsigned long long stoull(const string& __str, size_t* __idx = 0, int __base = 10);

_LIBCPP_FUNC_VIS float       stof (const string& __str, size_t* __idx = 0);
_LIBCPP_FUNC_VIS double      stod (const string& __str, size_t* __idx = 0);
_LIBCPP_FUNC_VIS long double stold(const string& __str, size_t* __idx = 0);

_LIBCPP_FUNC_VIS string to_string(int __val);
_LIBCPP_FUNC_VIS string to_string(unsigned __val);
_LIBCPP_FUNC_VIS string to_string(long __val);
_LIBCPP_FUNC_VIS string to_string(unsigned long __val);
_LIBCPP_FUNC_VIS string to_string(long long __val);
_LIBCPP_FUNC_VIS string to_string(unsigned long long __val);
_LIBCPP_FUNC_VIS string to_string(float __val);
_LIBCPP_FUNC_VIS string to_string(double __val);
_LIBCPP_FUNC_VIS string to_string(long double __val);

_LIBCPP_FUNC_VIS int                stoi  (const wstring& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS long               stol  (const wstring& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS unsigned long      stoul (const wstring& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS long long          stoll (const wstring& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS unsigned long long stoull(const wstring& __str, size_t* __idx = 0, int __base = 10);

_LIBCPP_FUNC_VIS float       stof (const wstring& __str, size_t* __idx = 0);
_LIBCPP_FUNC_VIS double      stod (const wstring& __str, size_t* __idx = 0);
_LIBCPP_FUNC_VIS long double stold(const wstring& __str, size_t* __idx = 0);

_LIBCPP_FUNC_VIS wstring to_wstring(int __val);
_LIBCPP_FUNC_VIS wstring to_wstring(unsigned __val);
_LIBCPP_FUNC_VIS wstring to_wstring(long __val);
_LIBCPP_FUNC_VIS wstring to_wstring(unsigned long __val);
_LIBCPP_FUNC_VIS wstring to_wstring(long long __val);
_LIBCPP_FUNC_VIS wstring to_wstring(unsigned long long __val);
_LIBCPP_FUNC_VIS wstring to_wstring(float __val);
_LIBCPP_FUNC_VIS wstring to_wstring(double __val);
_LIBCPP_FUNC_VIS wstring to_wstring(long double __val);

template<class _CharT, class _Traits, class _Allocator>
_LIBCPP_FUNC_VIS
const typename basic_string<_CharT, _Traits, _Allocator>::size_type
               basic_string<_CharT, _Traits, _Allocator>::npos;

template <class _CharT, class _Allocator>
struct _LIBCPP_TEMPLATE_VIS
    hash<basic_string<_CharT, char_traits<_CharT>, _Allocator> >
    : public unary_function<
          basic_string<_CharT, char_traits<_CharT>, _Allocator>, size_t>
{
    size_t
    operator()(const basic_string<_CharT, char_traits<_CharT>, _Allocator>& __val) const _NOEXCEPT
    { return __do_string_hash(__val.data(), __val.data() + __val.size()); }
};


template<class _CharT, class _Traits, class _Allocator>
basic_ostream<_CharT, _Traits>&
operator<<(basic_ostream<_CharT, _Traits>& __os,
           const basic_string<_CharT, _Traits, _Allocator>& __str);

template<class _CharT, class _Traits, class _Allocator>
basic_istream<_CharT, _Traits>&
operator>>(basic_istream<_CharT, _Traits>& __is,
           basic_string<_CharT, _Traits, _Allocator>& __str);

template<class _CharT, class _Traits, class _Allocator>
basic_istream<_CharT, _Traits>&
getline(basic_istream<_CharT, _Traits>& __is,
        basic_string<_CharT, _Traits, _Allocator>& __str, _CharT __dlm);

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_istream<_CharT, _Traits>&
getline(basic_istream<_CharT, _Traits>& __is,
        basic_string<_CharT, _Traits, _Allocator>& __str);

#ifndef _LIBCPP_CXX03_LANG

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_istream<_CharT, _Traits>&
getline(basic_istream<_CharT, _Traits>&& __is,
        basic_string<_CharT, _Traits, _Allocator>& __str, _CharT __dlm);

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_istream<_CharT, _Traits>&
getline(basic_istream<_CharT, _Traits>&& __is,
        basic_string<_CharT, _Traits, _Allocator>& __str);

#endif  // _LIBCPP_CXX03_LANG
# 4292 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4294 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
template<class _CharT, class _Traits, class _Allocator, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
void erase(basic_string<_CharT, _Traits, _Allocator>& __str, const _Up& __v)
{ __str.erase(_VSTD::remove(__str.begin(), __str.end(), __v), __str.end()); }

template<class _CharT, class _Traits, class _Allocator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
void erase_if(basic_string<_CharT, _Traits, _Allocator>& __str, _Predicate __pred)
{ __str.erase(_VSTD::remove_if(__str.begin(), __str.end(), __pred), __str.end()); }
#endif
# 4304 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

template<class _CharT, class _Traits, class _Allocator>
bool
basic_string<_CharT, _Traits, _Allocator>::__dereferenceable(const const_iterator* __i) const
{
    return this->data() <= _VSTD::__to_address(__i->base()) &&
           _VSTD::__to_address(__i->base()) < this->data() + this->size();
}

template<class _CharT, class _Traits, class _Allocator>
bool
basic_string<_CharT, _Traits, _Allocator>::__decrementable(const const_iterator* __i) const
{
    return this->data() < _VSTD::__to_address(__i->base()) &&
           _VSTD::__to_address(__i->base()) <= this->data() + this->size();
}

template<class _CharT, class _Traits, class _Allocator>
bool
basic_string<_CharT, _Traits, _Allocator>::__addable(const const_iterator* __i, ptrdiff_t __n) const
{
    const value_type* __p = _VSTD::__to_address(__i->base()) + __n;
    return this->data() <= __p && __p <= this->data() + this->size();
}

template<class _CharT, class _Traits, class _Allocator>
bool
basic_string<_CharT, _Traits, _Allocator>::__subscriptable(const const_iterator* __i, ptrdiff_t __n) const
{
    const value_type* __p = _VSTD::__to_address(__i->base()) + __n;
    return this->data() <= __p && __p < this->data() + this->size();
}

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 4340 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

_LIBCPP_STRING_EXTERN_TEMPLATE_LIST(_LIBCPP_EXTERN_TEMPLATE, char)
_LIBCPP_STRING_EXTERN_TEMPLATE_LIST(_LIBCPP_EXTERN_TEMPLATE, wchar_t)

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4345 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
// Literal suffixes for basic_string [basic.string.literals]
inline namespace literals
{
  inline namespace string_literals
  {
    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<char> operator "" s( const char *__str, size_t __len )
    {
        return basic_string<char> (__str, __len);
    }

    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<wchar_t> operator "" s( const wchar_t *__str, size_t __len )
    {
        return basic_string<wchar_t> (__str, __len);
    }

#ifndef _LIBCPP_NO_HAS_CHAR8_T
    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<char8_t> operator "" s(const char8_t *__str, size_t __len) _NOEXCEPT
    {
        return basic_string<char8_t> (__str, __len);
    }
#endif
# 4369 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<char16_t> operator "" s( const char16_t *__str, size_t __len )
    {
        return basic_string<char16_t> (__str, __len);
    }

    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<char32_t> operator "" s( const char32_t *__str, size_t __len )
    {
        return basic_string<char32_t> (__str, __len);
    }
  }
}
#endif
# 4384 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_STRING
# 4390 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/string" 3
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h" 2

namespace llvm {
class StringRef;
  class Twine;

  /// An error handler callback.
  typedef void (*fatal_error_handler_t)(void *user_data,
                                        const std::string& reason,
                                        bool gen_crash_diag);

  /// install_fatal_error_handler - Installs a new error handler to be used
  /// whenever a serious (non-recoverable) error is encountered by LLVM.
  ///
  /// If no error handler is installed the default is to print the error message
  /// to stderr, and call exit(1).  If an error handler is installed then it is
  /// the handler's responsibility to log the message, it will no longer be
  /// printed to stderr.  If the error handler returns, then exit(1) will be
  /// called.
  ///
  /// It is dangerous to naively use an error handler which throws an exception.
  /// Even though some applications desire to gracefully recover from arbitrary
  /// faults, blindly throwing exceptions through unfamiliar code isn't a way to
  /// achieve this.
  ///
  /// \param user_data - An argument which will be passed to the install error
  /// handler.
  void install_fatal_error_handler(fatal_error_handler_t handler,
                                   void *user_data = nullptr);

  /// Restores default error handling behaviour.
  void remove_fatal_error_handler();

  /// ScopedFatalErrorHandler - This is a simple helper class which just
  /// calls install_fatal_error_handler in its constructor and
  /// remove_fatal_error_handler in its destructor.
  struct ScopedFatalErrorHandler {
    explicit ScopedFatalErrorHandler(fatal_error_handler_t handler,
                                     void *user_data = nullptr) {
      install_fatal_error_handler(handler, user_data);
    }

    ~ScopedFatalErrorHandler() { remove_fatal_error_handler(); }
  };

/// Reports a serious error, calling any installed error handler. These
/// functions are intended to be used for error conditions which are outside
/// the control of the compiler (I/O errors, invalid user input, etc.)
///
/// If no error handler is installed the default is to print the message to
/// standard error, followed by a newline.
/// After the error handler is called this function will call abort(), it
/// does not return.
LLVM_ATTRIBUTE_NORETURN void report_fatal_error(const char *reason,
                                                bool gen_crash_diag = true);
LLVM_ATTRIBUTE_NORETURN void report_fatal_error(const std::string &reason,
                                                bool gen_crash_diag = true);
LLVM_ATTRIBUTE_NORETURN void report_fatal_error(StringRef reason,
                                                bool gen_crash_diag = true);
LLVM_ATTRIBUTE_NORETURN void report_fatal_error(const Twine &reason,
                                                bool gen_crash_diag = true);

/// Installs a new bad alloc error handler that should be used whenever a
/// bad alloc error, e.g. failing malloc/calloc, is encountered by LLVM.
///
/// The user can install a bad alloc handler, in order to define the behavior
/// in case of failing allocations, e.g. throwing an exception. Note that this
/// handler must not trigger any additional allocations itself.
///
/// If no error handler is installed the default is to print the error message
/// to stderr, and call exit(1).  If an error handler is installed then it is
/// the handler's responsibility to log the message, it will no longer be
/// printed to stderr.  If the error handler returns, then exit(1) will be
/// called.
///
///
/// \param user_data - An argument which will be passed to the installed error
/// handler.
void install_bad_alloc_error_handler(fatal_error_handler_t handler,
                                     void *user_data = nullptr);

/// Restores default bad alloc error handling behavior.
void remove_bad_alloc_error_handler();

void install_out_of_memory_new_handler();

/// Reports a bad alloc error, calling any user defined bad alloc
/// error handler. In contrast to the generic 'report_fatal_error'
/// functions, this function is expected to return, e.g. the user
/// defined error handler throws an exception.
///
/// Note: When throwing an exception in the bad alloc handler, make sure that
/// the following unwind succeeds, e.g. do not trigger additional allocations
/// in the unwind chain.
///
/// If no error handler is installed (default), then a bad_alloc exception
/// is thrown, if LLVM is compiled with exception support, otherwise an
/// assertion is called.
void report_bad_alloc_error(const char *Reason, bool GenCrashDiag = true);

/// This function calls abort(), and prints the optional message to stderr.
/// Use the llvm_unreachable macro (that adds location info), instead of
/// calling this function directly.
LLVM_ATTRIBUTE_NORETURN void
llvm_unreachable_internal(const char *msg = nullptr, const char *file = nullptr,
                          unsigned line = 0);
}

/// Marks that the current location is not supposed to be reachable.
/// In !NDEBUG builds, prints the message and location info to stderr.
/// In NDEBUG builds, becomes an optimizer hint that the current location
/// is not supposed to be reachable.  On compilers that don't support
/// such hints, prints a reduced message instead.
///
/// Use this instead of assert(0).  It conveys intent more clearly and
/// allows compilers to omit some unnecessary code.
#ifndef NDEBUG
#define llvm_unreachable(msg) \
  ::llvm::llvm_unreachable_internal(msg, __FILE__, __LINE__)
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(LLVM_BUILTIN_UNREACHABLE)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 138 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h"
#define llvm_unreachable(msg) LLVM_BUILTIN_UNREACHABLE
#else
# 140 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h"
#define llvm_unreachable(msg) ::llvm::llvm_unreachable_internal()
#endif
# 142 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h"

#endif
# 144 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorHandling.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <functional>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 37 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"

#ifdef EXPENSIVE_CHECKS
#if 0 /* expanded by -frewrite-includes */
#include <random> // for std::mt19937
#endif /* expanded by -frewrite-includes */
# 39 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
#endif
# 41 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"

namespace llvm {

// Only used by compiler if both template types are the same.  Useful when
// using SFINAE to test for the existence of member functions.
template <typename T, T> struct SameType;

namespace detail {

template <typename RangeT>
using IterOfRange = decltype(std::begin(std::declval<RangeT &>()));

} // end namespace detail

//===----------------------------------------------------------------------===//
//     Extra additions to <type_traits>
//===----------------------------------------------------------------------===//

template <typename T>
struct negation : std::integral_constant<bool, !bool(T::value)> {};

template <typename...> struct conjunction : std::true_type {};
template <typename B1> struct conjunction<B1> : B1 {};
template <typename B1, typename... Bn>
struct conjunction<B1, Bn...>
    : std::conditional<bool(B1::value), conjunction<Bn...>, B1>::type {};

template <typename T> struct make_const_ptr {
  using type =
      typename std::add_pointer<typename std::add_const<T>::type>::type;
};

template <typename T> struct make_const_ref {
  using type = typename std::add_lvalue_reference<
      typename std::add_const<T>::type>::type;
};

//===----------------------------------------------------------------------===//
//     Extra additions to <functional>
//===----------------------------------------------------------------------===//

template <class Ty> struct identity {
  using argument_type = Ty;

  Ty &operator()(Ty &self) const {
    return self;
  }
  const Ty &operator()(const Ty &self) const {
    return self;
  }
};

/// An efficient, type-erasing, non-owning reference to a callable. This is
/// intended for use as the type of a function parameter that is not used
/// after the function in question returns.
///
/// This class does not own the callable, so it is not in general safe to store
/// a function_ref.
template<typename Fn> class function_ref;

template<typename Ret, typename ...Params>
class function_ref<Ret(Params...)> {
  Ret (*callback)(intptr_t callable, Params ...params) = nullptr;
  intptr_t callable;

  template<typename Callable>
  static Ret callback_fn(intptr_t callable, Params ...params) {
    return (*reinterpret_cast<Callable*>(callable))(
        std::forward<Params>(params)...);
  }

public:
  function_ref() = default;
  function_ref(std::nullptr_t) {}

  template <typename Callable>
  function_ref(Callable &&callable,
               std::enable_if_t<!std::is_same<std::remove_reference_t<Callable>,
                                              function_ref>::value> * = nullptr)
      : callback(callback_fn<typename std::remove_reference<Callable>::type>),
        callable(reinterpret_cast<intptr_t>(&callable)) {}

  Ret operator()(Params ...params) const {
    return callback(callable, std::forward<Params>(params)...);
  }

  operator bool() const { return callback; }
};

// deleter - Very very very simple method that is used to invoke operator
// delete on something.  It is used like this:
//
//   for_each(V.begin(), B.end(), deleter<Interval>);
template <class T>
inline void deleter(T *Ptr) {
  delete Ptr;
}

//===----------------------------------------------------------------------===//
//     Extra additions to <iterator>
//===----------------------------------------------------------------------===//

namespace adl_detail {

using std::begin;

template <typename ContainerTy>
decltype(auto) adl_begin(ContainerTy &&container) {
  return begin(std::forward<ContainerTy>(container));
}

using std::end;

template <typename ContainerTy>
decltype(auto) adl_end(ContainerTy &&container) {
  return end(std::forward<ContainerTy>(container));
}

using std::swap;

template <typename T>
void adl_swap(T &&lhs, T &&rhs) noexcept(noexcept(swap(std::declval<T>(),
                                                       std::declval<T>()))) {
  swap(std::forward<T>(lhs), std::forward<T>(rhs));
}

} // end namespace adl_detail

template <typename ContainerTy>
decltype(auto) adl_begin(ContainerTy &&container) {
  return adl_detail::adl_begin(std::forward<ContainerTy>(container));
}

template <typename ContainerTy>
decltype(auto) adl_end(ContainerTy &&container) {
  return adl_detail::adl_end(std::forward<ContainerTy>(container));
}

template <typename T>
void adl_swap(T &&lhs, T &&rhs) noexcept(
    noexcept(adl_detail::adl_swap(std::declval<T>(), std::declval<T>()))) {
  adl_detail::adl_swap(std::forward<T>(lhs), std::forward<T>(rhs));
}

/// Test whether \p RangeOrContainer is empty. Similar to C++17 std::empty.
template <typename T>
constexpr bool empty(const T &RangeOrContainer) {
  return adl_begin(RangeOrContainer) == adl_end(RangeOrContainer);
}

/// Return a range covering \p RangeOrContainer with the first N elements
/// excluded.
template <typename T> auto drop_begin(T &&RangeOrContainer, size_t N) {
  return make_range(std::next(adl_begin(RangeOrContainer), N),
                    adl_end(RangeOrContainer));
}

// mapped_iterator - This is a simple iterator adapter that causes a function to
// be applied whenever operator* is invoked on the iterator.

template <typename ItTy, typename FuncTy,
          typename FuncReturnTy =
            decltype(std::declval<FuncTy>()(*std::declval<ItTy>()))>
class mapped_iterator
    : public iterator_adaptor_base<
             mapped_iterator<ItTy, FuncTy>, ItTy,
             typename std::iterator_traits<ItTy>::iterator_category,
             typename std::remove_reference<FuncReturnTy>::type> {
public:
  mapped_iterator(ItTy U, FuncTy F)
    : mapped_iterator::iterator_adaptor_base(std::move(U)), F(std::move(F)) {}

  ItTy getCurrent() { return this->I; }

  FuncReturnTy operator*() { return F(*this->I); }

private:
  FuncTy F;
};

// map_iterator - Provide a convenient way to create mapped_iterators, just like
// make_pair is useful for creating pairs...
template <class ItTy, class FuncTy>
inline mapped_iterator<ItTy, FuncTy> map_iterator(ItTy I, FuncTy F) {
  return mapped_iterator<ItTy, FuncTy>(std::move(I), std::move(F));
}

template <class ContainerTy, class FuncTy>
auto map_range(ContainerTy &&C, FuncTy F) {
  return make_range(map_iterator(C.begin(), F), map_iterator(C.end(), F));
}

/// Helper to determine if type T has a member called rbegin().
template <typename Ty> class has_rbegin_impl {
  using yes = char[1];
  using no = char[2];

  template <typename Inner>
  static yes& test(Inner *I, decltype(I->rbegin()) * = nullptr);

  template <typename>
  static no& test(...);

public:
  static const bool value = sizeof(test<Ty>(nullptr)) == sizeof(yes);
};

/// Metafunction to determine if T& or T has a member called rbegin().
template <typename Ty>
struct has_rbegin : has_rbegin_impl<typename std::remove_reference<Ty>::type> {
};

// Returns an iterator_range over the given container which iterates in reverse.
// Note that the container must have rbegin()/rend() methods for this to work.
template <typename ContainerTy>
auto reverse(ContainerTy &&C,
             std::enable_if_t<has_rbegin<ContainerTy>::value> * = nullptr) {
  return make_range(C.rbegin(), C.rend());
}

// Returns a std::reverse_iterator wrapped around the given iterator.
template <typename IteratorTy>
std::reverse_iterator<IteratorTy> make_reverse_iterator(IteratorTy It) {
  return std::reverse_iterator<IteratorTy>(It);
}

// Returns an iterator_range over the given container which iterates in reverse.
// Note that the container must have begin()/end() methods which return
// bidirectional iterators for this to work.
template <typename ContainerTy>
auto reverse(ContainerTy &&C,
             std::enable_if_t<!has_rbegin<ContainerTy>::value> * = nullptr) {
  return make_range(llvm::make_reverse_iterator(std::end(C)),
                    llvm::make_reverse_iterator(std::begin(C)));
}

/// An iterator adaptor that filters the elements of given inner iterators.
///
/// The predicate parameter should be a callable object that accepts the wrapped
/// iterator's reference type and returns a bool. When incrementing or
/// decrementing the iterator, it will call the predicate on each element and
/// skip any where it returns false.
///
/// \code
///   int A[] = { 1, 2, 3, 4 };
///   auto R = make_filter_range(A, [](int N) { return N % 2 == 1; });
///   // R contains { 1, 3 }.
/// \endcode
///
/// Note: filter_iterator_base implements support for forward iteration.
/// filter_iterator_impl exists to provide support for bidirectional iteration,
/// conditional on whether the wrapped iterator supports it.
template <typename WrappedIteratorT, typename PredicateT, typename IterTag>
class filter_iterator_base
    : public iterator_adaptor_base<
          filter_iterator_base<WrappedIteratorT, PredicateT, IterTag>,
          WrappedIteratorT,
          typename std::common_type<
              IterTag, typename std::iterator_traits<
                           WrappedIteratorT>::iterator_category>::type> {
  using BaseT = iterator_adaptor_base<
      filter_iterator_base<WrappedIteratorT, PredicateT, IterTag>,
      WrappedIteratorT,
      typename std::common_type<
          IterTag, typename std::iterator_traits<
                       WrappedIteratorT>::iterator_category>::type>;

protected:
  WrappedIteratorT End;
  PredicateT Pred;

  void findNextValid() {
    while (this->I != End && !Pred(*this->I))
      BaseT::operator++();
  }

  // Construct the iterator. The begin iterator needs to know where the end
  // is, so that it can properly stop when it gets there. The end iterator only
  // needs the predicate to support bidirectional iteration.
  filter_iterator_base(WrappedIteratorT Begin, WrappedIteratorT End,
                       PredicateT Pred)
      : BaseT(Begin), End(End), Pred(Pred) {
    findNextValid();
  }

public:
  using BaseT::operator++;

  filter_iterator_base &operator++() {
    BaseT::operator++();
    findNextValid();
    return *this;
  }
};

/// Specialization of filter_iterator_base for forward iteration only.
template <typename WrappedIteratorT, typename PredicateT,
          typename IterTag = std::forward_iterator_tag>
class filter_iterator_impl
    : public filter_iterator_base<WrappedIteratorT, PredicateT, IterTag> {
  using BaseT = filter_iterator_base<WrappedIteratorT, PredicateT, IterTag>;

public:
  filter_iterator_impl(WrappedIteratorT Begin, WrappedIteratorT End,
                       PredicateT Pred)
      : BaseT(Begin, End, Pred) {}
};

/// Specialization of filter_iterator_base for bidirectional iteration.
template <typename WrappedIteratorT, typename PredicateT>
class filter_iterator_impl<WrappedIteratorT, PredicateT,
                           std::bidirectional_iterator_tag>
    : public filter_iterator_base<WrappedIteratorT, PredicateT,
                                  std::bidirectional_iterator_tag> {
  using BaseT = filter_iterator_base<WrappedIteratorT, PredicateT,
                                     std::bidirectional_iterator_tag>;
  void findPrevValid() {
    while (!this->Pred(*this->I))
      BaseT::operator--();
  }

public:
  using BaseT::operator--;

  filter_iterator_impl(WrappedIteratorT Begin, WrappedIteratorT End,
                       PredicateT Pred)
      : BaseT(Begin, End, Pred) {}

  filter_iterator_impl &operator--() {
    BaseT::operator--();
    findPrevValid();
    return *this;
  }
};

namespace detail {

template <bool is_bidirectional> struct fwd_or_bidi_tag_impl {
  using type = std::forward_iterator_tag;
};

template <> struct fwd_or_bidi_tag_impl<true> {
  using type = std::bidirectional_iterator_tag;
};

/// Helper which sets its type member to forward_iterator_tag if the category
/// of \p IterT does not derive from bidirectional_iterator_tag, and to
/// bidirectional_iterator_tag otherwise.
template <typename IterT> struct fwd_or_bidi_tag {
  using type = typename fwd_or_bidi_tag_impl<std::is_base_of<
      std::bidirectional_iterator_tag,
      typename std::iterator_traits<IterT>::iterator_category>::value>::type;
};

} // namespace detail

/// Defines filter_iterator to a suitable specialization of
/// filter_iterator_impl, based on the underlying iterator's category.
template <typename WrappedIteratorT, typename PredicateT>
using filter_iterator = filter_iterator_impl<
    WrappedIteratorT, PredicateT,
    typename detail::fwd_or_bidi_tag<WrappedIteratorT>::type>;

/// Convenience function that takes a range of elements and a predicate,
/// and return a new filter_iterator range.
///
/// FIXME: Currently if RangeT && is a rvalue reference to a temporary, the
/// lifetime of that temporary is not kept by the returned range object, and the
/// temporary is going to be dropped on the floor after the make_iterator_range
/// full expression that contains this function call.
template <typename RangeT, typename PredicateT>
iterator_range<filter_iterator<detail::IterOfRange<RangeT>, PredicateT>>
make_filter_range(RangeT &&Range, PredicateT Pred) {
  using FilterIteratorT =
      filter_iterator<detail::IterOfRange<RangeT>, PredicateT>;
  return make_range(
      FilterIteratorT(std::begin(std::forward<RangeT>(Range)),
                      std::end(std::forward<RangeT>(Range)), Pred),
      FilterIteratorT(std::end(std::forward<RangeT>(Range)),
                      std::end(std::forward<RangeT>(Range)), Pred));
}

/// A pseudo-iterator adaptor that is designed to implement "early increment"
/// style loops.
///
/// This is *not a normal iterator* and should almost never be used directly. It
/// is intended primarily to be used with range based for loops and some range
/// algorithms.
///
/// The iterator isn't quite an `OutputIterator` or an `InputIterator` but
/// somewhere between them. The constraints of these iterators are:
///
/// - On construction or after being incremented, it is comparable and
///   dereferencable. It is *not* incrementable.
/// - After being dereferenced, it is neither comparable nor dereferencable, it
///   is only incrementable.
///
/// This means you can only dereference the iterator once, and you can only
/// increment it once between dereferences.
template <typename WrappedIteratorT>
class early_inc_iterator_impl
    : public iterator_adaptor_base<early_inc_iterator_impl<WrappedIteratorT>,
                                   WrappedIteratorT, std::input_iterator_tag> {
  using BaseT =
      iterator_adaptor_base<early_inc_iterator_impl<WrappedIteratorT>,
                            WrappedIteratorT, std::input_iterator_tag>;

  using PointerT = typename std::iterator_traits<WrappedIteratorT>::pointer;

protected:
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 452 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
  bool IsEarlyIncremented = false;
#endif
# 454 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"

public:
  early_inc_iterator_impl(WrappedIteratorT I) : BaseT(I) {}

  using BaseT::operator*;
  typename BaseT::reference operator*() {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 461 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
    assert(!IsEarlyIncremented && "Cannot dereference twice!");
    IsEarlyIncremented = true;
#endif
# 464 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
    return *(this->I)++;
  }

  using BaseT::operator++;
  early_inc_iterator_impl &operator++() {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 470 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
    assert(IsEarlyIncremented && "Cannot increment before dereferencing!");
    IsEarlyIncremented = false;
#endif
# 473 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
    return *this;
  }

  using BaseT::operator==;
  bool operator==(const early_inc_iterator_impl &RHS) const {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 479 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
    assert(!IsEarlyIncremented && "Cannot compare after dereferencing!");
#endif
# 481 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
    return BaseT::operator==(RHS);
  }
};

/// Make a range that does early increment to allow mutation of the underlying
/// range without disrupting iteration.
///
/// The underlying iterator will be incremented immediately after it is
/// dereferenced, allowing deletion of the current node or insertion of nodes to
/// not disrupt iteration provided they do not invalidate the *next* iterator --
/// the current iterator can be invalidated.
///
/// This requires a very exact pattern of use that is only really suitable to
/// range based for loops and other range algorithms that explicitly guarantee
/// to dereference exactly once each element, and to increment exactly once each
/// element.
template <typename RangeT>
iterator_range<early_inc_iterator_impl<detail::IterOfRange<RangeT>>>
make_early_inc_range(RangeT &&Range) {
  using EarlyIncIteratorT =
      early_inc_iterator_impl<detail::IterOfRange<RangeT>>;
  return make_range(EarlyIncIteratorT(std::begin(std::forward<RangeT>(Range))),
                    EarlyIncIteratorT(std::end(std::forward<RangeT>(Range))));
}

// forward declarations required by zip_shortest/zip_first/zip_longest
template <typename R, typename UnaryPredicate>
bool all_of(R &&range, UnaryPredicate P);
template <typename R, typename UnaryPredicate>
bool any_of(R &&range, UnaryPredicate P);

namespace detail {

using std::declval;

// We have to alias this since inlining the actual type at the usage site
// in the parameter list of iterator_facade_base<> below ICEs MSVC 2017.
template<typename... Iters> struct ZipTupleType {
  using type = std::tuple<decltype(*declval<Iters>())...>;
};

template <typename ZipType, typename... Iters>
using zip_traits = iterator_facade_base<
    ZipType, typename std::common_type<std::bidirectional_iterator_tag,
                                       typename std::iterator_traits<
                                           Iters>::iterator_category...>::type,
    // ^ TODO: Implement random access methods.
    typename ZipTupleType<Iters...>::type,
    typename std::iterator_traits<typename std::tuple_element<
        0, std::tuple<Iters...>>::type>::difference_type,
    // ^ FIXME: This follows boost::make_zip_iterator's assumption that all
    // inner iterators have the same difference_type. It would fail if, for
    // instance, the second field's difference_type were non-numeric while the
    // first is.
    typename ZipTupleType<Iters...>::type *,
    typename ZipTupleType<Iters...>::type>;

template <typename ZipType, typename... Iters>
struct zip_common : public zip_traits<ZipType, Iters...> {
  using Base = zip_traits<ZipType, Iters...>;
  using value_type = typename Base::value_type;

  std::tuple<Iters...> iterators;

protected:
  template <size_t... Ns> value_type deref(std::index_sequence<Ns...>) const {
    return value_type(*std::get<Ns>(iterators)...);
  }

  template <size_t... Ns>
  decltype(iterators) tup_inc(std::index_sequence<Ns...>) const {
    return std::tuple<Iters...>(std::next(std::get<Ns>(iterators))...);
  }

  template <size_t... Ns>
  decltype(iterators) tup_dec(std::index_sequence<Ns...>) const {
    return std::tuple<Iters...>(std::prev(std::get<Ns>(iterators))...);
  }

public:
  zip_common(Iters &&... ts) : iterators(std::forward<Iters>(ts)...) {}

  value_type operator*() { return deref(std::index_sequence_for<Iters...>{}); }

  const value_type operator*() const {
    return deref(std::index_sequence_for<Iters...>{});
  }

  ZipType &operator++() {
    iterators = tup_inc(std::index_sequence_for<Iters...>{});
    return *reinterpret_cast<ZipType *>(this);
  }

  ZipType &operator--() {
    static_assert(Base::IsBidirectional,
                  "All inner iterators must be at least bidirectional.");
    iterators = tup_dec(std::index_sequence_for<Iters...>{});
    return *reinterpret_cast<ZipType *>(this);
  }
};

template <typename... Iters>
struct zip_first : public zip_common<zip_first<Iters...>, Iters...> {
  using Base = zip_common<zip_first<Iters...>, Iters...>;

  bool operator==(const zip_first<Iters...> &other) const {
    return std::get<0>(this->iterators) == std::get<0>(other.iterators);
  }

  zip_first(Iters &&... ts) : Base(std::forward<Iters>(ts)...) {}
};

template <typename... Iters>
class zip_shortest : public zip_common<zip_shortest<Iters...>, Iters...> {
  template <size_t... Ns>
  bool test(const zip_shortest<Iters...> &other,
            std::index_sequence<Ns...>) const {
    return all_of(std::initializer_list<bool>{std::get<Ns>(this->iterators) !=
                                              std::get<Ns>(other.iterators)...},
                  identity<bool>{});
  }

public:
  using Base = zip_common<zip_shortest<Iters...>, Iters...>;

  zip_shortest(Iters &&... ts) : Base(std::forward<Iters>(ts)...) {}

  bool operator==(const zip_shortest<Iters...> &other) const {
    return !test(other, std::index_sequence_for<Iters...>{});
  }
};

template <template <typename...> class ItType, typename... Args> class zippy {
public:
  using iterator = ItType<decltype(std::begin(std::declval<Args>()))...>;
  using iterator_category = typename iterator::iterator_category;
  using value_type = typename iterator::value_type;
  using difference_type = typename iterator::difference_type;
  using pointer = typename iterator::pointer;
  using reference = typename iterator::reference;

private:
  std::tuple<Args...> ts;

  template <size_t... Ns>
  iterator begin_impl(std::index_sequence<Ns...>) const {
    return iterator(std::begin(std::get<Ns>(ts))...);
  }
  template <size_t... Ns> iterator end_impl(std::index_sequence<Ns...>) const {
    return iterator(std::end(std::get<Ns>(ts))...);
  }

public:
  zippy(Args &&... ts_) : ts(std::forward<Args>(ts_)...) {}

  iterator begin() const {
    return begin_impl(std::index_sequence_for<Args...>{});
  }
  iterator end() const { return end_impl(std::index_sequence_for<Args...>{}); }
};

} // end namespace detail

/// zip iterator for two or more iteratable types.
template <typename T, typename U, typename... Args>
detail::zippy<detail::zip_shortest, T, U, Args...> zip(T &&t, U &&u,
                                                       Args &&... args) {
  return detail::zippy<detail::zip_shortest, T, U, Args...>(
      std::forward<T>(t), std::forward<U>(u), std::forward<Args>(args)...);
}

/// zip iterator that, for the sake of efficiency, assumes the first iteratee to
/// be the shortest.
template <typename T, typename U, typename... Args>
detail::zippy<detail::zip_first, T, U, Args...> zip_first(T &&t, U &&u,
                                                          Args &&... args) {
  return detail::zippy<detail::zip_first, T, U, Args...>(
      std::forward<T>(t), std::forward<U>(u), std::forward<Args>(args)...);
}

namespace detail {
template <typename Iter>
static Iter next_or_end(const Iter &I, const Iter &End) {
  if (I == End)
    return End;
  return std::next(I);
}

template <typename Iter>
static auto deref_or_none(const Iter &I, const Iter &End) -> llvm::Optional<
    std::remove_const_t<std::remove_reference_t<decltype(*I)>>> {
  if (I == End)
    return None;
  return *I;
}

template <typename Iter> struct ZipLongestItemType {
  using type =
      llvm::Optional<typename std::remove_const<typename std::remove_reference<
          decltype(*std::declval<Iter>())>::type>::type>;
};

template <typename... Iters> struct ZipLongestTupleType {
  using type = std::tuple<typename ZipLongestItemType<Iters>::type...>;
};

template <typename... Iters>
class zip_longest_iterator
    : public iterator_facade_base<
          zip_longest_iterator<Iters...>,
          typename std::common_type<
              std::forward_iterator_tag,
              typename std::iterator_traits<Iters>::iterator_category...>::type,
          typename ZipLongestTupleType<Iters...>::type,
          typename std::iterator_traits<typename std::tuple_element<
              0, std::tuple<Iters...>>::type>::difference_type,
          typename ZipLongestTupleType<Iters...>::type *,
          typename ZipLongestTupleType<Iters...>::type> {
public:
  using value_type = typename ZipLongestTupleType<Iters...>::type;

private:
  std::tuple<Iters...> iterators;
  std::tuple<Iters...> end_iterators;

  template <size_t... Ns>
  bool test(const zip_longest_iterator<Iters...> &other,
            std::index_sequence<Ns...>) const {
    return llvm::any_of(
        std::initializer_list<bool>{std::get<Ns>(this->iterators) !=
                                    std::get<Ns>(other.iterators)...},
        identity<bool>{});
  }

  template <size_t... Ns> value_type deref(std::index_sequence<Ns...>) const {
    return value_type(
        deref_or_none(std::get<Ns>(iterators), std::get<Ns>(end_iterators))...);
  }

  template <size_t... Ns>
  decltype(iterators) tup_inc(std::index_sequence<Ns...>) const {
    return std::tuple<Iters...>(
        next_or_end(std::get<Ns>(iterators), std::get<Ns>(end_iterators))...);
  }

public:
  zip_longest_iterator(std::pair<Iters &&, Iters &&>... ts)
      : iterators(std::forward<Iters>(ts.first)...),
        end_iterators(std::forward<Iters>(ts.second)...) {}

  value_type operator*() { return deref(std::index_sequence_for<Iters...>{}); }

  value_type operator*() const {
    return deref(std::index_sequence_for<Iters...>{});
  }

  zip_longest_iterator<Iters...> &operator++() {
    iterators = tup_inc(std::index_sequence_for<Iters...>{});
    return *this;
  }

  bool operator==(const zip_longest_iterator<Iters...> &other) const {
    return !test(other, std::index_sequence_for<Iters...>{});
  }
};

template <typename... Args> class zip_longest_range {
public:
  using iterator =
      zip_longest_iterator<decltype(adl_begin(std::declval<Args>()))...>;
  using iterator_category = typename iterator::iterator_category;
  using value_type = typename iterator::value_type;
  using difference_type = typename iterator::difference_type;
  using pointer = typename iterator::pointer;
  using reference = typename iterator::reference;

private:
  std::tuple<Args...> ts;

  template <size_t... Ns>
  iterator begin_impl(std::index_sequence<Ns...>) const {
    return iterator(std::make_pair(adl_begin(std::get<Ns>(ts)),
                                   adl_end(std::get<Ns>(ts)))...);
  }

  template <size_t... Ns> iterator end_impl(std::index_sequence<Ns...>) const {
    return iterator(std::make_pair(adl_end(std::get<Ns>(ts)),
                                   adl_end(std::get<Ns>(ts)))...);
  }

public:
  zip_longest_range(Args &&... ts_) : ts(std::forward<Args>(ts_)...) {}

  iterator begin() const {
    return begin_impl(std::index_sequence_for<Args...>{});
  }
  iterator end() const { return end_impl(std::index_sequence_for<Args...>{}); }
};
} // namespace detail

/// Iterate over two or more iterators at the same time. Iteration continues
/// until all iterators reach the end. The llvm::Optional only contains a value
/// if the iterator has not reached the end.
template <typename T, typename U, typename... Args>
detail::zip_longest_range<T, U, Args...> zip_longest(T &&t, U &&u,
                                                     Args &&... args) {
  return detail::zip_longest_range<T, U, Args...>(
      std::forward<T>(t), std::forward<U>(u), std::forward<Args>(args)...);
}

/// Iterator wrapper that concatenates sequences together.
///
/// This can concatenate different iterators, even with different types, into
/// a single iterator provided the value types of all the concatenated
/// iterators expose `reference` and `pointer` types that can be converted to
/// `ValueT &` and `ValueT *` respectively. It doesn't support more
/// interesting/customized pointer or reference types.
///
/// Currently this only supports forward or higher iterator categories as
/// inputs and always exposes a forward iterator interface.
template <typename ValueT, typename... IterTs>
class concat_iterator
    : public iterator_facade_base<concat_iterator<ValueT, IterTs...>,
                                  std::forward_iterator_tag, ValueT> {
  using BaseT = typename concat_iterator::iterator_facade_base;

  /// We store both the current and end iterators for each concatenated
  /// sequence in a tuple of pairs.
  ///
  /// Note that something like iterator_range seems nice at first here, but the
  /// range properties are of little benefit and end up getting in the way
  /// because we need to do mutation on the current iterators.
  std::tuple<IterTs...> Begins;
  std::tuple<IterTs...> Ends;

  /// Attempts to increment a specific iterator.
  ///
  /// Returns true if it was able to increment the iterator. Returns false if
  /// the iterator is already at the end iterator.
  template <size_t Index> bool incrementHelper() {
    auto &Begin = std::get<Index>(Begins);
    auto &End = std::get<Index>(Ends);
    if (Begin == End)
      return false;

    ++Begin;
    return true;
  }

  /// Increments the first non-end iterator.
  ///
  /// It is an error to call this with all iterators at the end.
  template <size_t... Ns> void increment(std::index_sequence<Ns...>) {
    // Build a sequence of functions to increment each iterator if possible.
    bool (concat_iterator::*IncrementHelperFns[])() = {
        &concat_iterator::incrementHelper<Ns>...};

    // Loop over them, and stop as soon as we succeed at incrementing one.
    for (auto &IncrementHelperFn : IncrementHelperFns)
      if ((this->*IncrementHelperFn)())
        return;

    llvm_unreachable("Attempted to increment an end concat iterator!");
  }

  /// Returns null if the specified iterator is at the end. Otherwise,
  /// dereferences the iterator and returns the address of the resulting
  /// reference.
  template <size_t Index> ValueT *getHelper() const {
    auto &Begin = std::get<Index>(Begins);
    auto &End = std::get<Index>(Ends);
    if (Begin == End)
      return nullptr;

    return &*Begin;
  }

  /// Finds the first non-end iterator, dereferences, and returns the resulting
  /// reference.
  ///
  /// It is an error to call this with all iterators at the end.
  template <size_t... Ns> ValueT &get(std::index_sequence<Ns...>) const {
    // Build a sequence of functions to get from iterator if possible.
    ValueT *(concat_iterator::*GetHelperFns[])() const = {
        &concat_iterator::getHelper<Ns>...};

    // Loop over them, and return the first result we find.
    for (auto &GetHelperFn : GetHelperFns)
      if (ValueT *P = (this->*GetHelperFn)())
        return *P;

    llvm_unreachable("Attempted to get a pointer from an end concat iterator!");
  }

public:
  /// Constructs an iterator from a squence of ranges.
  ///
  /// We need the full range to know how to switch between each of the
  /// iterators.
  template <typename... RangeTs>
  explicit concat_iterator(RangeTs &&... Ranges)
      : Begins(std::begin(Ranges)...), Ends(std::end(Ranges)...) {}

  using BaseT::operator++;

  concat_iterator &operator++() {
    increment(std::index_sequence_for<IterTs...>());
    return *this;
  }

  ValueT &operator*() const {
    return get(std::index_sequence_for<IterTs...>());
  }

  bool operator==(const concat_iterator &RHS) const {
    return Begins == RHS.Begins && Ends == RHS.Ends;
  }
};

namespace detail {

/// Helper to store a sequence of ranges being concatenated and access them.
///
/// This is designed to facilitate providing actual storage when temporaries
/// are passed into the constructor such that we can use it as part of range
/// based for loops.
template <typename ValueT, typename... RangeTs> class concat_range {
public:
  using iterator =
      concat_iterator<ValueT,
                      decltype(std::begin(std::declval<RangeTs &>()))...>;

private:
  std::tuple<RangeTs...> Ranges;

  template <size_t... Ns> iterator begin_impl(std::index_sequence<Ns...>) {
    return iterator(std::get<Ns>(Ranges)...);
  }
  template <size_t... Ns> iterator end_impl(std::index_sequence<Ns...>) {
    return iterator(make_range(std::end(std::get<Ns>(Ranges)),
                               std::end(std::get<Ns>(Ranges)))...);
  }

public:
  concat_range(RangeTs &&... Ranges)
      : Ranges(std::forward<RangeTs>(Ranges)...) {}

  iterator begin() { return begin_impl(std::index_sequence_for<RangeTs...>{}); }
  iterator end() { return end_impl(std::index_sequence_for<RangeTs...>{}); }
};

} // end namespace detail

/// Concatenated range across two or more ranges.
///
/// The desired value type must be explicitly specified.
template <typename ValueT, typename... RangeTs>
detail::concat_range<ValueT, RangeTs...> concat(RangeTs &&... Ranges) {
  static_assert(sizeof...(RangeTs) > 1,
                "Need more than one range to concatenate!");
  return detail::concat_range<ValueT, RangeTs...>(
      std::forward<RangeTs>(Ranges)...);
}

//===----------------------------------------------------------------------===//
//     Extra additions to <utility>
//===----------------------------------------------------------------------===//

/// Function object to check whether the first component of a std::pair
/// compares less than the first component of another std::pair.
struct less_first {
  template <typename T> bool operator()(const T &lhs, const T &rhs) const {
    return lhs.first < rhs.first;
  }
};

/// Function object to check whether the second component of a std::pair
/// compares less than the second component of another std::pair.
struct less_second {
  template <typename T> bool operator()(const T &lhs, const T &rhs) const {
    return lhs.second < rhs.second;
  }
};

/// \brief Function object to apply a binary function to the first component of
/// a std::pair.
template<typename FuncTy>
struct on_first {
  FuncTy func;

  template <typename T>
  decltype(auto) operator()(const T &lhs, const T &rhs) const {
    return func(lhs.first, rhs.first);
  }
};

/// Utility type to build an inheritance chain that makes it easy to rank
/// overload candidates.
template <int N> struct rank : rank<N - 1> {};
template <> struct rank<0> {};

/// traits class for checking whether type T is one of any of the given
/// types in the variadic list.
template <typename T, typename... Ts> struct is_one_of {
  static const bool value = false;
};

template <typename T, typename U, typename... Ts>
struct is_one_of<T, U, Ts...> {
  static const bool value =
      std::is_same<T, U>::value || is_one_of<T, Ts...>::value;
};

/// traits class for checking whether type T is a base class for all
///  the given types in the variadic list.
template <typename T, typename... Ts> struct are_base_of {
  static const bool value = true;
};

template <typename T, typename U, typename... Ts>
struct are_base_of<T, U, Ts...> {
  static const bool value =
      std::is_base_of<T, U>::value && are_base_of<T, Ts...>::value;
};

//===----------------------------------------------------------------------===//
//     Extra additions for arrays
//===----------------------------------------------------------------------===//

/// Find the length of an array.
template <class T, std::size_t N>
constexpr inline size_t array_lengthof(T (&)[N]) {
  return N;
}

/// Adapt std::less<T> for array_pod_sort.
template<typename T>
inline int array_pod_sort_comparator(const void *P1, const void *P2) {
  if (std::less<T>()(*reinterpret_cast<const T*>(P1),
                     *reinterpret_cast<const T*>(P2)))
    return -1;
  if (std::less<T>()(*reinterpret_cast<const T*>(P2),
                     *reinterpret_cast<const T*>(P1)))
    return 1;
  return 0;
}

/// get_array_pod_sort_comparator - This is an internal helper function used to
/// get type deduction of T right.
template<typename T>
inline int (*get_array_pod_sort_comparator(const T &))
             (const void*, const void*) {
  return array_pod_sort_comparator<T>;
}

#ifdef EXPENSIVE_CHECKS
namespace detail {

inline unsigned presortShuffleEntropy() {
  static unsigned Result(std::random_device{}());
  return Result;
}

template <class IteratorTy>
inline void presortShuffle(IteratorTy Start, IteratorTy End) {
  std::mt19937 Generator(presortShuffleEntropy());
  std::shuffle(Start, End, Generator);
}

} // end namespace detail
#endif
# 1052 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"

/// array_pod_sort - This sorts an array with the specified start and end
/// extent.  This is just like std::sort, except that it calls qsort instead of
/// using an inlined template.  qsort is slightly slower than std::sort, but
/// most sorts are not performance critical in LLVM and std::sort has to be
/// template instantiated for each type, leading to significant measured code
/// bloat.  This function should generally be used instead of std::sort where
/// possible.
///
/// This function assumes that you have simple POD-like types that can be
/// compared with std::less and can be moved with memcpy.  If this isn't true,
/// you should use std::sort.
///
/// NOTE: If qsort_r were portable, we could allow a custom comparator and
/// default to std::less.
template<class IteratorTy>
inline void array_pod_sort(IteratorTy Start, IteratorTy End) {
  // Don't inefficiently call qsort with one element or trigger undefined
  // behavior with an empty sequence.
  auto NElts = End - Start;
  if (NElts <= 1) return;
#ifdef EXPENSIVE_CHECKS
  detail::presortShuffle<IteratorTy>(Start, End);
#endif
# 1076 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
  qsort(&*Start, NElts, sizeof(*Start), get_array_pod_sort_comparator(*Start));
}

template <class IteratorTy>
inline void array_pod_sort(
    IteratorTy Start, IteratorTy End,
    int (*Compare)(
        const typename std::iterator_traits<IteratorTy>::value_type *,
        const typename std::iterator_traits<IteratorTy>::value_type *)) {
  // Don't inefficiently call qsort with one element or trigger undefined
  // behavior with an empty sequence.
  auto NElts = End - Start;
  if (NElts <= 1) return;
#ifdef EXPENSIVE_CHECKS
  detail::presortShuffle<IteratorTy>(Start, End);
#endif
# 1092 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
  qsort(&*Start, NElts, sizeof(*Start),
        reinterpret_cast<int (*)(const void *, const void *)>(Compare));
}

// Provide wrappers to std::sort which shuffle the elements before sorting
// to help uncover non-deterministic behavior (PR35135).
template <typename IteratorTy>
inline void sort(IteratorTy Start, IteratorTy End) {
#ifdef EXPENSIVE_CHECKS
  detail::presortShuffle<IteratorTy>(Start, End);
#endif
# 1103 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
  std::sort(Start, End);
}

template <typename Container> inline void sort(Container &&C) {
  llvm::sort(adl_begin(C), adl_end(C));
}

template <typename IteratorTy, typename Compare>
inline void sort(IteratorTy Start, IteratorTy End, Compare Comp) {
#ifdef EXPENSIVE_CHECKS
  detail::presortShuffle<IteratorTy>(Start, End);
#endif
# 1115 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
  std::sort(Start, End, Comp);
}

template <typename Container, typename Compare>
inline void sort(Container &&C, Compare Comp) {
  llvm::sort(adl_begin(C), adl_end(C), Comp);
}

//===----------------------------------------------------------------------===//
//     Extra additions to <algorithm>
//===----------------------------------------------------------------------===//

/// For a container of pointers, deletes the pointers and then clears the
/// container.
template<typename Container>
void DeleteContainerPointers(Container &C) {
  for (auto V : C)
    delete V;
  C.clear();
}

/// In a container of pairs (usually a map) whose second element is a pointer,
/// deletes the second elements and then clears the container.
template<typename Container>
void DeleteContainerSeconds(Container &C) {
  for (auto &V : C)
    delete V.second;
  C.clear();
}

/// Get the size of a range. This is a wrapper function around std::distance
/// which is only enabled when the operation is O(1).
template <typename R>
auto size(R &&Range,
          std::enable_if_t<std::is_same<typename std::iterator_traits<decltype(
                                            Range.begin())>::iterator_category,
                                        std::random_access_iterator_tag>::value,
                           void> * = nullptr) {
  return std::distance(Range.begin(), Range.end());
}

/// Provide wrappers to std::for_each which take ranges instead of having to
/// pass begin/end explicitly.
template <typename R, typename UnaryPredicate>
UnaryPredicate for_each(R &&Range, UnaryPredicate P) {
  return std::for_each(adl_begin(Range), adl_end(Range), P);
}

/// Provide wrappers to std::all_of which take ranges instead of having to pass
/// begin/end explicitly.
template <typename R, typename UnaryPredicate>
bool all_of(R &&Range, UnaryPredicate P) {
  return std::all_of(adl_begin(Range), adl_end(Range), P);
}

/// Provide wrappers to std::any_of which take ranges instead of having to pass
/// begin/end explicitly.
template <typename R, typename UnaryPredicate>
bool any_of(R &&Range, UnaryPredicate P) {
  return std::any_of(adl_begin(Range), adl_end(Range), P);
}

/// Provide wrappers to std::none_of which take ranges instead of having to pass
/// begin/end explicitly.
template <typename R, typename UnaryPredicate>
bool none_of(R &&Range, UnaryPredicate P) {
  return std::none_of(adl_begin(Range), adl_end(Range), P);
}

/// Provide wrappers to std::find which take ranges instead of having to pass
/// begin/end explicitly.
template <typename R, typename T> auto find(R &&Range, const T &Val) {
  return std::find(adl_begin(Range), adl_end(Range), Val);
}

/// Provide wrappers to std::find_if which take ranges instead of having to pass
/// begin/end explicitly.
template <typename R, typename UnaryPredicate>
auto find_if(R &&Range, UnaryPredicate P) {
  return std::find_if(adl_begin(Range), adl_end(Range), P);
}

template <typename R, typename UnaryPredicate>
auto find_if_not(R &&Range, UnaryPredicate P) {
  return std::find_if_not(adl_begin(Range), adl_end(Range), P);
}

/// Provide wrappers to std::remove_if which take ranges instead of having to
/// pass begin/end explicitly.
template <typename R, typename UnaryPredicate>
auto remove_if(R &&Range, UnaryPredicate P) {
  return std::remove_if(adl_begin(Range), adl_end(Range), P);
}

/// Provide wrappers to std::copy_if which take ranges instead of having to
/// pass begin/end explicitly.
template <typename R, typename OutputIt, typename UnaryPredicate>
OutputIt copy_if(R &&Range, OutputIt Out, UnaryPredicate P) {
  return std::copy_if(adl_begin(Range), adl_end(Range), Out, P);
}

template <typename R, typename OutputIt>
OutputIt copy(R &&Range, OutputIt Out) {
  return std::copy(adl_begin(Range), adl_end(Range), Out);
}

/// Wrapper function around std::find to detect if an element exists
/// in a container.
template <typename R, typename E>
bool is_contained(R &&Range, const E &Element) {
  return std::find(adl_begin(Range), adl_end(Range), Element) != adl_end(Range);
}

/// Wrapper function around std::count to count the number of times an element
/// \p Element occurs in the given range \p Range.
template <typename R, typename E> auto count(R &&Range, const E &Element) {
  return std::count(adl_begin(Range), adl_end(Range), Element);
}

/// Wrapper function around std::count_if to count the number of times an
/// element satisfying a given predicate occurs in a range.
template <typename R, typename UnaryPredicate>
auto count_if(R &&Range, UnaryPredicate P) {
  return std::count_if(adl_begin(Range), adl_end(Range), P);
}

/// Wrapper function around std::transform to apply a function to a range and
/// store the result elsewhere.
template <typename R, typename OutputIt, typename UnaryPredicate>
OutputIt transform(R &&Range, OutputIt d_first, UnaryPredicate P) {
  return std::transform(adl_begin(Range), adl_end(Range), d_first, P);
}

/// Provide wrappers to std::partition which take ranges instead of having to
/// pass begin/end explicitly.
template <typename R, typename UnaryPredicate>
auto partition(R &&Range, UnaryPredicate P) {
  return std::partition(adl_begin(Range), adl_end(Range), P);
}

/// Provide wrappers to std::lower_bound which take ranges instead of having to
/// pass begin/end explicitly.
template <typename R, typename T> auto lower_bound(R &&Range, T &&Value) {
  return std::lower_bound(adl_begin(Range), adl_end(Range),
                          std::forward<T>(Value));
}

template <typename R, typename T, typename Compare>
auto lower_bound(R &&Range, T &&Value, Compare C) {
  return std::lower_bound(adl_begin(Range), adl_end(Range),
                          std::forward<T>(Value), C);
}

/// Provide wrappers to std::upper_bound which take ranges instead of having to
/// pass begin/end explicitly.
template <typename R, typename T> auto upper_bound(R &&Range, T &&Value) {
  return std::upper_bound(adl_begin(Range), adl_end(Range),
                          std::forward<T>(Value));
}

template <typename R, typename T, typename Compare>
auto upper_bound(R &&Range, T &&Value, Compare C) {
  return std::upper_bound(adl_begin(Range), adl_end(Range),
                          std::forward<T>(Value), C);
}

template <typename R>
void stable_sort(R &&Range) {
  std::stable_sort(adl_begin(Range), adl_end(Range));
}

template <typename R, typename Compare>
void stable_sort(R &&Range, Compare C) {
  std::stable_sort(adl_begin(Range), adl_end(Range), C);
}

/// Binary search for the first iterator in a range where a predicate is false.
/// Requires that C is always true below some limit, and always false above it.
template <typename R, typename Predicate,
          typename Val = decltype(*adl_begin(std::declval<R>()))>
auto partition_point(R &&Range, Predicate P) {
  return std::partition_point(adl_begin(Range), adl_end(Range), P);
}

/// Wrapper function around std::equal to detect if all elements
/// in a container are same.
template <typename R>
bool is_splat(R &&Range) {
  size_t range_size = size(Range);
  return range_size != 0 && (range_size == 1 ||
         std::equal(adl_begin(Range) + 1, adl_end(Range), adl_begin(Range)));
}

/// Provide a container algorithm similar to C++ Library Fundamentals v2's
/// `erase_if` which is equivalent to:
///
///   C.erase(remove_if(C, pred), C.end());
///
/// This version works for any container with an erase method call accepting
/// two iterators.
template <typename Container, typename UnaryPredicate>
void erase_if(Container &C, UnaryPredicate P) {
  C.erase(remove_if(C, P), C.end());
}

/// Given a sequence container Cont, replace the range [ContIt, ContEnd) with
/// the range [ValIt, ValEnd) (which is not from the same container).
template<typename Container, typename RandomAccessIterator>
void replace(Container &Cont, typename Container::iterator ContIt,
             typename Container::iterator ContEnd, RandomAccessIterator ValIt,
             RandomAccessIterator ValEnd) {
  while (true) {
    if (ValIt == ValEnd) {
      Cont.erase(ContIt, ContEnd);
      return;
    } else if (ContIt == ContEnd) {
      Cont.insert(ContIt, ValIt, ValEnd);
      return;
    }
    *ContIt++ = *ValIt++;
  }
}

/// Given a sequence container Cont, replace the range [ContIt, ContEnd) with
/// the range R.
template<typename Container, typename Range = std::initializer_list<
                                 typename Container::value_type>>
void replace(Container &Cont, typename Container::iterator ContIt,
             typename Container::iterator ContEnd, Range R) {
  replace(Cont, ContIt, ContEnd, R.begin(), R.end());
}

//===----------------------------------------------------------------------===//
//     Extra additions to <memory>
//===----------------------------------------------------------------------===//

struct FreeDeleter {
  void operator()(void* v) {
    ::free(v);
  }
};

template<typename First, typename Second>
struct pair_hash {
  size_t operator()(const std::pair<First, Second> &P) const {
    return std::hash<First>()(P.first) * 31 + std::hash<Second>()(P.second);
  }
};

/// Binary functor that adapts to any other binary functor after dereferencing
/// operands.
template <typename T> struct deref {
  T func;

  // Could be further improved to cope with non-derivable functors and
  // non-binary functors (should be a variadic template member function
  // operator()).
  template <typename A, typename B> auto operator()(A &lhs, B &rhs) const {
    assert(lhs);
    assert(rhs);
    return func(*lhs, *rhs);
  }
};

namespace detail {

template <typename R> class enumerator_iter;

template <typename R> struct result_pair {
  using value_reference =
      typename std::iterator_traits<IterOfRange<R>>::reference;

  friend class enumerator_iter<R>;

  result_pair() = default;
  result_pair(std::size_t Index, IterOfRange<R> Iter)
      : Index(Index), Iter(Iter) {}

  result_pair<R>(const result_pair<R> &Other)
      : Index(Other.Index), Iter(Other.Iter) {}
  result_pair<R> &operator=(const result_pair<R> &Other) {
    Index = Other.Index;
    Iter = Other.Iter;
    return *this;
  }

  std::size_t index() const { return Index; }
  const value_reference value() const { return *Iter; }
  value_reference value() { return *Iter; }

private:
  std::size_t Index = std::numeric_limits<std::size_t>::max();
  IterOfRange<R> Iter;
};

template <typename R>
class enumerator_iter
    : public iterator_facade_base<
          enumerator_iter<R>, std::forward_iterator_tag, result_pair<R>,
          typename std::iterator_traits<IterOfRange<R>>::difference_type,
          typename std::iterator_traits<IterOfRange<R>>::pointer,
          typename std::iterator_traits<IterOfRange<R>>::reference> {
  using result_type = result_pair<R>;

public:
  explicit enumerator_iter(IterOfRange<R> EndIter)
      : Result(std::numeric_limits<size_t>::max(), EndIter) {}

  enumerator_iter(std::size_t Index, IterOfRange<R> Iter)
      : Result(Index, Iter) {}

  result_type &operator*() { return Result; }
  const result_type &operator*() const { return Result; }

  enumerator_iter<R> &operator++() {
    assert(Result.Index != std::numeric_limits<size_t>::max());
    ++Result.Iter;
    ++Result.Index;
    return *this;
  }

  bool operator==(const enumerator_iter<R> &RHS) const {
    // Don't compare indices here, only iterators.  It's possible for an end
    // iterator to have different indices depending on whether it was created
    // by calling std::end() versus incrementing a valid iterator.
    return Result.Iter == RHS.Result.Iter;
  }

  enumerator_iter<R>(const enumerator_iter<R> &Other) : Result(Other.Result) {}
  enumerator_iter<R> &operator=(const enumerator_iter<R> &Other) {
    Result = Other.Result;
    return *this;
  }

private:
  result_type Result;
};

template <typename R> class enumerator {
public:
  explicit enumerator(R &&Range) : TheRange(std::forward<R>(Range)) {}

  enumerator_iter<R> begin() {
    return enumerator_iter<R>(0, std::begin(TheRange));
  }

  enumerator_iter<R> end() {
    return enumerator_iter<R>(std::end(TheRange));
  }

private:
  R TheRange;
};

} // end namespace detail

/// Given an input range, returns a new range whose values are are pair (A,B)
/// such that A is the 0-based index of the item in the sequence, and B is
/// the value from the original sequence.  Example:
///
/// std::vector<char> Items = {'A', 'B', 'C', 'D'};
/// for (auto X : enumerate(Items)) {
///   printf("Item %d - %c\n", X.index(), X.value());
/// }
///
/// Output:
///   Item 0 - A
///   Item 1 - B
///   Item 2 - C
///   Item 3 - D
///
template <typename R> detail::enumerator<R> enumerate(R &&TheRange) {
  return detail::enumerator<R>(std::forward<R>(TheRange));
}

namespace detail {

template <typename F, typename Tuple, std::size_t... I>
decltype(auto) apply_tuple_impl(F &&f, Tuple &&t, std::index_sequence<I...>) {
  return std::forward<F>(f)(std::get<I>(std::forward<Tuple>(t))...);
}

} // end namespace detail

/// Given an input tuple (a1, a2, ..., an), pass the arguments of the
/// tuple variadically to f as if by calling f(a1, a2, ..., an) and
/// return the result.
template <typename F, typename Tuple>
decltype(auto) apply_tuple(F &&f, Tuple &&t) {
  using Indices = std::make_index_sequence<
      std::tuple_size<typename std::decay<Tuple>::type>::value>;

  return detail::apply_tuple_impl(std::forward<F>(f), std::forward<Tuple>(t),
                                  Indices{});
}

/// Return true if the sequence [Begin, End) has exactly N items. Runs in O(N)
/// time. Not meant for use with random-access iterators.
template <typename IterTy>
bool hasNItems(
    IterTy &&Begin, IterTy &&End, unsigned N,
    std::enable_if_t<
        !std::is_same<typename std::iterator_traits<std::remove_reference_t<
                          decltype(Begin)>>::iterator_category,
                      std::random_access_iterator_tag>::value,
        void> * = nullptr) {
  for (; N; --N, ++Begin)
    if (Begin == End)
      return false; // Too few.
  return Begin == End;
}

/// Return true if the sequence [Begin, End) has N or more items. Runs in O(N)
/// time. Not meant for use with random-access iterators.
template <typename IterTy>
bool hasNItemsOrMore(
    IterTy &&Begin, IterTy &&End, unsigned N,
    std::enable_if_t<
        !std::is_same<typename std::iterator_traits<std::remove_reference_t<
                          decltype(Begin)>>::iterator_category,
                      std::random_access_iterator_tag>::value,
        void> * = nullptr) {
  for (; N; --N, ++Begin)
    if (Begin == End)
      return false; // Too few.
  return true;
}

/// Returns a raw pointer that represents the same address as the argument.
///
/// This implementation can be removed once we move to C++20 where it's defined
/// as std::to_addres().
///
/// The std::pointer_traits<>::to_address(p) variations of these overloads has
/// not been implemented.
template <class Ptr> auto to_address(const Ptr &P) { return P.operator->(); }
template <class T> constexpr T *to_address(T *P) { return P; }

} // end namespace llvm

#endif // LLVM_ADT_STLEXTRAS_H
# 1556 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/STLExtras.h"
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator_range.h"
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* disabled by -frewrite-includes */
#if __cplusplus > 201402L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <string_view>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#endif
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"

// Declare the __builtin_strlen intrinsic for MSVC so it can be used in
// constexpr context.
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
extern "C" size_t __builtin_strlen(const char *);
#endif
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"

namespace llvm {

  class APInt;
  class hash_code;
  template <typename T> class SmallVectorImpl;
  class StringRef;

  /// Helper functions for StringRef::getAsInteger.
  bool getAsUnsignedInteger(StringRef Str, unsigned Radix,
                            unsigned long long &Result);

  bool getAsSignedInteger(StringRef Str, unsigned Radix, long long &Result);

  bool consumeUnsignedInteger(StringRef &Str, unsigned Radix,
                              unsigned long long &Result);
  bool consumeSignedInteger(StringRef &Str, unsigned Radix, long long &Result);

  /// StringRef - Represent a constant reference to a string, i.e. a character
  /// array and a length, which need not be null terminated.
  ///
  /// This class does not own the string data, it is expected to be used in
  /// situations where the character data resides in some other buffer, whose
  /// lifetime extends past that of the StringRef. For this reason, it is not in
  /// general safe to store a StringRef.
  class StringRef {
  public:
    static const size_t npos = ~size_t(0);

    using iterator = const char *;
    using const_iterator = const char *;
    using size_type = size_t;

  private:
    /// The start of the string, in an external buffer.
    const char *Data = nullptr;

    /// The length of the string.
    size_t Length = 0;

    // Workaround memcmp issue with null pointers (undefined behavior)
    // by providing a specialized version
    static int compareMemory(const char *Lhs, const char *Rhs, size_t Length) {
      if (Length == 0) { return 0; }
      return ::memcmp(Lhs,Rhs,Length);
    }

    // Constexpr version of std::strlen.
    static constexpr size_t strLen(const char *Str) {
#if 0 /* disabled by -frewrite-includes */
#if __cplusplus > 201402L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 82 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
      return std::char_traits<char>::length(Str);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __has_builtin(__builtin_strlen) || defined(__GNUC__) || \
    (defined(_MSC_VER) && _MSC_VER >= 1916)
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 85 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
      return __builtin_strlen(Str);
#else
# 87 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
      const char *Begin = Str;
      while (*Str != '\0')
        ++Str;
      return Str - Begin;
#endif
# 92 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
    }

  public:
    /// @name Constructors
    /// @{

    /// Construct an empty string ref.
    /*implicit*/ StringRef() = default;

    /// Disable conversion from nullptr.  This prevents things like
    /// if (S == nullptr)
    StringRef(std::nullptr_t) = delete;

    /// Construct a string ref from a cstring.
    /*implicit*/ constexpr StringRef(const char *Str)
        : Data(Str), Length(Str ? strLen(Str) : 0) {}

    /// Construct a string ref from a pointer and length.
    /*implicit*/ constexpr StringRef(const char *data, size_t length)
        : Data(data), Length(length) {}

    /// Construct a string ref from an std::string.
    /*implicit*/ StringRef(const std::string &Str)
      : Data(Str.data()), Length(Str.length()) {}

#if 0 /* disabled by -frewrite-includes */
#if __cplusplus > 201402L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 118 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
    /// Construct a string ref from an std::string_view.
    /*implicit*/ constexpr StringRef(std::string_view Str)
        : Data(Str.data()), Length(Str.size()) {}
#endif
# 122 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"

    static StringRef withNullAsEmpty(const char *data) {
      return StringRef(data ? data : "");
    }

    /// @}
    /// @name Iterators
    /// @{

    iterator begin() const { return Data; }

    iterator end() const { return Data + Length; }

    const unsigned char *bytes_begin() const {
      return reinterpret_cast<const unsigned char *>(begin());
    }
    const unsigned char *bytes_end() const {
      return reinterpret_cast<const unsigned char *>(end());
    }
    iterator_range<const unsigned char *> bytes() const {
      return make_range(bytes_begin(), bytes_end());
    }

    /// @}
    /// @name String Operations
    /// @{

    /// data - Get a pointer to the start of the string (which may not be null
    /// terminated).
    LLVM_NODISCARD
    const char *data() const { return Data; }

    /// empty - Check if the string is empty.
    LLVM_NODISCARD
    bool empty() const { return Length == 0; }

    /// size - Get the string size.
    LLVM_NODISCARD
    size_t size() const { return Length; }

    /// front - Get the first character in the string.
    LLVM_NODISCARD
    char front() const {
      assert(!empty());
      return Data[0];
    }

    /// back - Get the last character in the string.
    LLVM_NODISCARD
    char back() const {
      assert(!empty());
      return Data[Length-1];
    }

    // copy - Allocate copy in Allocator and return StringRef to it.
    template <typename Allocator>
    LLVM_NODISCARD StringRef copy(Allocator &A) const {
      // Don't request a length 0 copy from the allocator.
      if (empty())
        return StringRef();
      char *S = A.template Allocate<char>(Length);
      std::copy(begin(), end(), S);
      return StringRef(S, Length);
    }

    /// equals - Check for string equality, this is more efficient than
    /// compare() when the relative ordering of inequal strings isn't needed.
    LLVM_NODISCARD
    bool equals(StringRef RHS) const {
      return (Length == RHS.Length &&
              compareMemory(Data, RHS.Data, RHS.Length) == 0);
    }

    /// equals_lower - Check for string equality, ignoring case.
    LLVM_NODISCARD
    bool equals_lower(StringRef RHS) const {
      return Length == RHS.Length && compare_lower(RHS) == 0;
    }

    /// compare - Compare two strings; the result is -1, 0, or 1 if this string
    /// is lexicographically less than, equal to, or greater than the \p RHS.
    LLVM_NODISCARD
    int compare(StringRef RHS) const {
      // Check the prefix for a mismatch.
      if (int Res = compareMemory(Data, RHS.Data, std::min(Length, RHS.Length)))
        return Res < 0 ? -1 : 1;

      // Otherwise the prefixes match, so we only need to check the lengths.
      if (Length == RHS.Length)
        return 0;
      return Length < RHS.Length ? -1 : 1;
    }

    /// compare_lower - Compare two strings, ignoring case.
    LLVM_NODISCARD
    int compare_lower(StringRef RHS) const;

    /// compare_numeric - Compare two strings, treating sequences of digits as
    /// numbers.
    LLVM_NODISCARD
    int compare_numeric(StringRef RHS) const;

    /// Determine the edit distance between this string and another
    /// string.
    ///
    /// \param Other the string to compare this string against.
    ///
    /// \param AllowReplacements whether to allow character
    /// replacements (change one character into another) as a single
    /// operation, rather than as two operations (an insertion and a
    /// removal).
    ///
    /// \param MaxEditDistance If non-zero, the maximum edit distance that
    /// this routine is allowed to compute. If the edit distance will exceed
    /// that maximum, returns \c MaxEditDistance+1.
    ///
    /// \returns the minimum number of character insertions, removals,
    /// or (if \p AllowReplacements is \c true) replacements needed to
    /// transform one of the given strings into the other. If zero,
    /// the strings are identical.
    LLVM_NODISCARD
    unsigned edit_distance(StringRef Other, bool AllowReplacements = true,
                           unsigned MaxEditDistance = 0) const;

    /// str - Get the contents as an std::string.
    LLVM_NODISCARD
    std::string str() const {
      if (!Data) return std::string();
      return std::string(Data, Length);
    }

    /// @}
    /// @name Operator Overloads
    /// @{

    LLVM_NODISCARD
    char operator[](size_t Index) const {
      assert(Index < Length && "Invalid index!");
      return Data[Index];
    }

    /// Disallow accidental assignment from a temporary std::string.
    ///
    /// The declaration here is extra complicated so that `stringRef = {}`
    /// and `stringRef = "abc"` continue to select the move assignment operator.
    template <typename T>
    std::enable_if_t<std::is_same<T, std::string>::value, StringRef> &
    operator=(T &&Str) = delete;

    /// @}
    /// @name Type Conversions
    /// @{

    explicit operator std::string() const { return str(); }

#if 0 /* disabled by -frewrite-includes */
#if __cplusplus > 201402L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 278 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
    operator std::string_view() const {
      return std::string_view(data(), size());
    }
#endif
# 282 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"

    /// @}
    /// @name String Predicates
    /// @{

    /// Check if this string starts with the given \p Prefix.
    LLVM_NODISCARD
    bool startswith(StringRef Prefix) const {
      return Length >= Prefix.Length &&
             compareMemory(Data, Prefix.Data, Prefix.Length) == 0;
    }

    /// Check if this string starts with the given \p Prefix, ignoring case.
    LLVM_NODISCARD
    bool startswith_lower(StringRef Prefix) const;

    /// Check if this string ends with the given \p Suffix.
    LLVM_NODISCARD
    bool endswith(StringRef Suffix) const {
      return Length >= Suffix.Length &&
        compareMemory(end() - Suffix.Length, Suffix.Data, Suffix.Length) == 0;
    }

    /// Check if this string ends with the given \p Suffix, ignoring case.
    LLVM_NODISCARD
    bool endswith_lower(StringRef Suffix) const;

    /// @}
    /// @name String Searching
    /// @{

    /// Search for the first character \p C in the string.
    ///
    /// \returns The index of the first occurrence of \p C, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t find(char C, size_t From = 0) const {
      size_t FindBegin = std::min(From, Length);
      if (FindBegin < Length) { // Avoid calling memchr with nullptr.
        // Just forward to memchr, which is faster than a hand-rolled loop.
        if (const void *P = ::memchr(Data + FindBegin, C, Length - FindBegin))
          return static_cast<const char *>(P) - Data;
      }
      return npos;
    }

    /// Search for the first character \p C in the string, ignoring case.
    ///
    /// \returns The index of the first occurrence of \p C, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t find_lower(char C, size_t From = 0) const;

    /// Search for the first character satisfying the predicate \p F
    ///
    /// \returns The index of the first character satisfying \p F starting from
    /// \p From, or npos if not found.
    LLVM_NODISCARD
    size_t find_if(function_ref<bool(char)> F, size_t From = 0) const {
      StringRef S = drop_front(From);
      while (!S.empty()) {
        if (F(S.front()))
          return size() - S.size();
        S = S.drop_front();
      }
      return npos;
    }

    /// Search for the first character not satisfying the predicate \p F
    ///
    /// \returns The index of the first character not satisfying \p F starting
    /// from \p From, or npos if not found.
    LLVM_NODISCARD
    size_t find_if_not(function_ref<bool(char)> F, size_t From = 0) const {
      return find_if([F](char c) { return !F(c); }, From);
    }

    /// Search for the first string \p Str in the string.
    ///
    /// \returns The index of the first occurrence of \p Str, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t find(StringRef Str, size_t From = 0) const;

    /// Search for the first string \p Str in the string, ignoring case.
    ///
    /// \returns The index of the first occurrence of \p Str, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t find_lower(StringRef Str, size_t From = 0) const;

    /// Search for the last character \p C in the string.
    ///
    /// \returns The index of the last occurrence of \p C, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t rfind(char C, size_t From = npos) const {
      From = std::min(From, Length);
      size_t i = From;
      while (i != 0) {
        --i;
        if (Data[i] == C)
          return i;
      }
      return npos;
    }

    /// Search for the last character \p C in the string, ignoring case.
    ///
    /// \returns The index of the last occurrence of \p C, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t rfind_lower(char C, size_t From = npos) const;

    /// Search for the last string \p Str in the string.
    ///
    /// \returns The index of the last occurrence of \p Str, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t rfind(StringRef Str) const;

    /// Search for the last string \p Str in the string, ignoring case.
    ///
    /// \returns The index of the last occurrence of \p Str, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t rfind_lower(StringRef Str) const;

    /// Find the first character in the string that is \p C, or npos if not
    /// found. Same as find.
    LLVM_NODISCARD
    size_t find_first_of(char C, size_t From = 0) const {
      return find(C, From);
    }

    /// Find the first character in the string that is in \p Chars, or npos if
    /// not found.
    ///
    /// Complexity: O(size() + Chars.size())
    LLVM_NODISCARD
    size_t find_first_of(StringRef Chars, size_t From = 0) const;

    /// Find the first character in the string that is not \p C or npos if not
    /// found.
    LLVM_NODISCARD
    size_t find_first_not_of(char C, size_t From = 0) const;

    /// Find the first character in the string that is not in the string
    /// \p Chars, or npos if not found.
    ///
    /// Complexity: O(size() + Chars.size())
    LLVM_NODISCARD
    size_t find_first_not_of(StringRef Chars, size_t From = 0) const;

    /// Find the last character in the string that is \p C, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t find_last_of(char C, size_t From = npos) const {
      return rfind(C, From);
    }

    /// Find the last character in the string that is in \p C, or npos if not
    /// found.
    ///
    /// Complexity: O(size() + Chars.size())
    LLVM_NODISCARD
    size_t find_last_of(StringRef Chars, size_t From = npos) const;

    /// Find the last character in the string that is not \p C, or npos if not
    /// found.
    LLVM_NODISCARD
    size_t find_last_not_of(char C, size_t From = npos) const;

    /// Find the last character in the string that is not in \p Chars, or
    /// npos if not found.
    ///
    /// Complexity: O(size() + Chars.size())
    LLVM_NODISCARD
    size_t find_last_not_of(StringRef Chars, size_t From = npos) const;

    /// Return true if the given string is a substring of *this, and false
    /// otherwise.
    LLVM_NODISCARD
    bool contains(StringRef Other) const { return find(Other) != npos; }

    /// Return true if the given character is contained in *this, and false
    /// otherwise.
    LLVM_NODISCARD
    bool contains(char C) const { return find_first_of(C) != npos; }

    /// Return true if the given string is a substring of *this, and false
    /// otherwise.
    LLVM_NODISCARD
    bool contains_lower(StringRef Other) const {
      return find_lower(Other) != npos;
    }

    /// Return true if the given character is contained in *this, and false
    /// otherwise.
    LLVM_NODISCARD
    bool contains_lower(char C) const { return find_lower(C) != npos; }

    /// @}
    /// @name Helpful Algorithms
    /// @{

    /// Return the number of occurrences of \p C in the string.
    LLVM_NODISCARD
    size_t count(char C) const {
      size_t Count = 0;
      for (size_t i = 0, e = Length; i != e; ++i)
        if (Data[i] == C)
          ++Count;
      return Count;
    }

    /// Return the number of non-overlapped occurrences of \p Str in
    /// the string.
    size_t count(StringRef Str) const;

    /// Parse the current string as an integer of the specified radix.  If
    /// \p Radix is specified as zero, this does radix autosensing using
    /// extended C rules: 0 is octal, 0x is hex, 0b is binary.
    ///
    /// If the string is invalid or if only a subset of the string is valid,
    /// this returns true to signify the error.  The string is considered
    /// erroneous if empty or if it overflows T.
    template <typename T>
    std::enable_if_t<std::numeric_limits<T>::is_signed, bool>
    getAsInteger(unsigned Radix, T &Result) const {
      long long LLVal;
      if (getAsSignedInteger(*this, Radix, LLVal) ||
            static_cast<T>(LLVal) != LLVal)
        return true;
      Result = LLVal;
      return false;
    }

    template <typename T>
    std::enable_if_t<!std::numeric_limits<T>::is_signed, bool>
    getAsInteger(unsigned Radix, T &Result) const {
      unsigned long long ULLVal;
      // The additional cast to unsigned long long is required to avoid the
      // Visual C++ warning C4805: '!=' : unsafe mix of type 'bool' and type
      // 'unsigned __int64' when instantiating getAsInteger with T = bool.
      if (getAsUnsignedInteger(*this, Radix, ULLVal) ||
          static_cast<unsigned long long>(static_cast<T>(ULLVal)) != ULLVal)
        return true;
      Result = ULLVal;
      return false;
    }

    /// Parse the current string as an integer of the specified radix.  If
    /// \p Radix is specified as zero, this does radix autosensing using
    /// extended C rules: 0 is octal, 0x is hex, 0b is binary.
    ///
    /// If the string does not begin with a number of the specified radix,
    /// this returns true to signify the error. The string is considered
    /// erroneous if empty or if it overflows T.
    /// The portion of the string representing the discovered numeric value
    /// is removed from the beginning of the string.
    template <typename T>
    std::enable_if_t<std::numeric_limits<T>::is_signed, bool>
    consumeInteger(unsigned Radix, T &Result) {
      long long LLVal;
      if (consumeSignedInteger(*this, Radix, LLVal) ||
          static_cast<long long>(static_cast<T>(LLVal)) != LLVal)
        return true;
      Result = LLVal;
      return false;
    }

    template <typename T>
    std::enable_if_t<!std::numeric_limits<T>::is_signed, bool>
    consumeInteger(unsigned Radix, T &Result) {
      unsigned long long ULLVal;
      if (consumeUnsignedInteger(*this, Radix, ULLVal) ||
          static_cast<unsigned long long>(static_cast<T>(ULLVal)) != ULLVal)
        return true;
      Result = ULLVal;
      return false;
    }

    /// Parse the current string as an integer of the specified \p Radix, or of
    /// an autosensed radix if the \p Radix given is 0.  The current value in
    /// \p Result is discarded, and the storage is changed to be wide enough to
    /// store the parsed integer.
    ///
    /// \returns true if the string does not solely consist of a valid
    /// non-empty number in the appropriate base.
    ///
    /// APInt::fromString is superficially similar but assumes the
    /// string is well-formed in the given radix.
    bool getAsInteger(unsigned Radix, APInt &Result) const;

    /// Parse the current string as an IEEE double-precision floating
    /// point value.  The string must be a well-formed double.
    ///
    /// If \p AllowInexact is false, the function will fail if the string
    /// cannot be represented exactly.  Otherwise, the function only fails
    /// in case of an overflow or underflow, or an invalid floating point
    /// representation.
    bool getAsDouble(double &Result, bool AllowInexact = true) const;

    /// @}
    /// @name String Operations
    /// @{

    // Convert the given ASCII string to lowercase.
    LLVM_NODISCARD
    std::string lower() const;

    /// Convert the given ASCII string to uppercase.
    LLVM_NODISCARD
    std::string upper() const;

    /// @}
    /// @name Substring Operations
    /// @{

    /// Return a reference to the substring from [Start, Start + N).
    ///
    /// \param Start The index of the starting character in the substring; if
    /// the index is npos or greater than the length of the string then the
    /// empty substring will be returned.
    ///
    /// \param N The number of characters to included in the substring. If N
    /// exceeds the number of characters remaining in the string, the string
    /// suffix (starting with \p Start) will be returned.
    LLVM_NODISCARD
    StringRef substr(size_t Start, size_t N = npos) const {
      Start = std::min(Start, Length);
      return StringRef(Data + Start, std::min(N, Length - Start));
    }

    /// Return a StringRef equal to 'this' but with only the first \p N
    /// elements remaining.  If \p N is greater than the length of the
    /// string, the entire string is returned.
    LLVM_NODISCARD
    StringRef take_front(size_t N = 1) const {
      if (N >= size())
        return *this;
      return drop_back(size() - N);
    }

    /// Return a StringRef equal to 'this' but with only the last \p N
    /// elements remaining.  If \p N is greater than the length of the
    /// string, the entire string is returned.
    LLVM_NODISCARD
    StringRef take_back(size_t N = 1) const {
      if (N >= size())
        return *this;
      return drop_front(size() - N);
    }

    /// Return the longest prefix of 'this' such that every character
    /// in the prefix satisfies the given predicate.
    LLVM_NODISCARD
    StringRef take_while(function_ref<bool(char)> F) const {
      return substr(0, find_if_not(F));
    }

    /// Return the longest prefix of 'this' such that no character in
    /// the prefix satisfies the given predicate.
    LLVM_NODISCARD
    StringRef take_until(function_ref<bool(char)> F) const {
      return substr(0, find_if(F));
    }

    /// Return a StringRef equal to 'this' but with the first \p N elements
    /// dropped.
    LLVM_NODISCARD
    StringRef drop_front(size_t N = 1) const {
      assert(size() >= N && "Dropping more elements than exist");
      return substr(N);
    }

    /// Return a StringRef equal to 'this' but with the last \p N elements
    /// dropped.
    LLVM_NODISCARD
    StringRef drop_back(size_t N = 1) const {
      assert(size() >= N && "Dropping more elements than exist");
      return substr(0, size()-N);
    }

    /// Return a StringRef equal to 'this', but with all characters satisfying
    /// the given predicate dropped from the beginning of the string.
    LLVM_NODISCARD
    StringRef drop_while(function_ref<bool(char)> F) const {
      return substr(find_if_not(F));
    }

    /// Return a StringRef equal to 'this', but with all characters not
    /// satisfying the given predicate dropped from the beginning of the string.
    LLVM_NODISCARD
    StringRef drop_until(function_ref<bool(char)> F) const {
      return substr(find_if(F));
    }

    /// Returns true if this StringRef has the given prefix and removes that
    /// prefix.
    bool consume_front(StringRef Prefix) {
      if (!startswith(Prefix))
        return false;

      *this = drop_front(Prefix.size());
      return true;
    }

    /// Returns true if this StringRef has the given suffix and removes that
    /// suffix.
    bool consume_back(StringRef Suffix) {
      if (!endswith(Suffix))
        return false;

      *this = drop_back(Suffix.size());
      return true;
    }

    /// Return a reference to the substring from [Start, End).
    ///
    /// \param Start The index of the starting character in the substring; if
    /// the index is npos or greater than the length of the string then the
    /// empty substring will be returned.
    ///
    /// \param End The index following the last character to include in the
    /// substring. If this is npos or exceeds the number of characters
    /// remaining in the string, the string suffix (starting with \p Start)
    /// will be returned. If this is less than \p Start, an empty string will
    /// be returned.
    LLVM_NODISCARD
    StringRef slice(size_t Start, size_t End) const {
      Start = std::min(Start, Length);
      End = std::min(std::max(Start, End), Length);
      return StringRef(Data + Start, End - Start);
    }

    /// Split into two substrings around the first occurrence of a separator
    /// character.
    ///
    /// If \p Separator is in the string, then the result is a pair (LHS, RHS)
    /// such that (*this == LHS + Separator + RHS) is true and RHS is
    /// maximal. If \p Separator is not in the string, then the result is a
    /// pair (LHS, RHS) where (*this == LHS) and (RHS == "").
    ///
    /// \param Separator The character to split on.
    /// \returns The split substrings.
    LLVM_NODISCARD
    std::pair<StringRef, StringRef> split(char Separator) const {
      return split(StringRef(&Separator, 1));
    }

    /// Split into two substrings around the first occurrence of a separator
    /// string.
    ///
    /// If \p Separator is in the string, then the result is a pair (LHS, RHS)
    /// such that (*this == LHS + Separator + RHS) is true and RHS is
    /// maximal. If \p Separator is not in the string, then the result is a
    /// pair (LHS, RHS) where (*this == LHS) and (RHS == "").
    ///
    /// \param Separator - The string to split on.
    /// \return - The split substrings.
    LLVM_NODISCARD
    std::pair<StringRef, StringRef> split(StringRef Separator) const {
      size_t Idx = find(Separator);
      if (Idx == npos)
        return std::make_pair(*this, StringRef());
      return std::make_pair(slice(0, Idx), slice(Idx + Separator.size(), npos));
    }

    /// Split into two substrings around the last occurrence of a separator
    /// string.
    ///
    /// If \p Separator is in the string, then the result is a pair (LHS, RHS)
    /// such that (*this == LHS + Separator + RHS) is true and RHS is
    /// minimal. If \p Separator is not in the string, then the result is a
    /// pair (LHS, RHS) where (*this == LHS) and (RHS == "").
    ///
    /// \param Separator - The string to split on.
    /// \return - The split substrings.
    LLVM_NODISCARD
    std::pair<StringRef, StringRef> rsplit(StringRef Separator) const {
      size_t Idx = rfind(Separator);
      if (Idx == npos)
        return std::make_pair(*this, StringRef());
      return std::make_pair(slice(0, Idx), slice(Idx + Separator.size(), npos));
    }

    /// Split into substrings around the occurrences of a separator string.
    ///
    /// Each substring is stored in \p A. If \p MaxSplit is >= 0, at most
    /// \p MaxSplit splits are done and consequently <= \p MaxSplit + 1
    /// elements are added to A.
    /// If \p KeepEmpty is false, empty strings are not added to \p A. They
    /// still count when considering \p MaxSplit
    /// An useful invariant is that
    /// Separator.join(A) == *this if MaxSplit == -1 and KeepEmpty == true
    ///
    /// \param A - Where to put the substrings.
    /// \param Separator - The string to split on.
    /// \param MaxSplit - The maximum number of times the string is split.
    /// \param KeepEmpty - True if empty substring should be added.
    void split(SmallVectorImpl<StringRef> &A,
               StringRef Separator, int MaxSplit = -1,
               bool KeepEmpty = true) const;

    /// Split into substrings around the occurrences of a separator character.
    ///
    /// Each substring is stored in \p A. If \p MaxSplit is >= 0, at most
    /// \p MaxSplit splits are done and consequently <= \p MaxSplit + 1
    /// elements are added to A.
    /// If \p KeepEmpty is false, empty strings are not added to \p A. They
    /// still count when considering \p MaxSplit
    /// An useful invariant is that
    /// Separator.join(A) == *this if MaxSplit == -1 and KeepEmpty == true
    ///
    /// \param A - Where to put the substrings.
    /// \param Separator - The string to split on.
    /// \param MaxSplit - The maximum number of times the string is split.
    /// \param KeepEmpty - True if empty substring should be added.
    void split(SmallVectorImpl<StringRef> &A, char Separator, int MaxSplit = -1,
               bool KeepEmpty = true) const;

    /// Split into two substrings around the last occurrence of a separator
    /// character.
    ///
    /// If \p Separator is in the string, then the result is a pair (LHS, RHS)
    /// such that (*this == LHS + Separator + RHS) is true and RHS is
    /// minimal. If \p Separator is not in the string, then the result is a
    /// pair (LHS, RHS) where (*this == LHS) and (RHS == "").
    ///
    /// \param Separator - The character to split on.
    /// \return - The split substrings.
    LLVM_NODISCARD
    std::pair<StringRef, StringRef> rsplit(char Separator) const {
      return rsplit(StringRef(&Separator, 1));
    }

    /// Return string with consecutive \p Char characters starting from the
    /// the left removed.
    LLVM_NODISCARD
    StringRef ltrim(char Char) const {
      return drop_front(std::min(Length, find_first_not_of(Char)));
    }

    /// Return string with consecutive characters in \p Chars starting from
    /// the left removed.
    LLVM_NODISCARD
    StringRef ltrim(StringRef Chars = " \t\n\v\f\r") const {
      return drop_front(std::min(Length, find_first_not_of(Chars)));
    }

    /// Return string with consecutive \p Char characters starting from the
    /// right removed.
    LLVM_NODISCARD
    StringRef rtrim(char Char) const {
      return drop_back(Length - std::min(Length, find_last_not_of(Char) + 1));
    }

    /// Return string with consecutive characters in \p Chars starting from
    /// the right removed.
    LLVM_NODISCARD
    StringRef rtrim(StringRef Chars = " \t\n\v\f\r") const {
      return drop_back(Length - std::min(Length, find_last_not_of(Chars) + 1));
    }

    /// Return string with consecutive \p Char characters starting from the
    /// left and right removed.
    LLVM_NODISCARD
    StringRef trim(char Char) const {
      return ltrim(Char).rtrim(Char);
    }

    /// Return string with consecutive characters in \p Chars starting from
    /// the left and right removed.
    LLVM_NODISCARD
    StringRef trim(StringRef Chars = " \t\n\v\f\r") const {
      return ltrim(Chars).rtrim(Chars);
    }

    /// @}
  };

  /// A wrapper around a string literal that serves as a proxy for constructing
  /// global tables of StringRefs with the length computed at compile time.
  /// In order to avoid the invocation of a global constructor, StringLiteral
  /// should *only* be used in a constexpr context, as such:
  ///
  /// constexpr StringLiteral S("test");
  ///
  class StringLiteral : public StringRef {
  private:
    constexpr StringLiteral(const char *Str, size_t N) : StringRef(Str, N) {
    }

  public:
    template <size_t N>
    constexpr StringLiteral(const char (&Str)[N])
#if 0 /* disabled by -frewrite-includes */
#if defined(__clang__) && __has_attribute(enable_if)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 881 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wgcc-compat"
        __attribute((enable_if(__builtin_strlen(Str) == N - 1,
                               "invalid string literal")))
#pragma clang diagnostic pop
#endif
# 887 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
        : StringRef(Str, N - 1) {
    }

    // Explicit construction for strings like "foo\0bar".
    template <size_t N>
    static constexpr StringLiteral withInnerNUL(const char (&Str)[N]) {
      return StringLiteral(Str, N - 1);
    }
  };

  /// @name StringRef Comparison Operators
  /// @{

  inline bool operator==(StringRef LHS, StringRef RHS) {
    return LHS.equals(RHS);
  }

  inline bool operator!=(StringRef LHS, StringRef RHS) { return !(LHS == RHS); }

  inline bool operator<(StringRef LHS, StringRef RHS) {
    return LHS.compare(RHS) == -1;
  }

  inline bool operator<=(StringRef LHS, StringRef RHS) {
    return LHS.compare(RHS) != 1;
  }

  inline bool operator>(StringRef LHS, StringRef RHS) {
    return LHS.compare(RHS) == 1;
  }

  inline bool operator>=(StringRef LHS, StringRef RHS) {
    return LHS.compare(RHS) != -1;
  }

  inline std::string &operator+=(std::string &buffer, StringRef string) {
    return buffer.append(string.data(), string.size());
  }

  /// @}

  /// Compute a hash_code for a StringRef.
  LLVM_NODISCARD
  hash_code hash_value(StringRef S);

} // end namespace llvm

#endif // LLVM_ADT_STRINGREF_H
# 935 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringRef.h"
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 1 3
// -*- C++ -*-
//===------------------------------ vector --------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_VECTOR
#define _LIBCPP_VECTOR

/*
    vector synopsis

namespace std
{

template <class T, class Allocator = allocator<T> >
class vector
{
public:
    typedef T                                        value_type;
    typedef Allocator                                allocator_type;
    typedef typename allocator_type::reference       reference;
    typedef typename allocator_type::const_reference const_reference;
    typedef implementation-defined                   iterator;
    typedef implementation-defined                   const_iterator;
    typedef typename allocator_type::size_type       size_type;
    typedef typename allocator_type::difference_type difference_type;
    typedef typename allocator_type::pointer         pointer;
    typedef typename allocator_type::const_pointer   const_pointer;
    typedef std::reverse_iterator<iterator>          reverse_iterator;
    typedef std::reverse_iterator<const_iterator>    const_reverse_iterator;

    vector()
        noexcept(is_nothrow_default_constructible<allocator_type>::value);
    explicit vector(const allocator_type&);
    explicit vector(size_type n);
    explicit vector(size_type n, const allocator_type&); // C++14
    vector(size_type n, const value_type& value, const allocator_type& = allocator_type());
    template <class InputIterator>
        vector(InputIterator first, InputIterator last, const allocator_type& = allocator_type());
    vector(const vector& x);
    vector(vector&& x)
        noexcept(is_nothrow_move_constructible<allocator_type>::value);
    vector(initializer_list<value_type> il);
    vector(initializer_list<value_type> il, const allocator_type& a);
    ~vector();
    vector& operator=(const vector& x);
    vector& operator=(vector&& x)
        noexcept(
             allocator_type::propagate_on_container_move_assignment::value ||
             allocator_type::is_always_equal::value); // C++17
    vector& operator=(initializer_list<value_type> il);
    template <class InputIterator>
        void assign(InputIterator first, InputIterator last);
    void assign(size_type n, const value_type& u);
    void assign(initializer_list<value_type> il);

    allocator_type get_allocator() const noexcept;

    iterator               begin() noexcept;
    const_iterator         begin()   const noexcept;
    iterator               end() noexcept;
    const_iterator         end()     const noexcept;

    reverse_iterator       rbegin() noexcept;
    const_reverse_iterator rbegin()  const noexcept;
    reverse_iterator       rend() noexcept;
    const_reverse_iterator rend()    const noexcept;

    const_iterator         cbegin()  const noexcept;
    const_iterator         cend()    const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend()   const noexcept;

    size_type size() const noexcept;
    size_type max_size() const noexcept;
    size_type capacity() const noexcept;
    bool empty() const noexcept;
    void reserve(size_type n);
    void shrink_to_fit() noexcept;

    reference       operator[](size_type n);
    const_reference operator[](size_type n) const;
    reference       at(size_type n);
    const_reference at(size_type n) const;

    reference       front();
    const_reference front() const;
    reference       back();
    const_reference back() const;

    value_type*       data() noexcept;
    const value_type* data() const noexcept;

    void push_back(const value_type& x);
    void push_back(value_type&& x);
    template <class... Args>
        reference emplace_back(Args&&... args); // reference in C++17
    void pop_back();

    template <class... Args> iterator emplace(const_iterator position, Args&&... args);
    iterator insert(const_iterator position, const value_type& x);
    iterator insert(const_iterator position, value_type&& x);
    iterator insert(const_iterator position, size_type n, const value_type& x);
    template <class InputIterator>
        iterator insert(const_iterator position, InputIterator first, InputIterator last);
    iterator insert(const_iterator position, initializer_list<value_type> il);

    iterator erase(const_iterator position);
    iterator erase(const_iterator first, const_iterator last);

    void clear() noexcept;

    void resize(size_type sz);
    void resize(size_type sz, const value_type& c);

    void swap(vector&)
        noexcept(allocator_traits<allocator_type>::propagate_on_container_swap::value ||
                 allocator_traits<allocator_type>::is_always_equal::value);  // C++17

    bool __invariants() const;
};

template <class Allocator = allocator<T> >
class vector<bool, Allocator>
{
public:
    typedef bool                                     value_type;
    typedef Allocator                                allocator_type;
    typedef implementation-defined                   iterator;
    typedef implementation-defined                   const_iterator;
    typedef typename allocator_type::size_type       size_type;
    typedef typename allocator_type::difference_type difference_type;
    typedef iterator                                 pointer;
    typedef const_iterator                           const_pointer;
    typedef std::reverse_iterator<iterator>          reverse_iterator;
    typedef std::reverse_iterator<const_iterator>    const_reverse_iterator;

    class reference
    {
    public:
        reference(const reference&) noexcept;
        operator bool() const noexcept;
        reference& operator=(const bool x) noexcept;
        reference& operator=(const reference& x) noexcept;
        iterator operator&() const noexcept;
        void flip() noexcept;
    };

    class const_reference
    {
    public:
        const_reference(const reference&) noexcept;
        operator bool() const noexcept;
        const_iterator operator&() const noexcept;
    };

    vector()
        noexcept(is_nothrow_default_constructible<allocator_type>::value);
    explicit vector(const allocator_type&);
    explicit vector(size_type n, const allocator_type& a = allocator_type()); // C++14
    vector(size_type n, const value_type& value, const allocator_type& = allocator_type());
    template <class InputIterator>
        vector(InputIterator first, InputIterator last, const allocator_type& = allocator_type());
    vector(const vector& x);
    vector(vector&& x)
        noexcept(is_nothrow_move_constructible<allocator_type>::value);
    vector(initializer_list<value_type> il);
    vector(initializer_list<value_type> il, const allocator_type& a);
    ~vector();
    vector& operator=(const vector& x);
    vector& operator=(vector&& x)
        noexcept(
             allocator_type::propagate_on_container_move_assignment::value ||
             allocator_type::is_always_equal::value); // C++17
    vector& operator=(initializer_list<value_type> il);
    template <class InputIterator>
        void assign(InputIterator first, InputIterator last);
    void assign(size_type n, const value_type& u);
    void assign(initializer_list<value_type> il);

    allocator_type get_allocator() const noexcept;

    iterator               begin() noexcept;
    const_iterator         begin()   const noexcept;
    iterator               end() noexcept;
    const_iterator         end()     const noexcept;

    reverse_iterator       rbegin() noexcept;
    const_reverse_iterator rbegin()  const noexcept;
    reverse_iterator       rend() noexcept;
    const_reverse_iterator rend()    const noexcept;

    const_iterator         cbegin()  const noexcept;
    const_iterator         cend()    const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend()   const noexcept;

    size_type size() const noexcept;
    size_type max_size() const noexcept;
    size_type capacity() const noexcept;
    bool empty() const noexcept;
    void reserve(size_type n);
    void shrink_to_fit() noexcept;

    reference       operator[](size_type n);
    const_reference operator[](size_type n) const;
    reference       at(size_type n);
    const_reference at(size_type n) const;

    reference       front();
    const_reference front() const;
    reference       back();
    const_reference back() const;

    void push_back(const value_type& x);
    template <class... Args> reference emplace_back(Args&&... args);  // C++14; reference in C++17
    void pop_back();

    template <class... Args> iterator emplace(const_iterator position, Args&&... args);  // C++14
    iterator insert(const_iterator position, const value_type& x);
    iterator insert(const_iterator position, size_type n, const value_type& x);
    template <class InputIterator>
        iterator insert(const_iterator position, InputIterator first, InputIterator last);
    iterator insert(const_iterator position, initializer_list<value_type> il);

    iterator erase(const_iterator position);
    iterator erase(const_iterator first, const_iterator last);

    void clear() noexcept;

    void resize(size_type sz);
    void resize(size_type sz, value_type x);

    void swap(vector&)
        noexcept(allocator_traits<allocator_type>::propagate_on_container_swap::value ||
                 allocator_traits<allocator_type>::is_always_equal::value);  // C++17
    void flip() noexcept;

    bool __invariants() const;
};

template <class InputIterator, class Allocator = allocator<typename iterator_traits<InputIterator>::value_type>>
   vector(InputIterator, InputIterator, Allocator = Allocator())
   -> vector<typename iterator_traits<InputIterator>::value_type, Allocator>;

template <class Allocator> struct hash<std::vector<bool, Allocator>>;

template <class T, class Allocator> bool operator==(const vector<T,Allocator>& x, const vector<T,Allocator>& y);
template <class T, class Allocator> bool operator< (const vector<T,Allocator>& x, const vector<T,Allocator>& y);
template <class T, class Allocator> bool operator!=(const vector<T,Allocator>& x, const vector<T,Allocator>& y);
template <class T, class Allocator> bool operator> (const vector<T,Allocator>& x, const vector<T,Allocator>& y);
template <class T, class Allocator> bool operator>=(const vector<T,Allocator>& x, const vector<T,Allocator>& y);
template <class T, class Allocator> bool operator<=(const vector<T,Allocator>& x, const vector<T,Allocator>& y);

template <class T, class Allocator>
void swap(vector<T,Allocator>& x, vector<T,Allocator>& y)
    noexcept(noexcept(x.swap(y)));

template <class T, class Allocator, class U>
    void erase(vector<T, Allocator>& c, const U& value);       // C++20
template <class T, class Allocator, class Predicate>
    void erase_if(vector<T, Allocator>& c, Predicate pred);    // C++20

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 272 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 273 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd> // for forward declaration of vector
#endif /* expanded by -frewrite-includes */
# 273 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 274 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <__bit_reference>
#endif /* expanded by -frewrite-includes */
# 274 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___BIT_REFERENCE
#define _LIBCPP___BIT_REFERENCE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
#if 0 /* expanded by -frewrite-includes */
#include <bit>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Cp, bool _IsConst, typename _Cp::__storage_type = 0> class __bit_iterator;
template <class _Cp> class __bit_const_reference;

template <class _Tp>
struct __has_storage_type
{
    static const bool value = false;
};

template <class _Cp, bool = __has_storage_type<_Cp>::value>
class __bit_reference
{
    typedef typename _Cp::__storage_type    __storage_type;
    typedef typename _Cp::__storage_pointer __storage_pointer;

    __storage_pointer __seg_;
    __storage_type    __mask_;

    friend typename _Cp::__self;

    friend class __bit_const_reference<_Cp>;
    friend class __bit_iterator<_Cp, false>;
public:
    _LIBCPP_INLINE_VISIBILITY
    __bit_reference(const __bit_reference&) = default;

    _LIBCPP_INLINE_VISIBILITY operator bool() const _NOEXCEPT
        {return static_cast<bool>(*__seg_ & __mask_);}
    _LIBCPP_INLINE_VISIBILITY bool operator ~() const _NOEXCEPT
        {return !static_cast<bool>(*this);}

    _LIBCPP_INLINE_VISIBILITY
    __bit_reference& operator=(bool __x) _NOEXCEPT
    {
        if (__x)
            *__seg_ |= __mask_;
        else
            *__seg_ &= ~__mask_;
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __bit_reference& operator=(const __bit_reference& __x) _NOEXCEPT
        {return operator=(static_cast<bool>(__x));}

    _LIBCPP_INLINE_VISIBILITY void flip() _NOEXCEPT {*__seg_ ^= __mask_;}
    _LIBCPP_INLINE_VISIBILITY __bit_iterator<_Cp, false> operator&() const _NOEXCEPT
        {return __bit_iterator<_Cp, false>(__seg_, static_cast<unsigned>(__libcpp_ctz(__mask_)));}
private:
    _LIBCPP_INLINE_VISIBILITY
    __bit_reference(__storage_pointer __s, __storage_type __m) _NOEXCEPT
        : __seg_(__s), __mask_(__m) {}
};

template <class _Cp>
class __bit_reference<_Cp, false>
{
};

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(__bit_reference<_Cp> __x, __bit_reference<_Cp> __y) _NOEXCEPT
{
    bool __t = __x;
    __x = __y;
    __y = __t;
}

template <class _Cp, class _Dp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(__bit_reference<_Cp> __x, __bit_reference<_Dp> __y) _NOEXCEPT
{
    bool __t = __x;
    __x = __y;
    __y = __t;
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(__bit_reference<_Cp> __x, bool& __y) _NOEXCEPT
{
    bool __t = __x;
    __x = __y;
    __y = __t;
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(bool& __x, __bit_reference<_Cp> __y) _NOEXCEPT
{
    bool __t = __x;
    __x = __y;
    __y = __t;
}

template <class _Cp>
class __bit_const_reference
{
    typedef typename _Cp::__storage_type          __storage_type;
    typedef typename _Cp::__const_storage_pointer __storage_pointer;

    __storage_pointer        __seg_;
    __storage_type __mask_;

    friend typename _Cp::__self;
    friend class __bit_iterator<_Cp, true>;
public:
    _LIBCPP_INLINE_VISIBILITY
    __bit_const_reference(const __bit_const_reference&) = default;

    _LIBCPP_INLINE_VISIBILITY
    __bit_const_reference(const __bit_reference<_Cp>& __x) _NOEXCEPT
        : __seg_(__x.__seg_), __mask_(__x.__mask_) {}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR operator bool() const _NOEXCEPT
        {return static_cast<bool>(*__seg_ & __mask_);}

    _LIBCPP_INLINE_VISIBILITY __bit_iterator<_Cp, true> operator&() const _NOEXCEPT
        {return __bit_iterator<_Cp, true>(__seg_, static_cast<unsigned>(__libcpp_ctz(__mask_)));}
private:
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR
    __bit_const_reference(__storage_pointer __s, __storage_type __m) _NOEXCEPT
        : __seg_(__s), __mask_(__m) {}

    __bit_const_reference& operator=(const __bit_const_reference&) = delete;
};

// find

template <class _Cp, bool _IsConst>
__bit_iterator<_Cp, _IsConst>
__find_bool_true(__bit_iterator<_Cp, _IsConst> __first, typename _Cp::size_type __n)
{
    typedef __bit_iterator<_Cp, _IsConst> _It;
    typedef typename _It::__storage_type __storage_type;
    static const int __bits_per_word = _It::__bits_per_word;
    // do first partial word
    if (__first.__ctz_ != 0)
    {
        __storage_type __clz_f = static_cast<__storage_type>(__bits_per_word - __first.__ctz_);
        __storage_type __dn = _VSTD::min(__clz_f, __n);
        __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
        __storage_type __b = *__first.__seg_ & __m;
        if (__b)
            return _It(__first.__seg_, static_cast<unsigned>(_VSTD::__libcpp_ctz(__b)));
        if (__n == __dn)
            return __first + __n;
        __n -= __dn;
        ++__first.__seg_;
    }
    // do middle whole words
    for (; __n >= __bits_per_word; ++__first.__seg_, __n -= __bits_per_word)
        if (*__first.__seg_)
            return _It(__first.__seg_, static_cast<unsigned>(_VSTD::__libcpp_ctz(*__first.__seg_)));
    // do last partial word
    if (__n > 0)
    {
        __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
        __storage_type __b = *__first.__seg_ & __m;
        if (__b)
            return _It(__first.__seg_, static_cast<unsigned>(_VSTD::__libcpp_ctz(__b)));
    }
    return _It(__first.__seg_, static_cast<unsigned>(__n));
}

template <class _Cp, bool _IsConst>
__bit_iterator<_Cp, _IsConst>
__find_bool_false(__bit_iterator<_Cp, _IsConst> __first, typename _Cp::size_type __n)
{
    typedef __bit_iterator<_Cp, _IsConst> _It;
    typedef typename _It::__storage_type __storage_type;
    const int __bits_per_word = _It::__bits_per_word;
    // do first partial word
    if (__first.__ctz_ != 0)
    {
        __storage_type __clz_f = static_cast<__storage_type>(__bits_per_word - __first.__ctz_);
        __storage_type __dn = _VSTD::min(__clz_f, __n);
        __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
        __storage_type __b = ~*__first.__seg_ & __m;
        if (__b)
            return _It(__first.__seg_, static_cast<unsigned>(_VSTD::__libcpp_ctz(__b)));
        if (__n == __dn)
            return __first + __n;
        __n -= __dn;
        ++__first.__seg_;
    }
    // do middle whole words
    for (; __n >= __bits_per_word; ++__first.__seg_, __n -= __bits_per_word)
    {
        __storage_type __b = ~*__first.__seg_;
        if (__b)
            return _It(__first.__seg_, static_cast<unsigned>(_VSTD::__libcpp_ctz(__b)));
    }
    // do last partial word
    if (__n > 0)
    {
        __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
        __storage_type __b = ~*__first.__seg_ & __m;
        if (__b)
            return _It(__first.__seg_, static_cast<unsigned>(_VSTD::__libcpp_ctz(__b)));
    }
    return _It(__first.__seg_, static_cast<unsigned>(__n));
}

template <class _Cp, bool _IsConst, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__bit_iterator<_Cp, _IsConst>
find(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last, const _Tp& __value_)
{
    if (static_cast<bool>(__value_))
        return __find_bool_true(__first, static_cast<typename _Cp::size_type>(__last - __first));
    return __find_bool_false(__first, static_cast<typename _Cp::size_type>(__last - __first));
}

// count

template <class _Cp, bool _IsConst>
typename __bit_iterator<_Cp, _IsConst>::difference_type
__count_bool_true(__bit_iterator<_Cp, _IsConst> __first, typename _Cp::size_type __n)
{
    typedef __bit_iterator<_Cp, _IsConst> _It;
    typedef typename _It::__storage_type __storage_type;
    typedef typename _It::difference_type difference_type;
    const int __bits_per_word = _It::__bits_per_word;
    difference_type __r = 0;
    // do first partial word
    if (__first.__ctz_ != 0)
    {
        __storage_type __clz_f = static_cast<__storage_type>(__bits_per_word - __first.__ctz_);
        __storage_type __dn = _VSTD::min(__clz_f, __n);
        __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
        __r = _VSTD::__libcpp_popcount(*__first.__seg_ & __m);
        __n -= __dn;
        ++__first.__seg_;
    }
    // do middle whole words
    for (; __n >= __bits_per_word; ++__first.__seg_, __n -= __bits_per_word)
        __r += _VSTD::__libcpp_popcount(*__first.__seg_);
    // do last partial word
    if (__n > 0)
    {
        __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
        __r += _VSTD::__libcpp_popcount(*__first.__seg_ & __m);
    }
    return __r;
}

template <class _Cp, bool _IsConst>
typename __bit_iterator<_Cp, _IsConst>::difference_type
__count_bool_false(__bit_iterator<_Cp, _IsConst> __first, typename _Cp::size_type __n)
{
    typedef __bit_iterator<_Cp, _IsConst> _It;
    typedef typename _It::__storage_type __storage_type;
    typedef typename _It::difference_type difference_type;
    const int __bits_per_word = _It::__bits_per_word;
    difference_type __r = 0;
    // do first partial word
    if (__first.__ctz_ != 0)
    {
        __storage_type __clz_f = static_cast<__storage_type>(__bits_per_word - __first.__ctz_);
        __storage_type __dn = _VSTD::min(__clz_f, __n);
        __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
        __r = _VSTD::__libcpp_popcount(~*__first.__seg_ & __m);
        __n -= __dn;
        ++__first.__seg_;
    }
    // do middle whole words
    for (; __n >= __bits_per_word; ++__first.__seg_, __n -= __bits_per_word)
        __r += _VSTD::__libcpp_popcount(~*__first.__seg_);
    // do last partial word
    if (__n > 0)
    {
        __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
        __r += _VSTD::__libcpp_popcount(~*__first.__seg_ & __m);
    }
    return __r;
}

template <class _Cp, bool _IsConst, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename __bit_iterator<_Cp, _IsConst>::difference_type
count(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last, const _Tp& __value_)
{
    if (static_cast<bool>(__value_))
        return __count_bool_true(__first, static_cast<typename _Cp::size_type>(__last - __first));
    return __count_bool_false(__first, static_cast<typename _Cp::size_type>(__last - __first));
}

// fill_n

template <class _Cp>
void
__fill_n_false(__bit_iterator<_Cp, false> __first, typename _Cp::size_type __n)
{
    typedef __bit_iterator<_Cp, false> _It;
    typedef typename _It::__storage_type __storage_type;
    const int __bits_per_word = _It::__bits_per_word;
    // do first partial word
    if (__first.__ctz_ != 0)
    {
        __storage_type __clz_f = static_cast<__storage_type>(__bits_per_word - __first.__ctz_);
        __storage_type __dn = _VSTD::min(__clz_f, __n);
        __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
        *__first.__seg_ &= ~__m;
        __n -= __dn;
        ++__first.__seg_;
    }
    // do middle whole words
    __storage_type __nw = __n / __bits_per_word;
    _VSTD::memset(_VSTD::__to_address(__first.__seg_), 0, __nw * sizeof(__storage_type));
    __n -= __nw * __bits_per_word;
    // do last partial word
    if (__n > 0)
    {
        __first.__seg_ += __nw;
        __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
        *__first.__seg_ &= ~__m;
    }
}

template <class _Cp>
void
__fill_n_true(__bit_iterator<_Cp, false> __first, typename _Cp::size_type __n)
{
    typedef __bit_iterator<_Cp, false> _It;
    typedef typename _It::__storage_type __storage_type;
    const int __bits_per_word = _It::__bits_per_word;
    // do first partial word
    if (__first.__ctz_ != 0)
    {
        __storage_type __clz_f = static_cast<__storage_type>(__bits_per_word - __first.__ctz_);
        __storage_type __dn = _VSTD::min(__clz_f, __n);
        __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
        *__first.__seg_ |= __m;
        __n -= __dn;
        ++__first.__seg_;
    }
    // do middle whole words
    __storage_type __nw = __n / __bits_per_word;
    _VSTD::memset(_VSTD::__to_address(__first.__seg_), -1, __nw * sizeof(__storage_type));
    __n -= __nw * __bits_per_word;
    // do last partial word
    if (__n > 0)
    {
        __first.__seg_ += __nw;
        __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
        *__first.__seg_ |= __m;
    }
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
void
fill_n(__bit_iterator<_Cp, false> __first, typename _Cp::size_type __n, bool __value_)
{
    if (__n > 0)
    {
        if (__value_)
            __fill_n_true(__first, __n);
        else
            __fill_n_false(__first, __n);
    }
}

// fill

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
void
fill(__bit_iterator<_Cp, false> __first, __bit_iterator<_Cp, false> __last, bool __value_)
{
    _VSTD::fill_n(__first, static_cast<typename _Cp::size_type>(__last - __first), __value_);
}

// copy

template <class _Cp, bool _IsConst>
__bit_iterator<_Cp, false>
__copy_aligned(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last,
                                                     __bit_iterator<_Cp, false> __result)
{
    typedef __bit_iterator<_Cp, _IsConst> _In;
    typedef  typename _In::difference_type difference_type;
    typedef typename _In::__storage_type __storage_type;
    const int __bits_per_word = _In::__bits_per_word;
    difference_type __n = __last - __first;
    if (__n > 0)
    {
        // do first word
        if (__first.__ctz_ != 0)
        {
            unsigned __clz = __bits_per_word - __first.__ctz_;
            difference_type __dn = _VSTD::min(static_cast<difference_type>(__clz), __n);
            __n -= __dn;
            __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz - __dn));
            __storage_type __b = *__first.__seg_ & __m;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b;
            __result.__seg_ += (__dn + __result.__ctz_) / __bits_per_word;
            __result.__ctz_ = static_cast<unsigned>((__dn + __result.__ctz_)  % __bits_per_word);
            ++__first.__seg_;
            // __first.__ctz_ = 0;
        }
        // __first.__ctz_ == 0;
        // do middle words
        __storage_type __nw = __n / __bits_per_word;
        _VSTD::memmove(_VSTD::__to_address(__result.__seg_),
                       _VSTD::__to_address(__first.__seg_),
                       __nw * sizeof(__storage_type));
        __n -= __nw * __bits_per_word;
        __result.__seg_ += __nw;
        // do last word
        if (__n > 0)
        {
            __first.__seg_ += __nw;
            __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
            __storage_type __b = *__first.__seg_ & __m;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b;
            __result.__ctz_ = static_cast<unsigned>(__n);
        }
    }
    return __result;
}

template <class _Cp, bool _IsConst>
__bit_iterator<_Cp, false>
__copy_unaligned(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last,
                                                       __bit_iterator<_Cp, false> __result)
{
    typedef __bit_iterator<_Cp, _IsConst> _In;
    typedef  typename _In::difference_type difference_type;
    typedef typename _In::__storage_type __storage_type;
    static const int __bits_per_word = _In::__bits_per_word;
    difference_type __n = __last - __first;
    if (__n > 0)
    {
        // do first word
        if (__first.__ctz_ != 0)
        {
            unsigned __clz_f = __bits_per_word - __first.__ctz_;
            difference_type __dn = _VSTD::min(static_cast<difference_type>(__clz_f), __n);
            __n -= __dn;
            __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
            __storage_type __b = *__first.__seg_ & __m;
            unsigned __clz_r = __bits_per_word - __result.__ctz_;
            __storage_type __ddn = _VSTD::min<__storage_type>(__dn, __clz_r);
            __m = (~__storage_type(0) << __result.__ctz_) & (~__storage_type(0) >> (__clz_r - __ddn));
            *__result.__seg_ &= ~__m;
            if (__result.__ctz_ > __first.__ctz_)
                *__result.__seg_ |= __b << (__result.__ctz_ - __first.__ctz_);
            else
                *__result.__seg_ |= __b >> (__first.__ctz_ - __result.__ctz_);
            __result.__seg_ += (__ddn + __result.__ctz_) / __bits_per_word;
            __result.__ctz_ = static_cast<unsigned>((__ddn + __result.__ctz_)  % __bits_per_word);
            __dn -= __ddn;
            if (__dn > 0)
            {
                __m = ~__storage_type(0) >> (__bits_per_word - __dn);
                *__result.__seg_ &= ~__m;
                *__result.__seg_ |= __b >> (__first.__ctz_ + __ddn);
                __result.__ctz_ = static_cast<unsigned>(__dn);
            }
            ++__first.__seg_;
            // __first.__ctz_ = 0;
        }
        // __first.__ctz_ == 0;
        // do middle words
        unsigned __clz_r = __bits_per_word - __result.__ctz_;
        __storage_type __m = ~__storage_type(0) << __result.__ctz_;
        for (; __n >= __bits_per_word; __n -= __bits_per_word, ++__first.__seg_)
        {
            __storage_type __b = *__first.__seg_;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b << __result.__ctz_;
            ++__result.__seg_;
            *__result.__seg_ &= __m;
            *__result.__seg_ |= __b >> __clz_r;
        }
        // do last word
        if (__n > 0)
        {
            __m = ~__storage_type(0) >> (__bits_per_word - __n);
            __storage_type __b = *__first.__seg_ & __m;
            __storage_type __dn = _VSTD::min(__n, static_cast<difference_type>(__clz_r));
            __m = (~__storage_type(0) << __result.__ctz_) & (~__storage_type(0) >> (__clz_r - __dn));
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b << __result.__ctz_;
            __result.__seg_ += (__dn + __result.__ctz_) / __bits_per_word;
            __result.__ctz_ = static_cast<unsigned>((__dn + __result.__ctz_)  % __bits_per_word);
            __n -= __dn;
            if (__n > 0)
            {
                __m = ~__storage_type(0) >> (__bits_per_word - __n);
                *__result.__seg_ &= ~__m;
                *__result.__seg_ |= __b >> __dn;
                __result.__ctz_ = static_cast<unsigned>(__n);
            }
        }
    }
    return __result;
}

template <class _Cp, bool _IsConst>
inline _LIBCPP_INLINE_VISIBILITY
__bit_iterator<_Cp, false>
copy(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last, __bit_iterator<_Cp, false> __result)
{
    if (__first.__ctz_ == __result.__ctz_)
        return __copy_aligned(__first, __last, __result);
    return __copy_unaligned(__first, __last, __result);
}

// copy_backward

template <class _Cp, bool _IsConst>
__bit_iterator<_Cp, false>
__copy_backward_aligned(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last,
                                                     __bit_iterator<_Cp, false> __result)
{
    typedef __bit_iterator<_Cp, _IsConst> _In;
    typedef  typename _In::difference_type difference_type;
    typedef typename _In::__storage_type __storage_type;
    const int __bits_per_word = _In::__bits_per_word;
    difference_type __n = __last - __first;
    if (__n > 0)
    {
        // do first word
        if (__last.__ctz_ != 0)
        {
            difference_type __dn = _VSTD::min(static_cast<difference_type>(__last.__ctz_), __n);
            __n -= __dn;
            unsigned __clz = __bits_per_word - __last.__ctz_;
            __storage_type __m = (~__storage_type(0) << (__last.__ctz_ - __dn)) & (~__storage_type(0) >> __clz);
            __storage_type __b = *__last.__seg_ & __m;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b;
            __result.__ctz_ = static_cast<unsigned>(((-__dn & (__bits_per_word - 1)) +
                                                       __result.__ctz_)  % __bits_per_word);
            // __last.__ctz_ = 0
         }
        // __last.__ctz_ == 0 || __n == 0
        // __result.__ctz_ == 0 || __n == 0
        // do middle words
        __storage_type __nw = __n / __bits_per_word;
        __result.__seg_ -= __nw;
        __last.__seg_ -= __nw;
        _VSTD::memmove(_VSTD::__to_address(__result.__seg_),
                       _VSTD::__to_address(__last.__seg_),
                       __nw * sizeof(__storage_type));
        __n -= __nw * __bits_per_word;
        // do last word
        if (__n > 0)
        {
            __storage_type __m = ~__storage_type(0) << (__bits_per_word - __n);
            __storage_type __b = *--__last.__seg_ & __m;
            *--__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b;
            __result.__ctz_ = static_cast<unsigned>(-__n & (__bits_per_word - 1));
        }
    }
    return __result;
}

template <class _Cp, bool _IsConst>
__bit_iterator<_Cp, false>
__copy_backward_unaligned(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last,
                                                       __bit_iterator<_Cp, false> __result)
{
    typedef __bit_iterator<_Cp, _IsConst> _In;
    typedef  typename _In::difference_type difference_type;
    typedef typename _In::__storage_type __storage_type;
    const int __bits_per_word = _In::__bits_per_word;
    difference_type __n = __last - __first;
    if (__n > 0)
    {
        // do first word
        if (__last.__ctz_ != 0)
        {
            difference_type __dn = _VSTD::min(static_cast<difference_type>(__last.__ctz_), __n);
            __n -= __dn;
            unsigned __clz_l = __bits_per_word - __last.__ctz_;
            __storage_type __m = (~__storage_type(0) << (__last.__ctz_ - __dn)) & (~__storage_type(0) >> __clz_l);
            __storage_type __b = *__last.__seg_ & __m;
            unsigned __clz_r = __bits_per_word - __result.__ctz_;
            __storage_type __ddn = _VSTD::min(__dn, static_cast<difference_type>(__result.__ctz_));
            if (__ddn > 0)
            {
                __m = (~__storage_type(0) << (__result.__ctz_ - __ddn)) & (~__storage_type(0) >> __clz_r);
                *__result.__seg_ &= ~__m;
                if (__result.__ctz_ > __last.__ctz_)
                    *__result.__seg_ |= __b << (__result.__ctz_ - __last.__ctz_);
                else
                    *__result.__seg_ |= __b >> (__last.__ctz_ - __result.__ctz_);
                __result.__ctz_ = static_cast<unsigned>(((-__ddn & (__bits_per_word - 1)) +
                                                         __result.__ctz_)  % __bits_per_word);
                __dn -= __ddn;
            }
            if (__dn > 0)
            {
                // __result.__ctz_ == 0
                --__result.__seg_;
                __result.__ctz_ = static_cast<unsigned>(-__dn & (__bits_per_word - 1));
                __m = ~__storage_type(0) << __result.__ctz_;
                *__result.__seg_ &= ~__m;
                __last.__ctz_ -= __dn + __ddn;
                *__result.__seg_ |= __b << (__result.__ctz_ - __last.__ctz_);
            }
            // __last.__ctz_ = 0
         }
        // __last.__ctz_ == 0 || __n == 0
        // __result.__ctz_ != 0 || __n == 0
        // do middle words
        unsigned __clz_r = __bits_per_word - __result.__ctz_;
        __storage_type __m = ~__storage_type(0) >> __clz_r;
        for (; __n >= __bits_per_word; __n -= __bits_per_word)
        {
            __storage_type __b = *--__last.__seg_;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b >> __clz_r;
            *--__result.__seg_ &= __m;
            *__result.__seg_ |= __b << __result.__ctz_;
        }
        // do last word
        if (__n > 0)
        {
            __m = ~__storage_type(0) << (__bits_per_word - __n);
            __storage_type __b = *--__last.__seg_ & __m;
            __clz_r = __bits_per_word - __result.__ctz_;
            __storage_type __dn = _VSTD::min(__n, static_cast<difference_type>(__result.__ctz_));
            __m = (~__storage_type(0) << (__result.__ctz_ - __dn)) & (~__storage_type(0) >> __clz_r);
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b >> (__bits_per_word - __result.__ctz_);
            __result.__ctz_ = static_cast<unsigned>(((-__dn & (__bits_per_word - 1)) +
                                                     __result.__ctz_)  % __bits_per_word);
            __n -= __dn;
            if (__n > 0)
            {
                // __result.__ctz_ == 0
                --__result.__seg_;
                __result.__ctz_ = static_cast<unsigned>(-__n & (__bits_per_word - 1));
                __m = ~__storage_type(0) << __result.__ctz_;
                *__result.__seg_ &= ~__m;
                *__result.__seg_ |= __b << (__result.__ctz_ - (__bits_per_word - __n - __dn));
            }
        }
    }
    return __result;
}

template <class _Cp, bool _IsConst>
inline _LIBCPP_INLINE_VISIBILITY
__bit_iterator<_Cp, false>
copy_backward(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last, __bit_iterator<_Cp, false> __result)
{
    if (__last.__ctz_ == __result.__ctz_)
        return __copy_backward_aligned(__first, __last, __result);
    return __copy_backward_unaligned(__first, __last, __result);
}

// move

template <class _Cp, bool _IsConst>
inline _LIBCPP_INLINE_VISIBILITY
__bit_iterator<_Cp, false>
move(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last, __bit_iterator<_Cp, false> __result)
{
    return _VSTD::copy(__first, __last, __result);
}

// move_backward

template <class _Cp, bool _IsConst>
inline _LIBCPP_INLINE_VISIBILITY
__bit_iterator<_Cp, false>
move_backward(__bit_iterator<_Cp, _IsConst> __first, __bit_iterator<_Cp, _IsConst> __last, __bit_iterator<_Cp, false> __result)
{
    return _VSTD::copy_backward(__first, __last, __result);
}

// swap_ranges

template <class __C1, class __C2>
__bit_iterator<__C2, false>
__swap_ranges_aligned(__bit_iterator<__C1, false> __first, __bit_iterator<__C1, false> __last,
                      __bit_iterator<__C2, false> __result)
{
    typedef __bit_iterator<__C1, false> _I1;
    typedef  typename _I1::difference_type difference_type;
    typedef typename _I1::__storage_type __storage_type;
    const int __bits_per_word = _I1::__bits_per_word;
    difference_type __n = __last - __first;
    if (__n > 0)
    {
        // do first word
        if (__first.__ctz_ != 0)
        {
            unsigned __clz = __bits_per_word - __first.__ctz_;
            difference_type __dn = _VSTD::min(static_cast<difference_type>(__clz), __n);
            __n -= __dn;
            __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz - __dn));
            __storage_type __b1 = *__first.__seg_ & __m;
            *__first.__seg_ &= ~__m;
            __storage_type __b2 = *__result.__seg_ & __m;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b1;
            *__first.__seg_  |= __b2;
            __result.__seg_ += (__dn + __result.__ctz_) / __bits_per_word;
            __result.__ctz_ = static_cast<unsigned>((__dn + __result.__ctz_)  % __bits_per_word);
            ++__first.__seg_;
            // __first.__ctz_ = 0;
        }
        // __first.__ctz_ == 0;
        // do middle words
        for (; __n >= __bits_per_word; __n -= __bits_per_word, ++__first.__seg_, ++__result.__seg_)
            swap(*__first.__seg_, *__result.__seg_);
        // do last word
        if (__n > 0)
        {
            __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
            __storage_type __b1 = *__first.__seg_ & __m;
            *__first.__seg_ &= ~__m;
            __storage_type __b2 = *__result.__seg_ & __m;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b1;
            *__first.__seg_  |= __b2;
            __result.__ctz_ = static_cast<unsigned>(__n);
        }
    }
    return __result;
}

template <class __C1, class __C2>
__bit_iterator<__C2, false>
__swap_ranges_unaligned(__bit_iterator<__C1, false> __first, __bit_iterator<__C1, false> __last,
                        __bit_iterator<__C2, false> __result)
{
    typedef __bit_iterator<__C1, false> _I1;
    typedef  typename _I1::difference_type difference_type;
    typedef typename _I1::__storage_type __storage_type;
    const int __bits_per_word = _I1::__bits_per_word;
    difference_type __n = __last - __first;
    if (__n > 0)
    {
        // do first word
        if (__first.__ctz_ != 0)
        {
            unsigned __clz_f = __bits_per_word - __first.__ctz_;
            difference_type __dn = _VSTD::min(static_cast<difference_type>(__clz_f), __n);
            __n -= __dn;
            __storage_type __m = (~__storage_type(0) << __first.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
            __storage_type __b1 = *__first.__seg_ & __m;
            *__first.__seg_ &= ~__m;
            unsigned __clz_r = __bits_per_word - __result.__ctz_;
            __storage_type __ddn = _VSTD::min<__storage_type>(__dn, __clz_r);
            __m = (~__storage_type(0) << __result.__ctz_) & (~__storage_type(0) >> (__clz_r - __ddn));
            __storage_type __b2 = *__result.__seg_ & __m;
            *__result.__seg_ &= ~__m;
            if (__result.__ctz_ > __first.__ctz_)
            {
                unsigned __s = __result.__ctz_ - __first.__ctz_;
                *__result.__seg_ |= __b1 << __s;
                *__first.__seg_  |= __b2 >> __s;
            }
            else
            {
                unsigned __s = __first.__ctz_ - __result.__ctz_;
                *__result.__seg_ |= __b1 >> __s;
                *__first.__seg_  |= __b2 << __s;
            }
            __result.__seg_ += (__ddn + __result.__ctz_) / __bits_per_word;
            __result.__ctz_ = static_cast<unsigned>((__ddn + __result.__ctz_)  % __bits_per_word);
            __dn -= __ddn;
            if (__dn > 0)
            {
                __m = ~__storage_type(0) >> (__bits_per_word - __dn);
                __b2 = *__result.__seg_ & __m;
                *__result.__seg_ &= ~__m;
                unsigned __s = __first.__ctz_ + __ddn;
                *__result.__seg_ |= __b1 >> __s;
                *__first.__seg_  |= __b2 << __s;
                __result.__ctz_ = static_cast<unsigned>(__dn);
            }
            ++__first.__seg_;
            // __first.__ctz_ = 0;
        }
        // __first.__ctz_ == 0;
        // do middle words
        __storage_type __m = ~__storage_type(0) << __result.__ctz_;
        unsigned __clz_r = __bits_per_word - __result.__ctz_;
        for (; __n >= __bits_per_word; __n -= __bits_per_word, ++__first.__seg_)
        {
            __storage_type __b1 = *__first.__seg_;
            __storage_type __b2 = *__result.__seg_ & __m;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b1 << __result.__ctz_;
            *__first.__seg_  = __b2 >> __result.__ctz_;
            ++__result.__seg_;
            __b2 = *__result.__seg_ & ~__m;
            *__result.__seg_ &= __m;
            *__result.__seg_ |= __b1 >> __clz_r;
            *__first.__seg_  |= __b2 << __clz_r;
        }
        // do last word
        if (__n > 0)
        {
            __m = ~__storage_type(0) >> (__bits_per_word - __n);
            __storage_type __b1 = *__first.__seg_ & __m;
            *__first.__seg_ &= ~__m;
            __storage_type __dn = _VSTD::min<__storage_type>(__n, __clz_r);
            __m = (~__storage_type(0) << __result.__ctz_) & (~__storage_type(0) >> (__clz_r - __dn));
            __storage_type __b2 = *__result.__seg_ & __m;
            *__result.__seg_ &= ~__m;
            *__result.__seg_ |= __b1 << __result.__ctz_;
            *__first.__seg_  |= __b2 >> __result.__ctz_;
            __result.__seg_ += (__dn + __result.__ctz_) / __bits_per_word;
            __result.__ctz_ = static_cast<unsigned>((__dn + __result.__ctz_)  % __bits_per_word);
            __n -= __dn;
            if (__n > 0)
            {
                __m = ~__storage_type(0) >> (__bits_per_word - __n);
                __b2 = *__result.__seg_ & __m;
                *__result.__seg_ &= ~__m;
                *__result.__seg_ |= __b1 >> __dn;
                *__first.__seg_  |= __b2 << __dn;
                __result.__ctz_ = static_cast<unsigned>(__n);
            }
        }
    }
    return __result;
}

template <class __C1, class __C2>
inline _LIBCPP_INLINE_VISIBILITY
__bit_iterator<__C2, false>
swap_ranges(__bit_iterator<__C1, false> __first1, __bit_iterator<__C1, false> __last1,
            __bit_iterator<__C2, false> __first2)
{
    if (__first1.__ctz_ == __first2.__ctz_)
        return __swap_ranges_aligned(__first1, __last1, __first2);
    return __swap_ranges_unaligned(__first1, __last1, __first2);
}

// rotate

template <class _Cp>
struct __bit_array
{
    typedef typename _Cp::difference_type difference_type;
    typedef typename _Cp::__storage_type  __storage_type;
    typedef typename _Cp::__storage_pointer __storage_pointer;
    typedef typename _Cp::iterator        iterator;
    static const unsigned __bits_per_word = _Cp::__bits_per_word;
    static const unsigned _Np = 4;

    difference_type __size_;
    __storage_type __word_[_Np];

    _LIBCPP_INLINE_VISIBILITY static difference_type capacity()
        {return static_cast<difference_type>(_Np * __bits_per_word);}
    _LIBCPP_INLINE_VISIBILITY explicit __bit_array(difference_type __s) : __size_(__s) {}
    _LIBCPP_INLINE_VISIBILITY iterator begin()
    {
        return iterator(pointer_traits<__storage_pointer>::pointer_to(__word_[0]), 0);
    }
    _LIBCPP_INLINE_VISIBILITY iterator end()
    {
        return iterator(pointer_traits<__storage_pointer>::pointer_to(__word_[0]) + __size_ / __bits_per_word,
                                                  static_cast<unsigned>(__size_ % __bits_per_word));
    }
};

template <class _Cp>
__bit_iterator<_Cp, false>
rotate(__bit_iterator<_Cp, false> __first, __bit_iterator<_Cp, false> __middle, __bit_iterator<_Cp, false> __last)
{
    typedef __bit_iterator<_Cp, false> _I1;
    typedef  typename _I1::difference_type difference_type;
    difference_type __d1 = __middle - __first;
    difference_type __d2 = __last - __middle;
    _I1 __r = __first + __d2;
    while (__d1 != 0 && __d2 != 0)
    {
        if (__d1 <= __d2)
        {
            if (__d1 <= __bit_array<_Cp>::capacity())
            {
                __bit_array<_Cp> __b(__d1);
                _VSTD::copy(__first, __middle, __b.begin());
                _VSTD::copy(__b.begin(), __b.end(), _VSTD::copy(__middle, __last, __first));
                break;
            }
            else
            {
                __bit_iterator<_Cp, false> __mp = _VSTD::swap_ranges(__first, __middle, __middle);
                __first = __middle;
                __middle = __mp;
                __d2 -= __d1;
            }
        }
        else
        {
            if (__d2 <= __bit_array<_Cp>::capacity())
            {
                __bit_array<_Cp> __b(__d2);
                _VSTD::copy(__middle, __last, __b.begin());
                _VSTD::copy_backward(__b.begin(), __b.end(), _VSTD::copy_backward(__first, __middle, __last));
                break;
            }
            else
            {
                __bit_iterator<_Cp, false> __mp = __first + __d2;
                _VSTD::swap_ranges(__first, __mp, __middle);
                __first = __mp;
                __d1 -= __d2;
            }
        }
    }
    return __r;
}

// equal

template <class _Cp, bool _IC1, bool _IC2>
bool
__equal_unaligned(__bit_iterator<_Cp, _IC1> __first1, __bit_iterator<_Cp, _IC1> __last1,
                  __bit_iterator<_Cp, _IC2> __first2)
{
    typedef __bit_iterator<_Cp, _IC1> _It;
    typedef  typename _It::difference_type difference_type;
    typedef typename _It::__storage_type __storage_type;
    static const int __bits_per_word = _It::__bits_per_word;
    difference_type __n = __last1 - __first1;
    if (__n > 0)
    {
        // do first word
        if (__first1.__ctz_ != 0)
        {
            unsigned __clz_f = __bits_per_word - __first1.__ctz_;
            difference_type __dn = _VSTD::min(static_cast<difference_type>(__clz_f), __n);
            __n -= __dn;
            __storage_type __m = (~__storage_type(0) << __first1.__ctz_) & (~__storage_type(0) >> (__clz_f - __dn));
            __storage_type __b = *__first1.__seg_ & __m;
            unsigned __clz_r = __bits_per_word - __first2.__ctz_;
            __storage_type __ddn = _VSTD::min<__storage_type>(__dn, __clz_r);
            __m = (~__storage_type(0) << __first2.__ctz_) & (~__storage_type(0) >> (__clz_r - __ddn));
            if (__first2.__ctz_ > __first1.__ctz_)
            {
                if ((*__first2.__seg_ & __m) != (__b << (__first2.__ctz_ - __first1.__ctz_)))
                    return false;
            }
            else
            {
                if ((*__first2.__seg_ & __m) != (__b >> (__first1.__ctz_ - __first2.__ctz_)))
                    return false;
            }
            __first2.__seg_ += (__ddn + __first2.__ctz_) / __bits_per_word;
            __first2.__ctz_ = static_cast<unsigned>((__ddn + __first2.__ctz_)  % __bits_per_word);
            __dn -= __ddn;
            if (__dn > 0)
            {
                __m = ~__storage_type(0) >> (__bits_per_word - __dn);
                if ((*__first2.__seg_ & __m) != (__b >> (__first1.__ctz_ + __ddn)))
                    return false;
                __first2.__ctz_ = static_cast<unsigned>(__dn);
            }
            ++__first1.__seg_;
            // __first1.__ctz_ = 0;
        }
        // __first1.__ctz_ == 0;
        // do middle words
        unsigned __clz_r = __bits_per_word - __first2.__ctz_;
        __storage_type __m = ~__storage_type(0) << __first2.__ctz_;
        for (; __n >= __bits_per_word; __n -= __bits_per_word, ++__first1.__seg_)
        {
            __storage_type __b = *__first1.__seg_;
            if ((*__first2.__seg_ & __m) != (__b << __first2.__ctz_))
                return false;
            ++__first2.__seg_;
            if ((*__first2.__seg_ & ~__m) != (__b >> __clz_r))
                return false;
        }
        // do last word
        if (__n > 0)
        {
            __m = ~__storage_type(0) >> (__bits_per_word - __n);
            __storage_type __b = *__first1.__seg_ & __m;
            __storage_type __dn = _VSTD::min(__n, static_cast<difference_type>(__clz_r));
            __m = (~__storage_type(0) << __first2.__ctz_) & (~__storage_type(0) >> (__clz_r - __dn));
            if ((*__first2.__seg_ & __m) != (__b << __first2.__ctz_))
                return false;
            __first2.__seg_ += (__dn + __first2.__ctz_) / __bits_per_word;
            __first2.__ctz_ = static_cast<unsigned>((__dn + __first2.__ctz_)  % __bits_per_word);
            __n -= __dn;
            if (__n > 0)
            {
                __m = ~__storage_type(0) >> (__bits_per_word - __n);
                if ((*__first2.__seg_ & __m) != (__b >> __dn))
                    return false;
            }
        }
    }
    return true;
}

template <class _Cp, bool _IC1, bool _IC2>
bool
__equal_aligned(__bit_iterator<_Cp, _IC1> __first1, __bit_iterator<_Cp, _IC1> __last1,
                __bit_iterator<_Cp, _IC2> __first2)
{
    typedef __bit_iterator<_Cp, _IC1> _It;
    typedef  typename _It::difference_type difference_type;
    typedef typename _It::__storage_type __storage_type;
    static const int __bits_per_word = _It::__bits_per_word;
    difference_type __n = __last1 - __first1;
    if (__n > 0)
    {
        // do first word
        if (__first1.__ctz_ != 0)
        {
            unsigned __clz = __bits_per_word - __first1.__ctz_;
            difference_type __dn = _VSTD::min(static_cast<difference_type>(__clz), __n);
            __n -= __dn;
            __storage_type __m = (~__storage_type(0) << __first1.__ctz_) & (~__storage_type(0) >> (__clz - __dn));
            if ((*__first2.__seg_ & __m) != (*__first1.__seg_ & __m))
                return false;
            ++__first2.__seg_;
            ++__first1.__seg_;
            // __first1.__ctz_ = 0;
            // __first2.__ctz_ = 0;
        }
        // __first1.__ctz_ == 0;
        // __first2.__ctz_ == 0;
        // do middle words
        for (; __n >= __bits_per_word; __n -= __bits_per_word, ++__first1.__seg_, ++__first2.__seg_)
            if (*__first2.__seg_ != *__first1.__seg_)
                return false;
        // do last word
        if (__n > 0)
        {
            __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
            if ((*__first2.__seg_ & __m) != (*__first1.__seg_ & __m))
                return false;
        }
    }
    return true;
}

template <class _Cp, bool _IC1, bool _IC2>
inline _LIBCPP_INLINE_VISIBILITY
bool
equal(__bit_iterator<_Cp, _IC1> __first1, __bit_iterator<_Cp, _IC1> __last1, __bit_iterator<_Cp, _IC2> __first2)
{
    if (__first1.__ctz_ == __first2.__ctz_)
        return __equal_aligned(__first1, __last1, __first2);
    return __equal_unaligned(__first1, __last1, __first2);
}

template <class _Cp, bool _IsConst,
          typename _Cp::__storage_type>
class __bit_iterator
{
public:
    typedef typename _Cp::difference_type                                                          difference_type;
    typedef bool                                                                                  value_type;
    typedef __bit_iterator                                                                        pointer;
    typedef typename conditional<_IsConst, __bit_const_reference<_Cp>, __bit_reference<_Cp> >::type reference;
    typedef random_access_iterator_tag                                                            iterator_category;

private:
    typedef typename _Cp::__storage_type                                           __storage_type;
    typedef typename conditional<_IsConst, typename _Cp::__const_storage_pointer,
                                           typename _Cp::__storage_pointer>::type  __storage_pointer;
    static const unsigned __bits_per_word = _Cp::__bits_per_word;

    __storage_pointer __seg_;
    unsigned          __ctz_;

public:
    _LIBCPP_INLINE_VISIBILITY __bit_iterator() _NOEXCEPT
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1113 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
    : __seg_(nullptr), __ctz_(0)
#endif
# 1115 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
    {}

    // avoid re-declaring a copy constructor for the non-const version.
    using __type_for_copy_to_const =
      _If<_IsConst, __bit_iterator<_Cp, false>, struct __private_nat>;

    _LIBCPP_INLINE_VISIBILITY
    __bit_iterator(const __type_for_copy_to_const& __it) _NOEXCEPT
        : __seg_(__it.__seg_), __ctz_(__it.__ctz_) {}

    _LIBCPP_INLINE_VISIBILITY reference operator*() const _NOEXCEPT
        {return reference(__seg_, __storage_type(1) << __ctz_);}

    _LIBCPP_INLINE_VISIBILITY __bit_iterator& operator++()
    {
        if (__ctz_ != __bits_per_word-1)
            ++__ctz_;
        else
        {
            __ctz_ = 0;
            ++__seg_;
        }
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY __bit_iterator operator++(int)
    {
        __bit_iterator __tmp = *this;
        ++(*this);
        return __tmp;
    }

    _LIBCPP_INLINE_VISIBILITY __bit_iterator& operator--()
    {
        if (__ctz_ != 0)
            --__ctz_;
        else
        {
            __ctz_ = __bits_per_word - 1;
            --__seg_;
        }
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY __bit_iterator operator--(int)
    {
        __bit_iterator __tmp = *this;
        --(*this);
        return __tmp;
    }

    _LIBCPP_INLINE_VISIBILITY __bit_iterator& operator+=(difference_type __n)
    {
        if (__n >= 0)
            __seg_ += (__n + __ctz_) / __bits_per_word;
        else
            __seg_ += static_cast<difference_type>(__n - __bits_per_word + __ctz_ + 1)
                    / static_cast<difference_type>(__bits_per_word);
        __n &= (__bits_per_word - 1);
        __ctz_ = static_cast<unsigned>((__n + __ctz_)  % __bits_per_word);
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY __bit_iterator& operator-=(difference_type __n)
    {
        return *this += -__n;
    }

    _LIBCPP_INLINE_VISIBILITY __bit_iterator operator+(difference_type __n) const
    {
        __bit_iterator __t(*this);
        __t += __n;
        return __t;
    }

    _LIBCPP_INLINE_VISIBILITY __bit_iterator operator-(difference_type __n) const
    {
        __bit_iterator __t(*this);
        __t -= __n;
        return __t;
    }

    _LIBCPP_INLINE_VISIBILITY
    friend __bit_iterator operator+(difference_type __n, const __bit_iterator& __it) {return __it + __n;}

    _LIBCPP_INLINE_VISIBILITY
    friend difference_type operator-(const __bit_iterator& __x, const __bit_iterator& __y)
        {return (__x.__seg_ - __y.__seg_) * __bits_per_word + __x.__ctz_ - __y.__ctz_;}

    _LIBCPP_INLINE_VISIBILITY reference operator[](difference_type __n) const {return *(*this + __n);}

    _LIBCPP_INLINE_VISIBILITY friend bool operator==(const __bit_iterator& __x, const __bit_iterator& __y)
        {return __x.__seg_ == __y.__seg_ && __x.__ctz_ == __y.__ctz_;}

    _LIBCPP_INLINE_VISIBILITY friend bool operator!=(const __bit_iterator& __x, const __bit_iterator& __y)
        {return !(__x == __y);}

    _LIBCPP_INLINE_VISIBILITY friend bool operator<(const __bit_iterator& __x, const __bit_iterator& __y)
        {return __x.__seg_ < __y.__seg_ || (__x.__seg_ == __y.__seg_ && __x.__ctz_ < __y.__ctz_);}

    _LIBCPP_INLINE_VISIBILITY friend bool operator>(const __bit_iterator& __x, const __bit_iterator& __y)
        {return __y < __x;}

    _LIBCPP_INLINE_VISIBILITY friend bool operator<=(const __bit_iterator& __x, const __bit_iterator& __y)
        {return !(__y < __x);}

    _LIBCPP_INLINE_VISIBILITY friend bool operator>=(const __bit_iterator& __x, const __bit_iterator& __y)
        {return !(__x < __y);}

private:
    _LIBCPP_INLINE_VISIBILITY
    __bit_iterator(__storage_pointer __s, unsigned __ctz) _NOEXCEPT
        : __seg_(__s), __ctz_(__ctz) {}

    friend typename _Cp::__self;

    friend class __bit_reference<_Cp>;
    friend class __bit_const_reference<_Cp>;
    friend class __bit_iterator<_Cp, true>;
    template <class _Dp> friend struct __bit_array;
    template <class _Dp> friend void __fill_n_false(__bit_iterator<_Dp, false> __first, typename _Dp::size_type __n);
    template <class _Dp> friend void __fill_n_true(__bit_iterator<_Dp, false> __first, typename _Dp::size_type __n);
    template <class _Dp, bool _IC> friend __bit_iterator<_Dp, false> __copy_aligned(__bit_iterator<_Dp, _IC> __first,
                                                                                  __bit_iterator<_Dp, _IC> __last,
                                                                                  __bit_iterator<_Dp, false> __result);
    template <class _Dp, bool _IC> friend __bit_iterator<_Dp, false> __copy_unaligned(__bit_iterator<_Dp, _IC> __first,
                                                                                    __bit_iterator<_Dp, _IC> __last,
                                                                                    __bit_iterator<_Dp, false> __result);
    template <class _Dp, bool _IC> friend __bit_iterator<_Dp, false> copy(__bit_iterator<_Dp, _IC> __first,
                                                                        __bit_iterator<_Dp, _IC> __last,
                                                                        __bit_iterator<_Dp, false> __result);
    template <class _Dp, bool _IC> friend __bit_iterator<_Dp, false> __copy_backward_aligned(__bit_iterator<_Dp, _IC> __first,
                                                                                           __bit_iterator<_Dp, _IC> __last,
                                                                                           __bit_iterator<_Dp, false> __result);
    template <class _Dp, bool _IC> friend __bit_iterator<_Dp, false> __copy_backward_unaligned(__bit_iterator<_Dp, _IC> __first,
                                                                                             __bit_iterator<_Dp, _IC> __last,
                                                                                             __bit_iterator<_Dp, false> __result);
    template <class _Dp, bool _IC> friend __bit_iterator<_Dp, false> copy_backward(__bit_iterator<_Dp, _IC> __first,
                                                                                 __bit_iterator<_Dp, _IC> __last,
                                                                                 __bit_iterator<_Dp, false> __result);
    template <class __C1, class __C2>friend __bit_iterator<__C2, false> __swap_ranges_aligned(__bit_iterator<__C1, false>,
                                                                                           __bit_iterator<__C1, false>,
                                                                                           __bit_iterator<__C2, false>);
    template <class __C1, class __C2>friend __bit_iterator<__C2, false> __swap_ranges_unaligned(__bit_iterator<__C1, false>,
                                                                                             __bit_iterator<__C1, false>,
                                                                                             __bit_iterator<__C2, false>);
    template <class __C1, class __C2>friend __bit_iterator<__C2, false> swap_ranges(__bit_iterator<__C1, false>,
                                                                                 __bit_iterator<__C1, false>,
                                                                                 __bit_iterator<__C2, false>);
    template <class _Dp> friend __bit_iterator<_Dp, false> rotate(__bit_iterator<_Dp, false>,
                                                                __bit_iterator<_Dp, false>,
                                                                __bit_iterator<_Dp, false>);
    template <class _Dp, bool _IC1, bool _IC2> friend bool __equal_aligned(__bit_iterator<_Dp, _IC1>,
                                                    __bit_iterator<_Dp, _IC1>,
                                                    __bit_iterator<_Dp, _IC2>);
    template <class _Dp, bool _IC1, bool _IC2> friend bool __equal_unaligned(__bit_iterator<_Dp, _IC1>,
                                                      __bit_iterator<_Dp, _IC1>,
                                                      __bit_iterator<_Dp, _IC2>);
    template <class _Dp, bool _IC1, bool _IC2> friend bool equal(__bit_iterator<_Dp, _IC1>,
                                                                __bit_iterator<_Dp, _IC1>,
                                                                __bit_iterator<_Dp, _IC2>);
    template <class _Dp, bool _IC> friend __bit_iterator<_Dp, _IC> __find_bool_true(__bit_iterator<_Dp, _IC>,
                                                                          typename _Dp::size_type);
    template <class _Dp, bool _IC> friend __bit_iterator<_Dp, _IC> __find_bool_false(__bit_iterator<_Dp, _IC>,
                                                                           typename _Dp::size_type);
    template <class _Dp, bool _IC> friend typename __bit_iterator<_Dp, _IC>::difference_type
                   __count_bool_true(__bit_iterator<_Dp, _IC>, typename _Dp::size_type);
    template <class _Dp, bool _IC> friend typename __bit_iterator<_Dp, _IC>::difference_type
                   __count_bool_false(__bit_iterator<_Dp, _IC>, typename _Dp::size_type);
};

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP___BIT_REFERENCE
# 1291 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__bit_reference" 3
# 275 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 275 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 276 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <climits>
#endif /* expanded by -frewrite-includes */
# 276 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 1 3
// -*- C++ -*-
//===--------------------------- climits ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CLIMITS
#define _LIBCPP_CLIMITS

/*
    climits synopsis

Macros:

    CHAR_BIT
    SCHAR_MIN
    SCHAR_MAX
    UCHAR_MAX
    CHAR_MIN
    CHAR_MAX
    MB_LEN_MAX
    SHRT_MIN
    SHRT_MAX
    USHRT_MAX
    INT_MIN
    INT_MAX
    UINT_MAX
    LONG_MIN
    LONG_MAX
    ULONG_MAX
    LLONG_MIN   // C99
    LLONG_MAX   // C99
    ULLONG_MAX  // C99

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 40 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 3
# 41 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits.h>
#endif /* expanded by -frewrite-includes */
# 41 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 1 3
// -*- C++ -*-
//===--------------------------- limits.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_LIMITS_H
#define _LIBCPP_LIMITS_H

/*
    limits.h synopsis

Macros:

    CHAR_BIT
    SCHAR_MIN
    SCHAR_MAX
    UCHAR_MAX
    CHAR_MIN
    CHAR_MAX
    MB_LEN_MAX
    SHRT_MIN
    SHRT_MAX
    USHRT_MAX
    INT_MIN
    INT_MAX
    UINT_MAX
    LONG_MIN
    LONG_MAX
    ULONG_MAX
    LLONG_MIN   // C99
    LLONG_MAX   // C99
    ULLONG_MAX  // C99

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 40 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
# 41 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 43 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 44 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
#endif
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3

#ifndef __GNUC__
#if 0 /* expanded by -frewrite-includes */
#include_next <limits.h>
#endif /* expanded by -frewrite-includes */
# 47 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
#else
# 49 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
// GCC header limits.h recursively includes itself through another header called
// syslimits.h for some reason. This setup breaks down if we directly
// #include_next GCC's limits.h (reasons not entirely clear to me). Therefore,
// we manually re-create the necessary include sequence below:

// Get the system limits.h defines (force recurse into the next level)
#define _GCC_LIMITS_H_
#define _GCC_NEXT_LIMITS_H
#if 0 /* expanded by -frewrite-includes */
#include_next <limits.h>
#endif /* expanded by -frewrite-includes */
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 1 3
/*===---- limits.h - Standard header for integer sizes --------------------===*\
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
\*===----------------------------------------------------------------------===*/

#ifndef __CLANG_LIMITS_H
#define __CLANG_LIMITS_H

/* The system's limits.h may, in turn, try to #include_next GCC's limits.h.
   Avert this #include_next madness. */
#if 0 /* disabled by -frewrite-includes */
#if defined __GNUC__ && !defined _GCC_LIMITS_H_
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3
#define _GCC_LIMITS_H_
#endif
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3

/* System headers include a number of constants from POSIX in <limits.h>.
   Include it if we're hosted. */
#if 0 /* disabled by -frewrite-includes */
#if __STDC_HOSTED__ && __has_include_next(<limits.h>)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3
#if 0 /* expanded by -frewrite-includes */
#include_next <limits.h>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 1 3 4
/*
 * Copyright (c) 2000, 2004-2007, 2009 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*	$NetBSD: limits.h,v 1.8 1996/10/21 05:10:50 jtc Exp $	*/

/*
 * Copyright (c) 1988, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)limits.h	8.2 (Berkeley) 1/4/94
 */

#ifndef _LIMITS_H_
#define	_LIMITS_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 63 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/limits.h>
#endif /* expanded by -frewrite-includes */
# 64 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/limits.h" 1 3 4
/* This is the `system' limits.h, independent of any particular
 *  compiler.  GCC provides its own limits.h which can be found in
 *  /usr/lib/gcc, although it is not very informative.
 *  This file is public domain.  */
#if 0 /* disabled by -frewrite-includes */
#if defined (__i386__) || defined(__x86_64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 6 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/limits.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <i386/limits.h>
#endif /* expanded by -frewrite-includes */
# 6 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/limits.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 1 3 4
/*
 * Copyright (c) 1988, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)limits.h	8.3 (Berkeley) 1/4/94
 */

#ifndef _I386_LIMITS_H_
#define _I386_LIMITS_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 39 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <i386/_limits.h>
#endif /* expanded by -frewrite-includes */
# 40 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_limits.h" 1 3 4
/*
 * Copyright (c) 2004 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 *
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
#ifndef _I386__LIMITS_H_
#define _I386__LIMITS_H_

#define __DARWIN_CLK_TCK                100     /* ticks per second */

#endif  /* _I386__LIMITS_H_ */
# 28 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/_limits.h" 3 4
# 41 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 2 3 4

#define CHAR_BIT        8               /* number of bits in a char */
#define MB_LEN_MAX      6               /* Allow 31 bit UTF2 */

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE) && (!defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
#define CLK_TCK         __DARWIN_CLK_TCK        /* ticks per second */
#endif /* !_ANSI_SOURCE && (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 48 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4

/*
 * According to ANSI (section 2.2.4.2), the values below must be usable by
 * #if preprocessing directives.  Additionally, the expression must have the
 * same type as would an expression that is an object of the corresponding
 * type converted according to the integral promotions.  The subtraction for
 * INT_MIN and LONG_MIN is so the value is not unsigned; 2147483648 is an
 * unsigned int for 32-bit two's complement ANSI compilers (section 3.1.3.2).
 * These numbers work for pcc as well.  The UINT_MAX and ULONG_MAX values
 * are written as hex so that GCC will be quiet about large integer constants.
 */
#define SCHAR_MAX       127             /* min value for a signed char */
#define SCHAR_MIN       (-128)          /* max value for a signed char */

#define UCHAR_MAX       255             /* max value for an unsigned char */
#define CHAR_MAX        127             /* max value for a char */
#define CHAR_MIN        (-128)          /* min value for a char */

#define USHRT_MAX       65535           /* max value for an unsigned short */
#define SHRT_MAX        32767           /* max value for a short */
#define SHRT_MIN        (-32768)        /* min value for a short */

#define UINT_MAX        0xffffffff      /* max value for an unsigned int */
#define INT_MAX         2147483647      /* max value for an int */
#define INT_MIN         (-2147483647-1) /* min value for an int */

#ifdef __LP64__
#define ULONG_MAX       0xffffffffffffffffUL    /* max unsigned long */
#define LONG_MAX        0x7fffffffffffffffL     /* max signed long */
#define LONG_MIN        (-0x7fffffffffffffffL-1) /* min signed long */
#else /* !__LP64__ */
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
#define ULONG_MAX       0xffffffffUL    /* max unsigned long */
#define LONG_MAX        2147483647L     /* max signed long */
#define LONG_MIN        (-2147483647L-1) /* min signed long */
#endif /* __LP64__ */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4

#define ULLONG_MAX      0xffffffffffffffffULL   /* max unsigned long long */
#define LLONG_MAX       0x7fffffffffffffffLL    /* max signed long long */
#define LLONG_MIN       (-0x7fffffffffffffffLL-1) /* min signed long long */

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 89 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
#ifdef __LP64__
#define LONG_BIT        64
#else /* !__LP64__ */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
#define LONG_BIT        32
#endif /* __LP64__ */
# 94 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
#define SSIZE_MAX       LONG_MAX        /* max value for a ssize_t */
#define WORD_BIT        32

#if 0 /* disabled by -frewrite-includes */
#if (!defined(_POSIX_C_SOURCE) && !defined(_XOPEN_SOURCE)) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
#define SIZE_T_MAX      ULONG_MAX       /* max value for a size_t */

#define UQUAD_MAX       ULLONG_MAX
#define QUAD_MAX        LLONG_MAX
#define QUAD_MIN        LLONG_MIN

#endif /* (!_POSIX_C_SOURCE && !_XOPEN_SOURCE) || _DARWIN_C_SOURCE */
# 105 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
#endif /* !_ANSI_SOURCE */
# 106 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4

#endif /* _I386_LIMITS_H_ */
# 108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/i386/limits.h" 3 4
# 7 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/limits.h" 2 3 4
#else
# 8 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/limits.h" 3 4
#error architecture not supported
#endif
# 10 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/machine/limits.h" 3 4
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/syslimits.h>
#endif /* expanded by -frewrite-includes */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 1 3 4
/*
 * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/*	$NetBSD: syslimits.h,v 1.15 1997/06/25 00:48:09 lukem Exp $	*/

/*
 * Copyright (c) 1988, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)syslimits.h	8.1 (Berkeley) 6/2/93
 */

#ifndef _SYS_SYSLIMITS_H_
#define _SYS_SYSLIMITS_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
# 69 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_ANSI_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 71 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
/*
 * Note: CHILD_MAX *must* be less than hard_maxproc, which is set at
 * compile time; you *cannot* set it higher than the hard limit!!
 */
#define ARG_MAX            (256 * 1024) /* max bytes for an exec function */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
#define CHILD_MAX                  266  /* max simultaneous processes */
#define GID_MAX            2147483647U  /* max value for a gid_t (2^31-2) */
#endif /* (_POSIX_C_SOURCE && !_DARWIN_C_SOURCE) */
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
#define LINK_MAX                32767   /* max file link count */
#define MAX_CANON                1024   /* max bytes in term canon input line */
#define MAX_INPUT                1024   /* max bytes in terminal input */
#define NAME_MAX                  255   /* max bytes in a file name */
#define NGROUPS_MAX                16   /* max supplemental group id's */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
#define UID_MAX            2147483647U  /* max value for a uid_t (2^31-2) */

#define OPEN_MAX                10240   /* max open files per process - todo, make a config option? */

#endif /* (_POSIX_C_SOURCE && !_DARWIN_C_SOURCE) */
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
#define PATH_MAX                 1024   /* max bytes in pathname */
#define PIPE_BUF                  512   /* max bytes for atomic pipe writes */

#define BC_BASE_MAX                99   /* max ibase/obase values in bc(1) */
#define BC_DIM_MAX               2048   /* max array elements in bc(1) */
#define BC_SCALE_MAX               99   /* max scale value in bc(1) */
#define BC_STRING_MAX            1000   /* max const string length in bc(1) */
#define CHARCLASS_NAME_MAX         14   /* max character class name size */
#define COLL_WEIGHTS_MAX            2   /* max weights for order keyword */
#define EQUIV_CLASS_MAX             2
#define EXPR_NEST_MAX              32   /* max expressions nested in expr(1) */
#define LINE_MAX                 2048   /* max bytes in an input line */
#define RE_DUP_MAX                255   /* max RE's in interval notation */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 106 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
#define NZERO                      20   /* default priority [XSI] */
                                        /* = ((PRIO_MAX - PRIO_MIN) / 2) + 1 */
                                        /* range: 0 - 39 [(2 * NZERO) - 1] */
                                        /* 0 is not actually used */
#else /* !__DARWIN_UNIX03 */
# 111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
#define NZERO                       0   /* default priority */
                                        /* range: -20 - 20 */
                                        /* (PRIO_MIN - PRIO_MAX) */
#endif /* __DARWIN_UNIX03 */
# 115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
#endif /* !_ANSI_SOURCE */
# 116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4

#endif /* !_SYS_SYSLIMITS_H_ */
# 118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/syslimits.h" 3 4
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL > __DARWIN_C_ANSI
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 68 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#define	_POSIX_ARG_MAX		4096
#define	_POSIX_CHILD_MAX	25
#define	_POSIX_LINK_MAX		8
#define	_POSIX_MAX_CANON	255
#define	_POSIX_MAX_INPUT	255
#define	_POSIX_NAME_MAX		14
#define	_POSIX_NGROUPS_MAX	8
#define	_POSIX_OPEN_MAX		20
#define	_POSIX_PATH_MAX		256
#define	_POSIX_PIPE_BUF		512
#define	_POSIX_SSIZE_MAX	32767
#define	_POSIX_STREAM_MAX	8
#define	_POSIX_TZNAME_MAX	6

#define	_POSIX2_BC_BASE_MAX		99
#define	_POSIX2_BC_DIM_MAX		2048
#define	_POSIX2_BC_SCALE_MAX		99
#define	_POSIX2_BC_STRING_MAX		1000
#define	_POSIX2_EQUIV_CLASS_MAX		2
#define	_POSIX2_EXPR_NEST_MAX		32
#define	_POSIX2_LINE_MAX		2048
#define	_POSIX2_RE_DUP_MAX		255
#endif /* __DARWIN_C_LEVEL > __DARWIN_C_ANSI */
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 199309L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 93 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#define _POSIX_AIO_LISTIO_MAX   2
#define _POSIX_AIO_MAX          1
#define _POSIX_DELAYTIMER_MAX   32
#define _POSIX_MQ_OPEN_MAX      8
#define _POSIX_MQ_PRIO_MAX	32
#define _POSIX_RTSIG_MAX 			8
#define _POSIX_SEM_NSEMS_MAX 			256
#define _POSIX_SEM_VALUE_MAX 			32767
#define _POSIX_SIGQUEUE_MAX 			32
#define _POSIX_TIMER_MAX 			32

#define _POSIX_CLOCKRES_MIN 20000000
#endif /* __DARWIN_C_LEVEL >= 199309L */
# 106 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 199506L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#define _POSIX_THREAD_DESTRUCTOR_ITERATIONS 	4
#define _POSIX_THREAD_KEYS_MAX 			128
#define _POSIX_THREAD_THREADS_MAX 		64

#define PTHREAD_DESTRUCTOR_ITERATIONS 	4
#define PTHREAD_KEYS_MAX 		512
#if 0 /* disabled by -frewrite-includes */
#if defined(__arm__) || defined(__arm64__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#define PTHREAD_STACK_MIN 		16384
#else
# 117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#define PTHREAD_STACK_MIN 		8192
#endif
# 119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#endif /* __DARWIN_C_LEVEL >= 199506L */
# 120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200112
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#define _POSIX_HOST_NAME_MAX    255
#define _POSIX_LOGIN_NAME_MAX   9
#define _POSIX_SS_REPL_MAX 			4
#define _POSIX_SYMLINK_MAX 			255
#define _POSIX_SYMLOOP_MAX 			8
#define _POSIX_TRACE_EVENT_NAME_MAX 		30
#define _POSIX_TRACE_NAME_MAX 			8
#define _POSIX_TRACE_SYS_MAX 			8
#define _POSIX_TRACE_USER_EVENT_MAX 		32
#define _POSIX_TTY_NAME_MAX 			9
#define _POSIX2_CHARCLASS_NAME_MAX	14
#define	_POSIX2_COLL_WEIGHTS_MAX	2

#define _POSIX_RE_DUP_MAX 		_POSIX2_RE_DUP_MAX
#endif /* __DARWIN_C_LEVEL >= 200112 */
# 137 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 139 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#define OFF_MIN		LLONG_MIN	/* min value for an off_t */
#define OFF_MAX		LLONG_MAX	/* max value for an off_t */
#endif /* __DARWIN_C_LEVEL >= __DARWIN_C_FULL */
# 142 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4

/* Actually for XSI Visible */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL > __DARWIN_C_ANSI
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 145 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4

/* Removed in Issue 6 */
#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || _POSIX_C_SOURCE < 200112L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 148 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
#define PASS_MAX	128
#endif
# 150 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4

#define NL_ARGMAX	9
#define NL_LANGMAX	14
#define NL_MSGMAX	32767
#define NL_NMAX		1
#define NL_SETMAX	255
#define NL_TEXTMAX	2048

#define _XOPEN_IOV_MAX	16
#define IOV_MAX		1024
#define _XOPEN_NAME_MAX 255
#define _XOPEN_PATH_MAX 1024

#endif /* __DARWIN_C_LEVEL > __DARWIN_C_ANSI */
# 164 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4

/* NZERO to be defined here. TBD. See also sys/param.h  */

#endif /* !_LIMITS_H_ */
# 168 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/limits.h" 3 4
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 2 3
#endif
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3

/* Many system headers try to "help us out" by defining these.  No really, we
   know how big each datatype is. */
#undef  SCHAR_MIN
#undef  SCHAR_MAX
#undef  UCHAR_MAX
#undef  SHRT_MIN
#undef  SHRT_MAX
#undef  USHRT_MAX
#undef  INT_MIN
#undef  INT_MAX
#undef  UINT_MAX
#undef  LONG_MIN
#undef  LONG_MAX
#undef  ULONG_MAX

#undef  CHAR_BIT
#undef  CHAR_MIN
#undef  CHAR_MAX

/* C90/99 5.2.4.2.1 */
#define SCHAR_MAX __SCHAR_MAX__
#define SHRT_MAX  __SHRT_MAX__
#define INT_MAX   __INT_MAX__
#define LONG_MAX  __LONG_MAX__

#define SCHAR_MIN (-__SCHAR_MAX__-1)
#define SHRT_MIN  (-__SHRT_MAX__ -1)
#define INT_MIN   (-__INT_MAX__  -1)
#define LONG_MIN  (-__LONG_MAX__ -1L)

#define UCHAR_MAX (__SCHAR_MAX__*2  +1)
#define USHRT_MAX (__SHRT_MAX__ *2  +1)
#define UINT_MAX  (__INT_MAX__  *2U +1U)
#define ULONG_MAX (__LONG_MAX__ *2UL+1UL)

#ifndef MB_LEN_MAX
#define MB_LEN_MAX 1
#endif
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3

#define CHAR_BIT  __CHAR_BIT__

#ifdef __CHAR_UNSIGNED__  /* -funsigned-char */
#define CHAR_MIN 0
#define CHAR_MAX UCHAR_MAX
#else
# 69 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3
#define CHAR_MIN SCHAR_MIN
#define CHAR_MAX __SCHAR_MAX__
#endif
# 72 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3

/* C99 5.2.4.2.1: Added long long.
   C++11 18.3.3.2: same contents as the Standard C Library header <limits.h>.
 */
#if 0 /* disabled by -frewrite-includes */
#if __STDC_VERSION__ >= 199901L || __cplusplus >= 201103L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 77 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3

#undef  LLONG_MIN
#undef  LLONG_MAX
#undef  ULLONG_MAX

#define LLONG_MAX  __LONG_LONG_MAX__
#define LLONG_MIN  (-__LONG_LONG_MAX__-1LL)
#define ULLONG_MAX (__LONG_LONG_MAX__*2ULL+1ULL)
#endif
# 86 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3

/* LONG_LONG_MIN/LONG_LONG_MAX/ULONG_LONG_MAX are a GNU extension.  It's too bad
   that we don't have something like #pragma poison that could be used to
   deprecate a macro - the code should just use LLONG_MAX and friends.
 */
#if 0 /* disabled by -frewrite-includes */
#if defined(__GNU_LIBRARY__) ? defined(__USE_GNU) : !defined(__STRICT_ANSI__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3

#undef   LONG_LONG_MIN
#undef   LONG_LONG_MAX
#undef   ULONG_LONG_MAX

#define LONG_LONG_MAX  __LONG_LONG_MAX__
#define LONG_LONG_MIN  (-__LONG_LONG_MAX__-1LL)
#define ULONG_LONG_MAX (__LONG_LONG_MAX__*2ULL+1ULL)
#endif
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3

#endif /* __CLANG_LIMITS_H */
# 103 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/limits.h" 3
# 58 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 2 3

// Get the ISO C defines
#undef _GCC_LIMITS_H_
#if 0 /* expanded by -frewrite-includes */
#include_next <limits.h>
#endif /* expanded by -frewrite-includes */
# 61 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
#endif // __GNUC__
# 63 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3

#endif  // _LIBCPP_LIMITS_H
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/limits.h" 3
# 42 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 44 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 3
#endif
# 46 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 3

#endif  // _LIBCPP_CLIMITS
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/climits" 3
# 277 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 277 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 278 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 278 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 279 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 279 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 280 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 280 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 281 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 281 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 282 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 282 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 283 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 283 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 284 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#include <__split_buffer>
#endif /* expanded by -frewrite-includes */
# 284 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 1 3
// -*- C++ -*-
#ifndef _LIBCPP_SPLIT_BUFFER
#define _LIBCPP_SPLIT_BUFFER

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 5 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
# 6 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 6 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
# 7 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 7 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
# 8 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 10 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
#endif
# 12 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

template <bool>
class __split_buffer_common
{
protected:
    void __throw_length_error() const;
    void __throw_out_of_range() const;
};

template <class _Tp, class _Allocator = allocator<_Tp> >
struct __split_buffer
    : private __split_buffer_common<true>
{
private:
    __split_buffer(const __split_buffer&);
    __split_buffer& operator=(const __split_buffer&);
public:
    typedef _Tp                                             value_type;
    typedef _Allocator                                      allocator_type;
    typedef typename remove_reference<allocator_type>::type __alloc_rr;
    typedef allocator_traits<__alloc_rr>                    __alloc_traits;
    typedef value_type&                                     reference;
    typedef const value_type&                               const_reference;
    typedef typename __alloc_traits::size_type              size_type;
    typedef typename __alloc_traits::difference_type        difference_type;
    typedef typename __alloc_traits::pointer                pointer;
    typedef typename __alloc_traits::const_pointer          const_pointer;
    typedef pointer                                         iterator;
    typedef const_pointer                                   const_iterator;

    pointer                                         __first_;
    pointer                                         __begin_;
    pointer                                         __end_;
    __compressed_pair<pointer, allocator_type> __end_cap_;

    typedef typename add_lvalue_reference<allocator_type>::type __alloc_ref;
    typedef typename add_lvalue_reference<allocator_type>::type __alloc_const_ref;

    _LIBCPP_INLINE_VISIBILITY __alloc_rr&           __alloc() _NOEXCEPT         {return __end_cap_.second();}
    _LIBCPP_INLINE_VISIBILITY const __alloc_rr&     __alloc() const _NOEXCEPT   {return __end_cap_.second();}
    _LIBCPP_INLINE_VISIBILITY pointer&              __end_cap() _NOEXCEPT       {return __end_cap_.first();}
    _LIBCPP_INLINE_VISIBILITY const pointer&        __end_cap() const _NOEXCEPT {return __end_cap_.first();}

    _LIBCPP_INLINE_VISIBILITY
    __split_buffer()
        _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value);
    _LIBCPP_INLINE_VISIBILITY
    explicit __split_buffer(__alloc_rr& __a);
    _LIBCPP_INLINE_VISIBILITY
    explicit __split_buffer(const __alloc_rr& __a);
    __split_buffer(size_type __cap, size_type __start, __alloc_rr& __a);
    ~__split_buffer();

#ifndef _LIBCPP_CXX03_LANG
    __split_buffer(__split_buffer&& __c)
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value);
    __split_buffer(__split_buffer&& __c, const __alloc_rr& __a);
    __split_buffer& operator=(__split_buffer&& __c)
        _NOEXCEPT_((__alloc_traits::propagate_on_container_move_assignment::value &&
                is_nothrow_move_assignable<allocator_type>::value) ||
               !__alloc_traits::propagate_on_container_move_assignment::value);
#endif  // _LIBCPP_CXX03_LANG
# 80 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3

    _LIBCPP_INLINE_VISIBILITY       iterator begin() _NOEXCEPT       {return __begin_;}
    _LIBCPP_INLINE_VISIBILITY const_iterator begin() const _NOEXCEPT {return __begin_;}
    _LIBCPP_INLINE_VISIBILITY       iterator end() _NOEXCEPT         {return __end_;}
    _LIBCPP_INLINE_VISIBILITY const_iterator end() const _NOEXCEPT   {return __end_;}

    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT
        {__destruct_at_end(__begin_);}
    _LIBCPP_INLINE_VISIBILITY size_type size() const {return static_cast<size_type>(__end_ - __begin_);}
    _LIBCPP_INLINE_VISIBILITY bool empty()     const {return __end_ == __begin_;}
    _LIBCPP_INLINE_VISIBILITY size_type capacity() const {return static_cast<size_type>(__end_cap() - __first_);}
    _LIBCPP_INLINE_VISIBILITY size_type __front_spare() const {return static_cast<size_type>(__begin_ - __first_);}
    _LIBCPP_INLINE_VISIBILITY size_type __back_spare() const {return static_cast<size_type>(__end_cap() - __end_);}

    _LIBCPP_INLINE_VISIBILITY       reference front()       {return *__begin_;}
    _LIBCPP_INLINE_VISIBILITY const_reference front() const {return *__begin_;}
    _LIBCPP_INLINE_VISIBILITY       reference back()        {return *(__end_ - 1);}
    _LIBCPP_INLINE_VISIBILITY const_reference back() const  {return *(__end_ - 1);}

    void reserve(size_type __n);
    void shrink_to_fit() _NOEXCEPT;
    void push_front(const_reference __x);
    _LIBCPP_INLINE_VISIBILITY void push_back(const_reference __x);
#ifndef _LIBCPP_CXX03_LANG
    void push_front(value_type&& __x);
    void push_back(value_type&& __x);
    template <class... _Args>
        void emplace_back(_Args&&... __args);
#endif  // !defined(_LIBCPP_CXX03_LANG)
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3

    _LIBCPP_INLINE_VISIBILITY void pop_front() {__destruct_at_begin(__begin_+1);}
    _LIBCPP_INLINE_VISIBILITY void pop_back() {__destruct_at_end(__end_-1);}

    void __construct_at_end(size_type __n);
    void __construct_at_end(size_type __n, const_reference __x);
    template <class _InputIter>
        typename enable_if
        <
            __is_cpp17_input_iterator<_InputIter>::value &&
           !__is_cpp17_forward_iterator<_InputIter>::value,
            void
        >::type
        __construct_at_end(_InputIter __first, _InputIter __last);
    template <class _ForwardIterator>
        typename enable_if
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value,
            void
        >::type
        __construct_at_end(_ForwardIterator __first, _ForwardIterator __last);

    _LIBCPP_INLINE_VISIBILITY void __destruct_at_begin(pointer __new_begin)
        {__destruct_at_begin(__new_begin, is_trivially_destructible<value_type>());}
        _LIBCPP_INLINE_VISIBILITY
        void __destruct_at_begin(pointer __new_begin, false_type);
        _LIBCPP_INLINE_VISIBILITY
        void __destruct_at_begin(pointer __new_begin, true_type);

    _LIBCPP_INLINE_VISIBILITY
    void __destruct_at_end(pointer __new_last) _NOEXCEPT
        {__destruct_at_end(__new_last, false_type());}
    _LIBCPP_INLINE_VISIBILITY
        void __destruct_at_end(pointer __new_last, false_type) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
        void __destruct_at_end(pointer __new_last, true_type) _NOEXCEPT;

    void swap(__split_buffer& __x)
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value||
                   __is_nothrow_swappable<__alloc_rr>::value);

    bool __invariants() const;

private:
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__split_buffer& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
        {
            __alloc() = _VSTD::move(__c.__alloc());
        }

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__split_buffer&, false_type) _NOEXCEPT
        {}

    struct _ConstructTransaction {
      explicit _ConstructTransaction(pointer* __p, size_type __n) _NOEXCEPT
      : __pos_(*__p), __end_(*__p + __n), __dest_(__p) {
      }
      ~_ConstructTransaction() {
        *__dest_ = __pos_;
      }
      pointer __pos_;
     const pointer __end_;
    private:
     pointer *__dest_;
    };
};

template <class _Tp, class _Allocator>
bool
__split_buffer<_Tp, _Allocator>::__invariants() const
{
    if (__first_ == nullptr)
    {
        if (__begin_ != nullptr)
            return false;
        if (__end_ != nullptr)
            return false;
        if (__end_cap() != nullptr)
            return false;
    }
    else
    {
        if (__begin_ < __first_)
            return false;
        if (__end_ < __begin_)
            return false;
        if (__end_cap() < __end_)
            return false;
    }
    return true;
}

//  Default constructs __n objects starting at __end_
//  throws if construction throws
//  Precondition:  __n > 0
//  Precondition:  size() + __n <= capacity()
//  Postcondition:  size() == size() + __n
template <class _Tp, class _Allocator>
void
__split_buffer<_Tp, _Allocator>::__construct_at_end(size_type __n)
{
    _ConstructTransaction __tx(&this->__end_, __n);
    for (; __tx.__pos_ != __tx.__end_; ++__tx.__pos_) {
        __alloc_traits::construct(this->__alloc(), _VSTD::__to_address(__tx.__pos_));
    }
}

//  Copy constructs __n objects starting at __end_ from __x
//  throws if construction throws
//  Precondition:  __n > 0
//  Precondition:  size() + __n <= capacity()
//  Postcondition:  size() == old size() + __n
//  Postcondition:  [i] == __x for all i in [size() - __n, __n)
template <class _Tp, class _Allocator>
void
__split_buffer<_Tp, _Allocator>::__construct_at_end(size_type __n, const_reference __x)
{
    _ConstructTransaction __tx(&this->__end_, __n);
    for (; __tx.__pos_ != __tx.__end_; ++__tx.__pos_) {
        __alloc_traits::construct(this->__alloc(),
            _VSTD::__to_address(__tx.__pos_), __x);
    }
}

template <class _Tp, class _Allocator>
template <class _InputIter>
typename enable_if
<
     __is_cpp17_input_iterator<_InputIter>::value &&
    !__is_cpp17_forward_iterator<_InputIter>::value,
    void
>::type
__split_buffer<_Tp, _Allocator>::__construct_at_end(_InputIter __first, _InputIter __last)
{
    __alloc_rr& __a = this->__alloc();
    for (; __first != __last; ++__first)
    {
        if (__end_ == __end_cap())
        {
            size_type __old_cap = __end_cap() - __first_;
            size_type __new_cap = _VSTD::max<size_type>(2 * __old_cap, 8);
            __split_buffer __buf(__new_cap, 0, __a);
            for (pointer __p = __begin_; __p != __end_; ++__p, ++__buf.__end_)
                __alloc_traits::construct(__buf.__alloc(),
                        _VSTD::__to_address(__buf.__end_), _VSTD::move(*__p));
            swap(__buf);
        }
        __alloc_traits::construct(__a, _VSTD::__to_address(this->__end_), *__first);
        ++this->__end_;
    }
}

template <class _Tp, class _Allocator>
template <class _ForwardIterator>
typename enable_if
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value,
    void
>::type
__split_buffer<_Tp, _Allocator>::__construct_at_end(_ForwardIterator __first, _ForwardIterator __last)
{
    _ConstructTransaction __tx(&this->__end_, std::distance(__first, __last));
    for (; __tx.__pos_ != __tx.__end_; ++__tx.__pos_, ++__first) {
        __alloc_traits::construct(this->__alloc(),
            _VSTD::__to_address(__tx.__pos_), *__first);
    }
}

template <class _Tp, class _Allocator>
inline
void
__split_buffer<_Tp, _Allocator>::__destruct_at_begin(pointer __new_begin, false_type)
{
    while (__begin_ != __new_begin)
        __alloc_traits::destroy(__alloc(), __to_address(__begin_++));
}

template <class _Tp, class _Allocator>
inline
void
__split_buffer<_Tp, _Allocator>::__destruct_at_begin(pointer __new_begin, true_type)
{
    __begin_ = __new_begin;
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
__split_buffer<_Tp, _Allocator>::__destruct_at_end(pointer __new_last, false_type) _NOEXCEPT
{
    while (__new_last != __end_)
        __alloc_traits::destroy(__alloc(), __to_address(--__end_));
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
__split_buffer<_Tp, _Allocator>::__destruct_at_end(pointer __new_last, true_type) _NOEXCEPT
{
    __end_ = __new_last;
}

template <class _Tp, class _Allocator>
__split_buffer<_Tp, _Allocator>::__split_buffer(size_type __cap, size_type __start, __alloc_rr& __a)
    : __end_cap_(nullptr, __a)
{
    __first_ = __cap != 0 ? __alloc_traits::allocate(__alloc(), __cap) : nullptr;
    __begin_ = __end_ = __first_ + __start;
    __end_cap() = __first_ + __cap;
}

template <class _Tp, class _Allocator>
inline
__split_buffer<_Tp, _Allocator>::__split_buffer()
    _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value)
    : __first_(nullptr), __begin_(nullptr), __end_(nullptr), __end_cap_(nullptr, __default_init_tag())
{
}

template <class _Tp, class _Allocator>
inline
__split_buffer<_Tp, _Allocator>::__split_buffer(__alloc_rr& __a)
    : __first_(nullptr), __begin_(nullptr), __end_(nullptr), __end_cap_(nullptr, __a)
{
}

template <class _Tp, class _Allocator>
inline
__split_buffer<_Tp, _Allocator>::__split_buffer(const __alloc_rr& __a)
    : __first_(nullptr), __begin_(nullptr), __end_(nullptr), __end_cap_(nullptr, __a)
{
}

template <class _Tp, class _Allocator>
__split_buffer<_Tp, _Allocator>::~__split_buffer()
{
    clear();
    if (__first_)
        __alloc_traits::deallocate(__alloc(), __first_, capacity());
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Allocator>
__split_buffer<_Tp, _Allocator>::__split_buffer(__split_buffer&& __c)
    _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value)
    : __first_(_VSTD::move(__c.__first_)),
      __begin_(_VSTD::move(__c.__begin_)),
      __end_(_VSTD::move(__c.__end_)),
      __end_cap_(_VSTD::move(__c.__end_cap_))
{
    __c.__first_ = nullptr;
    __c.__begin_ = nullptr;
    __c.__end_ = nullptr;
    __c.__end_cap() = nullptr;
}

template <class _Tp, class _Allocator>
__split_buffer<_Tp, _Allocator>::__split_buffer(__split_buffer&& __c, const __alloc_rr& __a)
    : __end_cap_(nullptr, __a)
{
    if (__a == __c.__alloc())
    {
        __first_ = __c.__first_;
        __begin_ = __c.__begin_;
        __end_ = __c.__end_;
        __end_cap() = __c.__end_cap();
        __c.__first_ = nullptr;
        __c.__begin_ = nullptr;
        __c.__end_ = nullptr;
        __c.__end_cap() = nullptr;
    }
    else
    {
        size_type __cap = __c.size();
        __first_ = __alloc_traits::allocate(__alloc(), __cap);
        __begin_ = __end_ = __first_;
        __end_cap() = __first_ + __cap;
        typedef move_iterator<iterator> _Ip;
        __construct_at_end(_Ip(__c.begin()), _Ip(__c.end()));
    }
}

template <class _Tp, class _Allocator>
__split_buffer<_Tp, _Allocator>&
__split_buffer<_Tp, _Allocator>::operator=(__split_buffer&& __c)
    _NOEXCEPT_((__alloc_traits::propagate_on_container_move_assignment::value &&
                is_nothrow_move_assignable<allocator_type>::value) ||
               !__alloc_traits::propagate_on_container_move_assignment::value)
{
    clear();
    shrink_to_fit();
    __first_ = __c.__first_;
    __begin_ = __c.__begin_;
    __end_ = __c.__end_;
    __end_cap() = __c.__end_cap();
    __move_assign_alloc(__c,
        integral_constant<bool,
                          __alloc_traits::propagate_on_container_move_assignment::value>());
    __c.__first_ = __c.__begin_ = __c.__end_ = __c.__end_cap() = nullptr;
    return *this;
}

#endif  // _LIBCPP_CXX03_LANG
# 416 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3

template <class _Tp, class _Allocator>
void
__split_buffer<_Tp, _Allocator>::swap(__split_buffer& __x)
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value||
                   __is_nothrow_swappable<__alloc_rr>::value)
{
    _VSTD::swap(__first_, __x.__first_);
    _VSTD::swap(__begin_, __x.__begin_);
    _VSTD::swap(__end_, __x.__end_);
    _VSTD::swap(__end_cap(), __x.__end_cap());
    __swap_allocator(__alloc(), __x.__alloc());
}

template <class _Tp, class _Allocator>
void
__split_buffer<_Tp, _Allocator>::reserve(size_type __n)
{
    if (__n < capacity())
    {
        __split_buffer<value_type, __alloc_rr&> __t(__n, 0, __alloc());
        __t.__construct_at_end(move_iterator<pointer>(__begin_),
                               move_iterator<pointer>(__end_));
        _VSTD::swap(__first_, __t.__first_);
        _VSTD::swap(__begin_, __t.__begin_);
        _VSTD::swap(__end_, __t.__end_);
        _VSTD::swap(__end_cap(), __t.__end_cap());
    }
}

template <class _Tp, class _Allocator>
void
__split_buffer<_Tp, _Allocator>::shrink_to_fit() _NOEXCEPT
{
    if (capacity() > size())
    {
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 456 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
            __split_buffer<value_type, __alloc_rr&> __t(size(), 0, __alloc());
            __t.__construct_at_end(move_iterator<pointer>(__begin_),
                                   move_iterator<pointer>(__end_));
            __t.__end_ = __t.__begin_ + (__end_ - __begin_);
            _VSTD::swap(__first_, __t.__first_);
            _VSTD::swap(__begin_, __t.__begin_);
            _VSTD::swap(__end_, __t.__end_);
            _VSTD::swap(__end_cap(), __t.__end_cap());
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 470 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
    }
}

template <class _Tp, class _Allocator>
void
__split_buffer<_Tp, _Allocator>::push_front(const_reference __x)
{
    if (__begin_ == __first_)
    {
        if (__end_ < __end_cap())
        {
            difference_type __d = __end_cap() - __end_;
            __d = (__d + 1) / 2;
            __begin_ = _VSTD::move_backward(__begin_, __end_, __end_ + __d);
            __end_ += __d;
        }
        else
        {
            size_type __c = max<size_type>(2 * static_cast<size_t>(__end_cap() - __first_), 1);
            __split_buffer<value_type, __alloc_rr&> __t(__c, (__c + 3) / 4, __alloc());
            __t.__construct_at_end(move_iterator<pointer>(__begin_),
                                   move_iterator<pointer>(__end_));
            _VSTD::swap(__first_, __t.__first_);
            _VSTD::swap(__begin_, __t.__begin_);
            _VSTD::swap(__end_, __t.__end_);
            _VSTD::swap(__end_cap(), __t.__end_cap());
        }
    }
    __alloc_traits::construct(__alloc(), _VSTD::__to_address(__begin_-1), __x);
    --__begin_;
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Allocator>
void
__split_buffer<_Tp, _Allocator>::push_front(value_type&& __x)
{
    if (__begin_ == __first_)
    {
        if (__end_ < __end_cap())
        {
            difference_type __d = __end_cap() - __end_;
            __d = (__d + 1) / 2;
            __begin_ = _VSTD::move_backward(__begin_, __end_, __end_ + __d);
            __end_ += __d;
        }
        else
        {
            size_type __c = max<size_type>(2 * static_cast<size_t>(__end_cap() - __first_), 1);
            __split_buffer<value_type, __alloc_rr&> __t(__c, (__c + 3) / 4, __alloc());
            __t.__construct_at_end(move_iterator<pointer>(__begin_),
                                   move_iterator<pointer>(__end_));
            _VSTD::swap(__first_, __t.__first_);
            _VSTD::swap(__begin_, __t.__begin_);
            _VSTD::swap(__end_, __t.__end_);
            _VSTD::swap(__end_cap(), __t.__end_cap());
        }
    }
    __alloc_traits::construct(__alloc(), _VSTD::__to_address(__begin_-1),
            _VSTD::move(__x));
    --__begin_;
}

#endif  // _LIBCPP_CXX03_LANG
# 535 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
__split_buffer<_Tp, _Allocator>::push_back(const_reference __x)
{
    if (__end_ == __end_cap())
    {
        if (__begin_ > __first_)
        {
            difference_type __d = __begin_ - __first_;
            __d = (__d + 1) / 2;
            __end_ = _VSTD::move(__begin_, __end_, __begin_ - __d);
            __begin_ -= __d;
        }
        else
        {
            size_type __c = max<size_type>(2 * static_cast<size_t>(__end_cap() - __first_), 1);
            __split_buffer<value_type, __alloc_rr&> __t(__c, __c / 4, __alloc());
            __t.__construct_at_end(move_iterator<pointer>(__begin_),
                                   move_iterator<pointer>(__end_));
            _VSTD::swap(__first_, __t.__first_);
            _VSTD::swap(__begin_, __t.__begin_);
            _VSTD::swap(__end_, __t.__end_);
            _VSTD::swap(__end_cap(), __t.__end_cap());
        }
    }
    __alloc_traits::construct(__alloc(), _VSTD::__to_address(__end_), __x);
    ++__end_;
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Allocator>
void
__split_buffer<_Tp, _Allocator>::push_back(value_type&& __x)
{
    if (__end_ == __end_cap())
    {
        if (__begin_ > __first_)
        {
            difference_type __d = __begin_ - __first_;
            __d = (__d + 1) / 2;
            __end_ = _VSTD::move(__begin_, __end_, __begin_ - __d);
            __begin_ -= __d;
        }
        else
        {
            size_type __c = max<size_type>(2 * static_cast<size_t>(__end_cap() - __first_), 1);
            __split_buffer<value_type, __alloc_rr&> __t(__c, __c / 4, __alloc());
            __t.__construct_at_end(move_iterator<pointer>(__begin_),
                                   move_iterator<pointer>(__end_));
            _VSTD::swap(__first_, __t.__first_);
            _VSTD::swap(__begin_, __t.__begin_);
            _VSTD::swap(__end_, __t.__end_);
            _VSTD::swap(__end_cap(), __t.__end_cap());
        }
    }
    __alloc_traits::construct(__alloc(), _VSTD::__to_address(__end_),
            _VSTD::move(__x));
    ++__end_;
}

template <class _Tp, class _Allocator>
template <class... _Args>
void
__split_buffer<_Tp, _Allocator>::emplace_back(_Args&&... __args)
{
    if (__end_ == __end_cap())
    {
        if (__begin_ > __first_)
        {
            difference_type __d = __begin_ - __first_;
            __d = (__d + 1) / 2;
            __end_ = _VSTD::move(__begin_, __end_, __begin_ - __d);
            __begin_ -= __d;
        }
        else
        {
            size_type __c = max<size_type>(2 * static_cast<size_t>(__end_cap() - __first_), 1);
            __split_buffer<value_type, __alloc_rr&> __t(__c, __c / 4, __alloc());
            __t.__construct_at_end(move_iterator<pointer>(__begin_),
                                   move_iterator<pointer>(__end_));
            _VSTD::swap(__first_, __t.__first_);
            _VSTD::swap(__begin_, __t.__begin_);
            _VSTD::swap(__end_, __t.__end_);
            _VSTD::swap(__end_cap(), __t.__end_cap());
        }
    }
    __alloc_traits::construct(__alloc(), _VSTD::__to_address(__end_),
                              _VSTD::forward<_Args>(__args)...);
    ++__end_;
}

#endif  // _LIBCPP_CXX03_LANG
# 630 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(__split_buffer<_Tp, _Allocator>& __x, __split_buffer<_Tp, _Allocator>& __y)
        _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_SPLIT_BUFFER
# 645 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__split_buffer" 3
# 285 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 285 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 286 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 287 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 288 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 290 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 291 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#endif
# 292 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 294 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

template <bool>
class _LIBCPP_TEMPLATE_VIS __vector_base_common
{
protected:
    _LIBCPP_INLINE_VISIBILITY __vector_base_common() {}
    _LIBCPP_NORETURN void __throw_length_error() const;
    _LIBCPP_NORETURN void __throw_out_of_range() const;
};

template <bool __b>
void
__vector_base_common<__b>::__throw_length_error() const
{
    _VSTD::__throw_length_error("vector");
}

template <bool __b>
void
__vector_base_common<__b>::__throw_out_of_range() const
{
    _VSTD::__throw_out_of_range("vector");
}

_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_EXTERN_TEMPLATE_TYPE_VIS __vector_base_common<true>)

template <class _Tp, class _Allocator>
class __vector_base
    : protected __vector_base_common<true>
{
public:
    typedef _Allocator                               allocator_type;
    typedef allocator_traits<allocator_type>         __alloc_traits;
    typedef typename __alloc_traits::size_type       size_type;
protected:
    typedef _Tp                                      value_type;
    typedef value_type&                              reference;
    typedef const value_type&                        const_reference;
    typedef typename __alloc_traits::difference_type difference_type;
    typedef typename __alloc_traits::pointer         pointer;
    typedef typename __alloc_traits::const_pointer   const_pointer;
    typedef pointer                                  iterator;
    typedef const_pointer                            const_iterator;

    pointer                                         __begin_;
    pointer                                         __end_;
    __compressed_pair<pointer, allocator_type> __end_cap_;

    _LIBCPP_INLINE_VISIBILITY
    allocator_type& __alloc() _NOEXCEPT
        {return __end_cap_.second();}
    _LIBCPP_INLINE_VISIBILITY
    const allocator_type& __alloc() const _NOEXCEPT
        {return __end_cap_.second();}
    _LIBCPP_INLINE_VISIBILITY
    pointer& __end_cap() _NOEXCEPT
        {return __end_cap_.first();}
    _LIBCPP_INLINE_VISIBILITY
    const pointer& __end_cap() const _NOEXCEPT
        {return __end_cap_.first();}

    _LIBCPP_INLINE_VISIBILITY
    __vector_base()
        _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value);
    _LIBCPP_INLINE_VISIBILITY __vector_base(const allocator_type& __a);
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY __vector_base(allocator_type&& __a) _NOEXCEPT;
#endif
# 366 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    ~__vector_base();

    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT {__destruct_at_end(__begin_);}
    _LIBCPP_INLINE_VISIBILITY
    size_type capacity() const _NOEXCEPT
        {return static_cast<size_type>(__end_cap() - __begin_);}

    _LIBCPP_INLINE_VISIBILITY
    void __destruct_at_end(pointer __new_last) _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __vector_base& __c)
        {__copy_assign_alloc(__c, integral_constant<bool,
                      __alloc_traits::propagate_on_container_copy_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__vector_base& __c)
        _NOEXCEPT_(
            !__alloc_traits::propagate_on_container_move_assignment::value ||
            is_nothrow_move_assignable<allocator_type>::value)
        {__move_assign_alloc(__c, integral_constant<bool,
                      __alloc_traits::propagate_on_container_move_assignment::value>());}
private:
    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __vector_base& __c, true_type)
        {
            if (__alloc() != __c.__alloc())
            {
                clear();
                __alloc_traits::deallocate(__alloc(), __begin_, capacity());
                __begin_ = __end_ = __end_cap() = nullptr;
            }
            __alloc() = __c.__alloc();
        }

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __vector_base&, false_type)
        {}

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__vector_base& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
        {
            __alloc() = _VSTD::move(__c.__alloc());
        }

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__vector_base&, false_type)
        _NOEXCEPT
        {}
};

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
__vector_base<_Tp, _Allocator>::__destruct_at_end(pointer __new_last) _NOEXCEPT
{
    pointer __soon_to_be_end = __end_;
    while (__new_last != __soon_to_be_end)
        __alloc_traits::destroy(__alloc(), _VSTD::__to_address(--__soon_to_be_end));
    __end_ = __new_last;
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
__vector_base<_Tp, _Allocator>::__vector_base()
        _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value)
    : __begin_(nullptr),
      __end_(nullptr),
      __end_cap_(nullptr, __default_init_tag())
{
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
__vector_base<_Tp, _Allocator>::__vector_base(const allocator_type& __a)
    : __begin_(nullptr),
      __end_(nullptr),
      __end_cap_(nullptr, __a)
{
}

#ifndef _LIBCPP_CXX03_LANG
template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
__vector_base<_Tp, _Allocator>::__vector_base(allocator_type&& __a) _NOEXCEPT
    : __begin_(nullptr),
      __end_(nullptr),
      __end_cap_(nullptr, std::move(__a)) {}
#endif
# 457 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Tp, class _Allocator>
__vector_base<_Tp, _Allocator>::~__vector_base()
{
    if (__begin_ != nullptr)
    {
        clear();
        __alloc_traits::deallocate(__alloc(), __begin_, capacity());
    }
}

template <class _Tp, class _Allocator /* = allocator<_Tp> */>
class _LIBCPP_TEMPLATE_VIS vector
    : private __vector_base<_Tp, _Allocator>
{
private:
    typedef __vector_base<_Tp, _Allocator>           __base;
    typedef allocator<_Tp>                           __default_allocator_type;
public:
    typedef vector                                   __self;
    typedef _Tp                                      value_type;
    typedef _Allocator                               allocator_type;
    typedef typename __base::__alloc_traits          __alloc_traits;
    typedef typename __base::reference               reference;
    typedef typename __base::const_reference         const_reference;
    typedef typename __base::size_type               size_type;
    typedef typename __base::difference_type         difference_type;
    typedef typename __base::pointer                 pointer;
    typedef typename __base::const_pointer           const_pointer;
    typedef __wrap_iter<pointer>                     iterator;
    typedef __wrap_iter<const_pointer>               const_iterator;
    typedef _VSTD::reverse_iterator<iterator>         reverse_iterator;
    typedef _VSTD::reverse_iterator<const_iterator>   const_reverse_iterator;

    static_assert((is_same<typename allocator_type::value_type, value_type>::value),
                  "Allocator::value_type must be same type as value_type");

    _LIBCPP_INLINE_VISIBILITY
    vector() _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value)
        {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 498 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
            __get_db()->__insert_c(this);
#endif
# 500 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        }
    _LIBCPP_INLINE_VISIBILITY explicit vector(const allocator_type& __a)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 503 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT_(is_nothrow_copy_constructible<allocator_type>::value)
#else
# 505 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT
#endif
# 507 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        : __base(__a)
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 510 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        __get_db()->__insert_c(this);
#endif
# 512 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }
    explicit vector(size_type __n);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 515 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    explicit vector(size_type __n, const allocator_type& __a);
#endif
# 517 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    vector(size_type __n, const value_type& __x);
    vector(size_type __n, const value_type& __x, const allocator_type& __a);
    template <class _InputIterator>
        vector(_InputIterator __first,
               typename enable_if<__is_cpp17_input_iterator  <_InputIterator>::value &&
                                 !__is_cpp17_forward_iterator<_InputIterator>::value &&
                                 is_constructible<
                                    value_type,
                                    typename iterator_traits<_InputIterator>::reference>::value,
                                 _InputIterator>::type __last);
    template <class _InputIterator>
        vector(_InputIterator __first, _InputIterator __last, const allocator_type& __a,
               typename enable_if<__is_cpp17_input_iterator  <_InputIterator>::value &&
                                 !__is_cpp17_forward_iterator<_InputIterator>::value &&
                                 is_constructible<
                                    value_type,
                                    typename iterator_traits<_InputIterator>::reference>::value>::type* = 0);
    template <class _ForwardIterator>
        vector(_ForwardIterator __first,
               typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value &&
                                 is_constructible<
                                    value_type,
                                    typename iterator_traits<_ForwardIterator>::reference>::value,
                                 _ForwardIterator>::type __last);
    template <class _ForwardIterator>
        vector(_ForwardIterator __first, _ForwardIterator __last, const allocator_type& __a,
               typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value &&
                                 is_constructible<
                                    value_type,
                                    typename iterator_traits<_ForwardIterator>::reference>::value>::type* = 0);

    _LIBCPP_INLINE_VISIBILITY
    ~vector()
    {
        __annotate_delete();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 553 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        __get_db()->__erase_c(this);
#endif
# 555 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }

    vector(const vector& __x);
    vector(const vector& __x, const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    vector& operator=(const vector& __x);

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    vector(initializer_list<value_type> __il);

    _LIBCPP_INLINE_VISIBILITY
    vector(initializer_list<value_type> __il, const allocator_type& __a);

    _LIBCPP_INLINE_VISIBILITY
    vector(vector&& __x)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 572 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT;
#else
# 574 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value);
#endif
# 576 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    _LIBCPP_INLINE_VISIBILITY
    vector(vector&& __x, const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    vector& operator=(vector&& __x)
        _NOEXCEPT_((__noexcept_move_assign_container<_Allocator, __alloc_traits>::value));

    _LIBCPP_INLINE_VISIBILITY
    vector& operator=(initializer_list<value_type> __il)
        {assign(__il.begin(), __il.end()); return *this;}

#endif  // !_LIBCPP_CXX03_LANG
# 588 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    template <class _InputIterator>
        typename enable_if
        <
             __is_cpp17_input_iterator  <_InputIterator>::value &&
            !__is_cpp17_forward_iterator<_InputIterator>::value &&
            is_constructible<
                 value_type,
                 typename iterator_traits<_InputIterator>::reference>::value,
            void
        >::type
        assign(_InputIterator __first, _InputIterator __last);
    template <class _ForwardIterator>
        typename enable_if
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value &&
            is_constructible<
                 value_type,
                 typename iterator_traits<_ForwardIterator>::reference>::value,
            void
        >::type
        assign(_ForwardIterator __first, _ForwardIterator __last);

    void assign(size_type __n, const_reference __u);

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    void assign(initializer_list<value_type> __il)
        {assign(__il.begin(), __il.end());}
#endif
# 618 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    _LIBCPP_INLINE_VISIBILITY
    allocator_type get_allocator() const _NOEXCEPT
        {return this->__alloc();}

    _LIBCPP_INLINE_VISIBILITY iterator               begin() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY const_iterator         begin()   const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY iterator               end() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY const_iterator         end()     const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator       rbegin() _NOEXCEPT
        {return       reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin()  const _NOEXCEPT
        {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator       rend() _NOEXCEPT
        {return       reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend()    const _NOEXCEPT
        {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY
    const_iterator         cbegin()  const _NOEXCEPT
        {return begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator         cend()    const _NOEXCEPT
        {return end();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT
        {return rbegin();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend()   const _NOEXCEPT
        {return rend();}

    _LIBCPP_INLINE_VISIBILITY
    size_type size() const _NOEXCEPT
        {return static_cast<size_type>(this->__end_ - this->__begin_);}
    _LIBCPP_INLINE_VISIBILITY
    size_type capacity() const _NOEXCEPT
        {return __base::capacity();}
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool empty() const _NOEXCEPT
        {return this->__begin_ == this->__end_;}
    size_type max_size() const _NOEXCEPT;
    void reserve(size_type __n);
    void shrink_to_fit() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY reference       operator[](size_type __n) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY const_reference operator[](size_type __n) const _NOEXCEPT;
    reference       at(size_type __n);
    const_reference at(size_type __n) const;

    _LIBCPP_INLINE_VISIBILITY reference       front() _NOEXCEPT
    {
        _LIBCPP_ASSERT(!empty(), "front() called for empty vector");
        return *this->__begin_;
    }
    _LIBCPP_INLINE_VISIBILITY const_reference front() const _NOEXCEPT
    {
        _LIBCPP_ASSERT(!empty(), "front() called for empty vector");
        return *this->__begin_;
    }
    _LIBCPP_INLINE_VISIBILITY reference       back() _NOEXCEPT
    {
        _LIBCPP_ASSERT(!empty(), "back() called for empty vector");
        return *(this->__end_ - 1);
    }
    _LIBCPP_INLINE_VISIBILITY const_reference back()  const _NOEXCEPT
    {
        _LIBCPP_ASSERT(!empty(), "back() called for empty vector");
        return *(this->__end_ - 1);
    }

    _LIBCPP_INLINE_VISIBILITY
    value_type*       data() _NOEXCEPT
        {return _VSTD::__to_address(this->__begin_);}
    _LIBCPP_INLINE_VISIBILITY
    const value_type* data() const _NOEXCEPT
        {return _VSTD::__to_address(this->__begin_);}

#ifdef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    void __emplace_back(const value_type& __x) { push_back(__x); }
#else
# 704 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    template <class _Arg>
    _LIBCPP_INLINE_VISIBILITY
    void __emplace_back(_Arg&& __arg) {
      emplace_back(_VSTD::forward<_Arg>(__arg));
    }
#endif
# 710 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    _LIBCPP_INLINE_VISIBILITY void push_back(const_reference __x);

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY void push_back(value_type&& __x);

    template <class... _Args>
        _LIBCPP_INLINE_VISIBILITY
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 719 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        reference emplace_back(_Args&&... __args);
#else
# 721 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        void      emplace_back(_Args&&... __args);
#endif
# 723 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
#endif // !_LIBCPP_CXX03_LANG
# 724 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    _LIBCPP_INLINE_VISIBILITY
    void pop_back();

    iterator insert(const_iterator __position, const_reference __x);

#ifndef _LIBCPP_CXX03_LANG
    iterator insert(const_iterator __position, value_type&& __x);
    template <class... _Args>
        iterator emplace(const_iterator __position, _Args&&... __args);
#endif  // !_LIBCPP_CXX03_LANG
# 735 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    iterator insert(const_iterator __position, size_type __n, const_reference __x);
    template <class _InputIterator>
        typename enable_if
        <
             __is_cpp17_input_iterator  <_InputIterator>::value &&
            !__is_cpp17_forward_iterator<_InputIterator>::value &&
            is_constructible<
                 value_type,
                 typename iterator_traits<_InputIterator>::reference>::value,
            iterator
        >::type
        insert(const_iterator __position, _InputIterator __first, _InputIterator __last);
    template <class _ForwardIterator>
        typename enable_if
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value &&
            is_constructible<
                 value_type,
                 typename iterator_traits<_ForwardIterator>::reference>::value,
            iterator
        >::type
        insert(const_iterator __position, _ForwardIterator __first, _ForwardIterator __last);

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __position, initializer_list<value_type> __il)
        {return insert(__position, __il.begin(), __il.end());}
#endif
# 764 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    _LIBCPP_INLINE_VISIBILITY iterator erase(const_iterator __position);
    iterator erase(const_iterator __first, const_iterator __last);

    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT
    {
        size_type __old_size = size();
        __base::clear();
        __annotate_shrink(__old_size);
        __invalidate_all_iterators();
    }

    void resize(size_type __sz);
    void resize(size_type __sz, const_reference __x);

    void swap(vector&)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 782 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT;
#else
# 784 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value);
#endif
# 787 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    bool __invariants() const;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 791 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    bool __dereferenceable(const const_iterator* __i) const;
    bool __decrementable(const const_iterator* __i) const;
    bool __addable(const const_iterator* __i, ptrdiff_t __n) const;
    bool __subscriptable(const const_iterator* __i, ptrdiff_t __n) const;

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 798 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

private:
    _LIBCPP_INLINE_VISIBILITY void __invalidate_all_iterators();
    _LIBCPP_INLINE_VISIBILITY void __invalidate_iterators_past(pointer __new_last);
    void __vallocate(size_type __n);
    void __vdeallocate() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY size_type __recommend(size_type __new_size) const;
    void __construct_at_end(size_type __n);
    _LIBCPP_INLINE_VISIBILITY
    void __construct_at_end(size_type __n, const_reference __x);
    template <class _ForwardIterator>
        typename enable_if
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value,
            void
        >::type
        __construct_at_end(_ForwardIterator __first, _ForwardIterator __last, size_type __n);
    void __append(size_type __n);
    void __append(size_type __n, const_reference __x);
    _LIBCPP_INLINE_VISIBILITY
    iterator       __make_iter(pointer __p) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    const_iterator __make_iter(const_pointer __p) const _NOEXCEPT;
    void __swap_out_circular_buffer(__split_buffer<value_type, allocator_type&>& __v);
    pointer __swap_out_circular_buffer(__split_buffer<value_type, allocator_type&>& __v, pointer __p);
    void __move_range(pointer __from_s, pointer __from_e, pointer __to);
    void __move_assign(vector& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value);
    void __move_assign(vector& __c, false_type)
        _NOEXCEPT_(__alloc_traits::is_always_equal::value);
    _LIBCPP_INLINE_VISIBILITY
    void __destruct_at_end(pointer __new_last) _NOEXCEPT
    {
        __invalidate_iterators_past(__new_last);
        size_type __old_size = size();
        __base::__destruct_at_end(__new_last);
        __annotate_shrink(__old_size);
    }

#ifndef _LIBCPP_CXX03_LANG
    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY
    inline void __push_back_slow_path(_Up&& __x);

    template <class... _Args>
    _LIBCPP_INLINE_VISIBILITY
    inline void __emplace_back_slow_path(_Args&&... __args);
#else
# 846 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY
    inline void __push_back_slow_path(_Up& __x);
#endif
# 850 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    // The following functions are no-ops outside of AddressSanitizer mode.
    // We call annotatations only for the default Allocator because other allocators
    // may not meet the AddressSanitizer alignment constraints.
    // See the documentation for __sanitizer_annotate_contiguous_container for more details.
#ifndef _LIBCPP_HAS_NO_ASAN
    void __annotate_contiguous_container(const void *__beg, const void *__end,
                                         const void *__old_mid,
                                         const void *__new_mid) const
    {

      if (__beg && is_same<allocator_type, __default_allocator_type>::value)
        __sanitizer_annotate_contiguous_container(__beg, __end, __old_mid, __new_mid);
    }
#else
# 865 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_INLINE_VISIBILITY
    void __annotate_contiguous_container(const void*, const void*, const void*,
                                         const void*) const _NOEXCEPT {}
#endif
# 869 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_INLINE_VISIBILITY
    void __annotate_new(size_type __current_size) const _NOEXCEPT {
      __annotate_contiguous_container(data(), data() + capacity(),
                                      data() + capacity(), data() + __current_size);
    }

    _LIBCPP_INLINE_VISIBILITY
    void __annotate_delete() const _NOEXCEPT {
      __annotate_contiguous_container(data(), data() + capacity(),
                                      data() + size(), data() + capacity());
    }

    _LIBCPP_INLINE_VISIBILITY
    void __annotate_increase(size_type __n) const _NOEXCEPT
    {
      __annotate_contiguous_container(data(), data() + capacity(),
                                      data() + size(), data() + size() + __n);
    }

    _LIBCPP_INLINE_VISIBILITY
    void __annotate_shrink(size_type __old_size) const _NOEXCEPT
    {
      __annotate_contiguous_container(data(), data() + capacity(),
                                      data() + __old_size, data() + size());
    }

  struct _ConstructTransaction {
    explicit _ConstructTransaction(vector &__v, size_type __n)
      : __v_(__v),  __pos_(__v.__end_), __new_end_(__v.__end_ + __n) {
#ifndef _LIBCPP_HAS_NO_ASAN
      __v_.__annotate_increase(__n);
#endif
# 901 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }
    ~_ConstructTransaction() {
      __v_.__end_ = __pos_;
#ifndef _LIBCPP_HAS_NO_ASAN
      if (__pos_ != __new_end_) {
        __v_.__annotate_shrink(__new_end_ - __v_.__begin_);
      }
#endif
# 909 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }

    vector &__v_;
    pointer __pos_;
    const_pointer const __new_end_;

  private:
    _ConstructTransaction(_ConstructTransaction const&) = delete;
    _ConstructTransaction& operator=(_ConstructTransaction const&) = delete;
  };

  template <class ..._Args>
  _LIBCPP_INLINE_VISIBILITY
  void __construct_one_at_end(_Args&& ...__args) {
    _ConstructTransaction __tx(*this, 1);
    __alloc_traits::construct(this->__alloc(), _VSTD::__to_address(__tx.__pos_),
        _VSTD::forward<_Args>(__args)...);
    ++__tx.__pos_;
  }
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _InputIterator,
         class _Alloc = typename std::allocator<typename iterator_traits<_InputIterator>::value_type>,
         class = typename enable_if<__is_allocator<_Alloc>::value, void>::type
         >
vector(_InputIterator, _InputIterator)
  -> vector<typename iterator_traits<_InputIterator>::value_type, _Alloc>;

template<class _InputIterator,
         class _Alloc,
         class = typename enable_if<__is_allocator<_Alloc>::value, void>::type
         >
vector(_InputIterator, _InputIterator, _Alloc)
  -> vector<typename iterator_traits<_InputIterator>::value_type, _Alloc>;
#endif
# 945 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__swap_out_circular_buffer(__split_buffer<value_type, allocator_type&>& __v)
{

    __annotate_delete();
    __alloc_traits::__construct_backward_with_exception_guarantees(
        this->__alloc(), this->__begin_, this->__end_, __v.__begin_);
    _VSTD::swap(this->__begin_, __v.__begin_);
    _VSTD::swap(this->__end_, __v.__end_);
    _VSTD::swap(this->__end_cap(), __v.__end_cap());
    __v.__first_ = __v.__begin_;
    __annotate_new(size());
    __invalidate_all_iterators();
}

template <class _Tp, class _Allocator>
typename vector<_Tp, _Allocator>::pointer
vector<_Tp, _Allocator>::__swap_out_circular_buffer(__split_buffer<value_type, allocator_type&>& __v, pointer __p)
{
    __annotate_delete();
    pointer __r = __v.__begin_;
    __alloc_traits::__construct_backward_with_exception_guarantees(
        this->__alloc(), this->__begin_, __p, __v.__begin_);
    __alloc_traits::__construct_forward_with_exception_guarantees(
        this->__alloc(), __p, this->__end_, __v.__end_);
    _VSTD::swap(this->__begin_, __v.__begin_);
    _VSTD::swap(this->__end_, __v.__end_);
    _VSTD::swap(this->__end_cap(), __v.__end_cap());
    __v.__first_ = __v.__begin_;
    __annotate_new(size());
    __invalidate_all_iterators();
    return __r;
}

//  Allocate space for __n objects
//  throws length_error if __n > max_size()
//  throws (probably bad_alloc) if memory run out
//  Precondition:  __begin_ == __end_ == __end_cap() == 0
//  Precondition:  __n > 0
//  Postcondition:  capacity() == __n
//  Postcondition:  size() == 0
template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__vallocate(size_type __n)
{
    if (__n > max_size())
        this->__throw_length_error();
    this->__begin_ = this->__end_ = __alloc_traits::allocate(this->__alloc(), __n);
    this->__end_cap() = this->__begin_ + __n;
    __annotate_new(0);
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__vdeallocate() _NOEXCEPT
{
    if (this->__begin_ != nullptr)
    {
        clear();
        __alloc_traits::deallocate(this->__alloc(), this->__begin_, capacity());
        this->__begin_ = this->__end_ = this->__end_cap() = nullptr;
    }
}

template <class _Tp, class _Allocator>
typename vector<_Tp, _Allocator>::size_type
vector<_Tp, _Allocator>::max_size() const _NOEXCEPT
{
    return _VSTD::min<size_type>(__alloc_traits::max_size(this->__alloc()),
                                 numeric_limits<difference_type>::max());
}

//  Precondition:  __new_size > capacity()
template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::size_type
vector<_Tp, _Allocator>::__recommend(size_type __new_size) const
{
    const size_type __ms = max_size();
    if (__new_size > __ms)
        this->__throw_length_error();
    const size_type __cap = capacity();
    if (__cap >= __ms / 2)
        return __ms;
    return _VSTD::max<size_type>(2*__cap, __new_size);
}

//  Default constructs __n objects starting at __end_
//  throws if construction throws
//  Precondition:  __n > 0
//  Precondition:  size() + __n <= capacity()
//  Postcondition:  size() == size() + __n
template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__construct_at_end(size_type __n)
{
    _ConstructTransaction __tx(*this, __n);
    for (; __tx.__pos_ != __tx.__new_end_; ++__tx.__pos_) {
      __alloc_traits::construct(this->__alloc(), _VSTD::__to_address(__tx.__pos_));
    }
}

//  Copy constructs __n objects starting at __end_ from __x
//  throws if construction throws
//  Precondition:  __n > 0
//  Precondition:  size() + __n <= capacity()
//  Postcondition:  size() == old size() + __n
//  Postcondition:  [i] == __x for all i in [size() - __n, __n)
template <class _Tp, class _Allocator>
inline
void
vector<_Tp, _Allocator>::__construct_at_end(size_type __n, const_reference __x)
{
    _ConstructTransaction __tx(*this, __n);
    for (; __tx.__pos_ != __tx.__new_end_; ++__tx.__pos_) {
        __alloc_traits::construct(this->__alloc(), _VSTD::__to_address(__tx.__pos_), __x);
    }
}

template <class _Tp, class _Allocator>
template <class _ForwardIterator>
typename enable_if
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value,
    void
>::type
vector<_Tp, _Allocator>::__construct_at_end(_ForwardIterator __first, _ForwardIterator __last, size_type __n)
{
    _ConstructTransaction __tx(*this, __n);
    __alloc_traits::__construct_range_forward(this->__alloc(), __first, __last, __tx.__pos_);
}

//  Default constructs __n objects starting at __end_
//  throws if construction throws
//  Postcondition:  size() == size() + __n
//  Exception safety: strong.
template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__append(size_type __n)
{
    if (static_cast<size_type>(this->__end_cap() - this->__end_) >= __n)
        this->__construct_at_end(__n);
    else
    {
        allocator_type& __a = this->__alloc();
        __split_buffer<value_type, allocator_type&> __v(__recommend(size() + __n), size(), __a);
        __v.__construct_at_end(__n);
        __swap_out_circular_buffer(__v);
    }
}

//  Default constructs __n objects starting at __end_
//  throws if construction throws
//  Postcondition:  size() == size() + __n
//  Exception safety: strong.
template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__append(size_type __n, const_reference __x)
{
    if (static_cast<size_type>(this->__end_cap() - this->__end_) >= __n)
        this->__construct_at_end(__n, __x);
    else
    {
        allocator_type& __a = this->__alloc();
        __split_buffer<value_type, allocator_type&> __v(__recommend(size() + __n), size(), __a);
        __v.__construct_at_end(__n, __x);
        __swap_out_circular_buffer(__v);
    }
}

template <class _Tp, class _Allocator>
vector<_Tp, _Allocator>::vector(size_type __n)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1121 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__n);
    }
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1131 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
template <class _Tp, class _Allocator>
vector<_Tp, _Allocator>::vector(size_type __n, const allocator_type& __a)
    : __base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1136 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1138 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__n);
    }
}
#endif
# 1145 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Tp, class _Allocator>
vector<_Tp, _Allocator>::vector(size_type __n, const value_type& __x)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1150 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__n, __x);
    }
}

template <class _Tp, class _Allocator>
vector<_Tp, _Allocator>::vector(size_type __n, const value_type& __x, const allocator_type& __a)
    : __base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__n, __x);
    }
}

template <class _Tp, class _Allocator>
template <class _InputIterator>
vector<_Tp, _Allocator>::vector(_InputIterator __first,
       typename enable_if<__is_cpp17_input_iterator  <_InputIterator>::value &&
                         !__is_cpp17_forward_iterator<_InputIterator>::value &&
                         is_constructible<
                            value_type,
                            typename iterator_traits<_InputIterator>::reference>::value,
                          _InputIterator>::type __last)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1184 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1186 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    for (; __first != __last; ++__first)
        __emplace_back(*__first);
}

template <class _Tp, class _Allocator>
template <class _InputIterator>
vector<_Tp, _Allocator>::vector(_InputIterator __first, _InputIterator __last, const allocator_type& __a,
       typename enable_if<__is_cpp17_input_iterator  <_InputIterator>::value &&
                         !__is_cpp17_forward_iterator<_InputIterator>::value &&
                         is_constructible<
                            value_type,
                            typename iterator_traits<_InputIterator>::reference>::value>::type*)
    : __base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1201 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1203 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    for (; __first != __last; ++__first)
        __emplace_back(*__first);
}

template <class _Tp, class _Allocator>
template <class _ForwardIterator>
vector<_Tp, _Allocator>::vector(_ForwardIterator __first,
                                typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value &&
                                is_constructible<
                                   value_type,
                                   typename iterator_traits<_ForwardIterator>::reference>::value,
                                                   _ForwardIterator>::type __last)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1217 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1219 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__first, __last, __n);
    }
}

template <class _Tp, class _Allocator>
template <class _ForwardIterator>
vector<_Tp, _Allocator>::vector(_ForwardIterator __first, _ForwardIterator __last, const allocator_type& __a,
                                typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value &&
                                is_constructible<
                                   value_type,
                                   typename iterator_traits<_ForwardIterator>::reference>::value>::type*)
    : __base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1237 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1239 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__first, __last, __n);
    }
}

template <class _Tp, class _Allocator>
vector<_Tp, _Allocator>::vector(const vector& __x)
    : __base(__alloc_traits::select_on_container_copy_construction(__x.__alloc()))
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1252 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1254 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    size_type __n = __x.size();
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__x.__begin_, __x.__end_, __n);
    }
}

template <class _Tp, class _Allocator>
vector<_Tp, _Allocator>::vector(const vector& __x, const allocator_type& __a)
    : __base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1267 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1269 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    size_type __n = __x.size();
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__x.__begin_, __x.__end_, __n);
    }
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<_Tp, _Allocator>::vector(vector&& __x)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1283 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT
#else
# 1285 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value)
#endif
# 1287 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    : __base(_VSTD::move(__x.__alloc()))
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1290 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
    __get_db()->swap(this, &__x);
#endif
# 1293 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    this->__begin_ = __x.__begin_;
    this->__end_ = __x.__end_;
    this->__end_cap() = __x.__end_cap();
    __x.__begin_ = __x.__end_ = __x.__end_cap() = nullptr;
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<_Tp, _Allocator>::vector(vector&& __x, const allocator_type& __a)
    : __base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1307 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    if (__a == __x.__alloc())
    {
        this->__begin_ = __x.__begin_;
        this->__end_ = __x.__end_;
        this->__end_cap() = __x.__end_cap();
        __x.__begin_ = __x.__end_ = __x.__end_cap() = nullptr;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1314 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        __get_db()->swap(this, &__x);
#endif
# 1316 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }
    else
    {
        typedef move_iterator<iterator> _Ip;
        assign(_Ip(__x.begin()), _Ip(__x.end()));
    }
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<_Tp, _Allocator>::vector(initializer_list<value_type> __il)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1329 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1331 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    if (__il.size() > 0)
    {
        __vallocate(__il.size());
        __construct_at_end(__il.begin(), __il.end(), __il.size());
    }
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<_Tp, _Allocator>::vector(initializer_list<value_type> __il, const allocator_type& __a)
    : __base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1344 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__insert_c(this);
#endif
# 1346 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    if (__il.size() > 0)
    {
        __vallocate(__il.size());
        __construct_at_end(__il.begin(), __il.end(), __il.size());
    }
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<_Tp, _Allocator>&
vector<_Tp, _Allocator>::operator=(vector&& __x)
    _NOEXCEPT_((__noexcept_move_assign_container<_Allocator, __alloc_traits>::value))
{
    __move_assign(__x, integral_constant<bool,
          __alloc_traits::propagate_on_container_move_assignment::value>());
    return *this;
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__move_assign(vector& __c, false_type)
    _NOEXCEPT_(__alloc_traits::is_always_equal::value)
{
    if (__base::__alloc() != __c.__alloc())
    {
        typedef move_iterator<iterator> _Ip;
        assign(_Ip(__c.begin()), _Ip(__c.end()));
    }
    else
        __move_assign(__c, true_type());
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__move_assign(vector& __c, true_type)
    _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
{
    __vdeallocate();
    __base::__move_assign_alloc(__c); // this can throw
    this->__begin_ = __c.__begin_;
    this->__end_ = __c.__end_;
    this->__end_cap() = __c.__end_cap();
    __c.__begin_ = __c.__end_ = __c.__end_cap() = nullptr;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1390 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->swap(this, &__c);
#endif
# 1392 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}

#endif  // !_LIBCPP_CXX03_LANG
# 1395 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<_Tp, _Allocator>&
vector<_Tp, _Allocator>::operator=(const vector& __x)
{
    if (this != &__x)
    {
        __base::__copy_assign_alloc(__x);
        assign(__x.__begin_, __x.__end_);
    }
    return *this;
}

template <class _Tp, class _Allocator>
template <class _InputIterator>
typename enable_if
<
     __is_cpp17_input_iterator  <_InputIterator>::value &&
    !__is_cpp17_forward_iterator<_InputIterator>::value &&
    is_constructible<
       _Tp,
       typename iterator_traits<_InputIterator>::reference>::value,
    void
>::type
vector<_Tp, _Allocator>::assign(_InputIterator __first, _InputIterator __last)
{
    clear();
    for (; __first != __last; ++__first)
        __emplace_back(*__first);
}

template <class _Tp, class _Allocator>
template <class _ForwardIterator>
typename enable_if
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value &&
    is_constructible<
       _Tp,
       typename iterator_traits<_ForwardIterator>::reference>::value,
    void
>::type
vector<_Tp, _Allocator>::assign(_ForwardIterator __first, _ForwardIterator __last)
{
    size_type __new_size = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__new_size <= capacity())
    {
        _ForwardIterator __mid = __last;
        bool __growing = false;
        if (__new_size > size())
        {
            __growing = true;
            __mid =  __first;
            _VSTD::advance(__mid, size());
        }
        pointer __m = _VSTD::copy(__first, __mid, this->__begin_);
        if (__growing)
            __construct_at_end(__mid, __last, __new_size - size());
        else
            this->__destruct_at_end(__m);
    }
    else
    {
        __vdeallocate();
        __vallocate(__recommend(__new_size));
        __construct_at_end(__first, __last, __new_size);
    }
    __invalidate_all_iterators();
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::assign(size_type __n, const_reference __u)
{
    if (__n <= capacity())
    {
        size_type __s = size();
        _VSTD::fill_n(this->__begin_, _VSTD::min(__n, __s), __u);
        if (__n > __s)
            __construct_at_end(__n - __s, __u);
        else
            this->__destruct_at_end(this->__begin_ + __n);
    }
    else
    {
        __vdeallocate();
        __vallocate(__recommend(static_cast<size_type>(__n)));
        __construct_at_end(__n, __u);
    }
    __invalidate_all_iterators();
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::__make_iter(pointer __p) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1493 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    return iterator(this, __p);
#else
# 1495 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    return iterator(__p);
#endif
# 1497 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::const_iterator
vector<_Tp, _Allocator>::__make_iter(const_pointer __p) const _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1505 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    return const_iterator(this, __p);
#else
# 1507 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    return const_iterator(__p);
#endif
# 1509 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::begin() _NOEXCEPT
{
    return __make_iter(this->__begin_);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::const_iterator
vector<_Tp, _Allocator>::begin() const _NOEXCEPT
{
    return __make_iter(this->__begin_);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::end() _NOEXCEPT
{
    return __make_iter(this->__end_);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::const_iterator
vector<_Tp, _Allocator>::end() const _NOEXCEPT
{
    return __make_iter(this->__end_);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::reference
vector<_Tp, _Allocator>::operator[](size_type __n) _NOEXCEPT
{
    _LIBCPP_ASSERT(__n < size(), "vector[] index out of bounds");
    return this->__begin_[__n];
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::const_reference
vector<_Tp, _Allocator>::operator[](size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n < size(), "vector[] index out of bounds");
    return this->__begin_[__n];
}

template <class _Tp, class _Allocator>
typename vector<_Tp, _Allocator>::reference
vector<_Tp, _Allocator>::at(size_type __n)
{
    if (__n >= size())
        this->__throw_out_of_range();
    return this->__begin_[__n];
}

template <class _Tp, class _Allocator>
typename vector<_Tp, _Allocator>::const_reference
vector<_Tp, _Allocator>::at(size_type __n) const
{
    if (__n >= size())
        this->__throw_out_of_range();
    return this->__begin_[__n];
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::reserve(size_type __n)
{
    if (__n > capacity())
    {
        allocator_type& __a = this->__alloc();
        __split_buffer<value_type, allocator_type&> __v(__n, size(), __a);
        __swap_out_circular_buffer(__v);
    }
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::shrink_to_fit() _NOEXCEPT
{
    if (capacity() > size())
    {
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1601 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
            allocator_type& __a = this->__alloc();
            __split_buffer<value_type, allocator_type&> __v(size(), size(), __a);
            __swap_out_circular_buffer(__v);
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1610 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }
}

template <class _Tp, class _Allocator>
template <class _Up>
void
#ifndef _LIBCPP_CXX03_LANG
vector<_Tp, _Allocator>::__push_back_slow_path(_Up&& __x)
#else
# 1619 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
vector<_Tp, _Allocator>::__push_back_slow_path(_Up& __x)
#endif
# 1621 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
{
    allocator_type& __a = this->__alloc();
    __split_buffer<value_type, allocator_type&> __v(__recommend(size() + 1), size(), __a);
    // __v.push_back(_VSTD::forward<_Up>(__x));
    __alloc_traits::construct(__a, _VSTD::__to_address(__v.__end_), _VSTD::forward<_Up>(__x));
    __v.__end_++;
    __swap_out_circular_buffer(__v);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
vector<_Tp, _Allocator>::push_back(const_reference __x)
{
    if (this->__end_ != this->__end_cap())
    {
        __construct_one_at_end(__x);
    }
    else
        __push_back_slow_path(__x);
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
vector<_Tp, _Allocator>::push_back(value_type&& __x)
{
    if (this->__end_ < this->__end_cap())
    {
        __construct_one_at_end(_VSTD::move(__x));
    }
    else
        __push_back_slow_path(_VSTD::move(__x));
}

template <class _Tp, class _Allocator>
template <class... _Args>
void
vector<_Tp, _Allocator>::__emplace_back_slow_path(_Args&&... __args)
{
    allocator_type& __a = this->__alloc();
    __split_buffer<value_type, allocator_type&> __v(__recommend(size() + 1), size(), __a);
//    __v.emplace_back(_VSTD::forward<_Args>(__args)...);
    __alloc_traits::construct(__a, _VSTD::__to_address(__v.__end_), _VSTD::forward<_Args>(__args)...);
    __v.__end_++;
    __swap_out_circular_buffer(__v);
}

template <class _Tp, class _Allocator>
template <class... _Args>
inline
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1675 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
typename vector<_Tp, _Allocator>::reference
#else
# 1677 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
void
#endif
# 1679 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
vector<_Tp, _Allocator>::emplace_back(_Args&&... __args)
{
    if (this->__end_ < this->__end_cap())
    {
        __construct_one_at_end(_VSTD::forward<_Args>(__args)...);
    }
    else
        __emplace_back_slow_path(_VSTD::forward<_Args>(__args)...);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1688 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    return this->back();
#endif
# 1690 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}

#endif  // !_LIBCPP_CXX03_LANG
# 1693 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Tp, class _Allocator>
inline
void
vector<_Tp, _Allocator>::pop_back()
{
    _LIBCPP_ASSERT(!empty(), "vector::pop_back called for empty vector");
    this->__destruct_at_end(this->__end_ - 1);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::erase(const_iterator __position)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1709 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__position) == this,
        "vector::erase(iterator) called with an iterator not"
        " referring to this vector");
#endif
# 1713 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__position != end(),
        "vector::erase(iterator) called with a non-dereferenceable iterator");
    difference_type __ps = __position - cbegin();
    pointer __p = this->__begin_ + __ps;
    this->__destruct_at_end(_VSTD::move(__p + 1, this->__end_, __p));
    this->__invalidate_iterators_past(__p-1);
    iterator __r = __make_iter(__p);
    return __r;
}

template <class _Tp, class _Allocator>
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::erase(const_iterator __first, const_iterator __last)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1728 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__first) == this,
        "vector::erase(iterator,  iterator) called with an iterator not"
        " referring to this vector");
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__last) == this,
        "vector::erase(iterator,  iterator) called with an iterator not"
        " referring to this vector");
#endif
# 1735 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__first <= __last, "vector::erase(first, last) called with invalid range");
    pointer __p = this->__begin_ + (__first - begin());
    if (__first != __last) {
        this->__destruct_at_end(_VSTD::move(__p + (__last - __first), this->__end_, __p));
        this->__invalidate_iterators_past(__p - 1);
    }
    iterator __r = __make_iter(__p);
    return __r;
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::__move_range(pointer __from_s, pointer __from_e, pointer __to)
{
    pointer __old_last = this->__end_;
    difference_type __n = __old_last - __to;
    {
      pointer __i = __from_s + __n;
      _ConstructTransaction __tx(*this, __from_e - __i);
      for (; __i < __from_e; ++__i, ++__tx.__pos_) {
          __alloc_traits::construct(this->__alloc(),
                                    _VSTD::__to_address(__tx.__pos_),
                                    _VSTD::move(*__i));
      }
    }
    _VSTD::move_backward(__from_s, __from_s + __n, __old_last);
}

template <class _Tp, class _Allocator>
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::insert(const_iterator __position, const_reference __x)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1768 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__position) == this,
        "vector::insert(iterator, x) called with an iterator not"
        " referring to this vector");
#endif
# 1772 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    pointer __p = this->__begin_ + (__position - begin());
    if (this->__end_ < this->__end_cap())
    {
        if (__p == this->__end_)
        {
            __construct_one_at_end(__x);
        }
        else
        {
            __move_range(__p, this->__end_, __p + 1);
            const_pointer __xr = pointer_traits<const_pointer>::pointer_to(__x);
            if (__p <= __xr && __xr < this->__end_)
                ++__xr;
            *__p = *__xr;
        }
    }
    else
    {
        allocator_type& __a = this->__alloc();
        __split_buffer<value_type, allocator_type&> __v(__recommend(size() + 1), __p - this->__begin_, __a);
        __v.push_back(__x);
        __p = __swap_out_circular_buffer(__v, __p);
    }
    return __make_iter(__p);
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Allocator>
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::insert(const_iterator __position, value_type&& __x)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1805 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__position) == this,
        "vector::insert(iterator, x) called with an iterator not"
        " referring to this vector");
#endif
# 1809 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    pointer __p = this->__begin_ + (__position - begin());
    if (this->__end_ < this->__end_cap())
    {
        if (__p == this->__end_)
        {
            __construct_one_at_end(_VSTD::move(__x));
        }
        else
        {
            __move_range(__p, this->__end_, __p + 1);
            *__p = _VSTD::move(__x);
        }
    }
    else
    {
        allocator_type& __a = this->__alloc();
        __split_buffer<value_type, allocator_type&> __v(__recommend(size() + 1), __p - this->__begin_, __a);
        __v.push_back(_VSTD::move(__x));
        __p = __swap_out_circular_buffer(__v, __p);
    }
    return __make_iter(__p);
}

template <class _Tp, class _Allocator>
template <class... _Args>
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::emplace(const_iterator __position, _Args&&... __args)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1838 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__position) == this,
        "vector::emplace(iterator, x) called with an iterator not"
        " referring to this vector");
#endif
# 1842 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    pointer __p = this->__begin_ + (__position - begin());
    if (this->__end_ < this->__end_cap())
    {
        if (__p == this->__end_)
        {
            __construct_one_at_end(_VSTD::forward<_Args>(__args)...);
        }
        else
        {
            __temp_value<value_type, _Allocator> __tmp(this->__alloc(), _VSTD::forward<_Args>(__args)...);
            __move_range(__p, this->__end_, __p + 1);
            *__p = _VSTD::move(__tmp.get());
        }
    }
    else
    {
        allocator_type& __a = this->__alloc();
        __split_buffer<value_type, allocator_type&> __v(__recommend(size() + 1), __p - this->__begin_, __a);
        __v.emplace_back(_VSTD::forward<_Args>(__args)...);
        __p = __swap_out_circular_buffer(__v, __p);
    }
    return __make_iter(__p);
}

#endif  // !_LIBCPP_CXX03_LANG
# 1867 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Tp, class _Allocator>
typename vector<_Tp, _Allocator>::iterator
vector<_Tp, _Allocator>::insert(const_iterator __position, size_type __n, const_reference __x)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1873 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__position) == this,
        "vector::insert(iterator, n, x) called with an iterator not"
        " referring to this vector");
#endif
# 1877 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    pointer __p = this->__begin_ + (__position - begin());
    if (__n > 0)
    {
        if (__n <= static_cast<size_type>(this->__end_cap() - this->__end_))
        {
            size_type __old_n = __n;
            pointer __old_last = this->__end_;
            if (__n > static_cast<size_type>(this->__end_ - __p))
            {
                size_type __cx = __n - (this->__end_ - __p);
                __construct_at_end(__cx, __x);
                __n -= __cx;
            }
            if (__n > 0)
            {
                __move_range(__p, __old_last, __p + __old_n);
                const_pointer __xr = pointer_traits<const_pointer>::pointer_to(__x);
                if (__p <= __xr && __xr < this->__end_)
                    __xr += __old_n;
                _VSTD::fill_n(__p, __n, *__xr);
            }
        }
        else
        {
            allocator_type& __a = this->__alloc();
            __split_buffer<value_type, allocator_type&> __v(__recommend(size() + __n), __p - this->__begin_, __a);
            __v.__construct_at_end(__n, __x);
            __p = __swap_out_circular_buffer(__v, __p);
        }
    }
    return __make_iter(__p);
}

template <class _Tp, class _Allocator>
template <class _InputIterator>
typename enable_if
<
     __is_cpp17_input_iterator  <_InputIterator>::value &&
    !__is_cpp17_forward_iterator<_InputIterator>::value &&
    is_constructible<
       _Tp,
       typename iterator_traits<_InputIterator>::reference>::value,
    typename vector<_Tp, _Allocator>::iterator
>::type
vector<_Tp, _Allocator>::insert(const_iterator __position, _InputIterator __first, _InputIterator __last)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1924 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__position) == this,
        "vector::insert(iterator, range) called with an iterator not"
        " referring to this vector");
#endif
# 1928 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    difference_type __off = __position - begin();
    pointer __p = this->__begin_ + __off;
    allocator_type& __a = this->__alloc();
    pointer __old_last = this->__end_;
    for (; this->__end_ != this->__end_cap() && __first != __last; ++__first)
    {
        __construct_one_at_end(*__first);
    }
    __split_buffer<value_type, allocator_type&> __v(__a);
    if (__first != __last)
    {
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1943 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
            __v.__construct_at_end(__first, __last);
            difference_type __old_size = __old_last - this->__begin_;
            difference_type __old_p = __p - this->__begin_;
            reserve(__recommend(size() + __v.size()));
            __p = this->__begin_ + __old_p;
            __old_last = this->__begin_ + __old_size;
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
            erase(__make_iter(__old_last), end());
            throw;
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1957 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }
    __p = _VSTD::rotate(__p, __old_last, this->__end_);
    insert(__make_iter(__p), _VSTD::make_move_iterator(__v.begin()),
                             _VSTD::make_move_iterator(__v.end()));
    return begin() + __off;
}

template <class _Tp, class _Allocator>
template <class _ForwardIterator>
typename enable_if
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value &&
    is_constructible<
       _Tp,
       typename iterator_traits<_ForwardIterator>::reference>::value,
    typename vector<_Tp, _Allocator>::iterator
>::type
vector<_Tp, _Allocator>::insert(const_iterator __position, _ForwardIterator __first, _ForwardIterator __last)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1977 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__position) == this,
        "vector::insert(iterator, range) called with an iterator not"
        " referring to this vector");
#endif
# 1981 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    pointer __p = this->__begin_ + (__position - begin());
    difference_type __n = _VSTD::distance(__first, __last);
    if (__n > 0)
    {
        if (__n <= this->__end_cap() - this->__end_)
        {
            size_type __old_n = __n;
            pointer __old_last = this->__end_;
            _ForwardIterator __m = __last;
            difference_type __dx = this->__end_ - __p;
            if (__n > __dx)
            {
                __m = __first;
                difference_type __diff = this->__end_ - __p;
                _VSTD::advance(__m, __diff);
                __construct_at_end(__m, __last, __n - __diff);
                __n = __dx;
            }
            if (__n > 0)
            {
                __move_range(__p, __old_last, __p + __old_n);
                _VSTD::copy(__first, __m, __p);
            }
        }
        else
        {
            allocator_type& __a = this->__alloc();
            __split_buffer<value_type, allocator_type&> __v(__recommend(size() + __n), __p - this->__begin_, __a);
            __v.__construct_at_end(__first, __last);
            __p = __swap_out_circular_buffer(__v, __p);
        }
    }
    return __make_iter(__p);
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::resize(size_type __sz)
{
    size_type __cs = size();
    if (__cs < __sz)
        this->__append(__sz - __cs);
    else if (__cs > __sz)
        this->__destruct_at_end(this->__begin_ + __sz);
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::resize(size_type __sz, const_reference __x)
{
    size_type __cs = size();
    if (__cs < __sz)
        this->__append(__sz - __cs, __x);
    else if (__cs > __sz)
        this->__destruct_at_end(this->__begin_ + __sz);
}

template <class _Tp, class _Allocator>
void
vector<_Tp, _Allocator>::swap(vector& __x)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2042 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _NOEXCEPT
#else
# 2044 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                __is_nothrow_swappable<allocator_type>::value)
#endif
# 2047 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
{
    _LIBCPP_ASSERT(__alloc_traits::propagate_on_container_swap::value ||
                   this->__alloc() == __x.__alloc(),
                   "vector::swap: Either propagate_on_container_swap must be true"
                   " or the allocators must compare equal");
    _VSTD::swap(this->__begin_, __x.__begin_);
    _VSTD::swap(this->__end_, __x.__end_);
    _VSTD::swap(this->__end_cap(), __x.__end_cap());
    __swap_allocator(this->__alloc(), __x.__alloc(),
        integral_constant<bool,__alloc_traits::propagate_on_container_swap::value>());
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2058 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->swap(this, &__x);
#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 2060 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}

template <class _Tp, class _Allocator>
bool
vector<_Tp, _Allocator>::__invariants() const
{
    if (this->__begin_ == nullptr)
    {
        if (this->__end_ != nullptr || this->__end_cap() != nullptr)
            return false;
    }
    else
    {
        if (this->__begin_ > this->__end_)
            return false;
        if (this->__begin_ == this->__end_cap())
            return false;
        if (this->__end_ > this->__end_cap())
            return false;
    }
    return true;
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2084 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Tp, class _Allocator>
bool
vector<_Tp, _Allocator>::__dereferenceable(const const_iterator* __i) const
{
    return this->__begin_ <= __i->base() && __i->base() < this->__end_;
}

template <class _Tp, class _Allocator>
bool
vector<_Tp, _Allocator>::__decrementable(const const_iterator* __i) const
{
    return this->__begin_ < __i->base() && __i->base() <= this->__end_;
}

template <class _Tp, class _Allocator>
bool
vector<_Tp, _Allocator>::__addable(const const_iterator* __i, ptrdiff_t __n) const
{
    const_pointer __p = __i->base() + __n;
    return this->__begin_ <= __p && __p <= this->__end_;
}

template <class _Tp, class _Allocator>
bool
vector<_Tp, _Allocator>::__subscriptable(const const_iterator* __i, ptrdiff_t __n) const
{
    const_pointer __p = __i->base() + __n;
    return this->__begin_ <= __p && __p < this->__end_;
}

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 2116 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
vector<_Tp, _Allocator>::__invalidate_all_iterators()
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    __get_db()->__invalidate_all(this);
#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 2125 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}


template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
vector<_Tp, _Allocator>::__invalidate_iterators_past(pointer __new_last) {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2133 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
  __c_node* __c = __get_db()->__find_c_and_lock(this);
  for (__i_node** __p = __c->end_; __p != __c->beg_; ) {
    --__p;
    const_iterator* __i = static_cast<const_iterator*>((*__p)->__i_);
    if (__i->base() > __new_last) {
      (*__p)->__c_ = nullptr;
      if (--__c->end_ != __p)
        memmove(__p, __p+1, (__c->end_ - __p)*sizeof(__i_node*));
    }
  }
  __get_db()->unlock();
#else
# 2145 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
  ((void)__new_last);
#endif
# 2147 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}

// vector<bool>

template <class _Allocator> class vector<bool, _Allocator>;

template <class _Allocator> struct hash<vector<bool, _Allocator> >;

template <class _Allocator>
struct __has_storage_type<vector<bool, _Allocator> >
{
    static const bool value = true;
};

template <class _Allocator>
class _LIBCPP_TEMPLATE_VIS vector<bool, _Allocator>
    : private __vector_base_common<true>
{
public:
    typedef vector                                   __self;
    typedef bool                                     value_type;
    typedef _Allocator                               allocator_type;
    typedef allocator_traits<allocator_type>         __alloc_traits;
    typedef typename __alloc_traits::size_type       size_type;
    typedef typename __alloc_traits::difference_type difference_type;
    typedef size_type __storage_type;
    typedef __bit_iterator<vector, false>            pointer;
    typedef __bit_iterator<vector, true>             const_pointer;
    typedef pointer                                  iterator;
    typedef const_pointer                            const_iterator;
    typedef _VSTD::reverse_iterator<iterator>         reverse_iterator;
    typedef _VSTD::reverse_iterator<const_iterator>   const_reverse_iterator;

private:
    typedef typename __rebind_alloc_helper<__alloc_traits, __storage_type>::type __storage_allocator;
    typedef allocator_traits<__storage_allocator>    __storage_traits;
    typedef typename __storage_traits::pointer       __storage_pointer;
    typedef typename __storage_traits::const_pointer __const_storage_pointer;

    __storage_pointer                                      __begin_;
    size_type                                              __size_;
    __compressed_pair<size_type, __storage_allocator> __cap_alloc_;
public:
    typedef __bit_reference<vector>                  reference;
    typedef __bit_const_reference<vector>            const_reference;
private:
    _LIBCPP_INLINE_VISIBILITY
    size_type& __cap() _NOEXCEPT
        {return __cap_alloc_.first();}
    _LIBCPP_INLINE_VISIBILITY
    const size_type& __cap() const _NOEXCEPT
        {return __cap_alloc_.first();}
    _LIBCPP_INLINE_VISIBILITY
    __storage_allocator& __alloc() _NOEXCEPT
        {return __cap_alloc_.second();}
    _LIBCPP_INLINE_VISIBILITY
    const __storage_allocator& __alloc() const _NOEXCEPT
        {return __cap_alloc_.second();}

    static const unsigned __bits_per_word = static_cast<unsigned>(sizeof(__storage_type) * CHAR_BIT);

    _LIBCPP_INLINE_VISIBILITY
    static size_type __internal_cap_to_external(size_type __n) _NOEXCEPT
        {return __n * __bits_per_word;}
    _LIBCPP_INLINE_VISIBILITY
    static size_type __external_cap_to_internal(size_type __n) _NOEXCEPT
        {return (__n - 1) / __bits_per_word + 1;}

public:
    _LIBCPP_INLINE_VISIBILITY
    vector() _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value);

    _LIBCPP_INLINE_VISIBILITY explicit vector(const allocator_type& __a)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2221 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT_(is_nothrow_copy_constructible<allocator_type>::value);
#else
# 2223 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT;
#endif
# 2225 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    ~vector();
    explicit vector(size_type __n);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2228 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    explicit vector(size_type __n, const allocator_type& __a);
#endif
# 2230 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    vector(size_type __n, const value_type& __v);
    vector(size_type __n, const value_type& __v, const allocator_type& __a);
    template <class _InputIterator>
        vector(_InputIterator __first, _InputIterator __last,
               typename enable_if<__is_cpp17_input_iterator  <_InputIterator>::value &&
                                 !__is_cpp17_forward_iterator<_InputIterator>::value>::type* = 0);
    template <class _InputIterator>
        vector(_InputIterator __first, _InputIterator __last, const allocator_type& __a,
               typename enable_if<__is_cpp17_input_iterator  <_InputIterator>::value &&
                                 !__is_cpp17_forward_iterator<_InputIterator>::value>::type* = 0);
    template <class _ForwardIterator>
        vector(_ForwardIterator __first, _ForwardIterator __last,
               typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value>::type* = 0);
    template <class _ForwardIterator>
        vector(_ForwardIterator __first, _ForwardIterator __last, const allocator_type& __a,
               typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value>::type* = 0);

    vector(const vector& __v);
    vector(const vector& __v, const allocator_type& __a);
    vector& operator=(const vector& __v);

#ifndef _LIBCPP_CXX03_LANG
    vector(initializer_list<value_type> __il);
    vector(initializer_list<value_type> __il, const allocator_type& __a);

    _LIBCPP_INLINE_VISIBILITY
    vector(vector&& __v)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2258 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT;
#else
# 2260 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value);
#endif
# 2262 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    vector(vector&& __v, const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    vector& operator=(vector&& __v)
        _NOEXCEPT_((__noexcept_move_assign_container<_Allocator, __alloc_traits>::value));

    _LIBCPP_INLINE_VISIBILITY
    vector& operator=(initializer_list<value_type> __il)
        {assign(__il.begin(), __il.end()); return *this;}

#endif  // !_LIBCPP_CXX03_LANG
# 2272 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    template <class _InputIterator>
        typename enable_if
        <
            __is_cpp17_input_iterator<_InputIterator>::value &&
           !__is_cpp17_forward_iterator<_InputIterator>::value,
           void
        >::type
        assign(_InputIterator __first, _InputIterator __last);
    template <class _ForwardIterator>
        typename enable_if
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value,
           void
        >::type
        assign(_ForwardIterator __first, _ForwardIterator __last);

    void assign(size_type __n, const value_type& __x);

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    void assign(initializer_list<value_type> __il)
        {assign(__il.begin(), __il.end());}
#endif
# 2296 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    _LIBCPP_INLINE_VISIBILITY allocator_type get_allocator() const _NOEXCEPT
        {return allocator_type(this->__alloc());}

    size_type max_size() const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type capacity() const _NOEXCEPT
        {return __internal_cap_to_external(__cap());}
    _LIBCPP_INLINE_VISIBILITY
    size_type size() const _NOEXCEPT
        {return __size_;}
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool empty() const _NOEXCEPT
        {return __size_ == 0;}
    void reserve(size_type __n);
    void shrink_to_fit() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    iterator begin() _NOEXCEPT
        {return __make_iter(0);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT
        {return __make_iter(0);}
    _LIBCPP_INLINE_VISIBILITY
    iterator end() _NOEXCEPT
        {return __make_iter(__size_);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end()   const _NOEXCEPT
        {return __make_iter(__size_);}

    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator rbegin() _NOEXCEPT
        {return       reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin() const _NOEXCEPT
        {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator rend() _NOEXCEPT
        {return       reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend()   const _NOEXCEPT
        {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY
    const_iterator         cbegin()  const _NOEXCEPT
        {return __make_iter(0);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator         cend()    const _NOEXCEPT
        {return __make_iter(__size_);}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT
        {return rbegin();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend()   const _NOEXCEPT
        {return rend();}

    _LIBCPP_INLINE_VISIBILITY reference       operator[](size_type __n)       {return __make_ref(__n);}
    _LIBCPP_INLINE_VISIBILITY const_reference operator[](size_type __n) const {return __make_ref(__n);}
    reference       at(size_type __n);
    const_reference at(size_type __n) const;

    _LIBCPP_INLINE_VISIBILITY reference       front()       {return __make_ref(0);}
    _LIBCPP_INLINE_VISIBILITY const_reference front() const {return __make_ref(0);}
    _LIBCPP_INLINE_VISIBILITY reference       back()        {return __make_ref(__size_ - 1);}
    _LIBCPP_INLINE_VISIBILITY const_reference back()  const {return __make_ref(__size_ - 1);}

    void push_back(const value_type& __x);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2364 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    template <class... _Args>
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2366 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_INLINE_VISIBILITY reference emplace_back(_Args&&... __args)
#else
# 2368 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _LIBCPP_INLINE_VISIBILITY void      emplace_back(_Args&&... __args)
#endif
# 2370 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    {
        push_back ( value_type ( _VSTD::forward<_Args>(__args)... ));
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2373 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        return this->back();
#endif
# 2375 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }
#endif
# 2377 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    _LIBCPP_INLINE_VISIBILITY void pop_back() {--__size_;}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2381 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    template <class... _Args>
   _LIBCPP_INLINE_VISIBILITY iterator emplace(const_iterator position, _Args&&... __args)
        { return insert ( position, value_type ( _VSTD::forward<_Args>(__args)... )); }
#endif
# 2385 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    iterator insert(const_iterator __position, const value_type& __x);
    iterator insert(const_iterator __position, size_type __n, const value_type& __x);
    iterator insert(const_iterator __position, size_type __n, const_reference __x);
    template <class _InputIterator>
        typename enable_if
        <
             __is_cpp17_input_iterator  <_InputIterator>::value &&
            !__is_cpp17_forward_iterator<_InputIterator>::value,
            iterator
        >::type
        insert(const_iterator __position, _InputIterator __first, _InputIterator __last);
    template <class _ForwardIterator>
        typename enable_if
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value,
            iterator
        >::type
        insert(const_iterator __position, _ForwardIterator __first, _ForwardIterator __last);

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __position, initializer_list<value_type> __il)
        {return insert(__position, __il.begin(), __il.end());}
#endif
# 2410 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

    _LIBCPP_INLINE_VISIBILITY iterator erase(const_iterator __position);
    iterator erase(const_iterator __first, const_iterator __last);

    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT {__size_ = 0;}

    void swap(vector&)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2419 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT;
#else
# 2421 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value);
#endif
# 2424 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    static void swap(reference __x, reference __y) _NOEXCEPT { _VSTD::swap(__x, __y); }

    void resize(size_type __sz, value_type __x = false);
    void flip() _NOEXCEPT;

    bool __invariants() const;

private:
    _LIBCPP_INLINE_VISIBILITY void __invalidate_all_iterators();
    void __vallocate(size_type __n);
    void __vdeallocate() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    static size_type __align_it(size_type __new_size) _NOEXCEPT
        {return __new_size + (__bits_per_word-1) & ~((size_type)__bits_per_word-1);}
    _LIBCPP_INLINE_VISIBILITY  size_type __recommend(size_type __new_size) const;
    _LIBCPP_INLINE_VISIBILITY void __construct_at_end(size_type __n, bool __x);
    template <class _ForwardIterator>
        typename enable_if
        <
            __is_cpp17_forward_iterator<_ForwardIterator>::value,
            void
        >::type
        __construct_at_end(_ForwardIterator __first, _ForwardIterator __last);
    void __append(size_type __n, const_reference __x);
    _LIBCPP_INLINE_VISIBILITY
    reference __make_ref(size_type __pos) _NOEXCEPT
        {return reference(__begin_ + __pos / __bits_per_word, __storage_type(1) << __pos % __bits_per_word);}
    _LIBCPP_INLINE_VISIBILITY
    const_reference __make_ref(size_type __pos) const _NOEXCEPT
        {return const_reference(__begin_ + __pos / __bits_per_word, __storage_type(1) << __pos % __bits_per_word);}
    _LIBCPP_INLINE_VISIBILITY
    iterator __make_iter(size_type __pos) _NOEXCEPT
        {return iterator(__begin_ + __pos / __bits_per_word, static_cast<unsigned>(__pos % __bits_per_word));}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator __make_iter(size_type __pos) const _NOEXCEPT
        {return const_iterator(__begin_ + __pos / __bits_per_word, static_cast<unsigned>(__pos % __bits_per_word));}
    _LIBCPP_INLINE_VISIBILITY
    iterator __const_iterator_cast(const_iterator __p) _NOEXCEPT
        {return begin() + (__p - cbegin());}

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const vector& __v)
        {__copy_assign_alloc(__v, integral_constant<bool,
                      __storage_traits::propagate_on_container_copy_assignment::value>());}
    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const vector& __c, true_type)
        {
            if (__alloc() != __c.__alloc())
                __vdeallocate();
            __alloc() = __c.__alloc();
        }

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const vector&, false_type)
        {}

    void __move_assign(vector& __c, false_type);
    void __move_assign(vector& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value);
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(vector& __c)
        _NOEXCEPT_(
            !__storage_traits::propagate_on_container_move_assignment::value ||
            is_nothrow_move_assignable<allocator_type>::value)
        {__move_assign_alloc(__c, integral_constant<bool,
                      __storage_traits::propagate_on_container_move_assignment::value>());}
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(vector& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
        {
            __alloc() = _VSTD::move(__c.__alloc());
        }

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(vector&, false_type)
        _NOEXCEPT
        {}

    size_t __hash_code() const _NOEXCEPT;

    friend class __bit_reference<vector>;
    friend class __bit_const_reference<vector>;
    friend class __bit_iterator<vector, false>;
    friend class __bit_iterator<vector, true>;
    friend struct __bit_array<vector>;
    friend struct _LIBCPP_TEMPLATE_VIS hash<vector>;
};

template <class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
vector<bool, _Allocator>::__invalidate_all_iterators()
{
}

//  Allocate space for __n objects
//  throws length_error if __n > max_size()
//  throws (probably bad_alloc) if memory run out
//  Precondition:  __begin_ == __end_ == __cap() == 0
//  Precondition:  __n > 0
//  Postcondition:  capacity() == __n
//  Postcondition:  size() == 0
template <class _Allocator>
void
vector<bool, _Allocator>::__vallocate(size_type __n)
{
    if (__n > max_size())
        this->__throw_length_error();
    __n = __external_cap_to_internal(__n);
    this->__begin_ = __storage_traits::allocate(this->__alloc(), __n);
    this->__size_ = 0;
    this->__cap() = __n;
}

template <class _Allocator>
void
vector<bool, _Allocator>::__vdeallocate() _NOEXCEPT
{
    if (this->__begin_ != nullptr)
    {
        __storage_traits::deallocate(this->__alloc(), this->__begin_, __cap());
        __invalidate_all_iterators();
        this->__begin_ = nullptr;
        this->__size_ = this->__cap() = 0;
    }
}

template <class _Allocator>
typename vector<bool, _Allocator>::size_type
vector<bool, _Allocator>::max_size() const _NOEXCEPT
{
    size_type __amax = __storage_traits::max_size(__alloc());
    size_type __nmax = numeric_limits<size_type>::max() / 2;  // end() >= begin(), always
    if (__nmax / __bits_per_word <= __amax)
        return __nmax;
    return __internal_cap_to_external(__amax);
}

//  Precondition:  __new_size > capacity()
template <class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<bool, _Allocator>::size_type
vector<bool, _Allocator>::__recommend(size_type __new_size) const
{
    const size_type __ms = max_size();
    if (__new_size > __ms)
        this->__throw_length_error();
    const size_type __cap = capacity();
    if (__cap >= __ms / 2)
        return __ms;
    return _VSTD::max(2*__cap, __align_it(__new_size));
}

//  Default constructs __n objects starting at __end_
//  Precondition:  __n > 0
//  Precondition:  size() + __n <= capacity()
//  Postcondition:  size() == size() + __n
template <class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
vector<bool, _Allocator>::__construct_at_end(size_type __n, bool __x)
{
    size_type __old_size = this->__size_;
    this->__size_ += __n;
    if (__old_size == 0 || ((__old_size - 1) / __bits_per_word) != ((this->__size_ - 1) / __bits_per_word))
    {
        if (this->__size_ <= __bits_per_word)
            this->__begin_[0] = __storage_type(0);
        else
            this->__begin_[(this->__size_ - 1) / __bits_per_word] = __storage_type(0);
    }
    _VSTD::fill_n(__make_iter(__old_size), __n, __x);
}

template <class _Allocator>
template <class _ForwardIterator>
typename enable_if
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value,
    void
>::type
vector<bool, _Allocator>::__construct_at_end(_ForwardIterator __first, _ForwardIterator __last)
{
    size_type __old_size = this->__size_;
    this->__size_ += _VSTD::distance(__first, __last);
    if (__old_size == 0 || ((__old_size - 1) / __bits_per_word) != ((this->__size_ - 1) / __bits_per_word))
    {
        if (this->__size_ <= __bits_per_word)
            this->__begin_[0] = __storage_type(0);
        else
            this->__begin_[(this->__size_ - 1) / __bits_per_word] = __storage_type(0);
    }
    _VSTD::copy(__first, __last, __make_iter(__old_size));
}

template <class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<bool, _Allocator>::vector()
    _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __default_init_tag())
{
}

template <class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<bool, _Allocator>::vector(const allocator_type& __a)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2633 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT_(is_nothrow_copy_constructible<allocator_type>::value)
#else
# 2635 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        _NOEXCEPT
#endif
# 2637 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, static_cast<__storage_allocator>(__a))
{
}

template <class _Allocator>
vector<bool, _Allocator>::vector(size_type __n)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __default_init_tag())
{
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__n, false);
    }
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2657 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
template <class _Allocator>
vector<bool, _Allocator>::vector(size_type __n, const allocator_type& __a)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, static_cast<__storage_allocator>(__a))
{
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__n, false);
    }
}
#endif
# 2670 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Allocator>
vector<bool, _Allocator>::vector(size_type __n, const value_type& __x)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __default_init_tag())
{
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__n, __x);
    }
}

template <class _Allocator>
vector<bool, _Allocator>::vector(size_type __n, const value_type& __x, const allocator_type& __a)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, static_cast<__storage_allocator>(__a))
{
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__n, __x);
    }
}

template <class _Allocator>
template <class _InputIterator>
vector<bool, _Allocator>::vector(_InputIterator __first, _InputIterator __last,
       typename enable_if<__is_cpp17_input_iterator  <_InputIterator>::value &&
                         !__is_cpp17_forward_iterator<_InputIterator>::value>::type*)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __default_init_tag())
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2710 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        for (; __first != __last; ++__first)
            push_back(*__first);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        if (__begin_ != nullptr)
            __storage_traits::deallocate(__alloc(), __begin_, __cap());
        __invalidate_all_iterators();
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2722 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}

template <class _Allocator>
template <class _InputIterator>
vector<bool, _Allocator>::vector(_InputIterator __first, _InputIterator __last, const allocator_type& __a,
       typename enable_if<__is_cpp17_input_iterator  <_InputIterator>::value &&
                         !__is_cpp17_forward_iterator<_InputIterator>::value>::type*)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, static_cast<__storage_allocator>(__a))
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2737 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
        for (; __first != __last; ++__first)
            push_back(*__first);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        if (__begin_ != nullptr)
            __storage_traits::deallocate(__alloc(), __begin_, __cap());
        __invalidate_all_iterators();
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2749 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
}

template <class _Allocator>
template <class _ForwardIterator>
vector<bool, _Allocator>::vector(_ForwardIterator __first, _ForwardIterator __last,
                                typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value>::type*)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __default_init_tag())
{
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__first, __last);
    }
}

template <class _Allocator>
template <class _ForwardIterator>
vector<bool, _Allocator>::vector(_ForwardIterator __first, _ForwardIterator __last, const allocator_type& __a,
                                typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value>::type*)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, static_cast<__storage_allocator>(__a))
{
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__first, __last);
    }
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Allocator>
vector<bool, _Allocator>::vector(initializer_list<value_type> __il)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __default_init_tag())
{
    size_type __n = static_cast<size_type>(__il.size());
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__il.begin(), __il.end());
    }
}

template <class _Allocator>
vector<bool, _Allocator>::vector(initializer_list<value_type> __il, const allocator_type& __a)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, static_cast<__storage_allocator>(__a))
{
    size_type __n = static_cast<size_type>(__il.size());
    if (__n > 0)
    {
        __vallocate(__n);
        __construct_at_end(__il.begin(), __il.end());
    }
}

#endif  // _LIBCPP_CXX03_LANG
# 2814 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Allocator>
vector<bool, _Allocator>::~vector()
{
    if (__begin_ != nullptr)
        __storage_traits::deallocate(__alloc(), __begin_, __cap());
    __invalidate_all_iterators();
}

template <class _Allocator>
vector<bool, _Allocator>::vector(const vector& __v)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __storage_traits::select_on_container_copy_construction(__v.__alloc()))
{
    if (__v.size() > 0)
    {
        __vallocate(__v.size());
        __construct_at_end(__v.begin(), __v.end());
    }
}

template <class _Allocator>
vector<bool, _Allocator>::vector(const vector& __v, const allocator_type& __a)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __a)
{
    if (__v.size() > 0)
    {
        __vallocate(__v.size());
        __construct_at_end(__v.begin(), __v.end());
    }
}

template <class _Allocator>
vector<bool, _Allocator>&
vector<bool, _Allocator>::operator=(const vector& __v)
{
    if (this != &__v)
    {
        __copy_assign_alloc(__v);
        if (__v.__size_)
        {
            if (__v.__size_ > capacity())
            {
                __vdeallocate();
                __vallocate(__v.__size_);
            }
            _VSTD::copy(__v.__begin_, __v.__begin_ + __external_cap_to_internal(__v.__size_), __begin_);
        }
        __size_ = __v.__size_;
    }
    return *this;
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY vector<bool, _Allocator>::vector(vector&& __v)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2875 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _NOEXCEPT
#else
# 2877 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value)
#endif
# 2879 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    : __begin_(__v.__begin_),
      __size_(__v.__size_),
      __cap_alloc_(std::move(__v.__cap_alloc_)) {
    __v.__begin_ = nullptr;
    __v.__size_ = 0;
    __v.__cap() = 0;
}

template <class _Allocator>
vector<bool, _Allocator>::vector(vector&& __v, const allocator_type& __a)
    : __begin_(nullptr),
      __size_(0),
      __cap_alloc_(0, __a)
{
    if (__a == allocator_type(__v.__alloc()))
    {
        this->__begin_ = __v.__begin_;
        this->__size_ = __v.__size_;
        this->__cap() = __v.__cap();
        __v.__begin_ = nullptr;
        __v.__cap() = __v.__size_ = 0;
    }
    else if (__v.size() > 0)
    {
        __vallocate(__v.size());
        __construct_at_end(__v.begin(), __v.end());
    }
}

template <class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
vector<bool, _Allocator>&
vector<bool, _Allocator>::operator=(vector&& __v)
    _NOEXCEPT_((__noexcept_move_assign_container<_Allocator, __alloc_traits>::value))
{
    __move_assign(__v, integral_constant<bool,
          __storage_traits::propagate_on_container_move_assignment::value>());
    return *this;
}

template <class _Allocator>
void
vector<bool, _Allocator>::__move_assign(vector& __c, false_type)
{
    if (__alloc() != __c.__alloc())
        assign(__c.begin(), __c.end());
    else
        __move_assign(__c, true_type());
}

template <class _Allocator>
void
vector<bool, _Allocator>::__move_assign(vector& __c, true_type)
    _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
{
    __vdeallocate();
    __move_assign_alloc(__c);
    this->__begin_ = __c.__begin_;
    this->__size_ = __c.__size_;
    this->__cap() = __c.__cap();
    __c.__begin_ = nullptr;
    __c.__cap() = __c.__size_ = 0;
}

#endif  // !_LIBCPP_CXX03_LANG
# 2944 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

template <class _Allocator>
void
vector<bool, _Allocator>::assign(size_type __n, const value_type& __x)
{
    __size_ = 0;
    if (__n > 0)
    {
        size_type __c = capacity();
        if (__n <= __c)
            __size_ = __n;
        else
        {
            vector __v(__alloc());
            __v.reserve(__recommend(__n));
            __v.__size_ = __n;
            swap(__v);
        }
        _VSTD::fill_n(begin(), __n, __x);
    }
  __invalidate_all_iterators();
}

template <class _Allocator>
template <class _InputIterator>
typename enable_if
<
    __is_cpp17_input_iterator<_InputIterator>::value &&
   !__is_cpp17_forward_iterator<_InputIterator>::value,
   void
>::type
vector<bool, _Allocator>::assign(_InputIterator __first, _InputIterator __last)
{
    clear();
    for (; __first != __last; ++__first)
        push_back(*__first);
}

template <class _Allocator>
template <class _ForwardIterator>
typename enable_if
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value,
   void
>::type
vector<bool, _Allocator>::assign(_ForwardIterator __first, _ForwardIterator __last)
{
    clear();
    difference_type __ns = _VSTD::distance(__first, __last);
    _LIBCPP_ASSERT(__ns >= 0, "invalid range specified");
    const size_t __n = static_cast<size_type>(__ns);
    if (__n)
    {
        if (__n > capacity())
        {
            __vdeallocate();
            __vallocate(__n);
        }
        __construct_at_end(__first, __last);
    }
}

template <class _Allocator>
void
vector<bool, _Allocator>::reserve(size_type __n)
{
    if (__n > capacity())
    {
        vector __v(this->__alloc());
        __v.__vallocate(__n);
        __v.__construct_at_end(this->begin(), this->end());
        swap(__v);
        __invalidate_all_iterators();
    }
}

template <class _Allocator>
void
vector<bool, _Allocator>::shrink_to_fit() _NOEXCEPT
{
    if (__external_cap_to_internal(size()) > __cap())
    {
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3030 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
            vector(*this, allocator_type(__alloc())).swap(*this);
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3037 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }
}

template <class _Allocator>
typename vector<bool, _Allocator>::reference
vector<bool, _Allocator>::at(size_type __n)
{
    if (__n >= size())
        this->__throw_out_of_range();
    return (*this)[__n];
}

template <class _Allocator>
typename vector<bool, _Allocator>::const_reference
vector<bool, _Allocator>::at(size_type __n) const
{
    if (__n >= size())
        this->__throw_out_of_range();
    return (*this)[__n];
}

template <class _Allocator>
void
vector<bool, _Allocator>::push_back(const value_type& __x)
{
    if (this->__size_ == this->capacity())
        reserve(__recommend(this->__size_ + 1));
    ++this->__size_;
    back() = __x;
}

template <class _Allocator>
typename vector<bool, _Allocator>::iterator
vector<bool, _Allocator>::insert(const_iterator __position, const value_type& __x)
{
    iterator __r;
    if (size() < capacity())
    {
        const_iterator __old_end = end();
        ++__size_;
        _VSTD::copy_backward(__position, __old_end, end());
        __r = __const_iterator_cast(__position);
    }
    else
    {
        vector __v(__alloc());
        __v.reserve(__recommend(__size_ + 1));
        __v.__size_ = __size_ + 1;
        __r = _VSTD::copy(cbegin(), __position, __v.begin());
        _VSTD::copy_backward(__position, cend(), __v.end());
        swap(__v);
    }
    *__r = __x;
    return __r;
}

template <class _Allocator>
typename vector<bool, _Allocator>::iterator
vector<bool, _Allocator>::insert(const_iterator __position, size_type __n, const value_type& __x)
{
    iterator __r;
    size_type __c = capacity();
    if (__n <= __c && size() <= __c - __n)
    {
        const_iterator __old_end = end();
        __size_ += __n;
        _VSTD::copy_backward(__position, __old_end, end());
        __r = __const_iterator_cast(__position);
    }
    else
    {
        vector __v(__alloc());
        __v.reserve(__recommend(__size_ + __n));
        __v.__size_ = __size_ + __n;
        __r = _VSTD::copy(cbegin(), __position, __v.begin());
        _VSTD::copy_backward(__position, cend(), __v.end());
        swap(__v);
    }
    _VSTD::fill_n(__r, __n, __x);
    return __r;
}

template <class _Allocator>
template <class _InputIterator>
typename enable_if
<
     __is_cpp17_input_iterator  <_InputIterator>::value &&
    !__is_cpp17_forward_iterator<_InputIterator>::value,
    typename vector<bool, _Allocator>::iterator
>::type
vector<bool, _Allocator>::insert(const_iterator __position, _InputIterator __first, _InputIterator __last)
{
    difference_type __off = __position - begin();
    iterator __p = __const_iterator_cast(__position);
    iterator __old_end = end();
    for (; size() != capacity() && __first != __last; ++__first)
    {
        ++this->__size_;
        back() = *__first;
    }
    vector __v(__alloc());
    if (__first != __last)
    {
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3144 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
            __v.assign(__first, __last);
            difference_type __old_size = static_cast<difference_type>(__old_end - begin());
            difference_type __old_p = __p - begin();
            reserve(__recommend(size() + __v.size()));
            __p = begin() + __old_p;
            __old_end = begin() + __old_size;
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
            erase(__old_end, end());
            throw;
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    }
    __p = _VSTD::rotate(__p, __old_end, end());
    insert(__p, __v.begin(), __v.end());
    return begin() + __off;
}

template <class _Allocator>
template <class _ForwardIterator>
typename enable_if
<
    __is_cpp17_forward_iterator<_ForwardIterator>::value,
    typename vector<bool, _Allocator>::iterator
>::type
vector<bool, _Allocator>::insert(const_iterator __position, _ForwardIterator __first, _ForwardIterator __last)
{
    const difference_type __n_signed = _VSTD::distance(__first, __last);
    _LIBCPP_ASSERT(__n_signed >= 0, "invalid range specified");
    const size_type __n = static_cast<size_type>(__n_signed);
    iterator __r;
    size_type __c = capacity();
    if (__n <= __c && size() <= __c - __n)
    {
        const_iterator __old_end = end();
        __size_ += __n;
        _VSTD::copy_backward(__position, __old_end, end());
        __r = __const_iterator_cast(__position);
    }
    else
    {
        vector __v(__alloc());
        __v.reserve(__recommend(__size_ + __n));
        __v.__size_ = __size_ + __n;
        __r = _VSTD::copy(cbegin(), __position, __v.begin());
        _VSTD::copy_backward(__position, cend(), __v.end());
        swap(__v);
    }
    _VSTD::copy(__first, __last, __r);
    return __r;
}

template <class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename vector<bool, _Allocator>::iterator
vector<bool, _Allocator>::erase(const_iterator __position)
{
    iterator __r = __const_iterator_cast(__position);
    _VSTD::copy(__position + 1, this->cend(), __r);
    --__size_;
    return __r;
}

template <class _Allocator>
typename vector<bool, _Allocator>::iterator
vector<bool, _Allocator>::erase(const_iterator __first, const_iterator __last)
{
    iterator __r = __const_iterator_cast(__first);
    difference_type __d = __last - __first;
    _VSTD::copy(__last, this->cend(), __r);
    __size_ -= __d;
    return __r;
}

template <class _Allocator>
void
vector<bool, _Allocator>::swap(vector& __x)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3224 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _NOEXCEPT
#else
# 3226 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
    _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                __is_nothrow_swappable<allocator_type>::value)
#endif
# 3229 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
{
    _VSTD::swap(this->__begin_, __x.__begin_);
    _VSTD::swap(this->__size_, __x.__size_);
    _VSTD::swap(this->__cap(), __x.__cap());
    __swap_allocator(this->__alloc(), __x.__alloc(),
        integral_constant<bool, __alloc_traits::propagate_on_container_swap::value>());
}

template <class _Allocator>
void
vector<bool, _Allocator>::resize(size_type __sz, value_type __x)
{
    size_type __cs = size();
    if (__cs < __sz)
    {
        iterator __r;
        size_type __c = capacity();
        size_type __n = __sz - __cs;
        if (__n <= __c && __cs <= __c - __n)
        {
            __r = end();
            __size_ += __n;
        }
        else
        {
            vector __v(__alloc());
            __v.reserve(__recommend(__size_ + __n));
            __v.__size_ = __size_ + __n;
            __r = _VSTD::copy(cbegin(), cend(), __v.begin());
            swap(__v);
        }
        _VSTD::fill_n(__r, __n, __x);
    }
    else
        __size_ = __sz;
}

template <class _Allocator>
void
vector<bool, _Allocator>::flip() _NOEXCEPT
{
    // do middle whole words
    size_type __n = __size_;
    __storage_pointer __p = __begin_;
    for (; __n >= __bits_per_word; ++__p, __n -= __bits_per_word)
        *__p = ~*__p;
    // do last partial word
    if (__n > 0)
    {
        __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
        __storage_type __b = *__p & __m;
        *__p &= ~__m;
        *__p |= ~__b & __m;
    }
}

template <class _Allocator>
bool
vector<bool, _Allocator>::__invariants() const
{
    if (this->__begin_ == nullptr)
    {
        if (this->__size_ != 0 || this->__cap() != 0)
            return false;
    }
    else
    {
        if (this->__cap() == 0)
            return false;
        if (this->__size_ > this->capacity())
            return false;
    }
    return true;
}

template <class _Allocator>
size_t
vector<bool, _Allocator>::__hash_code() const _NOEXCEPT
{
    size_t __h = 0;
    // do middle whole words
    size_type __n = __size_;
    __storage_pointer __p = __begin_;
    for (; __n >= __bits_per_word; ++__p, __n -= __bits_per_word)
        __h ^= *__p;
    // do last partial word
    if (__n > 0)
    {
        const __storage_type __m = ~__storage_type(0) >> (__bits_per_word - __n);
        __h ^= *__p & __m;
    }
    return __h;
}

template <class _Allocator>
struct _LIBCPP_TEMPLATE_VIS hash<vector<bool, _Allocator> >
    : public unary_function<vector<bool, _Allocator>, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(const vector<bool, _Allocator>& __vec) const _NOEXCEPT
        {return __vec.__hash_code();}
};

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const vector<_Tp, _Allocator>& __x, const vector<_Tp, _Allocator>& __y)
{
    const typename vector<_Tp, _Allocator>::size_type __sz = __x.size();
    return __sz == __y.size() && _VSTD::equal(__x.begin(), __x.end(), __y.begin());
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const vector<_Tp, _Allocator>& __x, const vector<_Tp, _Allocator>& __y)
{
    return !(__x == __y);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const vector<_Tp, _Allocator>& __x, const vector<_Tp, _Allocator>& __y)
{
    return _VSTD::lexicographical_compare(__x.begin(), __x.end(), __y.begin(), __y.end());
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const vector<_Tp, _Allocator>& __x, const vector<_Tp, _Allocator>& __y)
{
    return __y < __x;
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const vector<_Tp, _Allocator>& __x, const vector<_Tp, _Allocator>& __y)
{
    return !(__x < __y);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const vector<_Tp, _Allocator>& __x, const vector<_Tp, _Allocator>& __y)
{
    return !(__y < __x);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(vector<_Tp, _Allocator>& __x, vector<_Tp, _Allocator>& __y)
    _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3391 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
template <class _Tp, class _Allocator, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
void erase(vector<_Tp, _Allocator>& __c, const _Up& __v)
{ __c.erase(_VSTD::remove(__c.begin(), __c.end(), __v), __c.end()); }

template <class _Tp, class _Allocator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
void erase_if(vector<_Tp, _Allocator>& __c, _Predicate __pred)
{ __c.erase(_VSTD::remove_if(__c.begin(), __c.end(), __pred), __c.end()); }
#endif
# 3401 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_VECTOR
# 3407 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/vector" 3
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h" 2

namespace clang {
  class DiagnosticsEngine;
  class SourceLocation;

  // Import the diagnostic enums themselves.
  namespace diag {
    // Size of each of the diagnostic categories.
    enum {
      DIAG_SIZE_COMMON        =  300,
      DIAG_SIZE_DRIVER        =  200,
      DIAG_SIZE_FRONTEND      =  150,
      DIAG_SIZE_SERIALIZATION =  120,
      DIAG_SIZE_LEX           =  400,
      DIAG_SIZE_PARSE         =  600,
      DIAG_SIZE_AST           =  200,
      DIAG_SIZE_COMMENT       =  100,
      DIAG_SIZE_CROSSTU       =  100,
      DIAG_SIZE_SEMA          = 4000,
      DIAG_SIZE_ANALYSIS      =  100,
      DIAG_SIZE_REFACTORING   = 1000,
    };
    // Start position for diagnostics.
    enum {
      DIAG_START_COMMON        =                          0,
      DIAG_START_DRIVER        = DIAG_START_COMMON        + DIAG_SIZE_COMMON,
      DIAG_START_FRONTEND      = DIAG_START_DRIVER        + DIAG_SIZE_DRIVER,
      DIAG_START_SERIALIZATION = DIAG_START_FRONTEND      + DIAG_SIZE_FRONTEND,
      DIAG_START_LEX           = DIAG_START_SERIALIZATION + DIAG_SIZE_SERIALIZATION,
      DIAG_START_PARSE         = DIAG_START_LEX           + DIAG_SIZE_LEX,
      DIAG_START_AST           = DIAG_START_PARSE         + DIAG_SIZE_PARSE,
      DIAG_START_COMMENT       = DIAG_START_AST           + DIAG_SIZE_AST,
      DIAG_START_CROSSTU       = DIAG_START_COMMENT       + DIAG_SIZE_COMMENT,
      DIAG_START_SEMA          = DIAG_START_CROSSTU       + DIAG_SIZE_CROSSTU,
      DIAG_START_ANALYSIS      = DIAG_START_SEMA          + DIAG_SIZE_SEMA,
      DIAG_START_REFACTORING   = DIAG_START_ANALYSIS      + DIAG_SIZE_ANALYSIS,
      DIAG_UPPER_LIMIT         = DIAG_START_REFACTORING   + DIAG_SIZE_REFACTORING
    };

    class CustomDiagInfo;

    /// All of the diagnostics that can be emitted by the frontend.
    typedef unsigned kind;

    // Get typedefs for common diagnostics.
    enum {
#define DIAG(ENUM,FLAGS,DEFAULT_MAPPING,DESC,GROUP,\
             SFINAE,CATEGORY,NOWERROR,SHOWINSYSHEADER) ENUM,
#define COMMONSTART
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/DiagnosticCommonKinds.inc"
#endif /* expanded by -frewrite-includes */
# 70 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h"
# 1 "tools/clang/include/clang/Basic/DiagnosticCommonKinds.inc" 1
#ifdef COMMONSTART
__COMMONSTART = DIAG_START_COMMON,
#undef COMMONSTART
#endif
# 5 "tools/clang/include/clang/Basic/DiagnosticCommonKinds.inc"

DIAG(err_arcmt_nsinvocation_ownership, CLASS_ERROR, (unsigned)diag::Severity::Error, "NSInvocation's %0 is not safe to be used with an object with ownership other than __unsafe_unretained", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_asm_invalid_type_in_input, CLASS_ERROR, (unsigned)diag::Severity::Error, "invalid type %0 in asm input for constraint '%1'", 0, SFINAE_SubstitutionFailure, false, true, 12)
DIAG(err_attribute_not_type_attr, CLASS_ERROR, (unsigned)diag::Severity::Error, "%0 attribute cannot be applied to types", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_attribute_uuid_malformed_guid, CLASS_ERROR, (unsigned)diag::Severity::Error, "uuid attribute contains a malformed GUID", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_cannot_open_file, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "cannot open file '%0': %1", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_default_special_members, CLASS_ERROR, (unsigned)diag::Severity::Error, "only special member functions %select{|and comparison operators }0may be defaulted", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_deleted_non_function, CLASS_ERROR, (unsigned)diag::Severity::Error, "only functions can have deleted definitions", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_duplicate_declspec, CLASS_ERROR, (unsigned)diag::Severity::Error, "duplicate '%0' declaration specifier", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_enum_template, CLASS_ERROR, (unsigned)diag::Severity::Error, "enumeration cannot be a template", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_expected, CLASS_ERROR, (unsigned)diag::Severity::Error, "expected %0", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_expected_after, CLASS_ERROR, (unsigned)diag::Severity::Error, "expected %1 after %0", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_expected_colon_after_setter_name, CLASS_ERROR, (unsigned)diag::Severity::Error, "method name referenced in property setter attribute must end with ':'", 0, SFINAE_SubstitutionFailure, false, true, 1)
DIAG(err_expected_either, CLASS_ERROR, (unsigned)diag::Severity::Error, "expected %0 or %1", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_expected_namespace_name, CLASS_ERROR, (unsigned)diag::Severity::Error, "expected namespace name", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_expected_string_literal, CLASS_ERROR, (unsigned)diag::Severity::Error, "expected string literal %select{in %1|for diagnostic message in static_assert|for optional message in 'availability' attribute|for %select{language|source container}1 name in 'external_source_symbol' attribute}0", 0, SFINAE_SubstitutionFailure, false, true, 1)
DIAG(err_file_modified, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "file '%0' modified since it was first processed", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_file_too_large, CLASS_ERROR, (unsigned)diag::Severity::Error, "sorry, unsupported: file '%0' is too large for Clang to process", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_fixed_point_not_enabled, CLASS_ERROR, (unsigned)diag::Severity::Error, "compile with '-ffixed-point' to enable fixed point types", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_friend_decl_spec, CLASS_ERROR, (unsigned)diag::Severity::Error, "'%0' is invalid in friend declarations", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_include_too_large, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "sorry, this include generates a translation unit too large for Clang to process.", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_integer_literal_too_large, CLASS_ERROR, (unsigned)diag::Severity::Error, "integer literal is too large to be represented in any %select{signed |}0integer type", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_invalid_character_udl, CLASS_ERROR, (unsigned)diag::Severity::Error, "character literal with user-defined suffix cannot be used here", 0, SFINAE_SubstitutionFailure, false, true, 1)
DIAG(err_invalid_member_in_interface, CLASS_ERROR, (unsigned)diag::Severity::Error, "%select{data member |non-public member function |static member function |user-declared constructor|user-declared destructor|operator |nested class }0%1 is not permitted within an interface type", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_invalid_numeric_udl, CLASS_ERROR, (unsigned)diag::Severity::Error, "numeric literal with user-defined suffix cannot be used here", 0, SFINAE_SubstitutionFailure, false, true, 1)
DIAG(err_invalid_storage_class_in_func_decl, CLASS_ERROR, (unsigned)diag::Severity::Error, "invalid storage class specifier in function declarator", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_invalid_string_udl, CLASS_ERROR, (unsigned)diag::Severity::Error, "string literal with user-defined suffix cannot be used here", 0, SFINAE_SubstitutionFailure, false, true, 1)
DIAG(err_mips_fp64_req, CLASS_ERROR, (unsigned)diag::Severity::Error, "'%0' can only be used if the target supports the mfhc1 and mthc1 instructions", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_module_build_disabled, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "module '%0' is needed but has not been provided, and implicit use of module files is disabled", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_module_build_shadowed_submodule, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "build a shadowed submodule '%0'", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_module_cycle, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "cyclic dependency in module '%0': %1", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_module_format_unhandled, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "no handler registered for module format '%0'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_module_header_missing, CLASS_ERROR, (unsigned)diag::Severity::Error, "%select{|umbrella }0header '%1' not found", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_module_not_built, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "could not build module '%0'", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_module_not_found, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "module '%0' not found", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_module_prebuilt, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "error in loading module '%0' from prebuilt module path", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_module_shadowed, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "import of shadowed module '%0'", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_module_unavailable, CLASS_ERROR, (unsigned)diag::Severity::Error, "module '%0' %select{is incompatible with|requires}1 feature '%2'", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_mt_message, CLASS_ERROR, (unsigned)diag::Severity::Error, "[rewriter] %0", 0, SFINAE_SubstitutionFailure, false, false, 0)
DIAG(err_nullability_conflicting, CLASS_ERROR, (unsigned)diag::Severity::Error, "nullability specifier %0 conflicts with existing specifier %1", 0, SFINAE_SubstitutionFailure, false, true, 21)
DIAG(err_omp_more_one_clause, CLASS_ERROR, (unsigned)diag::Severity::Error, "directive '#pragma omp %0' cannot contain more than one '%1' clause%select{| with '%3' name modifier| with 'source' dependence}2", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_opencl_unknown_type_specifier, CLASS_ERROR, (unsigned)diag::Severity::Error, "%select{OpenCL C|C++ for OpenCL}0 version %1 does not support the '%2' %select{type qualifier|storage class specifier}3", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_openclcxx_not_supported, CLASS_ERROR, (unsigned)diag::Severity::Error, "'%0' is not supported in C++ for OpenCL", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_opt_not_valid_on_target, CLASS_ERROR, (unsigned)diag::Severity::Error, "option '%0' cannot be specified on this target", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_opt_not_valid_with_opt, CLASS_ERROR, (unsigned)diag::Severity::Error, "option '%0' cannot be specified with '%1'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_opt_not_valid_without_opt, CLASS_ERROR, (unsigned)diag::Severity::Error, "option '%0' cannot be specified without '%1'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_param_redefinition, CLASS_ERROR, (unsigned)diag::Severity::Error, "redefinition of parameter %0", 0, SFINAE_SubstitutionFailure, false, true, 4)
DIAG(err_seh___except_block, CLASS_ERROR, (unsigned)diag::Severity::Error, "%0 only allowed in __except block or filter expression", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_seh___except_filter, CLASS_ERROR, (unsigned)diag::Severity::Error, "%0 only allowed in __except filter expression", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_seh___finally_block, CLASS_ERROR, (unsigned)diag::Severity::Error, "%0 only allowed in __finally block", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_seh_expected_handler, CLASS_ERROR, (unsigned)diag::Severity::Error, "expected '__except' or '__finally' block", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unknown_abi, CLASS_ERROR, (unsigned)diag::Severity::Error, "unknown target ABI '%0'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unknown_cpu, CLASS_ERROR, (unsigned)diag::Severity::Error, "unknown target CPU '%0'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unknown_fpmath, CLASS_ERROR, (unsigned)diag::Severity::Error, "unknown FP unit '%0'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unknown_triple, CLASS_ERROR, (unsigned)diag::Severity::Error, "unknown target triple '%0', please use -triple or -arch", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unsupported_abi, CLASS_ERROR, (unsigned)diag::Severity::Error, "ABI '%0' is not supported on CPU '%1'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unsupported_abi_for_triple, CLASS_ERROR, (unsigned)diag::Severity::Error, "ABI '%0' is not supported for '%1'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unsupported_cpu_for_micromips, CLASS_ERROR, (unsigned)diag::Severity::Error, "micromips is not supported for target CPU '%0'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unsupported_execute_only, CLASS_ERROR, (unsigned)diag::Severity::Error, "execute only is not supported for the %0 sub-architecture", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unsupported_fpmath, CLASS_ERROR, (unsigned)diag::Severity::Error, "the '%0' unit is not supported with this instruction set", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unsupported_mcmse, CLASS_ERROR, (unsigned)diag::Severity::Error, "-mcmse is not supported for %0", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_target_unsupported_unaligned, CLASS_ERROR, (unsigned)diag::Severity::Error, "the %0 sub-architecture does not support unaligned accesses", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_too_large_for_fixed_point, CLASS_ERROR, (unsigned)diag::Severity::Error, "this value is too large for this fixed point type", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_unable_to_make_temp, CLASS_ERROR, (unsigned)diag::Severity::Error, "unable to make temporary file: %0", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_unable_to_rename_temp, CLASS_ERROR, (unsigned)diag::Severity::Error, "unable to rename temporary '%0' to output file '%1': '%2'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_unimplemented_conversion_with_fixed_point_type, CLASS_ERROR, (unsigned)diag::Severity::Error, "conversion between fixed point and %0 is not yet supported", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_unknown_analyzer_checker_or_package, CLASS_ERROR, (unsigned)diag::Severity::Error, "no analyzer checkers or packages are associated with '%0'", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_unsupported_abi_for_opt, CLASS_ERROR, (unsigned)diag::Severity::Error, "'%0' can only be used with the '%1' ABI", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_unsupported_bom, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "%0 byte order mark detected in '%1', but encoding is not supported", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(err_use_of_tag_name_without_tag, CLASS_ERROR, (unsigned)diag::Severity::Error, "must use '%1' tag to refer to type %0%select{| in this scope}2", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(ext_c99_longlong, CLASS_EXTENSION, (unsigned)diag::Severity::Ignored, "'long long' is an extension when C99 mode is not enabled", 401, SFINAE_Suppress, false, false, 0)
DIAG(ext_clang_diagnose_if, CLASS_EXTENSION, (unsigned)diag::Severity::Ignored, "'diagnose_if' is a clang extension", 285, SFINAE_Suppress, false, false, 0)
DIAG(ext_clang_enable_if, CLASS_EXTENSION, (unsigned)diag::Severity::Ignored, "'enable_if' is a clang extension", 285, SFINAE_Suppress, false, false, 0)
DIAG(ext_cxx11_longlong, CLASS_EXTENSION, (unsigned)diag::Severity::Ignored, "'long long' is a C++11 extension", 89, SFINAE_Suppress, false, false, 0)
DIAG(ext_duplicate_declspec, CLASS_EXTENSION, (unsigned)diag::Severity::Ignored, "duplicate '%0' declaration specifier", 220, SFINAE_Suppress, false, false, 0)
DIAG(ext_integer_literal_too_large_for_signed, CLASS_EXTENSION, (unsigned)diag::Severity::Warning, "integer literal is too large to be represented in a signed integer type, interpreting as unsigned", 338, SFINAE_Suppress, false, false, 0)
DIAG(ext_old_implicitly_unsigned_long_cxx, CLASS_EXTENSION, (unsigned)diag::Severity::Warning, "integer literal is too large to be represented in type 'long' and is subject to undefined behavior under C++98, interpreting as 'unsigned long'; this literal will %select{have type 'long long'|be ill-formed}0 in C++11 onwards", 82, SFINAE_Suppress, false, false, 0)
DIAG(ext_variadic_templates, CLASS_EXTENSION, (unsigned)diag::Severity::Warning, "variadic templates are a C++11 extension", 86, SFINAE_Suppress, false, false, 4)
DIAG(ext_warn_duplicate_declspec, CLASS_EXTENSION, (unsigned)diag::Severity::Warning, "duplicate '%0' declaration specifier", 220, SFINAE_Suppress, false, false, 0)
DIAG(fatal_too_many_errors, CLASS_ERROR, (unsigned)diag::Severity::Fatal, "too many errors emitted, stopping now", 0, SFINAE_SubstitutionFailure, false, true, 0)
DIAG(note_also_found, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "also found", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_decl_hiding_tag_type, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "%1 %0 is hidden by a non-type declaration of %0 here", 0, SFINAE_Suppress, false, false, 4)
DIAG(note_declared_at, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "declared here", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_duplicate_case_prev, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "previous case defined here", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_forward_declaration, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "forward declaration of %0", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_invalid_subexpr_in_const_expr, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "subexpression not valid in a constant expression", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_matching, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "to match this %0", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_mt_message, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "[rewriter] %0", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_possibility, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "one possibility", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_pragma_entered_here, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "#pragma entered here", 0, SFINAE_Suppress, false, false, 4)
DIAG(note_previous_declaration, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "previous declaration is here", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_previous_definition, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "previous definition is here", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_previous_implicit_declaration, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "previous implicit declaration is here", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_previous_use, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "previous use is here", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_suggest_disabling_all_checkers, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "use -analyzer-disable-all-checks to disable all static analyzer checkers", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_type_being_defined, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "definition of %0 is not complete until the closing '}'", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_using, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "using", 0, SFINAE_Suppress, false, false, 0)
DIAG(note_valid_options, CLASS_NOTE, (unsigned)diag::Severity::Fatal, "valid target CPU values are: %0", 0, SFINAE_Suppress, false, false, 0)
DIAG(remark_module_lock_failure, CLASS_REMARK, (unsigned)diag::Severity::Ignored, "could not acquire lock file for module '%0': %1", 464, SFINAE_Suppress, false, false, 4)
DIAG(remark_module_lock_timeout, CLASS_REMARK, (unsigned)diag::Severity::Ignored, "timed out waiting to acquire lock file for module '%0'", 464, SFINAE_Suppress, false, false, 4)
DIAG(warn_arcmt_nsalloc_realloc, CLASS_WARNING, (unsigned)diag::Severity::Warning, "[rewriter] call returns pointer to GC managed memory; it will become unmanaged in ARC", 0, SFINAE_Suppress, false, false, 0)
DIAG(warn_conflicting_nullability_attr_overriding_param_types, CLASS_WARNING, (unsigned)diag::Severity::Warning, "conflicting nullability specifier on parameter types, %0 conflicts with existing specifier %1", 505, SFINAE_Suppress, false, false, 21)
DIAG(warn_conflicting_nullability_attr_overriding_ret_types, CLASS_WARNING, (unsigned)diag::Severity::Warning, "conflicting nullability specifier on return types, %0 conflicts with existing specifier %1", 505, SFINAE_Suppress, false, false, 21)
DIAG(warn_cxx20_compat_consteval, CLASS_WARNING, (unsigned)diag::Severity::Ignored, "'consteval' specifier is incompatible with C++ standards before C++20", 103, SFINAE_Suppress, false, false, 4)
DIAG(warn_cxx98_compat_longlong, CLASS_WARNING, (unsigned)diag::Severity::Ignored, "'long long' is incompatible with C++98", 121, SFINAE_Suppress, false, false, 0)
DIAG(warn_cxx98_compat_variadic_templates, CLASS_WARNING, (unsigned)diag::Severity::Ignored, "variadic templates are incompatible with C++98", 117, SFINAE_Suppress, false, false, 4)
DIAG(warn_dup_category_def, CLASS_WARNING, (unsigned)diag::Severity::Warning, "duplicate definition of category %1 on interface %0", 0, SFINAE_Suppress, false, false, 0)
DIAG(warn_duplicate_declspec, CLASS_WARNING, (unsigned)diag::Severity::Warning, "duplicate '%0' declaration specifier", 220, SFINAE_Suppress, false, false, 0)
DIAG(warn_ignored_hip_only_option, CLASS_WARNING, (unsigned)diag::Severity::Warning, "'%0' is ignored since it is only supported for HIP", 317, SFINAE_Suppress, false, false, 0)
DIAG(warn_method_param_declaration, CLASS_WARNING, (unsigned)diag::Severity::Ignored, "redeclaration of method parameter %0", 222, SFINAE_Suppress, false, false, 4)
DIAG(warn_method_param_redefinition, CLASS_WARNING, (unsigned)diag::Severity::Warning, "redefinition of method parameter %0", 0, SFINAE_Suppress, false, false, 4)
DIAG(warn_mt_message, CLASS_WARNING, (unsigned)diag::Severity::Warning, "[rewriter] %0", 0, SFINAE_Suppress, false, false, 0)
DIAG(warn_nullability_duplicate, CLASS_WARNING, (unsigned)diag::Severity::Warning, "duplicate nullability specifier %0", 505, SFINAE_Suppress, false, false, 21)
DIAG(warn_old_implicitly_unsigned_long, CLASS_WARNING, (unsigned)diag::Severity::Warning, "integer literal is too large to be represented in type 'long', interpreting as 'unsigned long' per C89; this literal will %select{have type 'long long'|be ill-formed}0 in C99 onwards", 124, SFINAE_Suppress, false, false, 0)
DIAG(warn_old_implicitly_unsigned_long_cxx, CLASS_WARNING, (unsigned)diag::Severity::Warning, "integer literal is too large to be represented in type 'long', interpreting as 'unsigned long' per C++98; this literal will %select{have type 'long long'|be ill-formed}0 in C++11 onwards", 82, SFINAE_Suppress, false, false, 0)
DIAG(warn_poison_system_directories, CLASS_WARNING, (unsigned)diag::Severity::Ignored, "include location '%0' is unsafe for cross-compilation", 592, SFINAE_Suppress, false, false, 0)
DIAG(warn_stack_clash_protection_inline_asm, CLASS_WARNING, (unsigned)diag::Severity::Warning, "Unable to protect inline asm that clobbers stack pointer against stack clash", 680, SFINAE_Suppress, false, false, 12)
DIAG(warn_stack_exhausted, CLASS_WARNING, (unsigned)diag::Severity::Warning, "stack nearly exhausted; compilation time may suffer, and crashes due to stack overflow are likely", 679, SFINAE_Report, false, false, 0)
DIAG(warn_unknown_attribute_ignored, CLASS_WARNING, (unsigned)diag::Severity::Warning, "unknown attribute %0 ignored", 762, SFINAE_Suppress, false, false, 0)
# 71 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h" 2
      NUM_BUILTIN_COMMON_DIAGNOSTICS
#undef DIAG
    };

    /// Enum values that allow the client to map NOTEs, WARNINGs, and EXTENSIONs
    /// to either Ignore (nothing), Remark (emit a remark), Warning
    /// (emit a warning) or Error (emit as an error).  It allows clients to
    /// map ERRORs to Error or Fatal (stop emitting diagnostics after this one).
    enum class Severity {
      // NOTE: 0 means "uncomputed".
      Ignored = 1, ///< Do not present this diagnostic, ignore it.
      Remark = 2,  ///< Present this diagnostic as a remark.
      Warning = 3, ///< Present this diagnostic as a warning.
      Error = 4,   ///< Present this diagnostic as an error.
      Fatal = 5    ///< Present this diagnostic as a fatal error.
    };

    /// Flavors of diagnostics we can emit. Used to filter for a particular
    /// kind of diagnostic (for instance, for -W/-R flags).
    enum class Flavor {
      WarningOrError, ///< A diagnostic that indicates a problem or potential
                      ///< problem. Can be made fatal by -Werror.
      Remark          ///< A diagnostic that indicates normal progress through
                      ///< compilation.
    };
  }

class DiagnosticMapping {
  unsigned Severity : 3;
  unsigned IsUser : 1;
  unsigned IsPragma : 1;
  unsigned HasNoWarningAsError : 1;
  unsigned HasNoErrorAsFatal : 1;
  unsigned WasUpgradedFromWarning : 1;

public:
  static DiagnosticMapping Make(diag::Severity Severity, bool IsUser,
                                bool IsPragma) {
    DiagnosticMapping Result;
    Result.Severity = (unsigned)Severity;
    Result.IsUser = IsUser;
    Result.IsPragma = IsPragma;
    Result.HasNoWarningAsError = 0;
    Result.HasNoErrorAsFatal = 0;
    Result.WasUpgradedFromWarning = 0;
    return Result;
  }

  diag::Severity getSeverity() const { return (diag::Severity)Severity; }
  void setSeverity(diag::Severity Value) { Severity = (unsigned)Value; }

  bool isUser() const { return IsUser; }
  bool isPragma() const { return IsPragma; }

  bool isErrorOrFatal() const {
    return getSeverity() == diag::Severity::Error ||
           getSeverity() == diag::Severity::Fatal;
  }

  bool hasNoWarningAsError() const { return HasNoWarningAsError; }
  void setNoWarningAsError(bool Value) { HasNoWarningAsError = Value; }

  bool hasNoErrorAsFatal() const { return HasNoErrorAsFatal; }
  void setNoErrorAsFatal(bool Value) { HasNoErrorAsFatal = Value; }

  /// Whether this mapping attempted to map the diagnostic to a warning, but
  /// was overruled because the diagnostic was already mapped to an error or
  /// fatal error.
  bool wasUpgradedFromWarning() const { return WasUpgradedFromWarning; }
  void setUpgradedFromWarning(bool Value) { WasUpgradedFromWarning = Value; }

  /// Serialize this mapping as a raw integer.
  unsigned serialize() const {
    return (IsUser << 7) | (IsPragma << 6) | (HasNoWarningAsError << 5) |
           (HasNoErrorAsFatal << 4) | (WasUpgradedFromWarning << 3) | Severity;
  }
  /// Deserialize a mapping.
  static DiagnosticMapping deserialize(unsigned Bits) {
    DiagnosticMapping Result;
    Result.IsUser = (Bits >> 7) & 1;
    Result.IsPragma = (Bits >> 6) & 1;
    Result.HasNoWarningAsError = (Bits >> 5) & 1;
    Result.HasNoErrorAsFatal = (Bits >> 4) & 1;
    Result.WasUpgradedFromWarning = (Bits >> 3) & 1;
    Result.Severity = Bits & 0x7;
    return Result;
  }
};

/// Used for handling and querying diagnostic IDs.
///
/// Can be used and shared by multiple Diagnostics for multiple translation units.
class DiagnosticIDs : public RefCountedBase<DiagnosticIDs> {
public:
  /// The level of the diagnostic, after it has been through mapping.
  enum Level {
    Ignored, Note, Remark, Warning, Error, Fatal
  };

private:
  /// Information for uniquing and looking up custom diags.
  std::unique_ptr<diag::CustomDiagInfo> CustomDiagInfo;

public:
  DiagnosticIDs();
  ~DiagnosticIDs();

  /// Return an ID for a diagnostic with the specified format string and
  /// level.
  ///
  /// If this is the first request for this diagnostic, it is registered and
  /// created, otherwise the existing ID is returned.

  // FIXME: Replace this function with a create-only facilty like
  // createCustomDiagIDFromFormatString() to enforce safe usage. At the time of
  // writing, nearly all callers of this function were invalid.
  unsigned getCustomDiagID(Level L, StringRef FormatString);

  //===--------------------------------------------------------------------===//
  // Diagnostic classification and reporting interfaces.
  //

  /// Given a diagnostic ID, return a description of the issue.
  StringRef getDescription(unsigned DiagID) const;

  /// Return true if the unmapped diagnostic levelof the specified
  /// diagnostic ID is a Warning or Extension.
  ///
  /// This only works on builtin diagnostics, not custom ones, and is not
  /// legal to call on NOTEs.
  static bool isBuiltinWarningOrExtension(unsigned DiagID);

  /// Return true if the specified diagnostic is mapped to errors by
  /// default.
  static bool isDefaultMappingAsError(unsigned DiagID);

  /// Determine whether the given built-in diagnostic ID is a Note.
  static bool isBuiltinNote(unsigned DiagID);

  /// Determine whether the given built-in diagnostic ID is for an
  /// extension of some sort.
  static bool isBuiltinExtensionDiag(unsigned DiagID) {
    bool ignored;
    return isBuiltinExtensionDiag(DiagID, ignored);
  }

  /// Determine whether the given built-in diagnostic ID is for an
  /// extension of some sort, and whether it is enabled by default.
  ///
  /// This also returns EnabledByDefault, which is set to indicate whether the
  /// diagnostic is ignored by default (in which case -pedantic enables it) or
  /// treated as a warning/error by default.
  ///
  static bool isBuiltinExtensionDiag(unsigned DiagID, bool &EnabledByDefault);


  /// Return the lowest-level warning option that enables the specified
  /// diagnostic.
  ///
  /// If there is no -Wfoo flag that controls the diagnostic, this returns null.
  static StringRef getWarningOptionForDiag(unsigned DiagID);

  /// Return the category number that a specified \p DiagID belongs to,
  /// or 0 if no category.
  static unsigned getCategoryNumberForDiag(unsigned DiagID);

  /// Return the number of diagnostic categories.
  static unsigned getNumberOfCategories();

  /// Given a category ID, return the name of the category.
  static StringRef getCategoryNameFromID(unsigned CategoryID);

  /// Return true if a given diagnostic falls into an ARC diagnostic
  /// category.
  static bool isARCDiagnostic(unsigned DiagID);

  /// Enumeration describing how the emission of a diagnostic should
  /// be treated when it occurs during C++ template argument deduction.
  enum SFINAEResponse {
    /// The diagnostic should not be reported, but it should cause
    /// template argument deduction to fail.
    ///
    /// The vast majority of errors that occur during template argument
    /// deduction fall into this category.
    SFINAE_SubstitutionFailure,

    /// The diagnostic should be suppressed entirely.
    ///
    /// Warnings generally fall into this category.
    SFINAE_Suppress,

    /// The diagnostic should be reported.
    ///
    /// The diagnostic should be reported. Various fatal errors (e.g.,
    /// template instantiation depth exceeded) fall into this category.
    SFINAE_Report,

    /// The diagnostic is an access-control diagnostic, which will be
    /// substitution failures in some contexts and reported in others.
    SFINAE_AccessControl
  };

  /// Determines whether the given built-in diagnostic ID is
  /// for an error that is suppressed if it occurs during C++ template
  /// argument deduction.
  ///
  /// When an error is suppressed due to SFINAE, the template argument
  /// deduction fails but no diagnostic is emitted. Certain classes of
  /// errors, such as those errors that involve C++ access control,
  /// are not SFINAE errors.
  static SFINAEResponse getDiagnosticSFINAEResponse(unsigned DiagID);

  /// Get the string of all diagnostic flags.
  ///
  /// \returns A list of all diagnostics flags as they would be written in a
  /// command line invocation including their `no-` variants. For example:
  /// `{"-Wempty-body", "-Wno-empty-body", ...}`
  static std::vector<std::string> getDiagnosticFlags();

  /// Get the set of all diagnostic IDs in the group with the given name.
  ///
  /// \param[out] Diags - On return, the diagnostics in the group.
  /// \returns \c true if the given group is unknown, \c false otherwise.
  bool getDiagnosticsInGroup(diag::Flavor Flavor, StringRef Group,
                             SmallVectorImpl<diag::kind> &Diags) const;

  /// Get the set of all diagnostic IDs.
  static void getAllDiagnostics(diag::Flavor Flavor,
                                std::vector<diag::kind> &Diags);

  /// Get the diagnostic option with the closest edit distance to the
  /// given group name.
  static StringRef getNearestOption(diag::Flavor Flavor, StringRef Group);

private:
  /// Classify the specified diagnostic ID into a Level, consumable by
  /// the DiagnosticClient.
  ///
  /// The classification is based on the way the client configured the
  /// DiagnosticsEngine object.
  ///
  /// \param Loc The source location for which we are interested in finding out
  /// the diagnostic state. Can be null in order to query the latest state.
  DiagnosticIDs::Level
  getDiagnosticLevel(unsigned DiagID, SourceLocation Loc,
                     const DiagnosticsEngine &Diag) const LLVM_READONLY;

  diag::Severity
  getDiagnosticSeverity(unsigned DiagID, SourceLocation Loc,
                        const DiagnosticsEngine &Diag) const LLVM_READONLY;

  /// Used to report a diagnostic that is finally fully formed.
  ///
  /// \returns \c true if the diagnostic was emitted, \c false if it was
  /// suppressed.
  bool ProcessDiag(DiagnosticsEngine &Diag) const;

  /// Used to emit a diagnostic that is finally fully formed,
  /// ignoring suppression.
  void EmitDiag(DiagnosticsEngine &Diag, Level DiagLevel) const;

  /// Whether the diagnostic may leave the AST in a state where some
  /// invariants can break.
  bool isUnrecoverable(unsigned DiagID) const;

  friend class DiagnosticsEngine;
};

}  // end namespace clang

#endif
# 342 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticIDs.h"
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/DiagnosticOptions.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h" 1
//===- DiagnosticOptions.h --------------------------------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_DIAGNOSTICOPTIONS_H
#define LLVM_CLANG_BASIC_DIAGNOSTICOPTIONS_H

#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/LLVM.h"
#endif /* expanded by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 13 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/IntrusiveRefCntPtr.h"
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 14 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 15 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 16 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 17 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"

namespace clang {

/// Specifies which overload candidates to display when overload
/// resolution fails.
enum OverloadsShown : unsigned {
  /// Show all overloads.
  Ovl_All,

  /// Show just the "best" overload candidates.
  Ovl_Best
};

/// A bitmask representing the diagnostic levels used by
/// VerifyDiagnosticConsumer.
enum class DiagnosticLevelMask : unsigned {
  None    = 0,
  Note    = 1 << 0,
  Remark  = 1 << 1,
  Warning = 1 << 2,
  Error   = 1 << 3,
  All     = Note | Remark | Warning | Error
};

inline DiagnosticLevelMask operator~(DiagnosticLevelMask M) {
  using UT = std::underlying_type<DiagnosticLevelMask>::type;
  return static_cast<DiagnosticLevelMask>(~static_cast<UT>(M));
}

inline DiagnosticLevelMask operator|(DiagnosticLevelMask LHS,
                                     DiagnosticLevelMask RHS) {
  using UT = std::underlying_type<DiagnosticLevelMask>::type;
  return static_cast<DiagnosticLevelMask>(
    static_cast<UT>(LHS) | static_cast<UT>(RHS));
}

inline DiagnosticLevelMask operator&(DiagnosticLevelMask LHS,
                                     DiagnosticLevelMask RHS) {
  using UT = std::underlying_type<DiagnosticLevelMask>::type;
  return static_cast<DiagnosticLevelMask>(
    static_cast<UT>(LHS) & static_cast<UT>(RHS));
}

raw_ostream& operator<<(raw_ostream& Out, DiagnosticLevelMask M);

/// Options for controlling the compiler diagnostics engine.
class DiagnosticOptions : public RefCountedBase<DiagnosticOptions>{
public:
  enum TextDiagnosticFormat { Clang, MSVC, Vi };

  // Default values.
  enum {
    DefaultTabStop = 8,
    MaxTabStop = 100,
    DefaultMacroBacktraceLimit = 6,
    DefaultTemplateBacktraceLimit = 10,
    DefaultConstexprBacktraceLimit = 10,
    DefaultSpellCheckingLimit = 50,
    DefaultSnippetLineLimit = 1,
  };

  // Define simple diagnostic options (with no accessors).
#define DIAGOPT(Name, Bits, Default) unsigned Name : Bits;
#define ENUM_DIAGOPT(Name, Type, Bits, Default)
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/DiagnosticOptions.def"
#endif /* expanded by -frewrite-includes */
# 81 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def" 1
//===--- DiagOptions.def - Diagnostic option database ------------- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the diagnostic options. Users of this file
// must define the DIAGOPT macro to make use of this information.
// Optionally, the user may also define ENUM_DIAGOPT (for options
// that have enumeration type and VALUE_DIAGOPT (for options that
// describe a value rather than a flag). The SEMANTIC_* variants of these macros
// indicate options that affect the processing of the program, rather than
// simply the output.
//
//===----------------------------------------------------------------------===//
#ifndef DIAGOPT
#  error Define the DIAGOPT macro to handle language options
#endif
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef VALUE_DIAGOPT
#  define VALUE_DIAGOPT(Name, Bits, Default) \
DIAGOPT(Name, Bits, Default)
#endif
# 26 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef ENUM_DIAGOPT
#  define ENUM_DIAGOPT(Name, Type, Bits, Default) \
DIAGOPT(Name, Bits, Default)
#endif
# 31 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_DIAGOPT
#  define SEMANTIC_DIAGOPT(Name, Bits, Default) DIAGOPT(Name, Bits, Default)
#endif
# 35 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_VALUE_DIAGOPT
#  define SEMANTIC_VALUE_DIAGOPT(Name, Bits, Default) \
     VALUE_DIAGOPT(Name, Bits, Default)
#endif
# 40 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_ENUM_DIAGOPT
#  define SEMANTIC_ENUM_DIAGOPT(Name, Type, Bits, Default) \
     ENUM_DIAGOPT(Name, Type, Bits, Default)
#endif
# 45 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

SEMANTIC_DIAGOPT(IgnoreWarnings, 1, 0)   /// -w
DIAGOPT(NoRewriteMacros, 1, 0)  /// -Wno-rewrite-macros
DIAGOPT(Pedantic, 1, 0)         /// -pedantic
DIAGOPT(PedanticErrors, 1, 0)   /// -pedantic-errors
DIAGOPT(ShowColumn, 1, 1)       /// Show column number on diagnostics.
DIAGOPT(ShowLocation, 1, 1)     /// Show source location information.
DIAGOPT(ShowLevel, 1, 1)        /// Show diagnostic level.
DIAGOPT(AbsolutePath, 1, 0)     /// Use absolute paths.
DIAGOPT(ShowCarets, 1, 1)       /// Show carets in diagnostics.
DIAGOPT(ShowFixits, 1, 1)       /// Show fixit information.
DIAGOPT(ShowSourceRanges, 1, 0) /// Show source ranges in numeric form.
DIAGOPT(ShowParseableFixits, 1, 0) /// Show machine parseable fix-its.
DIAGOPT(ShowPresumedLoc, 1, 0)  /// Show presumed location for diagnostics.
DIAGOPT(ShowOptionNames, 1, 0)  /// Show the option name for mappable
                                /// diagnostics.
DIAGOPT(ShowNoteIncludeStack, 1, 0) /// Show include stacks for notes.
VALUE_DIAGOPT(ShowCategories, 2, 0) /// Show categories: 0 -> none, 1 -> Number,
                                    /// 2 -> Full Name.

ENUM_DIAGOPT(Format, TextDiagnosticFormat, 2, Clang) /// Format for diagnostics:

DIAGOPT(ShowColors, 1, 0)       /// Show diagnostics with ANSI color sequences.
ENUM_DIAGOPT(ShowOverloads, OverloadsShown, 1,
             Ovl_All)    /// Overload candidates to show.
DIAGOPT(VerifyDiagnostics, 1, 0) /// Check that diagnostics match the expected
                                 /// diagnostics, indicated by markers in the
                                 /// input source file.
ENUM_DIAGOPT(VerifyIgnoreUnexpected, DiagnosticLevelMask, 4,
             DiagnosticLevelMask::None) /// Ignore unexpected diagnostics of
                                        /// the specified levels when using
                                        /// -verify.
DIAGOPT(ElideType, 1, 0)         /// Elide identical types in template diffing
DIAGOPT(ShowTemplateTree, 1, 0)  /// Print a template tree when diffing
DIAGOPT(CLFallbackMode, 1, 0)    /// Format for clang-cl fallback mode

VALUE_DIAGOPT(ErrorLimit, 32, 0)           /// Limit # errors emitted.
/// Limit depth of macro expansion backtrace.
VALUE_DIAGOPT(MacroBacktraceLimit, 32, DefaultMacroBacktraceLimit)
/// Limit depth of instantiation backtrace.
VALUE_DIAGOPT(TemplateBacktraceLimit, 32, DefaultTemplateBacktraceLimit)
/// Limit depth of constexpr backtrace.
VALUE_DIAGOPT(ConstexprBacktraceLimit, 32, DefaultConstexprBacktraceLimit)
/// Limit number of times to perform spell checking.
VALUE_DIAGOPT(SpellCheckingLimit, 32, DefaultSpellCheckingLimit)
/// Limit number of lines shown in a snippet.
VALUE_DIAGOPT(SnippetLineLimit, 32, DefaultSnippetLineLimit)

VALUE_DIAGOPT(TabStop, 32, DefaultTabStop) /// The distance between tab stops.
/// Column limit for formatting message diagnostics, or 0 if unused.
VALUE_DIAGOPT(MessageLength, 32, 0)

#undef DIAGOPT
#undef ENUM_DIAGOPT
#undef VALUE_DIAGOPT
#undef SEMANTIC_DIAGOPT
#undef SEMANTIC_ENUM_DIAGOPT
#undef SEMANTIC_VALUE_DIAGOPT
# 82 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h" 2

protected:
  // Define diagnostic options of enumeration type. These are private, and will
  // have accessors (below).
#define DIAGOPT(Name, Bits, Default)
#define ENUM_DIAGOPT(Name, Type, Bits, Default) unsigned Name : Bits;
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/DiagnosticOptions.def"
#endif /* expanded by -frewrite-includes */
# 88 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def" 1
//===--- DiagOptions.def - Diagnostic option database ------------- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the diagnostic options. Users of this file
// must define the DIAGOPT macro to make use of this information.
// Optionally, the user may also define ENUM_DIAGOPT (for options
// that have enumeration type and VALUE_DIAGOPT (for options that
// describe a value rather than a flag). The SEMANTIC_* variants of these macros
// indicate options that affect the processing of the program, rather than
// simply the output.
//
//===----------------------------------------------------------------------===//
#ifndef DIAGOPT
#  error Define the DIAGOPT macro to handle language options
#endif
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef VALUE_DIAGOPT
#  define VALUE_DIAGOPT(Name, Bits, Default) \
DIAGOPT(Name, Bits, Default)
#endif
# 26 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef ENUM_DIAGOPT
#  define ENUM_DIAGOPT(Name, Type, Bits, Default) \
DIAGOPT(Name, Bits, Default)
#endif
# 31 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_DIAGOPT
#  define SEMANTIC_DIAGOPT(Name, Bits, Default) DIAGOPT(Name, Bits, Default)
#endif
# 35 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_VALUE_DIAGOPT
#  define SEMANTIC_VALUE_DIAGOPT(Name, Bits, Default) \
     VALUE_DIAGOPT(Name, Bits, Default)
#endif
# 40 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_ENUM_DIAGOPT
#  define SEMANTIC_ENUM_DIAGOPT(Name, Type, Bits, Default) \
     ENUM_DIAGOPT(Name, Type, Bits, Default)
#endif
# 45 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

SEMANTIC_DIAGOPT(IgnoreWarnings, 1, 0)   /// -w
DIAGOPT(NoRewriteMacros, 1, 0)  /// -Wno-rewrite-macros
DIAGOPT(Pedantic, 1, 0)         /// -pedantic
DIAGOPT(PedanticErrors, 1, 0)   /// -pedantic-errors
DIAGOPT(ShowColumn, 1, 1)       /// Show column number on diagnostics.
DIAGOPT(ShowLocation, 1, 1)     /// Show source location information.
DIAGOPT(ShowLevel, 1, 1)        /// Show diagnostic level.
DIAGOPT(AbsolutePath, 1, 0)     /// Use absolute paths.
DIAGOPT(ShowCarets, 1, 1)       /// Show carets in diagnostics.
DIAGOPT(ShowFixits, 1, 1)       /// Show fixit information.
DIAGOPT(ShowSourceRanges, 1, 0) /// Show source ranges in numeric form.
DIAGOPT(ShowParseableFixits, 1, 0) /// Show machine parseable fix-its.
DIAGOPT(ShowPresumedLoc, 1, 0)  /// Show presumed location for diagnostics.
DIAGOPT(ShowOptionNames, 1, 0)  /// Show the option name for mappable
                                /// diagnostics.
DIAGOPT(ShowNoteIncludeStack, 1, 0) /// Show include stacks for notes.
VALUE_DIAGOPT(ShowCategories, 2, 0) /// Show categories: 0 -> none, 1 -> Number,
                                    /// 2 -> Full Name.

ENUM_DIAGOPT(Format, TextDiagnosticFormat, 2, Clang) /// Format for diagnostics:

DIAGOPT(ShowColors, 1, 0)       /// Show diagnostics with ANSI color sequences.
ENUM_DIAGOPT(ShowOverloads, OverloadsShown, 1,
             Ovl_All)    /// Overload candidates to show.
DIAGOPT(VerifyDiagnostics, 1, 0) /// Check that diagnostics match the expected
                                 /// diagnostics, indicated by markers in the
                                 /// input source file.
ENUM_DIAGOPT(VerifyIgnoreUnexpected, DiagnosticLevelMask, 4,
             DiagnosticLevelMask::None) /// Ignore unexpected diagnostics of
                                        /// the specified levels when using
                                        /// -verify.
DIAGOPT(ElideType, 1, 0)         /// Elide identical types in template diffing
DIAGOPT(ShowTemplateTree, 1, 0)  /// Print a template tree when diffing
DIAGOPT(CLFallbackMode, 1, 0)    /// Format for clang-cl fallback mode

VALUE_DIAGOPT(ErrorLimit, 32, 0)           /// Limit # errors emitted.
/// Limit depth of macro expansion backtrace.
VALUE_DIAGOPT(MacroBacktraceLimit, 32, DefaultMacroBacktraceLimit)
/// Limit depth of instantiation backtrace.
VALUE_DIAGOPT(TemplateBacktraceLimit, 32, DefaultTemplateBacktraceLimit)
/// Limit depth of constexpr backtrace.
VALUE_DIAGOPT(ConstexprBacktraceLimit, 32, DefaultConstexprBacktraceLimit)
/// Limit number of times to perform spell checking.
VALUE_DIAGOPT(SpellCheckingLimit, 32, DefaultSpellCheckingLimit)
/// Limit number of lines shown in a snippet.
VALUE_DIAGOPT(SnippetLineLimit, 32, DefaultSnippetLineLimit)

VALUE_DIAGOPT(TabStop, 32, DefaultTabStop) /// The distance between tab stops.
/// Column limit for formatting message diagnostics, or 0 if unused.
VALUE_DIAGOPT(MessageLength, 32, 0)

#undef DIAGOPT
#undef ENUM_DIAGOPT
#undef VALUE_DIAGOPT
#undef SEMANTIC_DIAGOPT
#undef SEMANTIC_ENUM_DIAGOPT
#undef SEMANTIC_VALUE_DIAGOPT
# 89 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h" 2

public:
  /// The file to log diagnostic output to.
  std::string DiagnosticLogFile;

  /// The file to serialize diagnostics to (non-appending).
  std::string DiagnosticSerializationFile;

  /// The list of -W... options used to alter the diagnostic mappings, with the
  /// prefixes removed.
  std::vector<std::string> Warnings;

  /// The list of -R... options used to alter the diagnostic mappings, with the
  /// prefixes removed.
  std::vector<std::string> Remarks;

  /// The prefixes for comment directives sought by -verify ("expected" by
  /// default).
  std::vector<std::string> VerifyPrefixes;

public:
  // Define accessors/mutators for diagnostic options of enumeration type.
#define DIAGOPT(Name, Bits, Default)
#define ENUM_DIAGOPT(Name, Type, Bits, Default) \
  Type get##Name() const { return static_cast<Type>(Name); } \
  void set##Name(Type Value) { Name = static_cast<unsigned>(Value); }
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/DiagnosticOptions.def"
#endif /* expanded by -frewrite-includes */
# 115 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def" 1
//===--- DiagOptions.def - Diagnostic option database ------------- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the diagnostic options. Users of this file
// must define the DIAGOPT macro to make use of this information.
// Optionally, the user may also define ENUM_DIAGOPT (for options
// that have enumeration type and VALUE_DIAGOPT (for options that
// describe a value rather than a flag). The SEMANTIC_* variants of these macros
// indicate options that affect the processing of the program, rather than
// simply the output.
//
//===----------------------------------------------------------------------===//
#ifndef DIAGOPT
#  error Define the DIAGOPT macro to handle language options
#endif
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef VALUE_DIAGOPT
#  define VALUE_DIAGOPT(Name, Bits, Default) \
DIAGOPT(Name, Bits, Default)
#endif
# 26 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef ENUM_DIAGOPT
#  define ENUM_DIAGOPT(Name, Type, Bits, Default) \
DIAGOPT(Name, Bits, Default)
#endif
# 31 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_DIAGOPT
#  define SEMANTIC_DIAGOPT(Name, Bits, Default) DIAGOPT(Name, Bits, Default)
#endif
# 35 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_VALUE_DIAGOPT
#  define SEMANTIC_VALUE_DIAGOPT(Name, Bits, Default) \
     VALUE_DIAGOPT(Name, Bits, Default)
#endif
# 40 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_ENUM_DIAGOPT
#  define SEMANTIC_ENUM_DIAGOPT(Name, Type, Bits, Default) \
     ENUM_DIAGOPT(Name, Type, Bits, Default)
#endif
# 45 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

SEMANTIC_DIAGOPT(IgnoreWarnings, 1, 0)   /// -w
DIAGOPT(NoRewriteMacros, 1, 0)  /// -Wno-rewrite-macros
DIAGOPT(Pedantic, 1, 0)         /// -pedantic
DIAGOPT(PedanticErrors, 1, 0)   /// -pedantic-errors
DIAGOPT(ShowColumn, 1, 1)       /// Show column number on diagnostics.
DIAGOPT(ShowLocation, 1, 1)     /// Show source location information.
DIAGOPT(ShowLevel, 1, 1)        /// Show diagnostic level.
DIAGOPT(AbsolutePath, 1, 0)     /// Use absolute paths.
DIAGOPT(ShowCarets, 1, 1)       /// Show carets in diagnostics.
DIAGOPT(ShowFixits, 1, 1)       /// Show fixit information.
DIAGOPT(ShowSourceRanges, 1, 0) /// Show source ranges in numeric form.
DIAGOPT(ShowParseableFixits, 1, 0) /// Show machine parseable fix-its.
DIAGOPT(ShowPresumedLoc, 1, 0)  /// Show presumed location for diagnostics.
DIAGOPT(ShowOptionNames, 1, 0)  /// Show the option name for mappable
                                /// diagnostics.
DIAGOPT(ShowNoteIncludeStack, 1, 0) /// Show include stacks for notes.
VALUE_DIAGOPT(ShowCategories, 2, 0) /// Show categories: 0 -> none, 1 -> Number,
                                    /// 2 -> Full Name.

ENUM_DIAGOPT(Format, TextDiagnosticFormat, 2, Clang) /// Format for diagnostics:

DIAGOPT(ShowColors, 1, 0)       /// Show diagnostics with ANSI color sequences.
ENUM_DIAGOPT(ShowOverloads, OverloadsShown, 1,
             Ovl_All)    /// Overload candidates to show.
DIAGOPT(VerifyDiagnostics, 1, 0) /// Check that diagnostics match the expected
                                 /// diagnostics, indicated by markers in the
                                 /// input source file.
ENUM_DIAGOPT(VerifyIgnoreUnexpected, DiagnosticLevelMask, 4,
             DiagnosticLevelMask::None) /// Ignore unexpected diagnostics of
                                        /// the specified levels when using
                                        /// -verify.
DIAGOPT(ElideType, 1, 0)         /// Elide identical types in template diffing
DIAGOPT(ShowTemplateTree, 1, 0)  /// Print a template tree when diffing
DIAGOPT(CLFallbackMode, 1, 0)    /// Format for clang-cl fallback mode

VALUE_DIAGOPT(ErrorLimit, 32, 0)           /// Limit # errors emitted.
/// Limit depth of macro expansion backtrace.
VALUE_DIAGOPT(MacroBacktraceLimit, 32, DefaultMacroBacktraceLimit)
/// Limit depth of instantiation backtrace.
VALUE_DIAGOPT(TemplateBacktraceLimit, 32, DefaultTemplateBacktraceLimit)
/// Limit depth of constexpr backtrace.
VALUE_DIAGOPT(ConstexprBacktraceLimit, 32, DefaultConstexprBacktraceLimit)
/// Limit number of times to perform spell checking.
VALUE_DIAGOPT(SpellCheckingLimit, 32, DefaultSpellCheckingLimit)
/// Limit number of lines shown in a snippet.
VALUE_DIAGOPT(SnippetLineLimit, 32, DefaultSnippetLineLimit)

VALUE_DIAGOPT(TabStop, 32, DefaultTabStop) /// The distance between tab stops.
/// Column limit for formatting message diagnostics, or 0 if unused.
VALUE_DIAGOPT(MessageLength, 32, 0)

#undef DIAGOPT
#undef ENUM_DIAGOPT
#undef VALUE_DIAGOPT
#undef SEMANTIC_DIAGOPT
#undef SEMANTIC_ENUM_DIAGOPT
#undef SEMANTIC_VALUE_DIAGOPT
# 116 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h" 2

  DiagnosticOptions() {
#define DIAGOPT(Name, Bits, Default) Name = Default;
#define ENUM_DIAGOPT(Name, Type, Bits, Default) set##Name(Default);
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/DiagnosticOptions.def"
#endif /* expanded by -frewrite-includes */
# 120 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def" 1
//===--- DiagOptions.def - Diagnostic option database ------------- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the diagnostic options. Users of this file
// must define the DIAGOPT macro to make use of this information.
// Optionally, the user may also define ENUM_DIAGOPT (for options
// that have enumeration type and VALUE_DIAGOPT (for options that
// describe a value rather than a flag). The SEMANTIC_* variants of these macros
// indicate options that affect the processing of the program, rather than
// simply the output.
//
//===----------------------------------------------------------------------===//
#ifndef DIAGOPT
#  error Define the DIAGOPT macro to handle language options
#endif
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef VALUE_DIAGOPT
#  define VALUE_DIAGOPT(Name, Bits, Default) \
DIAGOPT(Name, Bits, Default)
#endif
# 26 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef ENUM_DIAGOPT
#  define ENUM_DIAGOPT(Name, Type, Bits, Default) \
DIAGOPT(Name, Bits, Default)
#endif
# 31 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_DIAGOPT
#  define SEMANTIC_DIAGOPT(Name, Bits, Default) DIAGOPT(Name, Bits, Default)
#endif
# 35 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_VALUE_DIAGOPT
#  define SEMANTIC_VALUE_DIAGOPT(Name, Bits, Default) \
     VALUE_DIAGOPT(Name, Bits, Default)
#endif
# 40 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

#ifndef SEMANTIC_ENUM_DIAGOPT
#  define SEMANTIC_ENUM_DIAGOPT(Name, Type, Bits, Default) \
     ENUM_DIAGOPT(Name, Type, Bits, Default)
#endif
# 45 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.def"

SEMANTIC_DIAGOPT(IgnoreWarnings, 1, 0)   /// -w
DIAGOPT(NoRewriteMacros, 1, 0)  /// -Wno-rewrite-macros
DIAGOPT(Pedantic, 1, 0)         /// -pedantic
DIAGOPT(PedanticErrors, 1, 0)   /// -pedantic-errors
DIAGOPT(ShowColumn, 1, 1)       /// Show column number on diagnostics.
DIAGOPT(ShowLocation, 1, 1)     /// Show source location information.
DIAGOPT(ShowLevel, 1, 1)        /// Show diagnostic level.
DIAGOPT(AbsolutePath, 1, 0)     /// Use absolute paths.
DIAGOPT(ShowCarets, 1, 1)       /// Show carets in diagnostics.
DIAGOPT(ShowFixits, 1, 1)       /// Show fixit information.
DIAGOPT(ShowSourceRanges, 1, 0) /// Show source ranges in numeric form.
DIAGOPT(ShowParseableFixits, 1, 0) /// Show machine parseable fix-its.
DIAGOPT(ShowPresumedLoc, 1, 0)  /// Show presumed location for diagnostics.
DIAGOPT(ShowOptionNames, 1, 0)  /// Show the option name for mappable
                                /// diagnostics.
DIAGOPT(ShowNoteIncludeStack, 1, 0) /// Show include stacks for notes.
VALUE_DIAGOPT(ShowCategories, 2, 0) /// Show categories: 0 -> none, 1 -> Number,
                                    /// 2 -> Full Name.

ENUM_DIAGOPT(Format, TextDiagnosticFormat, 2, Clang) /// Format for diagnostics:

DIAGOPT(ShowColors, 1, 0)       /// Show diagnostics with ANSI color sequences.
ENUM_DIAGOPT(ShowOverloads, OverloadsShown, 1,
             Ovl_All)    /// Overload candidates to show.
DIAGOPT(VerifyDiagnostics, 1, 0) /// Check that diagnostics match the expected
                                 /// diagnostics, indicated by markers in the
                                 /// input source file.
ENUM_DIAGOPT(VerifyIgnoreUnexpected, DiagnosticLevelMask, 4,
             DiagnosticLevelMask::None) /// Ignore unexpected diagnostics of
                                        /// the specified levels when using
                                        /// -verify.
DIAGOPT(ElideType, 1, 0)         /// Elide identical types in template diffing
DIAGOPT(ShowTemplateTree, 1, 0)  /// Print a template tree when diffing
DIAGOPT(CLFallbackMode, 1, 0)    /// Format for clang-cl fallback mode

VALUE_DIAGOPT(ErrorLimit, 32, 0)           /// Limit # errors emitted.
/// Limit depth of macro expansion backtrace.
VALUE_DIAGOPT(MacroBacktraceLimit, 32, DefaultMacroBacktraceLimit)
/// Limit depth of instantiation backtrace.
VALUE_DIAGOPT(TemplateBacktraceLimit, 32, DefaultTemplateBacktraceLimit)
/// Limit depth of constexpr backtrace.
VALUE_DIAGOPT(ConstexprBacktraceLimit, 32, DefaultConstexprBacktraceLimit)
/// Limit number of times to perform spell checking.
VALUE_DIAGOPT(SpellCheckingLimit, 32, DefaultSpellCheckingLimit)
/// Limit number of lines shown in a snippet.
VALUE_DIAGOPT(SnippetLineLimit, 32, DefaultSnippetLineLimit)

VALUE_DIAGOPT(TabStop, 32, DefaultTabStop) /// The distance between tab stops.
/// Column limit for formatting message diagnostics, or 0 if unused.
VALUE_DIAGOPT(MessageLength, 32, 0)

#undef DIAGOPT
#undef ENUM_DIAGOPT
#undef VALUE_DIAGOPT
#undef SEMANTIC_DIAGOPT
#undef SEMANTIC_ENUM_DIAGOPT
#undef SEMANTIC_VALUE_DIAGOPT
# 121 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h" 2
  }
};

using TextDiagnosticFormat = DiagnosticOptions::TextDiagnosticFormat;

} // namespace clang

#endif // LLVM_CLANG_BASIC_DIAGNOSTICOPTIONS_H
# 129 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/DiagnosticOptions.h"
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/SourceLocation.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h" 1
//===- SourceLocation.h - Compact identifier for Source Files ---*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
/// \file
/// Defines the clang::SourceLocation class and associated facilities.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_SOURCELOCATION_H
#define LLVM_CLANG_BASIC_SOURCELOCATION_H

#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/LLVM.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/PointerLikeTypeTraits.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/PointerLikeTypeTraits.h" 1
//===- llvm/Support/PointerLikeTypeTraits.h - Pointer Traits ----*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the PointerLikeTypeTraits class.  This allows data
// structures to reason about pointers and other things that are pointer sized.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_POINTERLIKETYPETRAITS_H
#define LLVM_SUPPORT_POINTERLIKETYPETRAITS_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/PointerLikeTypeTraits.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h" 1
//===-- llvm/Support/DataTypes.h - Define fixed size types ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// Due to layering constraints (Support depends on llvm-c) this is a thin
// wrapper around the implementation that lives in llvm-c, though most clients
// can/should think of this as being provided by Support for simplicity (not
// many clients are aware of their dependency on llvm-c).
//
//===----------------------------------------------------------------------===//

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h" 1
/*===-- include/llvm-c/DataTypes.h - Define fixed size types ------*- C -*-===*\
|*                                                                            *|
|* Part of the LLVM Project, under the Apache License v2.0 with LLVM          *|
|* Exceptions.                                                                *|
|* See https://llvm.org/LICENSE.txt for license information.                  *|
|* SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception                    *|
|*                                                                            *|
|*===----------------------------------------------------------------------===*|
|*                                                                            *|
|* This file contains definitions to figure out the size of _HOST_ data types.*|
|* This file is important because different host OS's define different macros,*|
|* which makes portability tough.  This file exports the following            *|
|* definitions:                                                               *|
|*                                                                            *|
|*   [u]int(32|64)_t : typedefs for signed and unsigned 32/64 bit system types*|
|*   [U]INT(8|16|32|64)_(MIN|MAX) : Constants for the min and max values.     *|
|*                                                                            *|
|* No library is required when using these functions.                         *|
|*                                                                            *|
|*===----------------------------------------------------------------------===*/

/* Please leave this file C-compatible. */

#ifndef LLVM_C_DATATYPES_H
#define LLVM_C_DATATYPES_H

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <cmath>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 1 3
// -*- C++ -*-
//===---------------------------- cmath -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CMATH
#define _LIBCPP_CMATH

/*
    cmath synopsis

Macros:

    HUGE_VAL
    HUGE_VALF               // C99
    HUGE_VALL               // C99
    INFINITY                // C99
    NAN                     // C99
    FP_INFINITE             // C99
    FP_NAN                  // C99
    FP_NORMAL               // C99
    FP_SUBNORMAL            // C99
    FP_ZERO                 // C99
    FP_FAST_FMA             // C99
    FP_FAST_FMAF            // C99
    FP_FAST_FMAL            // C99
    FP_ILOGB0               // C99
    FP_ILOGBNAN             // C99
    MATH_ERRNO              // C99
    MATH_ERREXCEPT          // C99
    math_errhandling        // C99

namespace std
{

Types:

    float_t                 // C99
    double_t                // C99

// C90

floating_point abs(floating_point x);

floating_point acos (arithmetic x);
float          acosf(float x);
long double    acosl(long double x);

floating_point asin (arithmetic x);
float          asinf(float x);
long double    asinl(long double x);

floating_point atan (arithmetic x);
float          atanf(float x);
long double    atanl(long double x);

floating_point atan2 (arithmetic y, arithmetic x);
float          atan2f(float y, float x);
long double    atan2l(long double y, long double x);

floating_point ceil (arithmetic x);
float          ceilf(float x);
long double    ceill(long double x);

floating_point cos (arithmetic x);
float          cosf(float x);
long double    cosl(long double x);

floating_point cosh (arithmetic x);
float          coshf(float x);
long double    coshl(long double x);

floating_point exp (arithmetic x);
float          expf(float x);
long double    expl(long double x);

floating_point fabs (arithmetic x);
float          fabsf(float x);
long double    fabsl(long double x);

floating_point floor (arithmetic x);
float          floorf(float x);
long double    floorl(long double x);

floating_point fmod (arithmetic x, arithmetic y);
float          fmodf(float x, float y);
long double    fmodl(long double x, long double y);

floating_point frexp (arithmetic value, int* exp);
float          frexpf(float value, int* exp);
long double    frexpl(long double value, int* exp);

floating_point ldexp (arithmetic value, int exp);
float          ldexpf(float value, int exp);
long double    ldexpl(long double value, int exp);

floating_point log (arithmetic x);
float          logf(float x);
long double    logl(long double x);

floating_point log10 (arithmetic x);
float          log10f(float x);
long double    log10l(long double x);

floating_point modf (floating_point value, floating_point* iptr);
float          modff(float value, float* iptr);
long double    modfl(long double value, long double* iptr);

floating_point pow (arithmetic x, arithmetic y);
float          powf(float x, float y);
long double    powl(long double x, long double y);

floating_point sin (arithmetic x);
float          sinf(float x);
long double    sinl(long double x);

floating_point sinh (arithmetic x);
float          sinhf(float x);
long double    sinhl(long double x);

floating_point sqrt (arithmetic x);
float          sqrtf(float x);
long double    sqrtl(long double x);

floating_point tan (arithmetic x);
float          tanf(float x);
long double    tanl(long double x);

floating_point tanh (arithmetic x);
float          tanhf(float x);
long double    tanhl(long double x);

//  C99

bool signbit(arithmetic x);

int fpclassify(arithmetic x);

bool isfinite(arithmetic x);
bool isinf(arithmetic x);
bool isnan(arithmetic x);
bool isnormal(arithmetic x);

bool isgreater(arithmetic x, arithmetic y);
bool isgreaterequal(arithmetic x, arithmetic y);
bool isless(arithmetic x, arithmetic y);
bool islessequal(arithmetic x, arithmetic y);
bool islessgreater(arithmetic x, arithmetic y);
bool isunordered(arithmetic x, arithmetic y);

floating_point acosh (arithmetic x);
float          acoshf(float x);
long double    acoshl(long double x);

floating_point asinh (arithmetic x);
float          asinhf(float x);
long double    asinhl(long double x);

floating_point atanh (arithmetic x);
float          atanhf(float x);
long double    atanhl(long double x);

floating_point cbrt (arithmetic x);
float          cbrtf(float x);
long double    cbrtl(long double x);

floating_point copysign (arithmetic x, arithmetic y);
float          copysignf(float x, float y);
long double    copysignl(long double x, long double y);

floating_point erf (arithmetic x);
float          erff(float x);
long double    erfl(long double x);

floating_point erfc (arithmetic x);
float          erfcf(float x);
long double    erfcl(long double x);

floating_point exp2 (arithmetic x);
float          exp2f(float x);
long double    exp2l(long double x);

floating_point expm1 (arithmetic x);
float          expm1f(float x);
long double    expm1l(long double x);

floating_point fdim (arithmetic x, arithmetic y);
float          fdimf(float x, float y);
long double    fdiml(long double x, long double y);

floating_point fma (arithmetic x, arithmetic y, arithmetic z);
float          fmaf(float x, float y, float z);
long double    fmal(long double x, long double y, long double z);

floating_point fmax (arithmetic x, arithmetic y);
float          fmaxf(float x, float y);
long double    fmaxl(long double x, long double y);

floating_point fmin (arithmetic x, arithmetic y);
float          fminf(float x, float y);
long double    fminl(long double x, long double y);

floating_point hypot (arithmetic x, arithmetic y);
float          hypotf(float x, float y);
long double    hypotl(long double x, long double y);

double       hypot(double x, double y, double z);                // C++17
float        hypot(float x, float y, float z);                   // C++17
long double  hypot(long double x, long double y, long double z); // C++17

int ilogb (arithmetic x);
int ilogbf(float x);
int ilogbl(long double x);

floating_point lgamma (arithmetic x);
float          lgammaf(float x);
long double    lgammal(long double x);

long long llrint (arithmetic x);
long long llrintf(float x);
long long llrintl(long double x);

long long llround (arithmetic x);
long long llroundf(float x);
long long llroundl(long double x);

floating_point log1p (arithmetic x);
float          log1pf(float x);
long double    log1pl(long double x);

floating_point log2 (arithmetic x);
float          log2f(float x);
long double    log2l(long double x);

floating_point logb (arithmetic x);
float          logbf(float x);
long double    logbl(long double x);

long lrint (arithmetic x);
long lrintf(float x);
long lrintl(long double x);

long lround (arithmetic x);
long lroundf(float x);
long lroundl(long double x);

double      nan (const char* str);
float       nanf(const char* str);
long double nanl(const char* str);

floating_point nearbyint (arithmetic x);
float          nearbyintf(float x);
long double    nearbyintl(long double x);

floating_point nextafter (arithmetic x, arithmetic y);
float          nextafterf(float x, float y);
long double    nextafterl(long double x, long double y);

floating_point nexttoward (arithmetic x, long double y);
float          nexttowardf(float x, long double y);
long double    nexttowardl(long double x, long double y);

floating_point remainder (arithmetic x, arithmetic y);
float          remainderf(float x, float y);
long double    remainderl(long double x, long double y);

floating_point remquo (arithmetic x, arithmetic y, int* pquo);
float          remquof(float x, float y, int* pquo);
long double    remquol(long double x, long double y, int* pquo);

floating_point rint (arithmetic x);
float          rintf(float x);
long double    rintl(long double x);

floating_point round (arithmetic x);
float          roundf(float x);
long double    roundl(long double x);

floating_point scalbln (arithmetic x, long ex);
float          scalblnf(float x, long ex);
long double    scalblnl(long double x, long ex);

floating_point scalbn (arithmetic x, int ex);
float          scalbnf(float x, int ex);
long double    scalbnl(long double x, int ex);

floating_point tgamma (arithmetic x);
float          tgammaf(float x);
long double    tgammal(long double x);

floating_point trunc (arithmetic x);
float          truncf(float x);
long double    truncl(long double x);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 303 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
# 304 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 304 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 1 3
// -*- C++ -*-
//===---------------------------- math.h ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_MATH_H
#define _LIBCPP_MATH_H

/*
    math.h synopsis

Macros:

    HUGE_VAL
    HUGE_VALF               // C99
    HUGE_VALL               // C99
    INFINITY                // C99
    NAN                     // C99
    FP_INFINITE             // C99
    FP_NAN                  // C99
    FP_NORMAL               // C99
    FP_SUBNORMAL            // C99
    FP_ZERO                 // C99
    FP_FAST_FMA             // C99
    FP_FAST_FMAF            // C99
    FP_FAST_FMAL            // C99
    FP_ILOGB0               // C99
    FP_ILOGBNAN             // C99
    MATH_ERRNO              // C99
    MATH_ERREXCEPT          // C99
    math_errhandling        // C99

Types:

    float_t                 // C99
    double_t                // C99

// C90

floating_point abs(floating_point x);

floating_point acos (arithmetic x);
float          acosf(float x);
long double    acosl(long double x);

floating_point asin (arithmetic x);
float          asinf(float x);
long double    asinl(long double x);

floating_point atan (arithmetic x);
float          atanf(float x);
long double    atanl(long double x);

floating_point atan2 (arithmetic y, arithmetic x);
float          atan2f(float y, float x);
long double    atan2l(long double y, long double x);

floating_point ceil (arithmetic x);
float          ceilf(float x);
long double    ceill(long double x);

floating_point cos (arithmetic x);
float          cosf(float x);
long double    cosl(long double x);

floating_point cosh (arithmetic x);
float          coshf(float x);
long double    coshl(long double x);

floating_point exp (arithmetic x);
float          expf(float x);
long double    expl(long double x);

floating_point fabs (arithmetic x);
float          fabsf(float x);
long double    fabsl(long double x);

floating_point floor (arithmetic x);
float          floorf(float x);
long double    floorl(long double x);

floating_point fmod (arithmetic x, arithmetic y);
float          fmodf(float x, float y);
long double    fmodl(long double x, long double y);

floating_point frexp (arithmetic value, int* exp);
float          frexpf(float value, int* exp);
long double    frexpl(long double value, int* exp);

floating_point ldexp (arithmetic value, int exp);
float          ldexpf(float value, int exp);
long double    ldexpl(long double value, int exp);

floating_point log (arithmetic x);
float          logf(float x);
long double    logl(long double x);

floating_point log10 (arithmetic x);
float          log10f(float x);
long double    log10l(long double x);

floating_point modf (floating_point value, floating_point* iptr);
float          modff(float value, float* iptr);
long double    modfl(long double value, long double* iptr);

floating_point pow (arithmetic x, arithmetic y);
float          powf(float x, float y);
long double    powl(long double x, long double y);

floating_point sin (arithmetic x);
float          sinf(float x);
long double    sinl(long double x);

floating_point sinh (arithmetic x);
float          sinhf(float x);
long double    sinhl(long double x);

floating_point sqrt (arithmetic x);
float          sqrtf(float x);
long double    sqrtl(long double x);

floating_point tan (arithmetic x);
float          tanf(float x);
long double    tanl(long double x);

floating_point tanh (arithmetic x);
float          tanhf(float x);
long double    tanhl(long double x);

//  C99

bool signbit(arithmetic x);

int fpclassify(arithmetic x);

bool isfinite(arithmetic x);
bool isinf(arithmetic x);
bool isnan(arithmetic x);
bool isnormal(arithmetic x);

bool isgreater(arithmetic x, arithmetic y);
bool isgreaterequal(arithmetic x, arithmetic y);
bool isless(arithmetic x, arithmetic y);
bool islessequal(arithmetic x, arithmetic y);
bool islessgreater(arithmetic x, arithmetic y);
bool isunordered(arithmetic x, arithmetic y);

floating_point acosh (arithmetic x);
float          acoshf(float x);
long double    acoshl(long double x);

floating_point asinh (arithmetic x);
float          asinhf(float x);
long double    asinhl(long double x);

floating_point atanh (arithmetic x);
float          atanhf(float x);
long double    atanhl(long double x);

floating_point cbrt (arithmetic x);
float          cbrtf(float x);
long double    cbrtl(long double x);

floating_point copysign (arithmetic x, arithmetic y);
float          copysignf(float x, float y);
long double    copysignl(long double x, long double y);

floating_point erf (arithmetic x);
float          erff(float x);
long double    erfl(long double x);

floating_point erfc (arithmetic x);
float          erfcf(float x);
long double    erfcl(long double x);

floating_point exp2 (arithmetic x);
float          exp2f(float x);
long double    exp2l(long double x);

floating_point expm1 (arithmetic x);
float          expm1f(float x);
long double    expm1l(long double x);

floating_point fdim (arithmetic x, arithmetic y);
float          fdimf(float x, float y);
long double    fdiml(long double x, long double y);

floating_point fma (arithmetic x, arithmetic y, arithmetic z);
float          fmaf(float x, float y, float z);
long double    fmal(long double x, long double y, long double z);

floating_point fmax (arithmetic x, arithmetic y);
float          fmaxf(float x, float y);
long double    fmaxl(long double x, long double y);

floating_point fmin (arithmetic x, arithmetic y);
float          fminf(float x, float y);
long double    fminl(long double x, long double y);

floating_point hypot (arithmetic x, arithmetic y);
float          hypotf(float x, float y);
long double    hypotl(long double x, long double y);

int ilogb (arithmetic x);
int ilogbf(float x);
int ilogbl(long double x);

floating_point lgamma (arithmetic x);
float          lgammaf(float x);
long double    lgammal(long double x);

long long llrint (arithmetic x);
long long llrintf(float x);
long long llrintl(long double x);

long long llround (arithmetic x);
long long llroundf(float x);
long long llroundl(long double x);

floating_point log1p (arithmetic x);
float          log1pf(float x);
long double    log1pl(long double x);

floating_point log2 (arithmetic x);
float          log2f(float x);
long double    log2l(long double x);

floating_point logb (arithmetic x);
float          logbf(float x);
long double    logbl(long double x);

long lrint (arithmetic x);
long lrintf(float x);
long lrintl(long double x);

long lround (arithmetic x);
long lroundf(float x);
long lroundl(long double x);

double      nan (const char* str);
float       nanf(const char* str);
long double nanl(const char* str);

floating_point nearbyint (arithmetic x);
float          nearbyintf(float x);
long double    nearbyintl(long double x);

floating_point nextafter (arithmetic x, arithmetic y);
float          nextafterf(float x, float y);
long double    nextafterl(long double x, long double y);

floating_point nexttoward (arithmetic x, long double y);
float          nexttowardf(float x, long double y);
long double    nexttowardl(long double x, long double y);

floating_point remainder (arithmetic x, arithmetic y);
float          remainderf(float x, float y);
long double    remainderl(long double x, long double y);

floating_point remquo (arithmetic x, arithmetic y, int* pquo);
float          remquof(float x, float y, int* pquo);
long double    remquol(long double x, long double y, int* pquo);

floating_point rint (arithmetic x);
float          rintf(float x);
long double    rintl(long double x);

floating_point round (arithmetic x);
float          roundf(float x);
long double    roundl(long double x);

floating_point scalbln (arithmetic x, long ex);
float          scalblnf(float x, long ex);
long double    scalblnl(long double x, long ex);

floating_point scalbn (arithmetic x, int ex);
float          scalbnf(float x, int ex);
long double    scalbnl(long double x, int ex);

floating_point tgamma (arithmetic x);
float          tgammaf(float x);
long double    tgammal(long double x);

floating_point trunc (arithmetic x);
float          truncf(float x);
long double    truncl(long double x);

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 294 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 298 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#endif
# 299 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#define _LIBCPP_STDLIB_INCLUDE_NEXT
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 301 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 302 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <math.h>
#endif /* expanded by -frewrite-includes */
# 303 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 304 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#ifdef __cplusplus

// We support including .h headers inside 'extern "C"' contexts, so switch
// back to C++ linkage before including these C++ headers.
extern "C++" {

#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 311 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 312 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 312 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 313 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// signbit

#ifdef signbit

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_signbit(_A1 __lcpp_x) _NOEXCEPT
{
    return signbit(__lcpp_x);
}

#undef signbit

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
signbit(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_signbit((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_integral<_A1>::value && std::is_signed<_A1>::value, bool>::type
signbit(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x < 0; }

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_integral<_A1>::value && !std::is_signed<_A1>::value, bool>::type
signbit(_A1) _NOEXCEPT
{ return false; }

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_MSVCRT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 351 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <typename _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
signbit(_A1 __lcpp_x) _NOEXCEPT
{
  return ::signbit(static_cast<typename std::__promote<_A1>::type>(__lcpp_x));
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_integral<_A1>::value && std::is_signed<_A1>::value, bool>::type
signbit(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x < 0; }

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_integral<_A1>::value && !std::is_signed<_A1>::value, bool>::type
signbit(_A1) _NOEXCEPT
{ return false; }

#endif  // signbit
# 375 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// fpclassify

#ifdef fpclassify

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
int
__libcpp_fpclassify(_A1 __lcpp_x) _NOEXCEPT
{
    return fpclassify(__lcpp_x);
}

#undef fpclassify

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, int>::type
fpclassify(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_fpclassify((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, int>::type
fpclassify(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x == 0 ? FP_ZERO : FP_NORMAL; }

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_LIBCPP_MSVCRT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 405 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <typename _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
fpclassify(_A1 __lcpp_x) _NOEXCEPT
{
  return ::fpclassify(static_cast<typename std::__promote<_A1>::type>(__lcpp_x));
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, int>::type
fpclassify(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x == 0 ? FP_ZERO : FP_NORMAL; }

#endif  // fpclassify
# 421 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isfinite

#ifdef isfinite

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isfinite(_A1 __lcpp_x) _NOEXCEPT
{
    return isfinite(__lcpp_x);
}

#undef isfinite

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_arithmetic<_A1>::value && std::numeric_limits<_A1>::has_infinity,
    bool>::type
isfinite(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_isfinite((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_arithmetic<_A1>::value && !std::numeric_limits<_A1>::has_infinity,
    bool>::type
isfinite(_A1) _NOEXCEPT
{ return true; }

#endif  // isfinite
# 455 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isinf

#ifdef isinf

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isinf(_A1 __lcpp_x) _NOEXCEPT
{
    return isinf(__lcpp_x);
}

#undef isinf

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_arithmetic<_A1>::value && std::numeric_limits<_A1>::has_infinity,
    bool>::type
isinf(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_isinf((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<
    std::is_arithmetic<_A1>::value && !std::numeric_limits<_A1>::has_infinity,
    bool>::type
isinf(_A1) _NOEXCEPT
{ return false; }

#ifdef _LIBCPP_PREFERRED_OVERLOAD
inline _LIBCPP_INLINE_VISIBILITY
bool
isinf(float __lcpp_x) _NOEXCEPT { return __libcpp_isinf(__lcpp_x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
bool
isinf(double __lcpp_x) _NOEXCEPT { return __libcpp_isinf(__lcpp_x); }

inline _LIBCPP_INLINE_VISIBILITY
bool
isinf(long double __lcpp_x) _NOEXCEPT { return __libcpp_isinf(__lcpp_x); }
#endif
# 501 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#endif  // isinf
# 503 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isnan

#ifdef isnan

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isnan(_A1 __lcpp_x) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_isnan)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 514 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
    return __builtin_isnan(__lcpp_x);
#else
# 516 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
    return isnan(__lcpp_x);
#endif
# 518 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
}

#undef isnan

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
isnan(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_isnan((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, bool>::type
isnan(_A1) _NOEXCEPT
{ return false; }

#ifdef _LIBCPP_PREFERRED_OVERLOAD
inline _LIBCPP_INLINE_VISIBILITY
bool
isnan(float __lcpp_x) _NOEXCEPT { return __libcpp_isnan(__lcpp_x); }

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_PREFERRED_OVERLOAD
bool
isnan(double __lcpp_x) _NOEXCEPT { return __libcpp_isnan(__lcpp_x); }

inline _LIBCPP_INLINE_VISIBILITY
bool
isnan(long double __lcpp_x) _NOEXCEPT { return __libcpp_isnan(__lcpp_x); }
#endif
# 549 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#endif  // isnan
# 551 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isnormal

#ifdef isnormal

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isnormal(_A1 __lcpp_x) _NOEXCEPT
{
    return isnormal(__lcpp_x);
}

#undef isnormal

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_floating_point<_A1>::value, bool>::type
isnormal(_A1 __lcpp_x) _NOEXCEPT
{
    return __libcpp_isnormal((typename std::__promote<_A1>::type)__lcpp_x);
}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, bool>::type
isnormal(_A1 __lcpp_x) _NOEXCEPT
{ return __lcpp_x != 0; }

#endif  // isnormal
# 581 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isgreater

#ifdef isgreater

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isgreater(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return isgreater(__lcpp_x, __lcpp_y);
}

#undef isgreater

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isgreater(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isgreater((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // isgreater
# 611 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isgreaterequal

#ifdef isgreaterequal

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isgreaterequal(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return isgreaterequal(__lcpp_x, __lcpp_y);
}

#undef isgreaterequal

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isgreaterequal(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isgreaterequal((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // isgreaterequal
# 641 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isless

#ifdef isless

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isless(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return isless(__lcpp_x, __lcpp_y);
}

#undef isless

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isless(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isless((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // isless
# 671 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// islessequal

#ifdef islessequal

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_islessequal(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return islessequal(__lcpp_x, __lcpp_y);
}

#undef islessequal

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
islessequal(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_islessequal((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // islessequal
# 701 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// islessgreater

#ifdef islessgreater

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_islessgreater(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return islessgreater(__lcpp_x, __lcpp_y);
}

#undef islessgreater

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
islessgreater(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_islessgreater((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // islessgreater
# 731 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// isunordered

#ifdef isunordered

template <class _A1, class _A2>
_LIBCPP_INLINE_VISIBILITY
bool
__libcpp_isunordered(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    return isunordered(__lcpp_x, __lcpp_y);
}

#undef isunordered

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isunordered(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isunordered((type)__lcpp_x, (type)__lcpp_y);
}

#endif  // isunordered
# 761 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// abs

#undef abs
#undef labs
#ifndef _LIBCPP_HAS_NO_LONG_LONG
#undef llabs
#endif
# 769 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// MSVCRT already has the correct prototype in <stdlib.h> if __cplusplus is defined
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_MSVCRT) && !defined(__sun__) && !defined(_AIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 772 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY long abs(long __x) _NOEXCEPT {
  return ::labs(__x);
}
#ifndef _LIBCPP_HAS_NO_LONG_LONG
inline _LIBCPP_INLINE_VISIBILITY long long abs(long long __x) _NOEXCEPT {
  return ::llabs(__x);
}
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 780 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#endif // !defined(_LIBCPP_MSVCRT) && !defined(__sun__) && !defined(_AIX)
# 781 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3


#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 784 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float abs(float __lcpp_x) _NOEXCEPT {
  return ::fabsf(__lcpp_x);
}

inline _LIBCPP_INLINE_VISIBILITY double abs(double __lcpp_x) _NOEXCEPT {
  return ::fabs(__lcpp_x);
}

inline _LIBCPP_INLINE_VISIBILITY long double
abs(long double __lcpp_x) _NOEXCEPT {
  return ::fabsl(__lcpp_x);
}
#endif // !(defined(_AIX) || defined(__sun__))
# 797 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// div

#undef div
#undef ldiv
#ifndef _LIBCPP_HAS_NO_LONG_LONG
#undef lldiv
#endif
# 805 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// MSVCRT already has the correct prototype in <stdlib.h> if __cplusplus is defined
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_MSVCRT) && !defined(__sun__) && !defined(_AIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 808 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY ldiv_t div(long __x, long __y) _NOEXCEPT {
  return ::ldiv(__x, __y);
}
#ifndef _LIBCPP_HAS_NO_LONG_LONG
inline _LIBCPP_INLINE_VISIBILITY lldiv_t div(long long __x,
                                             long long __y) _NOEXCEPT {
  return ::lldiv(__x, __y);
}
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 817 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#endif // _LIBCPP_MSVCRT / __sun__ / _AIX
# 818 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// acos

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 822 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       acos(float __lcpp_x) _NOEXCEPT       {return ::acosf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double acos(long double __lcpp_x) _NOEXCEPT {return ::acosl(__lcpp_x);}
#endif
# 825 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
acos(_A1 __lcpp_x) _NOEXCEPT {return ::acos((double)__lcpp_x);}

// asin

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 834 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       asin(float __lcpp_x) _NOEXCEPT       {return ::asinf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double asin(long double __lcpp_x) _NOEXCEPT {return ::asinl(__lcpp_x);}
#endif
# 837 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
asin(_A1 __lcpp_x) _NOEXCEPT {return ::asin((double)__lcpp_x);}

// atan

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 846 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       atan(float __lcpp_x) _NOEXCEPT       {return ::atanf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double atan(long double __lcpp_x) _NOEXCEPT {return ::atanl(__lcpp_x);}
#endif
# 849 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
atan(_A1 __lcpp_x) _NOEXCEPT {return ::atan((double)__lcpp_x);}

// atan2

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 858 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       atan2(float __lcpp_y, float __lcpp_x) _NOEXCEPT             {return ::atan2f(__lcpp_y, __lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double atan2(long double __lcpp_y, long double __lcpp_x) _NOEXCEPT {return ::atan2l(__lcpp_y, __lcpp_x);}
#endif
# 861 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
atan2(_A1 __lcpp_y, _A2 __lcpp_x) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::atan2((__result_type)__lcpp_y, (__result_type)__lcpp_x);
}

// ceil

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 881 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       ceil(float __lcpp_x) _NOEXCEPT       {return ::ceilf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double ceil(long double __lcpp_x) _NOEXCEPT {return ::ceill(__lcpp_x);}
#endif
# 884 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
ceil(_A1 __lcpp_x) _NOEXCEPT {return ::ceil((double)__lcpp_x);}

// cos

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 893 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       cos(float __lcpp_x) _NOEXCEPT       {return ::cosf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double cos(long double __lcpp_x) _NOEXCEPT {return ::cosl(__lcpp_x);}
#endif
# 896 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
cos(_A1 __lcpp_x) _NOEXCEPT {return ::cos((double)__lcpp_x);}

// cosh

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 905 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       cosh(float __lcpp_x) _NOEXCEPT       {return ::coshf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double cosh(long double __lcpp_x) _NOEXCEPT {return ::coshl(__lcpp_x);}
#endif
# 908 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
cosh(_A1 __lcpp_x) _NOEXCEPT {return ::cosh((double)__lcpp_x);}

// exp

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 917 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       exp(float __lcpp_x) _NOEXCEPT       {return ::expf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double exp(long double __lcpp_x) _NOEXCEPT {return ::expl(__lcpp_x);}
#endif
# 920 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
exp(_A1 __lcpp_x) _NOEXCEPT {return ::exp((double)__lcpp_x);}

// fabs

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 929 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       fabs(float __lcpp_x) _NOEXCEPT       {return ::fabsf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double fabs(long double __lcpp_x) _NOEXCEPT {return ::fabsl(__lcpp_x);}
#endif
# 932 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
fabs(_A1 __lcpp_x) _NOEXCEPT {return ::fabs((double)__lcpp_x);}

// floor

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 941 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       floor(float __lcpp_x) _NOEXCEPT       {return ::floorf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double floor(long double __lcpp_x) _NOEXCEPT {return ::floorl(__lcpp_x);}
#endif
# 944 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
floor(_A1 __lcpp_x) _NOEXCEPT {return ::floor((double)__lcpp_x);}

// fmod

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 953 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       fmod(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::fmodf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmod(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::fmodl(__lcpp_x, __lcpp_y);}
#endif
# 956 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
fmod(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::fmod((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// frexp

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 976 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       frexp(float __lcpp_x, int* __lcpp_e) _NOEXCEPT       {return ::frexpf(__lcpp_x, __lcpp_e);}
inline _LIBCPP_INLINE_VISIBILITY long double frexp(long double __lcpp_x, int* __lcpp_e) _NOEXCEPT {return ::frexpl(__lcpp_x, __lcpp_e);}
#endif
# 979 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
frexp(_A1 __lcpp_x, int* __lcpp_e) _NOEXCEPT {return ::frexp((double)__lcpp_x, __lcpp_e);}

// ldexp

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 988 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       ldexp(float __lcpp_x, int __lcpp_e) _NOEXCEPT       {return ::ldexpf(__lcpp_x, __lcpp_e);}
inline _LIBCPP_INLINE_VISIBILITY long double ldexp(long double __lcpp_x, int __lcpp_e) _NOEXCEPT {return ::ldexpl(__lcpp_x, __lcpp_e);}
#endif
# 991 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
ldexp(_A1 __lcpp_x, int __lcpp_e) _NOEXCEPT {return ::ldexp((double)__lcpp_x, __lcpp_e);}

// log

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1000 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       log(float __lcpp_x) _NOEXCEPT       {return ::logf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double log(long double __lcpp_x) _NOEXCEPT {return ::logl(__lcpp_x);}
#endif
# 1003 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
log(_A1 __lcpp_x) _NOEXCEPT {return ::log((double)__lcpp_x);}

// log10

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1012 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       log10(float __lcpp_x) _NOEXCEPT       {return ::log10f(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double log10(long double __lcpp_x) _NOEXCEPT {return ::log10l(__lcpp_x);}
#endif
# 1015 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
log10(_A1 __lcpp_x) _NOEXCEPT {return ::log10((double)__lcpp_x);}

// modf

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1024 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       modf(float __lcpp_x, float* __lcpp_y) _NOEXCEPT             {return ::modff(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double modf(long double __lcpp_x, long double* __lcpp_y) _NOEXCEPT {return ::modfl(__lcpp_x, __lcpp_y);}
#endif
# 1027 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// pow

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1031 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       pow(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::powf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double pow(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::powl(__lcpp_x, __lcpp_y);}
#endif
# 1034 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
pow(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::pow((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// sin

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1054 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       sin(float __lcpp_x) _NOEXCEPT       {return ::sinf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double sin(long double __lcpp_x) _NOEXCEPT {return ::sinl(__lcpp_x);}
#endif
# 1057 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
sin(_A1 __lcpp_x) _NOEXCEPT {return ::sin((double)__lcpp_x);}

// sinh

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1066 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       sinh(float __lcpp_x) _NOEXCEPT       {return ::sinhf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double sinh(long double __lcpp_x) _NOEXCEPT {return ::sinhl(__lcpp_x);}
#endif
# 1069 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
sinh(_A1 __lcpp_x) _NOEXCEPT {return ::sinh((double)__lcpp_x);}

// sqrt

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1078 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       sqrt(float __lcpp_x) _NOEXCEPT       {return ::sqrtf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double sqrt(long double __lcpp_x) _NOEXCEPT {return ::sqrtl(__lcpp_x);}
#endif
# 1081 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
sqrt(_A1 __lcpp_x) _NOEXCEPT {return ::sqrt((double)__lcpp_x);}

// tan

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1090 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       tan(float __lcpp_x) _NOEXCEPT       {return ::tanf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double tan(long double __lcpp_x) _NOEXCEPT {return ::tanl(__lcpp_x);}
#endif
# 1093 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
tan(_A1 __lcpp_x) _NOEXCEPT {return ::tan((double)__lcpp_x);}

// tanh

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_AIX) || defined(__sun__))
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
inline _LIBCPP_INLINE_VISIBILITY float       tanh(float __lcpp_x) _NOEXCEPT       {return ::tanhf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double tanh(long double __lcpp_x) _NOEXCEPT {return ::tanhl(__lcpp_x);}
#endif
# 1105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
tanh(_A1 __lcpp_x) _NOEXCEPT {return ::tanh((double)__lcpp_x);}

// acosh

inline _LIBCPP_INLINE_VISIBILITY float       acosh(float __lcpp_x) _NOEXCEPT       {return ::acoshf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double acosh(long double __lcpp_x) _NOEXCEPT {return ::acoshl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
acosh(_A1 __lcpp_x) _NOEXCEPT {return ::acosh((double)__lcpp_x);}

// asinh

inline _LIBCPP_INLINE_VISIBILITY float       asinh(float __lcpp_x) _NOEXCEPT       {return ::asinhf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double asinh(long double __lcpp_x) _NOEXCEPT {return ::asinhl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
asinh(_A1 __lcpp_x) _NOEXCEPT {return ::asinh((double)__lcpp_x);}

// atanh

inline _LIBCPP_INLINE_VISIBILITY float       atanh(float __lcpp_x) _NOEXCEPT       {return ::atanhf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double atanh(long double __lcpp_x) _NOEXCEPT {return ::atanhl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
atanh(_A1 __lcpp_x) _NOEXCEPT {return ::atanh((double)__lcpp_x);}

// cbrt

inline _LIBCPP_INLINE_VISIBILITY float       cbrt(float __lcpp_x) _NOEXCEPT       {return ::cbrtf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double cbrt(long double __lcpp_x) _NOEXCEPT {return ::cbrtl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
cbrt(_A1 __lcpp_x) _NOEXCEPT {return ::cbrt((double)__lcpp_x);}

// copysign

inline _LIBCPP_INLINE_VISIBILITY float copysign(float __lcpp_x,
                                                float __lcpp_y) _NOEXCEPT {
  return ::copysignf(__lcpp_x, __lcpp_y);
}
inline _LIBCPP_INLINE_VISIBILITY long double
copysign(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {
  return ::copysignl(__lcpp_x, __lcpp_y);
}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
copysign(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::copysign((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// erf

inline _LIBCPP_INLINE_VISIBILITY float       erf(float __lcpp_x) _NOEXCEPT       {return ::erff(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double erf(long double __lcpp_x) _NOEXCEPT {return ::erfl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
erf(_A1 __lcpp_x) _NOEXCEPT {return ::erf((double)__lcpp_x);}

// erfc

inline _LIBCPP_INLINE_VISIBILITY float       erfc(float __lcpp_x) _NOEXCEPT       {return ::erfcf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double erfc(long double __lcpp_x) _NOEXCEPT {return ::erfcl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
erfc(_A1 __lcpp_x) _NOEXCEPT {return ::erfc((double)__lcpp_x);}

// exp2

inline _LIBCPP_INLINE_VISIBILITY float       exp2(float __lcpp_x) _NOEXCEPT       {return ::exp2f(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double exp2(long double __lcpp_x) _NOEXCEPT {return ::exp2l(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
exp2(_A1 __lcpp_x) _NOEXCEPT {return ::exp2((double)__lcpp_x);}

// expm1

inline _LIBCPP_INLINE_VISIBILITY float       expm1(float __lcpp_x) _NOEXCEPT       {return ::expm1f(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double expm1(long double __lcpp_x) _NOEXCEPT {return ::expm1l(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
expm1(_A1 __lcpp_x) _NOEXCEPT {return ::expm1((double)__lcpp_x);}

// fdim

inline _LIBCPP_INLINE_VISIBILITY float       fdim(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::fdimf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double fdim(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::fdiml(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
fdim(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::fdim((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// fma

inline _LIBCPP_INLINE_VISIBILITY float       fma(float __lcpp_x, float __lcpp_y, float __lcpp_z) _NOEXCEPT                   {return ::fmaf(__lcpp_x, __lcpp_y, __lcpp_z);}
inline _LIBCPP_INLINE_VISIBILITY long double fma(long double __lcpp_x, long double __lcpp_y, long double __lcpp_z) _NOEXCEPT {return ::fmal(__lcpp_x, __lcpp_y, __lcpp_z);}

template <class _A1, class _A2, class _A3>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value &&
    std::is_arithmetic<_A3>::value,
    std::__promote<_A1, _A2, _A3>
>::type
fma(_A1 __lcpp_x, _A2 __lcpp_y, _A3 __lcpp_z) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2, _A3>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value &&
                     std::_IsSame<_A3, __result_type>::value)), "");
    return ::fma((__result_type)__lcpp_x, (__result_type)__lcpp_y, (__result_type)__lcpp_z);
}

// fmax

inline _LIBCPP_INLINE_VISIBILITY float       fmax(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::fmaxf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmax(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::fmaxl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
fmax(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::fmax((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// fmin

inline _LIBCPP_INLINE_VISIBILITY float       fmin(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::fminf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmin(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::fminl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
fmin(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::fmin((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// hypot

inline _LIBCPP_INLINE_VISIBILITY float       hypot(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::hypotf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double hypot(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::hypotl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
hypot(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::hypot((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// ilogb

inline _LIBCPP_INLINE_VISIBILITY int ilogb(float __lcpp_x) _NOEXCEPT       {return ::ilogbf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY int ilogb(long double __lcpp_x) _NOEXCEPT {return ::ilogbl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, int>::type
ilogb(_A1 __lcpp_x) _NOEXCEPT {return ::ilogb((double)__lcpp_x);}

// lgamma

inline _LIBCPP_INLINE_VISIBILITY float       lgamma(float __lcpp_x) _NOEXCEPT       {return ::lgammaf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double lgamma(long double __lcpp_x) _NOEXCEPT {return ::lgammal(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
lgamma(_A1 __lcpp_x) _NOEXCEPT {return ::lgamma((double)__lcpp_x);}

// llrint

inline _LIBCPP_INLINE_VISIBILITY long long llrint(float __lcpp_x) _NOEXCEPT       {return ::llrintf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long long llrint(long double __lcpp_x) _NOEXCEPT {return ::llrintl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, long long>::type
llrint(_A1 __lcpp_x) _NOEXCEPT {return ::llrint((double)__lcpp_x);}

// llround

inline _LIBCPP_INLINE_VISIBILITY long long llround(float __lcpp_x) _NOEXCEPT       {return ::llroundf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long long llround(long double __lcpp_x) _NOEXCEPT {return ::llroundl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, long long>::type
llround(_A1 __lcpp_x) _NOEXCEPT {return ::llround((double)__lcpp_x);}

// log1p

inline _LIBCPP_INLINE_VISIBILITY float       log1p(float __lcpp_x) _NOEXCEPT       {return ::log1pf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double log1p(long double __lcpp_x) _NOEXCEPT {return ::log1pl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
log1p(_A1 __lcpp_x) _NOEXCEPT {return ::log1p((double)__lcpp_x);}

// log2

inline _LIBCPP_INLINE_VISIBILITY float       log2(float __lcpp_x) _NOEXCEPT       {return ::log2f(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double log2(long double __lcpp_x) _NOEXCEPT {return ::log2l(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
log2(_A1 __lcpp_x) _NOEXCEPT {return ::log2((double)__lcpp_x);}

// logb

inline _LIBCPP_INLINE_VISIBILITY float       logb(float __lcpp_x) _NOEXCEPT       {return ::logbf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double logb(long double __lcpp_x) _NOEXCEPT {return ::logbl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
logb(_A1 __lcpp_x) _NOEXCEPT {return ::logb((double)__lcpp_x);}

// lrint

inline _LIBCPP_INLINE_VISIBILITY long lrint(float __lcpp_x) _NOEXCEPT       {return ::lrintf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long lrint(long double __lcpp_x) _NOEXCEPT {return ::lrintl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, long>::type
lrint(_A1 __lcpp_x) _NOEXCEPT {return ::lrint((double)__lcpp_x);}

// lround

inline _LIBCPP_INLINE_VISIBILITY long lround(float __lcpp_x) _NOEXCEPT       {return ::lroundf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long lround(long double __lcpp_x) _NOEXCEPT {return ::lroundl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, long>::type
lround(_A1 __lcpp_x) _NOEXCEPT {return ::lround((double)__lcpp_x);}

// nan

// nearbyint

inline _LIBCPP_INLINE_VISIBILITY float       nearbyint(float __lcpp_x) _NOEXCEPT       {return ::nearbyintf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double nearbyint(long double __lcpp_x) _NOEXCEPT {return ::nearbyintl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
nearbyint(_A1 __lcpp_x) _NOEXCEPT {return ::nearbyint((double)__lcpp_x);}

// nextafter

inline _LIBCPP_INLINE_VISIBILITY float       nextafter(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::nextafterf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double nextafter(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::nextafterl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
nextafter(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::nextafter((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// nexttoward

inline _LIBCPP_INLINE_VISIBILITY float       nexttoward(float __lcpp_x, long double __lcpp_y) _NOEXCEPT       {return ::nexttowardf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double nexttoward(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::nexttowardl(__lcpp_x, __lcpp_y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
nexttoward(_A1 __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::nexttoward((double)__lcpp_x, __lcpp_y);}

// remainder

inline _LIBCPP_INLINE_VISIBILITY float       remainder(float __lcpp_x, float __lcpp_y) _NOEXCEPT             {return ::remainderf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double remainder(long double __lcpp_x, long double __lcpp_y) _NOEXCEPT {return ::remainderl(__lcpp_x, __lcpp_y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
remainder(_A1 __lcpp_x, _A2 __lcpp_y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::remainder((__result_type)__lcpp_x, (__result_type)__lcpp_y);
}

// remquo

inline _LIBCPP_INLINE_VISIBILITY float       remquo(float __lcpp_x, float __lcpp_y, int* __lcpp_z) _NOEXCEPT             {return ::remquof(__lcpp_x, __lcpp_y, __lcpp_z);}
inline _LIBCPP_INLINE_VISIBILITY long double remquo(long double __lcpp_x, long double __lcpp_y, int* __lcpp_z) _NOEXCEPT {return ::remquol(__lcpp_x, __lcpp_y, __lcpp_z);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::_EnableIf
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    std::__promote<_A1, _A2>
>::type
remquo(_A1 __lcpp_x, _A2 __lcpp_y, int* __lcpp_z) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type __result_type;
    static_assert((!(std::_IsSame<_A1, __result_type>::value &&
                     std::_IsSame<_A2, __result_type>::value)), "");
    return ::remquo((__result_type)__lcpp_x, (__result_type)__lcpp_y, __lcpp_z);
}

// rint

inline _LIBCPP_INLINE_VISIBILITY float       rint(float __lcpp_x) _NOEXCEPT       {return ::rintf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double rint(long double __lcpp_x) _NOEXCEPT {return ::rintl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
rint(_A1 __lcpp_x) _NOEXCEPT {return ::rint((double)__lcpp_x);}

// round

inline _LIBCPP_INLINE_VISIBILITY float       round(float __lcpp_x) _NOEXCEPT       {return ::roundf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double round(long double __lcpp_x) _NOEXCEPT {return ::roundl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
round(_A1 __lcpp_x) _NOEXCEPT {return ::round((double)__lcpp_x);}

// scalbln

inline _LIBCPP_INLINE_VISIBILITY float       scalbln(float __lcpp_x, long __lcpp_y) _NOEXCEPT       {return ::scalblnf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double scalbln(long double __lcpp_x, long __lcpp_y) _NOEXCEPT {return ::scalblnl(__lcpp_x, __lcpp_y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
scalbln(_A1 __lcpp_x, long __lcpp_y) _NOEXCEPT {return ::scalbln((double)__lcpp_x, __lcpp_y);}

// scalbn

inline _LIBCPP_INLINE_VISIBILITY float       scalbn(float __lcpp_x, int __lcpp_y) _NOEXCEPT       {return ::scalbnf(__lcpp_x, __lcpp_y);}
inline _LIBCPP_INLINE_VISIBILITY long double scalbn(long double __lcpp_x, int __lcpp_y) _NOEXCEPT {return ::scalbnl(__lcpp_x, __lcpp_y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
scalbn(_A1 __lcpp_x, int __lcpp_y) _NOEXCEPT {return ::scalbn((double)__lcpp_x, __lcpp_y);}

// tgamma

inline _LIBCPP_INLINE_VISIBILITY float       tgamma(float __lcpp_x) _NOEXCEPT       {return ::tgammaf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double tgamma(long double __lcpp_x) _NOEXCEPT {return ::tgammal(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
tgamma(_A1 __lcpp_x) _NOEXCEPT {return ::tgamma((double)__lcpp_x);}

// trunc

inline _LIBCPP_INLINE_VISIBILITY float       trunc(float __lcpp_x) _NOEXCEPT       {return ::truncf(__lcpp_x);}
inline _LIBCPP_INLINE_VISIBILITY long double trunc(long double __lcpp_x) _NOEXCEPT {return ::truncl(__lcpp_x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_integral<_A1>::value, double>::type
trunc(_A1 __lcpp_x) _NOEXCEPT {return ::trunc((double)__lcpp_x);}

} // extern "C++"

#endif // __cplusplus
# 1563 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#else // _LIBCPP_MATH_H
# 1565 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

// This include lives outside the header guard in order to support an MSVC
// extension which allows users to do:
//
// #define _USE_MATH_DEFINES
// #include <math.h>
//
// and receive the definitions of mathematical constants, even if <math.h>
// has previously been included.
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_MSVCRT) && defined(_USE_MATH_DEFINES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1575 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#if 0 /* expanded by -frewrite-includes */
#include_next <math.h>
#endif /* expanded by -frewrite-includes */
# 1575 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 1576 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
#endif
# 1577 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3

#endif  // _LIBCPP_MATH_H
# 1579 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/math.h" 3
# 305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
# 306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
# 307 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 309 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 310 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
#endif
# 311 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 313 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 314 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 2 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::signbit;
using ::fpclassify;
using ::isfinite;
using ::isinf;
using ::isnan;
using ::isnormal;
using ::isgreater;
using ::isgreaterequal;
using ::isless;
using ::islessequal;
using ::islessgreater;
using ::isunordered;
using ::isunordered;

using ::float_t;
using ::double_t;

#ifndef _AIX
using ::abs;
#endif
# 337 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3

using ::acos;
using ::acosf;
using ::asin;
using ::asinf;
using ::atan;
using ::atanf;
using ::atan2;
using ::atan2f;
using ::ceil;
using ::ceilf;
using ::cos;
using ::cosf;
using ::cosh;
using ::coshf;

using ::exp;
using ::expf;

using ::fabs;
using ::fabsf;
using ::floor;
using ::floorf;

using ::fmod;
using ::fmodf;

using ::frexp;
using ::frexpf;
using ::ldexp;
using ::ldexpf;

using ::log;
using ::logf;

using ::log10;
using ::log10f;
using ::modf;
using ::modff;

using ::pow;
using ::powf;

using ::sin;
using ::sinf;
using ::sinh;
using ::sinhf;

using ::sqrt;
using ::sqrtf;
using ::tan;
using ::tanf;

using ::tanh;
using ::tanhf;

using ::acosh;
using ::acoshf;
using ::asinh;
using ::asinhf;
using ::atanh;
using ::atanhf;
using ::cbrt;
using ::cbrtf;

using ::copysign;
using ::copysignf;

using ::erf;
using ::erff;
using ::erfc;
using ::erfcf;
using ::exp2;
using ::exp2f;
using ::expm1;
using ::expm1f;
using ::fdim;
using ::fdimf;
using ::fmaf;
using ::fma;
using ::fmax;
using ::fmaxf;
using ::fmin;
using ::fminf;
using ::hypot;
using ::hypotf;
using ::ilogb;
using ::ilogbf;
using ::lgamma;
using ::lgammaf;
using ::llrint;
using ::llrintf;
using ::llround;
using ::llroundf;
using ::log1p;
using ::log1pf;
using ::log2;
using ::log2f;
using ::logb;
using ::logbf;
using ::lrint;
using ::lrintf;
using ::lround;
using ::lroundf;

using ::nan;
using ::nanf;

using ::nearbyint;
using ::nearbyintf;
using ::nextafter;
using ::nextafterf;
using ::nexttoward;
using ::nexttowardf;
using ::remainder;
using ::remainderf;
using ::remquo;
using ::remquof;
using ::rint;
using ::rintf;
using ::round;
using ::roundf;
using ::scalbln;
using ::scalblnf;
using ::scalbn;
using ::scalbnf;
using ::tgamma;
using ::tgammaf;
using ::trunc;
using ::truncf;

using ::acosl;
using ::asinl;
using ::atanl;
using ::atan2l;
using ::ceill;
using ::cosl;
using ::coshl;
using ::expl;
using ::fabsl;
using ::floorl;
using ::fmodl;
using ::frexpl;
using ::ldexpl;
using ::logl;
using ::log10l;
using ::modfl;
using ::powl;
using ::sinl;
using ::sinhl;
using ::sqrtl;
using ::tanl;

using ::tanhl;
using ::acoshl;
using ::asinhl;
using ::atanhl;
using ::cbrtl;

using ::copysignl;

using ::erfl;
using ::erfcl;
using ::exp2l;
using ::expm1l;
using ::fdiml;
using ::fmal;
using ::fmaxl;
using ::fminl;
using ::hypotl;
using ::ilogbl;
using ::lgammal;
using ::llrintl;
using ::llroundl;
using ::log1pl;
using ::log2l;
using ::logbl;
using ::lrintl;
using ::lroundl;
using ::nanl;
using ::nearbyintl;
using ::nextafterl;
using ::nexttowardl;
using ::remainderl;
using ::remquol;
using ::rintl;
using ::roundl;
using ::scalblnl;
using ::scalbnl;
using ::tgammal;
using ::truncl;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 530 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
inline _LIBCPP_INLINE_VISIBILITY float       hypot(       float x,       float y,       float z ) { return sqrt(x*x + y*y + z*z); }
inline _LIBCPP_INLINE_VISIBILITY double      hypot(      double x,      double y,      double z ) { return sqrt(x*x + y*y + z*z); }
inline _LIBCPP_INLINE_VISIBILITY long double hypot( long double x, long double y, long double z ) { return sqrt(x*x + y*y + z*z); }

template <class _A1, class _A2, class _A3>
inline _LIBCPP_INLINE_VISIBILITY
typename _EnableIf
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value &&
    is_arithmetic<_A3>::value,
    __promote<_A1, _A2, _A3>
>::type
hypot(_A1 __lcpp_x, _A2 __lcpp_y, _A3 __lcpp_z) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2, _A3>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                     is_same<_A2, __result_type>::value &&
                     is_same<_A3, __result_type>::value)), "");
    return hypot((__result_type)__lcpp_x, (__result_type)__lcpp_y, (__result_type)__lcpp_z);
}
#endif
# 552 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR typename enable_if<is_floating_point<_A1>::value, bool>::type
__libcpp_isnan_or_builtin(_A1 __lcpp_x) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_isnan)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 559 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
    return __builtin_isnan(__lcpp_x);
#else
# 561 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
    return isnan(__lcpp_x);
#endif
# 563 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
}

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR typename enable_if<!is_floating_point<_A1>::value, bool>::type
__libcpp_isnan_or_builtin(_A1 __lcpp_x) _NOEXCEPT
{
    return isnan(__lcpp_x);
}

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR typename enable_if<is_floating_point<_A1>::value, bool>::type
__libcpp_isinf_or_builtin(_A1 __lcpp_x) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_isinf)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 579 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
    return __builtin_isinf(__lcpp_x);
#else
# 581 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
    return isinf(__lcpp_x);
#endif
# 583 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
}

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR typename enable_if<!is_floating_point<_A1>::value, bool>::type
__libcpp_isinf_or_builtin(_A1 __lcpp_x) _NOEXCEPT
{
    return isinf(__lcpp_x);
}

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR typename enable_if<is_floating_point<_A1>::value, bool>::type
__libcpp_isfinite_or_builtin(_A1 __lcpp_x) _NOEXCEPT
{
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_isfinite)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 599 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
    return __builtin_isfinite(__lcpp_x);
#else
# 601 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
    return isfinite(__lcpp_x);
#endif
# 603 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
}

template <class _A1>
_LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR typename enable_if<!is_floating_point<_A1>::value, bool>::type
__libcpp_isfinite_or_builtin(_A1 __lcpp_x) _NOEXCEPT
{
    return isfinite(__lcpp_x);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 614 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
template <typename _Fp>
constexpr
_Fp __lerp(_Fp __a, _Fp __b, _Fp __t) noexcept {
    if ((__a <= 0 && __b >= 0) || (__a >= 0 && __b <= 0))
        return __t * __b + (1 - __t) * __a;

    if (__t == 1) return __b;
    const _Fp __x = __a + __t * (__b - __a);
    if (__t > 1 == __b > __a)
    	return __b < __x ? __x : __b;
    else
    	return __x < __b ? __x : __b;
}

constexpr float
lerp(float __a, float __b, float __t)                   _NOEXCEPT { return __lerp(__a, __b, __t); }

constexpr double
lerp(double __a, double __b, double __t)                _NOEXCEPT { return __lerp(__a, __b, __t); }

constexpr long double
lerp(long double __a, long double __b, long double __t) _NOEXCEPT { return __lerp(__a, __b, __t); }

#endif // _LIBCPP_STD_VER > 17
# 638 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3

template <class _IntT, class _FloatT,
    bool _FloatBigger = (numeric_limits<_FloatT>::digits > numeric_limits<_IntT>::digits),
    int _Bits = (numeric_limits<_IntT>::digits - numeric_limits<_FloatT>::digits)>
_LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR _IntT __max_representable_int_for_float() _NOEXCEPT {
  static_assert(is_floating_point<_FloatT>::value, "must be a floating point type");
  static_assert(is_integral<_IntT>::value, "must be an integral type");
  static_assert(numeric_limits<_FloatT>::radix == 2, "FloatT has incorrect radix");
  static_assert((_IsSame<_FloatT, float>::value || _IsSame<_FloatT, double>::value
                 || _IsSame<_FloatT,long double>::value), "unsupported floating point type");
  return _FloatBigger ? numeric_limits<_IntT>::max() :  (numeric_limits<_IntT>::max() >> _Bits << _Bits);
}

// Convert a floating point number to the specified integral type after
// clamping to the integral types representable range.
//
// The behavior is undefined if `__r` is NaN.
template <class _IntT, class _RealT>
_LIBCPP_INLINE_VISIBILITY
_IntT __clamp_to_integral(_RealT __r) _NOEXCEPT {
  using _Lim = std::numeric_limits<_IntT>;
  const _IntT _MaxVal = std::__max_representable_int_for_float<_IntT, _RealT>();
  if (__r >= ::nextafter(static_cast<_RealT>(_MaxVal), INFINITY)) {
    return _Lim::max();
  } else if (__r <= _Lim::lowest()) {
    return _Lim::min();
  }
  return static_cast<_IntT>(__r);
}

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_CMATH
# 674 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cmath" 3
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h" 2
#else
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#endif
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

#if 0 /* expanded by -frewrite-includes */
#include <inttypes.h>
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 1 3
// -*- C++ -*-
//===--------------------------- inttypes.h -------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_INTTYPES_H
// AIX system headers need inttypes.h to be re-enterable while _STD_TYPES_T
// is defined until an inclusion of it without _STD_TYPES_T occurs, in which
// case the header guard macro is defined.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_AIX) || !defined(_STD_TYPES_T)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3
#define _LIBCPP_INTTYPES_H
#endif // _STD_TYPES_T
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3

/*
    inttypes.h synopsis

This entire header is C99 / C++0X

#include <stdint.h>  // <cinttypes> includes <cstdint>

Macros:

    PRId8
    PRId16
    PRId32
    PRId64

    PRIdLEAST8
    PRIdLEAST16
    PRIdLEAST32
    PRIdLEAST64

    PRIdFAST8
    PRIdFAST16
    PRIdFAST32
    PRIdFAST64

    PRIdMAX
    PRIdPTR

    PRIi8
    PRIi16
    PRIi32
    PRIi64

    PRIiLEAST8
    PRIiLEAST16
    PRIiLEAST32
    PRIiLEAST64

    PRIiFAST8
    PRIiFAST16
    PRIiFAST32
    PRIiFAST64

    PRIiMAX
    PRIiPTR

    PRIo8
    PRIo16
    PRIo32
    PRIo64

    PRIoLEAST8
    PRIoLEAST16
    PRIoLEAST32
    PRIoLEAST64

    PRIoFAST8
    PRIoFAST16
    PRIoFAST32
    PRIoFAST64

    PRIoMAX
    PRIoPTR

    PRIu8
    PRIu16
    PRIu32
    PRIu64

    PRIuLEAST8
    PRIuLEAST16
    PRIuLEAST32
    PRIuLEAST64

    PRIuFAST8
    PRIuFAST16
    PRIuFAST32
    PRIuFAST64

    PRIuMAX
    PRIuPTR

    PRIx8
    PRIx16
    PRIx32
    PRIx64

    PRIxLEAST8
    PRIxLEAST16
    PRIxLEAST32
    PRIxLEAST64

    PRIxFAST8
    PRIxFAST16
    PRIxFAST32
    PRIxFAST64

    PRIxMAX
    PRIxPTR

    PRIX8
    PRIX16
    PRIX32
    PRIX64

    PRIXLEAST8
    PRIXLEAST16
    PRIXLEAST32
    PRIXLEAST64

    PRIXFAST8
    PRIXFAST16
    PRIXFAST32
    PRIXFAST64

    PRIXMAX
    PRIXPTR

    SCNd8
    SCNd16
    SCNd32
    SCNd64

    SCNdLEAST8
    SCNdLEAST16
    SCNdLEAST32
    SCNdLEAST64

    SCNdFAST8
    SCNdFAST16
    SCNdFAST32
    SCNdFAST64

    SCNdMAX
    SCNdPTR

    SCNi8
    SCNi16
    SCNi32
    SCNi64

    SCNiLEAST8
    SCNiLEAST16
    SCNiLEAST32
    SCNiLEAST64

    SCNiFAST8
    SCNiFAST16
    SCNiFAST32
    SCNiFAST64

    SCNiMAX
    SCNiPTR

    SCNo8
    SCNo16
    SCNo32
    SCNo64

    SCNoLEAST8
    SCNoLEAST16
    SCNoLEAST32
    SCNoLEAST64

    SCNoFAST8
    SCNoFAST16
    SCNoFAST32
    SCNoFAST64

    SCNoMAX
    SCNoPTR

    SCNu8
    SCNu16
    SCNu32
    SCNu64

    SCNuLEAST8
    SCNuLEAST16
    SCNuLEAST32
    SCNuLEAST64

    SCNuFAST8
    SCNuFAST16
    SCNuFAST32
    SCNuFAST64

    SCNuMAX
    SCNuPTR

    SCNx8
    SCNx16
    SCNx32
    SCNx64

    SCNxLEAST8
    SCNxLEAST16
    SCNxLEAST32
    SCNxLEAST64

    SCNxFAST8
    SCNxFAST16
    SCNxFAST32
    SCNxFAST64

    SCNxMAX
    SCNxPTR

Types:

    imaxdiv_t

intmax_t  imaxabs(intmax_t j);
imaxdiv_t imaxdiv(intmax_t numer, intmax_t denom);
intmax_t  strtoimax(const char* restrict nptr, char** restrict endptr, int base);
uintmax_t strtoumax(const char* restrict nptr, char** restrict endptr, int base);
intmax_t  wcstoimax(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
uintmax_t wcstoumax(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 238 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3
# 239 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 241 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 242 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3
#endif
# 243 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3

/* C99 stdlib (e.g. glibc < 2.18) does not provide format macros needed
   for C++11 unless __STDC_FORMAT_MACROS is defined
*/
#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus) && !defined(__STDC_FORMAT_MACROS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 248 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3
#   define __STDC_FORMAT_MACROS
#endif
# 250 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <inttypes.h>
#endif /* expanded by -frewrite-includes */
# 251 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 1 3
/*===---- inttypes.h - Standard header for integer printf macros ----------===*\
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
\*===----------------------------------------------------------------------===*/

#ifndef __CLANG_INTTYPES_H
// AIX system headers need inttypes.h to be re-enterable while _STD_TYPES_T
// is defined until an inclusion of it without _STD_TYPES_T occurs, in which
// case the header guard macro is defined.
#if 0 /* disabled by -frewrite-includes */
#if !defined(_AIX) || !defined(_STD_TYPES_T)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 3
#define __CLANG_INTTYPES_H
#endif
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER) && _MSC_VER < 1800
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 3
#error MSVC does not have inttypes.h prior to Visual Studio 2013
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <inttypes.h>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 1 3 4
/*
 * Copyright (c) 2000-2004, 2013 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

/*
 * <inttypes.h> -- Standard C header, defined in ISO/IEC 9899:1999
 * (aka "C99"), section 7.8.   This defines format string conversion
 * specifiers suitable for use within arguments to fprintf and fscanf
 * and their ilk.
 */

#if 0 /* disabled by -frewrite-includes */
#if !defined(_INTTYPES_H_)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
#define _INTTYPES_H_

#  define __PRI_8_LENGTH_MODIFIER__ "hh"
#  define __PRI_64_LENGTH_MODIFIER__ "ll"
#  define __SCN_64_LENGTH_MODIFIER__ "ll"
#  define __PRI_MAX_LENGTH_MODIFIER__ "j"
#  define __SCN_MAX_LENGTH_MODIFIER__ "j"

#  define PRId8         __PRI_8_LENGTH_MODIFIER__ "d"
#  define PRIi8         __PRI_8_LENGTH_MODIFIER__ "i"
#  define PRIo8         __PRI_8_LENGTH_MODIFIER__ "o"
#  define PRIu8         __PRI_8_LENGTH_MODIFIER__ "u"
#  define PRIx8         __PRI_8_LENGTH_MODIFIER__ "x"
#  define PRIX8         __PRI_8_LENGTH_MODIFIER__ "X"

#  define PRId16        "hd"
#  define PRIi16        "hi"
#  define PRIo16        "ho"
#  define PRIu16        "hu"
#  define PRIx16        "hx"
#  define PRIX16        "hX"

#  define PRId32        "d"
#  define PRIi32        "i"
#  define PRIo32        "o"
#  define PRIu32        "u"
#  define PRIx32        "x"
#  define PRIX32        "X"

#  define PRId64        __PRI_64_LENGTH_MODIFIER__ "d"
#  define PRIi64        __PRI_64_LENGTH_MODIFIER__ "i"
#  define PRIo64        __PRI_64_LENGTH_MODIFIER__ "o"
#  define PRIu64        __PRI_64_LENGTH_MODIFIER__ "u"
#  define PRIx64        __PRI_64_LENGTH_MODIFIER__ "x"
#  define PRIX64        __PRI_64_LENGTH_MODIFIER__ "X"

#  define PRIdLEAST8    PRId8
#  define PRIiLEAST8    PRIi8
#  define PRIoLEAST8    PRIo8
#  define PRIuLEAST8    PRIu8
#  define PRIxLEAST8    PRIx8
#  define PRIXLEAST8    PRIX8

#  define PRIdLEAST16   PRId16
#  define PRIiLEAST16   PRIi16
#  define PRIoLEAST16   PRIo16
#  define PRIuLEAST16   PRIu16
#  define PRIxLEAST16   PRIx16
#  define PRIXLEAST16   PRIX16

#  define PRIdLEAST32   PRId32
#  define PRIiLEAST32   PRIi32
#  define PRIoLEAST32   PRIo32
#  define PRIuLEAST32   PRIu32
#  define PRIxLEAST32   PRIx32
#  define PRIXLEAST32   PRIX32

#  define PRIdLEAST64   PRId64
#  define PRIiLEAST64   PRIi64
#  define PRIoLEAST64   PRIo64
#  define PRIuLEAST64   PRIu64
#  define PRIxLEAST64   PRIx64
#  define PRIXLEAST64   PRIX64

#  define PRIdFAST8     PRId8
#  define PRIiFAST8     PRIi8
#  define PRIoFAST8     PRIo8
#  define PRIuFAST8     PRIu8
#  define PRIxFAST8     PRIx8
#  define PRIXFAST8     PRIX8

#  define PRIdFAST16    PRId16
#  define PRIiFAST16    PRIi16
#  define PRIoFAST16    PRIo16
#  define PRIuFAST16    PRIu16
#  define PRIxFAST16    PRIx16
#  define PRIXFAST16    PRIX16

#  define PRIdFAST32    PRId32
#  define PRIiFAST32    PRIi32
#  define PRIoFAST32    PRIo32
#  define PRIuFAST32    PRIu32
#  define PRIxFAST32    PRIx32
#  define PRIXFAST32    PRIX32

#  define PRIdFAST64    PRId64
#  define PRIiFAST64    PRIi64
#  define PRIoFAST64    PRIo64
#  define PRIuFAST64    PRIu64
#  define PRIxFAST64    PRIx64
#  define PRIXFAST64    PRIX64

/* int32_t is 'int', but intptr_t is 'long'.  */
#  define PRIdPTR       "ld"
#  define PRIiPTR       "li"
#  define PRIoPTR       "lo"
#  define PRIuPTR       "lu"
#  define PRIxPTR       "lx"
#  define PRIXPTR       "lX"

#  define PRIdMAX        __PRI_MAX_LENGTH_MODIFIER__ "d"
#  define PRIiMAX        __PRI_MAX_LENGTH_MODIFIER__ "i"
#  define PRIoMAX        __PRI_MAX_LENGTH_MODIFIER__ "o"
#  define PRIuMAX        __PRI_MAX_LENGTH_MODIFIER__ "u"
#  define PRIxMAX        __PRI_MAX_LENGTH_MODIFIER__ "x"
#  define PRIXMAX        __PRI_MAX_LENGTH_MODIFIER__ "X"

#  define SCNd8         __PRI_8_LENGTH_MODIFIER__ "d"
#  define SCNi8         __PRI_8_LENGTH_MODIFIER__ "i"
#  define SCNo8         __PRI_8_LENGTH_MODIFIER__ "o"
#  define SCNu8         __PRI_8_LENGTH_MODIFIER__ "u"
#  define SCNx8         __PRI_8_LENGTH_MODIFIER__ "x"

#  define SCNd16        "hd"
#  define SCNi16        "hi"
#  define SCNo16        "ho"
#  define SCNu16        "hu"
#  define SCNx16        "hx"

#  define SCNd32        "d"
#  define SCNi32        "i"
#  define SCNo32        "o"
#  define SCNu32        "u"
#  define SCNx32        "x"

#  define SCNd64        __SCN_64_LENGTH_MODIFIER__ "d"
#  define SCNi64        __SCN_64_LENGTH_MODIFIER__ "i"
#  define SCNo64        __SCN_64_LENGTH_MODIFIER__ "o"
#  define SCNu64        __SCN_64_LENGTH_MODIFIER__ "u"
#  define SCNx64        __SCN_64_LENGTH_MODIFIER__ "x"

#  define SCNdLEAST8    SCNd8
#  define SCNiLEAST8    SCNi8
#  define SCNoLEAST8    SCNo8
#  define SCNuLEAST8    SCNu8
#  define SCNxLEAST8    SCNx8

#  define SCNdLEAST16   SCNd16
#  define SCNiLEAST16   SCNi16
#  define SCNoLEAST16   SCNo16
#  define SCNuLEAST16   SCNu16
#  define SCNxLEAST16   SCNx16

#  define SCNdLEAST32   SCNd32
#  define SCNiLEAST32   SCNi32
#  define SCNoLEAST32   SCNo32
#  define SCNuLEAST32   SCNu32
#  define SCNxLEAST32   SCNx32

#  define SCNdLEAST64   SCNd64
#  define SCNiLEAST64   SCNi64
#  define SCNoLEAST64   SCNo64
#  define SCNuLEAST64   SCNu64
#  define SCNxLEAST64   SCNx64

#  define SCNdFAST8     SCNd8
#  define SCNiFAST8     SCNi8
#  define SCNoFAST8     SCNo8
#  define SCNuFAST8     SCNu8
#  define SCNxFAST8     SCNx8

#  define SCNdFAST16    SCNd16
#  define SCNiFAST16    SCNi16
#  define SCNoFAST16    SCNo16
#  define SCNuFAST16    SCNu16
#  define SCNxFAST16    SCNx16

#  define SCNdFAST32    SCNd32
#  define SCNiFAST32    SCNi32
#  define SCNoFAST32    SCNo32
#  define SCNuFAST32    SCNu32
#  define SCNxFAST32    SCNx32

#  define SCNdFAST64    SCNd64
#  define SCNiFAST64    SCNi64
#  define SCNoFAST64    SCNo64
#  define SCNuFAST64    SCNu64
#  define SCNxFAST64    SCNx64

#  define SCNdPTR       "ld"
#  define SCNiPTR       "li"
#  define SCNoPTR       "lo"
#  define SCNuPTR       "lu"
#  define SCNxPTR       "lx"

#  define SCNdMAX       __SCN_MAX_LENGTH_MODIFIER__ "d"
#  define SCNiMAX       __SCN_MAX_LENGTH_MODIFIER__ "i"
#  define SCNoMAX       __SCN_MAX_LENGTH_MODIFIER__ "o"
#  define SCNuMAX       __SCN_MAX_LENGTH_MODIFIER__ "u"
#  define SCNxMAX       __SCN_MAX_LENGTH_MODIFIER__ "x"

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
# 224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
# 225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <_types.h>
#endif /* expanded by -frewrite-includes */
# 226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
# 227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_wchar_t.h>
#endif /* expanded by -frewrite-includes */
# 227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 1 3 4
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

/* wchar_t is a built-in type in C++ */
#ifndef __cplusplus
#ifndef _WCHAR_T
#define _WCHAR_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_wchar_t */
#endif /* expanded by -frewrite-includes */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
# 34 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
typedef __darwin_wchar_t wchar_t;
#endif /* _WCHAR_T */
# 36 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
#endif /* __cplusplus */
# 37 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_wchar_t.h" 3 4
# 228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 2 3 4

#if 0 /* expanded by -frewrite-includes */
#include <stdint.h>
#endif /* expanded by -frewrite-includes */
# 229 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
# 230 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4

__BEGIN_DECLS

/* 7.8.2.1 */
__OSX_AVAILABLE_STARTING(__MAC_10_4, __IPHONE_2_0)
extern intmax_t
imaxabs(intmax_t j);

/* 7.8.2.2 */
typedef struct {
	intmax_t quot;
	intmax_t rem;
} imaxdiv_t;

__OSX_AVAILABLE_STARTING(__MAC_10_4, __IPHONE_2_0)
extern imaxdiv_t
imaxdiv(intmax_t __numer, intmax_t __denom);

/* 7.8.2.3 */
__OSX_AVAILABLE_STARTING(__MAC_10_4, __IPHONE_2_0)
extern intmax_t
strtoimax(const char * __restrict __nptr,
	  char ** __restrict __endptr,
	  int __base);

__OSX_AVAILABLE_STARTING(__MAC_10_4, __IPHONE_2_0)
extern uintmax_t
strtoumax(const char * __restrict __nptr,
	  char ** __restrict __endptr,
	  int __base);

/* 7.8.2.4 */
__OSX_AVAILABLE_STARTING(__MAC_10_4, __IPHONE_2_0)
extern intmax_t
wcstoimax(const wchar_t * __restrict __nptr,
	  wchar_t ** __restrict __endptr,
	  int __base);

__OSX_AVAILABLE_STARTING(__MAC_10_4, __IPHONE_2_0)
extern uintmax_t
wcstoumax(const wchar_t * __restrict __nptr,
	  wchar_t ** __restrict __endptr,
	  int __base);

/* Poison the following routines if -fshort-wchar is set */
#if 0 /* disabled by -frewrite-includes */
#if !defined(__cplusplus) && defined(__WCHAR_MAX__) && __WCHAR_MAX__ <= 0xffffU
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 276 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
#pragma GCC poison wcstoimax wcstoumax
#endif
# 278 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4

__END_DECLS

#ifdef _USE_EXTENDED_LOCALES_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_inttypes.h>
#endif /* expanded by -frewrite-includes */
# 282 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
# 283 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
#endif /* _USE_EXTENDED_LOCALES_ */
# 284 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4

/*
   No need to #undef the __*_{8,64}_LENGTH_MODIFIER__ macros;
   in fact, you can't #undef them, because later uses of any of
   their dependents will *not* then do the intended substitution.
   Expansion of a #define like this one:

        #define x IDENT y

   uses the cpp value of IDENT at the location where x is *expanded*,
   not where it is #defined.
*/

#endif /* !_INTTYPES_H_ */
# 298 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/inttypes.h" 3 4
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 2 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER) && _MSC_VER < 1900
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 3
/* MSVC headers define int32_t as int, but PRIx32 as "lx" instead of "x".
 * This triggers format warnings, so fix it up here. */
#undef PRId32
#undef PRIdLEAST32
#undef PRIdFAST32
#undef PRIi32
#undef PRIiLEAST32
#undef PRIiFAST32
#undef PRIo32
#undef PRIoLEAST32
#undef PRIoFAST32
#undef PRIu32
#undef PRIuLEAST32
#undef PRIuFAST32
#undef PRIx32
#undef PRIxLEAST32
#undef PRIxFAST32
#undef PRIX32
#undef PRIXLEAST32
#undef PRIXFAST32

#undef SCNd32
#undef SCNdLEAST32
#undef SCNdFAST32
#undef SCNi32
#undef SCNiLEAST32
#undef SCNiFAST32
#undef SCNo32
#undef SCNoLEAST32
#undef SCNoFAST32
#undef SCNu32
#undef SCNuLEAST32
#undef SCNuFAST32
#undef SCNx32
#undef SCNxLEAST32
#undef SCNxFAST32

#define PRId32 "d"
#define PRIdLEAST32 "d"
#define PRIdFAST32 "d"
#define PRIi32 "i"
#define PRIiLEAST32 "i"
#define PRIiFAST32 "i"
#define PRIo32 "o"
#define PRIoLEAST32 "o"
#define PRIoFAST32 "o"
#define PRIu32 "u"
#define PRIuLEAST32 "u"
#define PRIuFAST32 "u"
#define PRIx32 "x"
#define PRIxLEAST32 "x"
#define PRIxFAST32 "x"
#define PRIX32 "X"
#define PRIXLEAST32 "X"
#define PRIXFAST32 "X"

#define SCNd32 "d"
#define SCNdLEAST32 "d"
#define SCNdFAST32 "d"
#define SCNi32 "i"
#define SCNiLEAST32 "i"
#define SCNiFAST32 "i"
#define SCNo32 "o"
#define SCNoLEAST32 "o"
#define SCNoFAST32 "o"
#define SCNu32 "u"
#define SCNuLEAST32 "u"
#define SCNuFAST32 "u"
#define SCNx32 "x"
#define SCNxLEAST32 "x"
#define SCNxFAST32 "x"
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 3

#endif /* __CLANG_INTTYPES_H */
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/inttypes.h" 3
# 252 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 2 3

#ifdef __cplusplus

#if 0 /* expanded by -frewrite-includes */
#include <stdint.h>
#endif /* expanded by -frewrite-includes */
# 255 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3
# 256 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3

#undef imaxabs
#undef imaxdiv

#endif // __cplusplus
# 261 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3

#endif  // _LIBCPP_INTTYPES_H
# 263 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/inttypes.h" 3
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <stdint.h>
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

#ifndef _MSC_VER

#if 0 /* disabled by -frewrite-includes */
#if !defined(UINT32_MAX)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 39 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# error "The standard header <cstdint> is not C++11 compliant. Must #define "\
        "__STDC_LIMIT_MACROS before #including llvm-c/DataTypes.h"
#endif
# 42 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

#if 0 /* disabled by -frewrite-includes */
#if !defined(UINT32_C)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 44 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# error "The standard header <cstdint> is not C++11 compliant. Must #define "\
        "__STDC_CONSTANT_MACROS before #including llvm-c/DataTypes.h"
#endif
# 47 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

/* Note that <inttypes.h> includes <stdint.h>, if this is a C99 system. */
#if 0 /* expanded by -frewrite-includes */
#include <sys/types.h>
#endif /* expanded by -frewrite-includes */
# 49 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 1 3 4
/*
 * Copyright (c) 2000-2008 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/* Copyright (c) 1995 NeXT Computer, Inc. All Rights Reserved */
/*
 * Copyright (c) 1982, 1986, 1991, 1993, 1994
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)types.h	8.4 (Berkeley) 1/21/94
 */

#ifndef _SYS_TYPES_H_
#define _SYS_TYPES_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/appleapiopts.h>
#endif /* expanded by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#ifndef __ASSEMBLER__
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 75 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

/* Machine type dependent parameters. */
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h>
#endif /* expanded by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 79 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <machine/endian.h>
#endif /* expanded by -frewrite-includes */
# 81 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 82 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_u_char.h>
#endif /* expanded by -frewrite-includes */
# 84 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_char.h" 1 3 4
/*
 * Copyright (c) 2017 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _U_CHAR
#define _U_CHAR
typedef unsigned char   u_char;
#endif /* _U_CHAR */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_char.h" 3 4
# 85 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_u_short.h>
#endif /* expanded by -frewrite-includes */
# 85 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_short.h" 1 3 4
/*
 * Copyright (c) 2017 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _U_SHORT
#define _U_SHORT
typedef unsigned short  u_short;
#endif /* _U_SHORT */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_short.h" 3 4
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_u_int.h>
#endif /* expanded by -frewrite-includes */
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int.h" 1 3 4
/*
 * Copyright (c) 2017 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _U_INT
#define _U_INT
typedef unsigned int    u_int;
#endif /* _U_INT */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_u_int.h" 3 4
# 87 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#ifndef _U_LONG
typedef unsigned long           u_long;
#define _U_LONG
#endif
# 91 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
typedef unsigned short          ushort;         /* Sys V compatibility */
typedef unsigned int            uint;           /* Sys V compatibility */
#endif
# 94 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

typedef u_int64_t               u_quad_t;       /* quads */
typedef int64_t                 quad_t;
typedef quad_t *                qaddr_t;

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_caddr_t.h>        /* core address */
#endif /* expanded by -frewrite-includes */
# 99 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_caddr_t.h" 1 3 4
/*
 * Copyright (c) 2017 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _CADDR_T
#define _CADDR_T
typedef char *          caddr_t;
#endif /* _CADDR_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_caddr_t.h" 3 4
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4

typedef int32_t                 daddr_t;        /* disk address */

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_dev_t.h>                  /* device number */
#endif /* expanded by -frewrite-includes */
# 103 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 104 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

typedef u_int32_t               fixpt_t;        /* fixed point number */

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_blkcnt_t.h>
#endif /* expanded by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_blkcnt_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _BLKCNT_T
#define _BLKCNT_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_blkcnt_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_blkcnt_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_blkcnt_t.h" 3 4
typedef __darwin_blkcnt_t        blkcnt_t;
#endif  /* _BLKCNT_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_blkcnt_t.h" 3 4
# 108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_blksize_t.h>
#endif /* expanded by -frewrite-includes */
# 108 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_blksize_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _BLKSIZE_T
#define _BLKSIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_blksize_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_blksize_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_blksize_t.h" 3 4
typedef __darwin_blksize_t        blksize_t;
#endif  /* _BLKSIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_blksize_t.h" 3 4
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_gid_t.h>
#endif /* expanded by -frewrite-includes */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_gid_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _GID_T
#define _GID_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_gid_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_gid_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_gid_t.h" 3 4
typedef __darwin_gid_t  gid_t;
#endif
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_gid_t.h" 3 4
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_in_addr_t.h>
#endif /* expanded by -frewrite-includes */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_in_addr_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _IN_ADDR_T
#define _IN_ADDR_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __uint32_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_in_addr_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_in_addr_t.h" 3 4
typedef __uint32_t      in_addr_t;      /* base type for internet address */
#endif /* _IN_ADDR_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_in_addr_t.h" 3 4
# 111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_in_port_t.h>
#endif /* expanded by -frewrite-includes */
# 111 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_in_port_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _IN_PORT_T
#define _IN_PORT_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __uint16_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_in_port_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_in_port_t.h" 3 4
typedef __uint16_t              in_port_t;
#endif /* _IN_PORT_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_in_port_t.h" 3 4
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ino_t.h>
#endif /* expanded by -frewrite-includes */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ino_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _INO_T
#define _INO_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_ino_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ino_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ino_t.h" 3 4
typedef __darwin_ino_t          ino_t;          /* inode number */
#endif  /* _INO_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ino_t.h" 3 4
# 113 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ino64_t.h>                        /* 64bit inode number */
#endif /* expanded by -frewrite-includes */
# 115 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ino64_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _INO64_T
#define _INO64_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_ino64_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ino64_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ino64_t.h" 3 4
typedef __darwin_ino64_t        ino64_t;        /* 64bit inode number */
#endif  /* _INO64_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_ino64_t.h" 3 4
# 116 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#endif /* !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE) */
# 117 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_key_t.h>
#endif /* expanded by -frewrite-includes */
# 118 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_key_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _KEY_T
#define _KEY_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __int32_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_key_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_key_t.h" 3 4
typedef __int32_t        key_t;         /* IPC key (for Sys V IPC) */
#endif  /* _KEY_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_key_t.h" 3 4
# 119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_mode_t.h>
#endif /* expanded by -frewrite-includes */
# 119 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_nlink_t.h>
#endif /* expanded by -frewrite-includes */
# 120 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_nlink_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _NLINK_T
#define _NLINK_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __uint16_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_nlink_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_nlink_t.h" 3 4
typedef __uint16_t        nlink_t;      /* link count */
#endif  /* _NLINK_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_nlink_t.h" 3 4
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_id_t.h>
#endif /* expanded by -frewrite-includes */
# 121 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_pid_t.h>
#endif /* expanded by -frewrite-includes */
# 122 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_off_t.h>
#endif /* expanded by -frewrite-includes */
# 123 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 124 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

typedef int32_t                 segsz_t;        /* segment size */
typedef int32_t                 swblk_t;        /* swap offset */

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_uid_t.h>
#endif /* expanded by -frewrite-includes */
# 128 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 129 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 131 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
/* Major, minor numbers, dev_t's. */
#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 133 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
/*
 * These lowercase macros tend to match member functions in some C++ code,
 * so for C++, we must use inline functions instead.
 */

static inline __int32_t
major(__uint32_t _x)
{
	return (__int32_t)(((__uint32_t)_x >> 24) & 0xff);
}

static inline __int32_t
minor(__uint32_t _x)
{
	return (__int32_t)((_x) & 0xffffff);
}

static inline dev_t
makedev(__uint32_t _major, __uint32_t _minor)
{
	return (dev_t)(((_major) << 24) | (_minor));
}

#else   /* !__cplusplus */
# 157 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#define major(x)        ((int32_t)(((u_int32_t)(x) >> 24) & 0xff))
#define minor(x)        ((int32_t)((x) & 0xffffff))
#define makedev(x, y)    ((dev_t)(((x) << 24) | (y)))

#endif  /* !__cplusplus */
# 163 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#endif  /* !_POSIX_C_SOURCE */
# 164 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_clock_t.h>
#endif /* expanded by -frewrite-includes */
# 165 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 166 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_size_t.h>
#endif /* expanded by -frewrite-includes */
# 166 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SIZE_T
#define _SIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
typedef __darwin_size_t        size_t;
#endif  /* _SIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_size_t.h" 3 4
# 167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_ssize_t.h>
#endif /* expanded by -frewrite-includes */
# 167 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 168 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_time_t.h>
#endif /* expanded by -frewrite-includes */
# 168 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 169 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_useconds_t.h>
#endif /* expanded by -frewrite-includes */
# 170 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_useconds_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _USECONDS_T
#define _USECONDS_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_useconds_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_useconds_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_useconds_t.h" 3 4
typedef __darwin_useconds_t     useconds_t;
#endif /* _USECONDS_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_useconds_t.h" 3 4
# 171 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_suseconds_t.h>
#endif /* expanded by -frewrite-includes */
# 171 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_suseconds_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _SUSECONDS_T
#define _SUSECONDS_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_suseconds_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_suseconds_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_suseconds_t.h" 3 4
typedef __darwin_suseconds_t    suseconds_t;
#endif  /* _SUSECONDS_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_suseconds_t.h" 3 4
# 172 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_rsize_t.h>
#endif /* expanded by -frewrite-includes */
# 174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_rsize_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _RSIZE_T
#define _RSIZE_T
#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __darwin_size_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_rsize_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_rsize_t.h" 3 4
typedef __darwin_size_t        rsize_t;
#endif  /* _RSIZE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_rsize_t.h" 3 4
# 175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_errno_t.h>
#endif /* expanded by -frewrite-includes */
# 175 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_errno_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _ERRNO_T
#define _ERRNO_T
typedef int                    errno_t;
#endif  /* _ERRNO_T */
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_errno_t.h" 3 4
# 176 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#endif
# 177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 179 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
/*
 * This code is present here in order to maintain historical backward
 * compatability, and is intended to be removed at some point in the
 * future; please include <sys/select.h> instead.
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fd_def.h>
#endif /* expanded by -frewrite-includes */
# 184 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _FD_SET
#define _FD_SET

#if 0 /* expanded by -frewrite-includes */
#include <machine/types.h> /* __int32_t */
#endif /* expanded by -frewrite-includes */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 3 4
# 32 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 3 4

/*
 * Select uses bit masks of file descriptors in longs.  These macros
 * manipulate such bit fields (the filesystem macros use chars).  The
 * extra protection here is to permit application redefinition above
 * the default size.
 */
#ifdef FD_SETSIZE
#define __DARWIN_FD_SETSIZE     FD_SETSIZE
#else /* !FD_SETSIZE */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 3 4
#define __DARWIN_FD_SETSIZE     1024
#endif /* FD_SETSIZE */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 3 4
#define __DARWIN_NBBY           8                               /* bits in a byte */
#define __DARWIN_NFDBITS        (sizeof(__int32_t) * __DARWIN_NBBY) /* bits per mask */
#define __DARWIN_howmany(x, y)  ((((x) % (y)) == 0) ? ((x) / (y)) : (((x) / (y)) + 1)) /* # y's == x bits? */

__BEGIN_DECLS
typedef struct fd_set {
	__int32_t       fds_bits[__DARWIN_howmany(__DARWIN_FD_SETSIZE, __DARWIN_NFDBITS)];
} fd_set;
__END_DECLS

/* This inline avoids argument side-effect issues with FD_ISSET() */
static __inline int
__darwin_fd_isset(int _n, const struct fd_set *_p)
{
	return _p->fds_bits[(unsigned long)_n / __DARWIN_NFDBITS] & ((__int32_t)(((unsigned long)1) << ((unsigned long)_n % __DARWIN_NFDBITS)));
}

#define __DARWIN_FD_SET(n, p)   do { int __fd = (n); ((p)->fds_bits[(unsigned long)__fd/__DARWIN_NFDBITS] |= ((__int32_t)(((unsigned long)1)<<((unsigned long)__fd % __DARWIN_NFDBITS)))); } while(0)
#define __DARWIN_FD_CLR(n, p)   do { int __fd = (n); ((p)->fds_bits[(unsigned long)__fd/__DARWIN_NFDBITS] &= ~((__int32_t)(((unsigned long)1)<<((unsigned long)__fd % __DARWIN_NFDBITS)))); } while(0)
#define __DARWIN_FD_ISSET(n, p) __darwin_fd_isset((n), (p))

#if 0 /* disabled by -frewrite-includes */
#if __GNUC__ > 3 || __GNUC__ == 3 && __GNUC_MINOR__ >= 3
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 66 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 3 4
/*
 * Use the built-in bzero function instead of the library version so that
 * we do not pollute the namespace or introduce prototype warnings.
 */
#define __DARWIN_FD_ZERO(p)     __builtin_bzero(p, sizeof(*(p)))
#else
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 3 4
#define __DARWIN_FD_ZERO(p)     bzero(p, sizeof(*(p)))
#endif
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 3 4

#define __DARWIN_FD_COPY(f, t)  bcopy(f, t, sizeof(*(f)))
#endif /* _FD_SET */
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_def.h" 3 4
# 185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4

#define NBBY            __DARWIN_NBBY           /* bits in a byte */
#define NFDBITS         __DARWIN_NFDBITS        /* bits per mask */
#define howmany(x, y)   __DARWIN_howmany(x, y)  /* # y's == x bits? */
typedef __int32_t       fd_mask;

/*
 * Select uses bit masks of file descriptors in longs.  These macros
 * manipulate such bit fields (the filesystem macros use chars).  The
 * extra protection here is to permit application redefinition above
 * the default size.
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fd_setsize.h>
#endif /* expanded by -frewrite-includes */
# 197 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_setsize.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef FD_SETSIZE
#define FD_SETSIZE      __DARWIN_FD_SETSIZE
#endif /* FD_SETSIZE */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_setsize.h" 3 4
# 198 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fd_set.h>
#endif /* expanded by -frewrite-includes */
# 198 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_set.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef FD_SET
#define FD_SET(n, p)    __DARWIN_FD_SET(n, p)
#endif /* FD_SET */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_set.h" 3 4
# 199 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fd_clr.h>
#endif /* expanded by -frewrite-includes */
# 199 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_clr.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef FD_CLR
#define FD_CLR(n, p)    __DARWIN_FD_CLR(n, p)
#endif /* FD_CLR */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_clr.h" 3 4
# 200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fd_zero.h>
#endif /* expanded by -frewrite-includes */
# 200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_zero.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef FD_ZERO
#define FD_ZERO(p)      __DARWIN_FD_ZERO(p)
#endif /* FD_ZERO */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_zero.h" 3 4
# 201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fd_isset.h>
#endif /* expanded by -frewrite-includes */
# 201 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_isset.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef FD_ISSET
#define FD_ISSET(n, p)  __DARWIN_FD_ISSET(n, p)
#endif /* FD_ISSET */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_isset.h" 3 4
# 202 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_POSIX_C_SOURCE) || defined(_DARWIN_C_SOURCE)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fd_copy.h>
#endif /* expanded by -frewrite-includes */
# 204 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_copy.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef FD_COPY
#define FD_COPY(f, t)   __DARWIN_FD_COPY(f, t)
#endif /* FD_COPY */
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fd_copy.h" 3 4
# 205 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#endif  /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 206 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4



#endif /* (!_POSIX_C_SOURCE || _DARWIN_C_SOURCE) */
# 210 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#endif /* __ASSEMBLER__ */
# 211 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4


#ifndef __POSIX_LIB__

#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_attr_t.h>
#endif /* expanded by -frewrite-includes */
# 215 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_cond_t.h>
#endif /* expanded by -frewrite-includes */
# 216 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_cond_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_COND_T
#define _PTHREAD_COND_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_cond_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_cond_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_cond_t.h" 3 4
typedef __darwin_pthread_cond_t pthread_cond_t;
#endif /* _PTHREAD_COND_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_cond_t.h" 3 4
# 217 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_condattr_t.h>
#endif /* expanded by -frewrite-includes */
# 217 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_condattr_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_CONDATTR_T
#define _PTHREAD_CONDATTR_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_condattr_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_condattr_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_condattr_t.h" 3 4
typedef __darwin_pthread_condattr_t pthread_condattr_t;
#endif /* _PTHREAD_CONDATTR_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_condattr_t.h" 3 4
# 218 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_mutex_t.h>
#endif /* expanded by -frewrite-includes */
# 218 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_mutex_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_MUTEX_T
#define _PTHREAD_MUTEX_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_mutex_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_mutex_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_mutex_t.h" 3 4
typedef __darwin_pthread_mutex_t pthread_mutex_t;
#endif /*_PTHREAD_MUTEX_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_mutex_t.h" 3 4
# 219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_mutexattr_t.h>
#endif /* expanded by -frewrite-includes */
# 219 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_mutexattr_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_MUTEXATTR_T
#define _PTHREAD_MUTEXATTR_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_mutexattr_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_mutexattr_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_mutexattr_t.h" 3 4
typedef __darwin_pthread_mutexattr_t pthread_mutexattr_t;
#endif /* _PTHREAD_MUTEXATTR_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_mutexattr_t.h" 3 4
# 220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_once_t.h>
#endif /* expanded by -frewrite-includes */
# 220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_once_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_ONCE_T
#define _PTHREAD_ONCE_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_once_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_once_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_once_t.h" 3 4
typedef __darwin_pthread_once_t pthread_once_t;
#endif /* _PTHREAD_ONCE_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_once_t.h" 3 4
# 221 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_rwlock_t.h>
#endif /* expanded by -frewrite-includes */
# 221 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_rwlock_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_RWLOCK_T
#define _PTHREAD_RWLOCK_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_rwlock_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_rwlock_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_rwlock_t.h" 3 4
typedef __darwin_pthread_rwlock_t pthread_rwlock_t;
#endif /* _PTHREAD_RWLOCK_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_rwlock_t.h" 3 4
# 222 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_rwlockattr_t.h>
#endif /* expanded by -frewrite-includes */
# 222 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_rwlockattr_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_RWLOCKATTR_T
#define _PTHREAD_RWLOCKATTR_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_rwlockattr_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_rwlockattr_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_rwlockattr_t.h" 3 4
typedef __darwin_pthread_rwlockattr_t pthread_rwlockattr_t;
#endif /* _PTHREAD_RWLOCKATTR_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_rwlockattr_t.h" 3 4
# 223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_t.h>
#endif /* expanded by -frewrite-includes */
# 223 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_T
#define _PTHREAD_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_t.h" 3 4
typedef __darwin_pthread_t pthread_t;
#endif /* _PTHREAD_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_t.h" 3 4
# 224 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4

#endif /* __POSIX_LIB__ */
# 226 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_key_t.h>
#endif /* expanded by -frewrite-includes */
# 227 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_key_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _PTHREAD_KEY_T
#define _PTHREAD_KEY_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthread/_pthread_types.h> /* __darwin_pthread_key_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_key_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_key_t.h" 3 4
typedef __darwin_pthread_key_t pthread_key_t;
#endif /* _PTHREAD_KEY_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_pthread/_pthread_key_t.h" 3 4
# 228 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4


/* statvfs and fstatvfs */

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fsblkcnt_t.h>
#endif /* expanded by -frewrite-includes */
# 232 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fsblkcnt_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _FSBLKCNT_T
#define _FSBLKCNT_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_fsblkcnt_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fsblkcnt_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fsblkcnt_t.h" 3 4
typedef __darwin_fsblkcnt_t             fsblkcnt_t;
#endif /* _FSBLKCNT_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fsblkcnt_t.h" 3 4
# 233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_fsfilcnt_t.h>
#endif /* expanded by -frewrite-includes */
# 233 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fsfilcnt_t.h" 1 3 4
/*
 * Copyright (c) 2003-2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifndef _FSFILCNT_T
#define _FSFILCNT_T
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h> /* __darwin_fsfilcnt_t */
#endif /* expanded by -frewrite-includes */
# 30 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fsfilcnt_t.h" 3 4
# 31 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fsfilcnt_t.h" 3 4
typedef __darwin_fsfilcnt_t             fsfilcnt_t;
#endif /* _FSFILCNT_T */
# 33 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/_types/_fsfilcnt_t.h" 3 4
# 234 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 2 3 4

#endif /* !_SYS_TYPES_H_ */
# 236 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/types.h" 3 4
# 50 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h" 2

#ifdef _AIX
// GCC is strict about defining large constants: they must have LL modifier.
#undef INT64_MAX
#undef INT64_MIN
#endif
# 56 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

#else /* _MSC_VER */
# 58 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 59 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 60 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 60 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 61 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#else
# 62 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#if 0 /* expanded by -frewrite-includes */
#include <stddef.h>
#endif /* expanded by -frewrite-includes */
# 62 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 63 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 63 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 64 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#endif
# 65 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#if 0 /* expanded by -frewrite-includes */
#include <sys/types.h>
#endif /* expanded by -frewrite-includes */
# 65 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 66 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

#if 0 /* disabled by -frewrite-includes */
#if defined(_WIN64)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 68 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
typedef signed __int64 ssize_t;
#else
# 70 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
typedef signed int ssize_t;
#endif /* _WIN64 */
# 72 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

#endif /* _MSC_VER */
# 74 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

/* Set defaults for constants which we cannot find. */
#if 0 /* disabled by -frewrite-includes */
#if !defined(INT64_MAX)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 77 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# define INT64_MAX 9223372036854775807LL
#endif
# 79 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#if 0 /* disabled by -frewrite-includes */
#if !defined(INT64_MIN)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 80 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# define INT64_MIN ((-INT64_MAX)-1)
#endif
# 82 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
#if 0 /* disabled by -frewrite-includes */
#if !defined(UINT64_MAX)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# define UINT64_MAX 0xffffffffffffffffULL
#endif
# 85 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

#ifndef HUGE_VALF
#define HUGE_VALF (float)HUGE_VAL
#endif
# 89 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"

#endif /* LLVM_C_DATATYPES_H */
# 91 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/DataTypes.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h" 2
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/PointerLikeTypeTraits.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/PointerLikeTypeTraits.h"
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/PointerLikeTypeTraits.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/PointerLikeTypeTraits.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/PointerLikeTypeTraits.h"

namespace llvm {

/// A traits type that is used to handle pointer types and things that are just
/// wrappers for pointers as a uniform entity.
template <typename T> struct PointerLikeTypeTraits;

namespace detail {
/// A tiny meta function to compute the log2 of a compile time constant.
template <size_t N>
struct ConstantLog2
    : std::integral_constant<size_t, ConstantLog2<N / 2>::value + 1> {};
template <> struct ConstantLog2<1> : std::integral_constant<size_t, 0> {};

// Provide a trait to check if T is pointer-like.
template <typename T, typename U = void> struct HasPointerLikeTypeTraits {
  static const bool value = false;
};

// sizeof(T) is valid only for a complete T.
template <typename T> struct HasPointerLikeTypeTraits<
  T, decltype((sizeof(PointerLikeTypeTraits<T>) + sizeof(T)), void())> {
  static const bool value = true;
};

template <typename T> struct IsPointerLike {
  static const bool value = HasPointerLikeTypeTraits<T>::value;
};

template <typename T> struct IsPointerLike<T *> {
  static const bool value = true;
};
} // namespace detail

// Provide PointerLikeTypeTraits for non-cvr pointers.
template <typename T> struct PointerLikeTypeTraits<T *> {
  static inline void *getAsVoidPointer(T *P) { return P; }
  static inline T *getFromVoidPointer(void *P) { return static_cast<T *>(P); }

  static constexpr int NumLowBitsAvailable =
      detail::ConstantLog2<alignof(T)>::value;
};

template <> struct PointerLikeTypeTraits<void *> {
  static inline void *getAsVoidPointer(void *P) { return P; }
  static inline void *getFromVoidPointer(void *P) { return P; }

  /// Note, we assume here that void* is related to raw malloc'ed memory and
  /// that malloc returns objects at least 4-byte aligned. However, this may be
  /// wrong, or pointers may be from something other than malloc. In this case,
  /// you should specify a real typed pointer or avoid this template.
  ///
  /// All clients should use assertions to do a run-time check to ensure that
  /// this is actually true.
  static constexpr int NumLowBitsAvailable = 2;
};

// Provide PointerLikeTypeTraits for const things.
template <typename T> struct PointerLikeTypeTraits<const T> {
  typedef PointerLikeTypeTraits<T> NonConst;

  static inline const void *getAsVoidPointer(const T P) {
    return NonConst::getAsVoidPointer(P);
  }
  static inline const T getFromVoidPointer(const void *P) {
    return NonConst::getFromVoidPointer(const_cast<void *>(P));
  }
  static constexpr int NumLowBitsAvailable = NonConst::NumLowBitsAvailable;
};

// Provide PointerLikeTypeTraits for const pointers.
template <typename T> struct PointerLikeTypeTraits<const T *> {
  typedef PointerLikeTypeTraits<T *> NonConst;

  static inline const void *getAsVoidPointer(const T *P) {
    return NonConst::getAsVoidPointer(const_cast<T *>(P));
  }
  static inline const T *getFromVoidPointer(const void *P) {
    return NonConst::getFromVoidPointer(const_cast<void *>(P));
  }
  static constexpr int NumLowBitsAvailable = NonConst::NumLowBitsAvailable;
};

// Provide PointerLikeTypeTraits for uintptr_t.
template <> struct PointerLikeTypeTraits<uintptr_t> {
  static inline void *getAsVoidPointer(uintptr_t P) {
    return reinterpret_cast<void *>(P);
  }
  static inline uintptr_t getFromVoidPointer(void *P) {
    return reinterpret_cast<uintptr_t>(P);
  }
  // No bits are available!
  static constexpr int NumLowBitsAvailable = 0;
};

/// Provide suitable custom traits struct for function pointers.
///
/// Function pointers can't be directly given these traits as functions can't
/// have their alignment computed with `alignof` and we need different casting.
///
/// To rely on higher alignment for a specialized use, you can provide a
/// customized form of this template explicitly with higher alignment, and
/// potentially use alignment attributes on functions to satisfy that.
template <int Alignment, typename FunctionPointerT>
struct FunctionPointerLikeTypeTraits {
  static constexpr int NumLowBitsAvailable =
      detail::ConstantLog2<Alignment>::value;
  static inline void *getAsVoidPointer(FunctionPointerT P) {
    assert((reinterpret_cast<uintptr_t>(P) &
            ~((uintptr_t)-1 << NumLowBitsAvailable)) == 0 &&
           "Alignment not satisfied for an actual function pointer!");
    return reinterpret_cast<void *>(P);
  }
  static inline FunctionPointerT getFromVoidPointer(void *P) {
    return reinterpret_cast<FunctionPointerT>(P);
  }
};

/// Provide a default specialization for function pointers that assumes 4-byte
/// alignment.
///
/// We assume here that functions used with this are always at least 4-byte
/// aligned. This means that, for example, thumb functions won't work or systems
/// with weird unaligned function pointers won't work. But all practical systems
/// we support satisfy this requirement.
template <typename ReturnT, typename... ParamTs>
struct PointerLikeTypeTraits<ReturnT (*)(ParamTs...)>
    : FunctionPointerLikeTypeTraits<4, ReturnT (*)(ParamTs...)> {};

} // end namespace llvm

#endif
# 152 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/PointerLikeTypeTraits.h"
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
# 23 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"

namespace llvm {

template <typename T> struct DenseMapInfo;

} // namespace llvm

namespace clang {

class SourceManager;

/// An opaque identifier used by SourceManager which refers to a
/// source file (MemoryBuffer) along with its \#include path and \#line data.
///
class FileID {
  /// A mostly-opaque identifier, where 0 is "invalid", >0 is
  /// this module, and <-1 is something loaded from another module.
  int ID = 0;

public:
  bool isValid() const { return ID != 0; }
  bool isInvalid() const { return ID == 0; }

  bool operator==(const FileID &RHS) const { return ID == RHS.ID; }
  bool operator<(const FileID &RHS) const { return ID < RHS.ID; }
  bool operator<=(const FileID &RHS) const { return ID <= RHS.ID; }
  bool operator!=(const FileID &RHS) const { return !(*this == RHS); }
  bool operator>(const FileID &RHS) const { return RHS < *this; }
  bool operator>=(const FileID &RHS) const { return RHS <= *this; }

  static FileID getSentinel() { return get(-1); }
  unsigned getHashValue() const { return static_cast<unsigned>(ID); }

private:
  friend class ASTWriter;
  friend class ASTReader;
  friend class SourceManager;

  static FileID get(int V) {
    FileID F;
    F.ID = V;
    return F;
  }

  int getOpaqueValue() const { return ID; }
};

/// Encodes a location in the source. The SourceManager can decode this
/// to get at the full include stack, line and column information.
///
/// Technically, a source location is simply an offset into the manager's view
/// of the input source, which is all input buffers (including macro
/// expansions) concatenated in an effectively arbitrary order. The manager
/// actually maintains two blocks of input buffers. One, starting at offset
/// 0 and growing upwards, contains all buffers from this module. The other,
/// starting at the highest possible offset and growing downwards, contains
/// buffers of loaded modules.
///
/// In addition, one bit of SourceLocation is used for quick access to the
/// information whether the location is in a file or a macro expansion.
///
/// It is important that this type remains small. It is currently 32 bits wide.
class SourceLocation {
  friend class ASTReader;
  friend class ASTWriter;
  friend class SourceManager;

  unsigned ID = 0;

  enum : unsigned {
    MacroIDBit = 1U << 31
  };

public:
  bool isFileID() const  { return (ID & MacroIDBit) == 0; }
  bool isMacroID() const { return (ID & MacroIDBit) != 0; }

  /// Return true if this is a valid SourceLocation object.
  ///
  /// Invalid SourceLocations are often used when events have no corresponding
  /// location in the source (e.g. a diagnostic is required for a command line
  /// option).
  bool isValid() const { return ID != 0; }
  bool isInvalid() const { return ID == 0; }

private:
  /// Return the offset into the manager's global input view.
  unsigned getOffset() const {
    return ID & ~MacroIDBit;
  }

  static SourceLocation getFileLoc(unsigned ID) {
    assert((ID & MacroIDBit) == 0 && "Ran out of source locations!");
    SourceLocation L;
    L.ID = ID;
    return L;
  }

  static SourceLocation getMacroLoc(unsigned ID) {
    assert((ID & MacroIDBit) == 0 && "Ran out of source locations!");
    SourceLocation L;
    L.ID = MacroIDBit | ID;
    return L;
  }

public:
  /// Return a source location with the specified offset from this
  /// SourceLocation.
  SourceLocation getLocWithOffset(int Offset) const {
    assert(((getOffset()+Offset) & MacroIDBit) == 0 && "offset overflow");
    SourceLocation L;
    L.ID = ID+Offset;
    return L;
  }

  /// When a SourceLocation itself cannot be used, this returns
  /// an (opaque) 32-bit integer encoding for it.
  ///
  /// This should only be passed to SourceLocation::getFromRawEncoding, it
  /// should not be inspected directly.
  unsigned getRawEncoding() const { return ID; }

  /// Turn a raw encoding of a SourceLocation object into
  /// a real SourceLocation.
  ///
  /// \see getRawEncoding.
  static SourceLocation getFromRawEncoding(unsigned Encoding) {
    SourceLocation X;
    X.ID = Encoding;
    return X;
  }

  /// When a SourceLocation itself cannot be used, this returns
  /// an (opaque) pointer encoding for it.
  ///
  /// This should only be passed to SourceLocation::getFromPtrEncoding, it
  /// should not be inspected directly.
  void* getPtrEncoding() const {
    // Double cast to avoid a warning "cast to pointer from integer of different
    // size".
    return (void*)(uintptr_t)getRawEncoding();
  }

  /// Turn a pointer encoding of a SourceLocation object back
  /// into a real SourceLocation.
  static SourceLocation getFromPtrEncoding(const void *Encoding) {
    return getFromRawEncoding((unsigned)(uintptr_t)Encoding);
  }

  static bool isPairOfFileLocations(SourceLocation Start, SourceLocation End) {
    return Start.isValid() && Start.isFileID() && End.isValid() &&
           End.isFileID();
  }

  void print(raw_ostream &OS, const SourceManager &SM) const;
  std::string printToString(const SourceManager &SM) const;
  void dump(const SourceManager &SM) const;
};

inline bool operator==(const SourceLocation &LHS, const SourceLocation &RHS) {
  return LHS.getRawEncoding() == RHS.getRawEncoding();
}

inline bool operator!=(const SourceLocation &LHS, const SourceLocation &RHS) {
  return !(LHS == RHS);
}

// Ordering is meaningful only if LHS and RHS have the same FileID!
// Otherwise use SourceManager::isBeforeInTranslationUnit().
inline bool operator<(const SourceLocation &LHS, const SourceLocation &RHS) {
  return LHS.getRawEncoding() < RHS.getRawEncoding();
}
inline bool operator>(const SourceLocation &LHS, const SourceLocation &RHS) {
  return LHS.getRawEncoding() > RHS.getRawEncoding();
}
inline bool operator<=(const SourceLocation &LHS, const SourceLocation &RHS) {
  return LHS.getRawEncoding() <= RHS.getRawEncoding();
}
inline bool operator>=(const SourceLocation &LHS, const SourceLocation &RHS) {
  return LHS.getRawEncoding() >= RHS.getRawEncoding();
}

/// A trivial tuple used to represent a source range.
class SourceRange {
  SourceLocation B;
  SourceLocation E;

public:
  SourceRange() = default;
  SourceRange(SourceLocation loc) : B(loc), E(loc) {}
  SourceRange(SourceLocation begin, SourceLocation end) : B(begin), E(end) {}

  SourceLocation getBegin() const { return B; }
  SourceLocation getEnd() const { return E; }

  void setBegin(SourceLocation b) { B = b; }
  void setEnd(SourceLocation e) { E = e; }

  bool isValid() const { return B.isValid() && E.isValid(); }
  bool isInvalid() const { return !isValid(); }

  bool operator==(const SourceRange &X) const {
    return B == X.B && E == X.E;
  }

  bool operator!=(const SourceRange &X) const {
    return B != X.B || E != X.E;
  }

  // Returns true iff other is wholly contained within this range.
  bool fullyContains(const SourceRange &other) const {
    return B <= other.B && E >= other.E;
  }

  void print(raw_ostream &OS, const SourceManager &SM) const;
  std::string printToString(const SourceManager &SM) const;
  void dump(const SourceManager &SM) const;
};

/// Represents a character-granular source range.
///
/// The underlying SourceRange can either specify the starting/ending character
/// of the range, or it can specify the start of the range and the start of the
/// last token of the range (a "token range").  In the token range case, the
/// size of the last token must be measured to determine the actual end of the
/// range.
class CharSourceRange {
  SourceRange Range;
  bool IsTokenRange = false;

public:
  CharSourceRange() = default;
  CharSourceRange(SourceRange R, bool ITR) : Range(R), IsTokenRange(ITR) {}

  static CharSourceRange getTokenRange(SourceRange R) {
    return CharSourceRange(R, true);
  }

  static CharSourceRange getCharRange(SourceRange R) {
    return CharSourceRange(R, false);
  }

  static CharSourceRange getTokenRange(SourceLocation B, SourceLocation E) {
    return getTokenRange(SourceRange(B, E));
  }

  static CharSourceRange getCharRange(SourceLocation B, SourceLocation E) {
    return getCharRange(SourceRange(B, E));
  }

  /// Return true if the end of this range specifies the start of
  /// the last token.  Return false if the end of this range specifies the last
  /// character in the range.
  bool isTokenRange() const { return IsTokenRange; }
  bool isCharRange() const { return !IsTokenRange; }

  SourceLocation getBegin() const { return Range.getBegin(); }
  SourceLocation getEnd() const { return Range.getEnd(); }
  SourceRange getAsRange() const { return Range; }

  void setBegin(SourceLocation b) { Range.setBegin(b); }
  void setEnd(SourceLocation e) { Range.setEnd(e); }
  void setTokenRange(bool TR) { IsTokenRange = TR; }

  bool isValid() const { return Range.isValid(); }
  bool isInvalid() const { return !isValid(); }
};

/// Represents an unpacked "presumed" location which can be presented
/// to the user.
///
/// A 'presumed' location can be modified by \#line and GNU line marker
/// directives and is always the expansion point of a normal location.
///
/// You can get a PresumedLoc from a SourceLocation with SourceManager.
class PresumedLoc {
  const char *Filename = nullptr;
  FileID ID;
  unsigned Line, Col;
  SourceLocation IncludeLoc;

public:
  PresumedLoc() = default;
  PresumedLoc(const char *FN, FileID FID, unsigned Ln, unsigned Co,
              SourceLocation IL)
      : Filename(FN), ID(FID), Line(Ln), Col(Co), IncludeLoc(IL) {}

  /// Return true if this object is invalid or uninitialized.
  ///
  /// This occurs when created with invalid source locations or when walking
  /// off the top of a \#include stack.
  bool isInvalid() const { return Filename == nullptr; }
  bool isValid() const { return Filename != nullptr; }

  /// Return the presumed filename of this location.
  ///
  /// This can be affected by \#line etc.
  const char *getFilename() const {
    assert(isValid());
    return Filename;
  }

  FileID getFileID() const {
    assert(isValid());
    return ID;
  }

  /// Return the presumed line number of this location.
  ///
  /// This can be affected by \#line etc.
  unsigned getLine() const {
    assert(isValid());
    return Line;
  }

  /// Return the presumed column number of this location.
  ///
  /// This cannot be affected by \#line, but is packaged here for convenience.
  unsigned getColumn() const {
    assert(isValid());
    return Col;
  }

  /// Return the presumed include location of this location.
  ///
  /// This can be affected by GNU linemarker directives.
  SourceLocation getIncludeLoc() const {
    assert(isValid());
    return IncludeLoc;
  }
};

class FileEntry;

/// A SourceLocation and its associated SourceManager.
///
/// This is useful for argument passing to functions that expect both objects.
class FullSourceLoc : public SourceLocation {
  const SourceManager *SrcMgr = nullptr;

public:
  /// Creates a FullSourceLoc where isValid() returns \c false.
  FullSourceLoc() = default;

  explicit FullSourceLoc(SourceLocation Loc, const SourceManager &SM)
      : SourceLocation(Loc), SrcMgr(&SM) {}

  bool hasManager() const {
      bool hasSrcMgr =  SrcMgr != nullptr;
      assert(hasSrcMgr == isValid() && "FullSourceLoc has location but no manager");
      return hasSrcMgr;
  }

  /// \pre This FullSourceLoc has an associated SourceManager.
  const SourceManager &getManager() const {
    assert(SrcMgr && "SourceManager is NULL.");
    return *SrcMgr;
  }

  FileID getFileID() const;

  FullSourceLoc getExpansionLoc() const;
  FullSourceLoc getSpellingLoc() const;
  FullSourceLoc getFileLoc() const;
  PresumedLoc getPresumedLoc(bool UseLineDirectives = true) const;
  bool isMacroArgExpansion(FullSourceLoc *StartLoc = nullptr) const;
  FullSourceLoc getImmediateMacroCallerLoc() const;
  std::pair<FullSourceLoc, StringRef> getModuleImportLoc() const;
  unsigned getFileOffset() const;

  unsigned getExpansionLineNumber(bool *Invalid = nullptr) const;
  unsigned getExpansionColumnNumber(bool *Invalid = nullptr) const;

  unsigned getSpellingLineNumber(bool *Invalid = nullptr) const;
  unsigned getSpellingColumnNumber(bool *Invalid = nullptr) const;

  const char *getCharacterData(bool *Invalid = nullptr) const;

  unsigned getLineNumber(bool *Invalid = nullptr) const;
  unsigned getColumnNumber(bool *Invalid = nullptr) const;

  const FileEntry *getFileEntry() const;

  /// Return a StringRef to the source buffer data for the
  /// specified FileID.
  StringRef getBufferData(bool *Invalid = nullptr) const;

  /// Decompose the specified location into a raw FileID + Offset pair.
  ///
  /// The first element is the FileID, the second is the offset from the
  /// start of the buffer of the location.
  std::pair<FileID, unsigned> getDecomposedLoc() const;

  bool isInSystemHeader() const;

  /// Determines the order of 2 source locations in the translation unit.
  ///
  /// \returns true if this source location comes before 'Loc', false otherwise.
  bool isBeforeInTranslationUnitThan(SourceLocation Loc) const;

  /// Determines the order of 2 source locations in the translation unit.
  ///
  /// \returns true if this source location comes before 'Loc', false otherwise.
  bool isBeforeInTranslationUnitThan(FullSourceLoc Loc) const {
    assert(Loc.isValid());
    assert(SrcMgr == Loc.SrcMgr && "Loc comes from another SourceManager!");
    return isBeforeInTranslationUnitThan((SourceLocation)Loc);
  }

  /// Comparison function class, useful for sorting FullSourceLocs.
  struct BeforeThanCompare {
    bool operator()(const FullSourceLoc& lhs, const FullSourceLoc& rhs) const {
      return lhs.isBeforeInTranslationUnitThan(rhs);
    }
  };

  /// Prints information about this FullSourceLoc to stderr.
  ///
  /// This is useful for debugging.
  void dump() const;

  friend bool
  operator==(const FullSourceLoc &LHS, const FullSourceLoc &RHS) {
    return LHS.getRawEncoding() == RHS.getRawEncoding() &&
          LHS.SrcMgr == RHS.SrcMgr;
  }

  friend bool
  operator!=(const FullSourceLoc &LHS, const FullSourceLoc &RHS) {
    return !(LHS == RHS);
  }
};

} // namespace clang

namespace llvm {

  /// Define DenseMapInfo so that FileID's can be used as keys in DenseMap and
  /// DenseSets.
  template <>
  struct DenseMapInfo<clang::FileID> {
    static clang::FileID getEmptyKey() {
      return {};
    }

    static clang::FileID getTombstoneKey() {
      return clang::FileID::getSentinel();
    }

    static unsigned getHashValue(clang::FileID S) {
      return S.getHashValue();
    }

    static bool isEqual(clang::FileID LHS, clang::FileID RHS) {
      return LHS == RHS;
    }
  };

  // Teach SmallPtrSet how to handle SourceLocation.
  template<>
  struct PointerLikeTypeTraits<clang::SourceLocation> {
    static constexpr int NumLowBitsAvailable = 0;

    static void *getAsVoidPointer(clang::SourceLocation L) {
      return L.getPtrEncoding();
    }

    static clang::SourceLocation getFromVoidPointer(void *P) {
      return clang::SourceLocation::getFromRawEncoding((unsigned)(uintptr_t)P);
    }
  };

} // namespace llvm

#endif // LLVM_CLANG_BASIC_SOURCELOCATION_H
# 499 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceLocation.h"
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/Specifiers.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h" 1
//===--- Specifiers.h - Declaration and Type Specifiers ---------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
///
/// \file
/// Defines various enumerations that describe declaration and
/// type specifiers.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_SPECIFIERS_H
#define LLVM_CLANG_BASIC_SPECIFIERS_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h"
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h" 1
//===-- llvm/Support/DataTypes.h - Define fixed size types ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// Due to layering constraints (Support depends on llvm-c) this is a thin
// wrapper around the implementation that lives in llvm-c, though most clients
// can/should think of this as being provided by Support for simplicity (not
// many clients are aware of their dependency on llvm-c).
//
//===----------------------------------------------------------------------===//

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h"
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h"

namespace clang {

  /// Define the meaning of possible values of the kind in ExplicitSpecifier.
  enum class ExplicitSpecKind : unsigned {
    ResolvedFalse,
    ResolvedTrue,
    Unresolved,
  };

  /// Define the kind of constexpr specifier.
  enum ConstexprSpecKind {
    CSK_unspecified,
    CSK_constexpr,
    CSK_consteval,
    CSK_constinit
  };

  /// Specifies the width of a type, e.g., short, long, or long long.
  enum TypeSpecifierWidth {
    TSW_unspecified,
    TSW_short,
    TSW_long,
    TSW_longlong
  };

  /// Specifies the signedness of a type, e.g., signed or unsigned.
  enum TypeSpecifierSign {
    TSS_unspecified,
    TSS_signed,
    TSS_unsigned
  };

  enum TypeSpecifiersPipe {
    TSP_unspecified,
    TSP_pipe
  };

  /// Specifies the kind of type.
  enum TypeSpecifierType {
    TST_unspecified,
    TST_void,
    TST_char,
    TST_wchar,        // C++ wchar_t
    TST_char8,        // C++20 char8_t (proposed)
    TST_char16,       // C++11 char16_t
    TST_char32,       // C++11 char32_t
    TST_int,
    TST_int128,
    TST_half,         // OpenCL half, ARM NEON __fp16
    TST_Float16,      // C11 extension ISO/IEC TS 18661-3
    TST_Accum,        // ISO/IEC JTC1 SC22 WG14 N1169 Extension
    TST_Fract,
    TST_float,
    TST_double,
    TST_float128,
    TST_bool,         // _Bool
    TST_decimal32,    // _Decimal32
    TST_decimal64,    // _Decimal64
    TST_decimal128,   // _Decimal128
    TST_enum,
    TST_union,
    TST_struct,
    TST_class,        // C++ class type
    TST_interface,    // C++ (Microsoft-specific) __interface type
    TST_typename,     // Typedef, C++ class-name or enum name, etc.
    TST_typeofType,
    TST_typeofExpr,
    TST_decltype,         // C++11 decltype
    TST_underlyingType,   // __underlying_type for C++11
    TST_auto,             // C++11 auto
    TST_decltype_auto,    // C++1y decltype(auto)
    TST_auto_type,        // __auto_type extension
    TST_unknown_anytype,  // __unknown_anytype extension
    TST_atomic,           // C11 _Atomic
#define GENERIC_IMAGE_TYPE(ImgType, Id) TST_##ImgType##_t, // OpenCL image types
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/OpenCLImageTypes.def"
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/OpenCLImageTypes.def" 1
//===-- OpenCLImageTypes.def - Metadata about BuiltinTypes ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//  This file extends builtin types database with OpenCL image singleton types.
//  Custom code should define one of those three macros:
//    GENERIC_IMAGE_TYPE(Type, Id) - a generic image with its Id without an
//      access type
//    IMAGE_TYPE(Type, Id, SingletonId, AccessType, CGSuffix) - an image type
//      with given ID, singleton ID access type and a codegen suffix
//    GENERIC_IMAGE_TYPE_EXT(Type, Id, Ext) - a generic image with its Id and
//      required extension without an access type

#ifdef GENERIC_IMAGE_TYPE

#define IMAGE_READ_TYPE(Type, Id, Ext) GENERIC_IMAGE_TYPE(Type, Id)
#define IMAGE_WRITE_TYPE(Type, Id, Ext)
#define IMAGE_READ_WRITE_TYPE(Type, Id, Ext)

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(GENERIC_IMAGE_TYPE_EXT)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/OpenCLImageTypes.def"
#define IMAGE_READ_TYPE(Type, Id, Ext) GENERIC_IMAGE_TYPE_EXT(Type, Id##ROTy, Ext)
#define IMAGE_WRITE_TYPE(Type, Id, Ext) GENERIC_IMAGE_TYPE_EXT(Type, Id##WOTy, Ext)
#define IMAGE_READ_WRITE_TYPE(Type, Id, Ext) GENERIC_IMAGE_TYPE_EXT(Type, Id##RWTy, Ext)

#else
# 29 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/OpenCLImageTypes.def"
#ifndef IMAGE_READ_TYPE
#define IMAGE_READ_TYPE(Type, Id, Ext) \
          IMAGE_TYPE(Type, Id##RO, Id##ROTy,  read_only, ro)
#endif
# 33 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/OpenCLImageTypes.def"
#ifndef IMAGE_WRITE_TYPE
#define IMAGE_WRITE_TYPE(Type, Id, Ext) \
          IMAGE_TYPE(Type, Id##WO, Id##WOTy, write_only, wo)
#endif
# 37 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/OpenCLImageTypes.def"
#ifndef IMAGE_READ_WRITE_TYPE
#define IMAGE_READ_WRITE_TYPE(Type, Id, Ext) \
          IMAGE_TYPE(Type, Id##RW, Id##RWTy, read_write, rw)
#endif
# 41 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/OpenCLImageTypes.def"

#endif
# 43 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/OpenCLImageTypes.def"

IMAGE_READ_TYPE(image1d, OCLImage1d, "")
IMAGE_READ_TYPE(image1d_array, OCLImage1dArray, "")
IMAGE_READ_TYPE(image1d_buffer, OCLImage1dBuffer, "")
IMAGE_READ_TYPE(image2d, OCLImage2d, "")
IMAGE_READ_TYPE(image2d_array, OCLImage2dArray, "")
IMAGE_READ_TYPE(image2d_depth, OCLImage2dDepth, "")
IMAGE_READ_TYPE(image2d_array_depth, OCLImage2dArrayDepth, "")
IMAGE_READ_TYPE(image2d_msaa, OCLImage2dMSAA, "cl_khr_gl_msaa_sharing")
IMAGE_READ_TYPE(image2d_array_msaa, OCLImage2dArrayMSAA, "cl_khr_gl_msaa_sharing")
IMAGE_READ_TYPE(image2d_msaa_depth, OCLImage2dMSAADepth, "cl_khr_gl_msaa_sharing")
IMAGE_READ_TYPE(image2d_array_msaa_depth, OCLImage2dArrayMSAADepth, "cl_khr_gl_msaa_sharing")
IMAGE_READ_TYPE(image3d, OCLImage3d, "")

IMAGE_WRITE_TYPE(image1d, OCLImage1d, "")
IMAGE_WRITE_TYPE(image1d_array, OCLImage1dArray, "")
IMAGE_WRITE_TYPE(image1d_buffer, OCLImage1dBuffer, "")
IMAGE_WRITE_TYPE(image2d, OCLImage2d, "")
IMAGE_WRITE_TYPE(image2d_array, OCLImage2dArray, "")
IMAGE_WRITE_TYPE(image2d_depth, OCLImage2dDepth, "")
IMAGE_WRITE_TYPE(image2d_array_depth, OCLImage2dArrayDepth, "")
IMAGE_WRITE_TYPE(image2d_msaa, OCLImage2dMSAA, "cl_khr_gl_msaa_sharing")
IMAGE_WRITE_TYPE(image2d_array_msaa, OCLImage2dArrayMSAA, "cl_khr_gl_msaa_sharing")
IMAGE_WRITE_TYPE(image2d_msaa_depth, OCLImage2dMSAADepth, "cl_khr_gl_msaa_sharing")
IMAGE_WRITE_TYPE(image2d_array_msaa_depth, OCLImage2dArrayMSAADepth, "cl_khr_gl_msaa_sharing")
IMAGE_WRITE_TYPE(image3d, OCLImage3d, "cl_khr_3d_image_writes")

IMAGE_READ_WRITE_TYPE(image1d, OCLImage1d, "")
IMAGE_READ_WRITE_TYPE(image1d_array, OCLImage1dArray, "")
IMAGE_READ_WRITE_TYPE(image1d_buffer, OCLImage1dBuffer, "")
IMAGE_READ_WRITE_TYPE(image2d, OCLImage2d, "")
IMAGE_READ_WRITE_TYPE(image2d_array, OCLImage2dArray, "")
IMAGE_READ_WRITE_TYPE(image2d_depth, OCLImage2dDepth, "")
IMAGE_READ_WRITE_TYPE(image2d_array_depth, OCLImage2dArrayDepth, "")
IMAGE_READ_WRITE_TYPE(image2d_msaa, OCLImage2dMSAA, "cl_khr_gl_msaa_sharing")
IMAGE_READ_WRITE_TYPE(image2d_array_msaa, OCLImage2dArrayMSAA, "cl_khr_gl_msaa_sharing")
IMAGE_READ_WRITE_TYPE(image2d_msaa_depth, OCLImage2dMSAADepth, "cl_khr_gl_msaa_sharing")
IMAGE_READ_WRITE_TYPE(image2d_array_msaa_depth, OCLImage2dArrayMSAADepth, "cl_khr_gl_msaa_sharing")
IMAGE_READ_WRITE_TYPE(image3d, OCLImage3d, "")

#undef IMAGE_TYPE
#undef GENERIC_IMAGE_TYPE
#undef IMAGE_READ_TYPE
#undef IMAGE_WRITE_TYPE
#undef IMAGE_READ_WRITE_TYPE
# 98 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h" 2
    TST_error // erroneous type
  };

  /// Structure that packs information about the type specifiers that
  /// were written in a particular type specifier sequence.
  struct WrittenBuiltinSpecs {
    static_assert(TST_error < 1 << 6, "Type bitfield not wide enough for TST");
    /*DeclSpec::TST*/ unsigned Type  : 6;
    /*DeclSpec::TSS*/ unsigned Sign  : 2;
    /*DeclSpec::TSW*/ unsigned Width : 2;
    unsigned ModeAttr : 1;
  };

  /// A C++ access specifier (public, private, protected), plus the
  /// special value "none" which means different things in different contexts.
  enum AccessSpecifier {
    AS_public,
    AS_protected,
    AS_private,
    AS_none
  };

  /// The categorization of expression values, currently following the
  /// C++11 scheme.
  enum ExprValueKind {
    /// An r-value expression (a pr-value in the C++11 taxonomy)
    /// produces a temporary value.
    VK_RValue,

    /// An l-value expression is a reference to an object with
    /// independent storage.
    VK_LValue,

    /// An x-value expression is a reference to an object with
    /// independent storage but which can be "moved", i.e.
    /// efficiently cannibalized for its resources.
    VK_XValue
  };

  /// A further classification of the kind of object referenced by an
  /// l-value or x-value.
  enum ExprObjectKind {
    /// An ordinary object is located at an address in memory.
    OK_Ordinary,

    /// A bitfield object is a bitfield on a C or C++ record.
    OK_BitField,

    /// A vector component is an element or range of elements on a vector.
    OK_VectorComponent,

    /// An Objective-C property is a logical field of an Objective-C
    /// object which is read and written via Objective-C method calls.
    OK_ObjCProperty,

    /// An Objective-C array/dictionary subscripting which reads an
    /// object or writes at the subscripted array/dictionary element via
    /// Objective-C method calls.
    OK_ObjCSubscript
  };

  /// The reason why a DeclRefExpr does not constitute an odr-use.
  enum NonOdrUseReason {
    /// This is an odr-use.
    NOUR_None = 0,
    /// This name appears in an unevaluated operand.
    NOUR_Unevaluated,
    /// This name appears as a potential result of an lvalue-to-rvalue
    /// conversion that is a constant expression.
    NOUR_Constant,
    /// This name appears as a potential result of a discarded value
    /// expression.
    NOUR_Discarded,
  };

  /// Describes the kind of template specialization that a
  /// particular template specialization declaration represents.
  enum TemplateSpecializationKind {
    /// This template specialization was formed from a template-id but
    /// has not yet been declared, defined, or instantiated.
    TSK_Undeclared = 0,
    /// This template specialization was implicitly instantiated from a
    /// template. (C++ [temp.inst]).
    TSK_ImplicitInstantiation,
    /// This template specialization was declared or defined by an
    /// explicit specialization (C++ [temp.expl.spec]) or partial
    /// specialization (C++ [temp.class.spec]).
    TSK_ExplicitSpecialization,
    /// This template specialization was instantiated from a template
    /// due to an explicit instantiation declaration request
    /// (C++11 [temp.explicit]).
    TSK_ExplicitInstantiationDeclaration,
    /// This template specialization was instantiated from a template
    /// due to an explicit instantiation definition request
    /// (C++ [temp.explicit]).
    TSK_ExplicitInstantiationDefinition
  };

  /// Determine whether this template specialization kind refers
  /// to an instantiation of an entity (as opposed to a non-template or
  /// an explicit specialization).
  inline bool isTemplateInstantiation(TemplateSpecializationKind Kind) {
    return Kind != TSK_Undeclared && Kind != TSK_ExplicitSpecialization;
  }

  /// True if this template specialization kind is an explicit
  /// specialization, explicit instantiation declaration, or explicit
  /// instantiation definition.
  inline bool isTemplateExplicitInstantiationOrSpecialization(
      TemplateSpecializationKind Kind) {
    switch (Kind) {
    case TSK_ExplicitSpecialization:
    case TSK_ExplicitInstantiationDeclaration:
    case TSK_ExplicitInstantiationDefinition:
      return true;

    case TSK_Undeclared:
    case TSK_ImplicitInstantiation:
      return false;
    }
    llvm_unreachable("bad template specialization kind");
  }

  /// Thread storage-class-specifier.
  enum ThreadStorageClassSpecifier {
    TSCS_unspecified,
    /// GNU __thread.
    TSCS___thread,
    /// C++11 thread_local. Implies 'static' at block scope, but not at
    /// class scope.
    TSCS_thread_local,
    /// C11 _Thread_local. Must be combined with either 'static' or 'extern'
    /// if used at block scope.
    TSCS__Thread_local
  };

  /// Storage classes.
  enum StorageClass {
    // These are legal on both functions and variables.
    SC_None,
    SC_Extern,
    SC_Static,
    SC_PrivateExtern,

    // These are only legal on variables.
    SC_Auto,
    SC_Register
  };

  /// Checks whether the given storage class is legal for functions.
  inline bool isLegalForFunction(StorageClass SC) {
    return SC <= SC_PrivateExtern;
  }

  /// Checks whether the given storage class is legal for variables.
  inline bool isLegalForVariable(StorageClass SC) {
    return true;
  }

  /// In-class initialization styles for non-static data members.
  enum InClassInitStyle {
    ICIS_NoInit,   ///< No in-class initializer.
    ICIS_CopyInit, ///< Copy initialization.
    ICIS_ListInit  ///< Direct list-initialization.
  };

  /// CallingConv - Specifies the calling convention that a function uses.
  enum CallingConv {
    CC_C,           // __attribute__((cdecl))
    CC_X86StdCall,  // __attribute__((stdcall))
    CC_X86FastCall, // __attribute__((fastcall))
    CC_X86ThisCall, // __attribute__((thiscall))
    CC_X86VectorCall, // __attribute__((vectorcall))
    CC_X86Pascal,   // __attribute__((pascal))
    CC_Win64,       // __attribute__((ms_abi))
    CC_X86_64SysV,  // __attribute__((sysv_abi))
    CC_X86RegCall, // __attribute__((regcall))
    CC_AAPCS,       // __attribute__((pcs("aapcs")))
    CC_AAPCS_VFP,   // __attribute__((pcs("aapcs-vfp")))
    CC_IntelOclBicc, // __attribute__((intel_ocl_bicc))
    CC_SpirFunction, // default for OpenCL functions on SPIR target
    CC_OpenCLKernel, // inferred for OpenCL kernels
    CC_Swift,        // __attribute__((swiftcall))
    CC_PreserveMost, // __attribute__((preserve_most))
    CC_PreserveAll,  // __attribute__((preserve_all))
    CC_AArch64VectorCall, // __attribute__((aarch64_vector_pcs))
  };

  /// Checks whether the given calling convention supports variadic
  /// calls. Unprototyped calls also use the variadic call rules.
  inline bool supportsVariadicCall(CallingConv CC) {
    switch (CC) {
    case CC_X86StdCall:
    case CC_X86FastCall:
    case CC_X86ThisCall:
    case CC_X86RegCall:
    case CC_X86Pascal:
    case CC_X86VectorCall:
    case CC_SpirFunction:
    case CC_OpenCLKernel:
    case CC_Swift:
      return false;
    default:
      return true;
    }
  }

  /// The storage duration for an object (per C++ [basic.stc]).
  enum StorageDuration {
    SD_FullExpression, ///< Full-expression storage duration (for temporaries).
    SD_Automatic,      ///< Automatic storage duration (most local variables).
    SD_Thread,         ///< Thread storage duration.
    SD_Static,         ///< Static storage duration.
    SD_Dynamic         ///< Dynamic storage duration.
  };

  /// Describes the nullability of a particular type.
  enum class NullabilityKind : uint8_t {
    /// Values of this type can never be null.
    NonNull = 0,
    /// Values of this type can be null.
    Nullable,
    /// Whether values of this type can be null is (explicitly)
    /// unspecified. This captures a (fairly rare) case where we
    /// can't conclude anything about the nullability of the type even
    /// though it has been considered.
    Unspecified
  };

  /// Return true if \p L has a weaker nullability annotation than \p R. The
  /// ordering is: Unspecified < Nullable < NonNull.
  inline bool hasWeakerNullability(NullabilityKind L, NullabilityKind R) {
    return uint8_t(L) > uint8_t(R);
  }

  /// Retrieve the spelling of the given nullability kind.
  llvm::StringRef getNullabilitySpelling(NullabilityKind kind,
                                         bool isContextSensitive = false);

  /// Kinds of parameter ABI.
  enum class ParameterABI {
    /// This parameter uses ordinary ABI rules for its type.
    Ordinary,

    /// This parameter (which must have pointer type) is a Swift
    /// indirect result parameter.
    SwiftIndirectResult,

    /// This parameter (which must have pointer-to-pointer type) uses
    /// the special Swift error-result ABI treatment.  There can be at
    /// most one parameter on a given function that uses this treatment.
    SwiftErrorResult,

    /// This parameter (which must have pointer type) uses the special
    /// Swift context-pointer ABI treatment.  There can be at
    /// most one parameter on a given function that uses this treatment.
    SwiftContext
  };

  /// Assigned inheritance model for a class in the MS C++ ABI. Must match order
  /// of spellings in MSInheritanceAttr.
  enum class MSInheritanceModel {
    Single = 0,
    Multiple = 1,
    Virtual = 2,
    Unspecified = 3,
  };

  llvm::StringRef getParameterABISpelling(ParameterABI kind);
} // end namespace clang

#endif // LLVM_CLANG_BASIC_SPECIFIERS_H
# 370 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Specifiers.h"
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/ArrayRef.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h" 1
//===- ArrayRef.h - Array Reference Wrapper ---------------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_ARRAYREF_H
#define LLVM_ADT_ARRAYREF_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Hashing.h"
#endif /* expanded by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h" 1
//===-- llvm/ADT/Hashing.h - Utilities for hashing --------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file implements the newly proposed standard C++ interfaces for hashing
// arbitrary data and building hash functions for user-defined types. This
// interface was originally proposed in N3333[1] and is currently under review
// for inclusion in a future TR and/or standard.
//
// The primary interfaces provide are comprised of one type and three functions:
//
//  -- 'hash_code' class is an opaque type representing the hash code for some
//     data. It is the intended product of hashing, and can be used to implement
//     hash tables, checksumming, and other common uses of hashes. It is not an
//     integer type (although it can be converted to one) because it is risky
//     to assume much about the internals of a hash_code. In particular, each
//     execution of the program has a high probability of producing a different
//     hash_code for a given input. Thus their values are not stable to save or
//     persist, and should only be used during the execution for the
//     construction of hashing datastructures.
//
//  -- 'hash_value' is a function designed to be overloaded for each
//     user-defined type which wishes to be used within a hashing context. It
//     should be overloaded within the user-defined type's namespace and found
//     via ADL. Overloads for primitive types are provided by this library.
//
//  -- 'hash_combine' and 'hash_combine_range' are functions designed to aid
//      programmers in easily and intuitively combining a set of data into
//      a single hash_code for their object. They should only logically be used
//      within the implementation of a 'hash_value' routine or similar context.
//
// Note that 'hash_combine_range' contains very special logic for hashing
// a contiguous array of integers or pointers. This logic is *extremely* fast,
// on a modern Intel "Gainestown" Xeon (Nehalem uarch) @2.2 GHz, these were
// benchmarked at over 6.5 GiB/s for large keys, and <20 cycles/hash for keys
// under 32-bytes.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_HASHING_H
#define LLVM_ADT_HASHING_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 47 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h" 1
//===-- llvm/Support/DataTypes.h - Define fixed size types ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// Due to layering constraints (Support depends on llvm-c) this is a thin
// wrapper around the implementation that lives in llvm-c, though most clients
// can/should think of this as being provided by Support for simplicity (not
// many clients are aware of their dependency on llvm-c).
//
//===----------------------------------------------------------------------===//

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 48 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 48 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 49 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/SwapByteOrder.h"
#endif /* expanded by -frewrite-includes */
# 49 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h" 1
//===- SwapByteOrder.h - Generic and optimized byte swaps -------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file declares generic and optimized functions to swap the byte order of
// an integral type.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_SWAPBYTEORDER_H
#define LLVM_SUPPORT_SWAPBYTEORDER_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h" 1
//===-- llvm/Support/DataTypes.h - Define fixed size types ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// Due to layering constraints (Support depends on llvm-c) this is a thin
// wrapper around the implementation that lives in llvm-c, though most clients
// can/should think of this as being provided by Support for simplicity (not
// many clients are aware of their dependency on llvm-c).
//
//===----------------------------------------------------------------------===//

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER) && !defined(_DEBUG)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#endif
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"

#if 0 /* disabled by -frewrite-includes */
#if defined(__linux__) || defined(__GNU__) || defined(__HAIKU__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* expanded by -frewrite-includes */
#include <endian.h>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_AIX)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* expanded by -frewrite-includes */
#include <sys/machine.h>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(__sun)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
/* Solaris provides _BIG_ENDIAN/_LITTLE_ENDIAN selector in sys/types.h */
#if 0 /* expanded by -frewrite-includes */
#include <sys/types.h>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#define BIG_ENDIAN 4321
#define LITTLE_ENDIAN 1234
#if 0 /* disabled by -frewrite-includes */
#if defined(_BIG_ENDIAN)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#define BYTE_ORDER BIG_ENDIAN
#else
# 37 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#define BYTE_ORDER LITTLE_ENDIAN
#endif
# 39 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#else
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* disabled by -frewrite-includes */
#if !defined(BYTE_ORDER) && !defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 41 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#if 0 /* expanded by -frewrite-includes */
#include <machine/endian.h>
#endif /* expanded by -frewrite-includes */
# 41 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 42 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#endif
# 43 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#endif
# 44 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"

namespace llvm {
namespace sys {

#if 0 /* disabled by -frewrite-includes */
#if defined(BYTE_ORDER) && defined(BIG_ENDIAN) && BYTE_ORDER == BIG_ENDIAN
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 49 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
constexpr bool IsBigEndianHost = true;
#else
# 51 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
constexpr bool IsBigEndianHost = false;
#endif
# 53 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"

static const bool IsLittleEndianHost = !IsBigEndianHost;

/// SwapByteOrder_16 - This function returns a byte-swapped representation of
/// the 16-bit argument.
inline uint16_t SwapByteOrder_16(uint16_t value) {
#if 0 /* disabled by -frewrite-includes */
#if defined(_MSC_VER) && !defined(_DEBUG)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 60 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
  // The DLL version of the runtime lacks these functions (bug!?), but in a
  // release build they're replaced with BSWAP instructions anyway.
  return _byteswap_ushort(value);
#else
# 64 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
  uint16_t Hi = value << 8;
  uint16_t Lo = value >> 8;
  return Hi | Lo;
#endif
# 68 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
}

/// This function returns a byte-swapped representation of the 32-bit argument.
inline uint32_t SwapByteOrder_32(uint32_t value) {
#if 0 /* disabled by -frewrite-includes */
#if defined(__llvm__) || (defined(__GNUC__) && !defined(__ICC))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 73 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
  return __builtin_bswap32(value);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER) && !defined(_DEBUG)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 75 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
  return _byteswap_ulong(value);
#else
# 77 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
  uint32_t Byte0 = value & 0x000000FF;
  uint32_t Byte1 = value & 0x0000FF00;
  uint32_t Byte2 = value & 0x00FF0000;
  uint32_t Byte3 = value & 0xFF000000;
  return (Byte0 << 24) | (Byte1 << 8) | (Byte2 >> 8) | (Byte3 >> 24);
#endif
# 83 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
}

/// This function returns a byte-swapped representation of the 64-bit argument.
inline uint64_t SwapByteOrder_64(uint64_t value) {
#if 0 /* disabled by -frewrite-includes */
#if defined(__llvm__) || (defined(__GNUC__) && !defined(__ICC))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 88 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
  return __builtin_bswap64(value);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER) && !defined(_DEBUG)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 90 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
  return _byteswap_uint64(value);
#else
# 92 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
  uint64_t Hi = SwapByteOrder_32(uint32_t(value));
  uint32_t Lo = SwapByteOrder_32(uint32_t(value >> 32));
  return (Hi << 32) | Lo;
#endif
# 96 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
}

inline unsigned char  getSwappedBytes(unsigned char C) { return C; }
inline   signed char  getSwappedBytes(signed char C) { return C; }
inline          char  getSwappedBytes(char C) { return C; }

inline unsigned short getSwappedBytes(unsigned short C) { return SwapByteOrder_16(C); }
inline   signed short getSwappedBytes(  signed short C) { return SwapByteOrder_16(C); }

inline unsigned int   getSwappedBytes(unsigned int   C) { return SwapByteOrder_32(C); }
inline   signed int   getSwappedBytes(  signed int   C) { return SwapByteOrder_32(C); }

#if 0 /* disabled by -frewrite-includes */
#if __LONG_MAX__ == __INT_MAX__
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 109 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
inline unsigned long  getSwappedBytes(unsigned long  C) { return SwapByteOrder_32(C); }
inline   signed long  getSwappedBytes(  signed long  C) { return SwapByteOrder_32(C); }
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif __LONG_MAX__ == __LONG_LONG_MAX__
#endif
#endif /* disabled by -frewrite-includes */
#elif 1 /* evaluated by -frewrite-includes */
# 112 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
inline unsigned long  getSwappedBytes(unsigned long  C) { return SwapByteOrder_64(C); }
inline   signed long  getSwappedBytes(  signed long  C) { return SwapByteOrder_64(C); }
#else
# 115 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
#error "Unknown long size!"
#endif
# 117 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"

inline unsigned long long getSwappedBytes(unsigned long long C) {
  return SwapByteOrder_64(C);
}
inline signed long long getSwappedBytes(signed long long C) {
  return SwapByteOrder_64(C);
}

inline float getSwappedBytes(float C) {
  union {
    uint32_t i;
    float f;
  } in, out;
  in.f = C;
  out.i = SwapByteOrder_32(in.i);
  return out.f;
}

inline double getSwappedBytes(double C) {
  union {
    uint64_t i;
    double d;
  } in, out;
  in.d = C;
  out.i = SwapByteOrder_64(in.i);
  return out.d;
}

template <typename T>
inline std::enable_if_t<std::is_enum<T>::value, T> getSwappedBytes(T C) {
  return static_cast<T>(
      getSwappedBytes(static_cast<std::underlying_type_t<T>>(C)));
}

template<typename T>
inline void swapByteOrder(T &Value) {
  Value = getSwappedBytes(Value);
}

} // end namespace sys
} // end namespace llvm

#endif
# 160 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SwapByteOrder.h"
# 50 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/type_traits.h"
#endif /* expanded by -frewrite-includes */
# 50 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 51 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 51 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 52 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 52 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 53 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 53 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 54 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 54 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 55 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 55 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 56 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"

namespace llvm {

/// An opaque object representing a hash code.
///
/// This object represents the result of hashing some entity. It is intended to
/// be used to implement hashtables or other hashing-based data structures.
/// While it wraps and exposes a numeric value, this value should not be
/// trusted to be stable or predictable across processes or executions.
///
/// In order to obtain the hash_code for an object 'x':
/// \code
///   using llvm::hash_value;
///   llvm::hash_code code = hash_value(x);
/// \endcode
class hash_code {
  size_t value;

public:
  /// Default construct a hash_code.
  /// Note that this leaves the value uninitialized.
  hash_code() = default;

  /// Form a hash code directly from a numerical value.
  hash_code(size_t value) : value(value) {}

  /// Convert the hash code to its numerical value for use.
  /*explicit*/ operator size_t() const { return value; }

  friend bool operator==(const hash_code &lhs, const hash_code &rhs) {
    return lhs.value == rhs.value;
  }
  friend bool operator!=(const hash_code &lhs, const hash_code &rhs) {
    return lhs.value != rhs.value;
  }

  /// Allow a hash_code to be directly run through hash_value.
  friend size_t hash_value(const hash_code &code) { return code.value; }
};

/// Compute a hash_code for any integer value.
///
/// Note that this function is intended to compute the same hash_code for
/// a particular value without regard to the pre-promotion type. This is in
/// contrast to hash_combine which may produce different hash_codes for
/// differing argument types even if they would implicit promote to a common
/// type without changing the value.
template <typename T>
std::enable_if_t<is_integral_or_enum<T>::value, hash_code> hash_value(T value);

/// Compute a hash_code for a pointer's address.
///
/// N.B.: This hashes the *address*. Not the value and not the type.
template <typename T> hash_code hash_value(const T *ptr);

/// Compute a hash_code for a pair of objects.
template <typename T, typename U>
hash_code hash_value(const std::pair<T, U> &arg);

/// Compute a hash_code for a standard string.
template <typename T>
hash_code hash_value(const std::basic_string<T> &arg);


/// Override the execution seed with a fixed value.
///
/// This hashing library uses a per-execution seed designed to change on each
/// run with high probability in order to ensure that the hash codes are not
/// attackable and to ensure that output which is intended to be stable does
/// not rely on the particulars of the hash codes produced.
///
/// That said, there are use cases where it is important to be able to
/// reproduce *exactly* a specific behavior. To that end, we provide a function
/// which will forcibly set the seed to a fixed value. This must be done at the
/// start of the program, before any hashes are computed. Also, it cannot be
/// undone. This makes it thread-hostile and very hard to use outside of
/// immediately on start of a simple program designed for reproducible
/// behavior.
void set_fixed_execution_hash_seed(uint64_t fixed_value);


// All of the implementation details of actually computing the various hash
// code values are held within this namespace. These routines are included in
// the header file mainly to allow inlining and constant propagation.
namespace hashing {
namespace detail {

inline uint64_t fetch64(const char *p) {
  uint64_t result;
  memcpy(&result, p, sizeof(result));
  if (sys::IsBigEndianHost)
    sys::swapByteOrder(result);
  return result;
}

inline uint32_t fetch32(const char *p) {
  uint32_t result;
  memcpy(&result, p, sizeof(result));
  if (sys::IsBigEndianHost)
    sys::swapByteOrder(result);
  return result;
}

/// Some primes between 2^63 and 2^64 for various uses.
static const uint64_t k0 = 0xc3a5c85c97cb3127ULL;
static const uint64_t k1 = 0xb492b66fbe98f273ULL;
static const uint64_t k2 = 0x9ae16a3b2f90404fULL;
static const uint64_t k3 = 0xc949d7c7509e6557ULL;

/// Bitwise right rotate.
/// Normally this will compile to a single instruction, especially if the
/// shift is a manifest constant.
inline uint64_t rotate(uint64_t val, size_t shift) {
  // Avoid shifting by 64: doing so yields an undefined result.
  return shift == 0 ? val : ((val >> shift) | (val << (64 - shift)));
}

inline uint64_t shift_mix(uint64_t val) {
  return val ^ (val >> 47);
}

inline uint64_t hash_16_bytes(uint64_t low, uint64_t high) {
  // Murmur-inspired hashing.
  const uint64_t kMul = 0x9ddfea08eb382d69ULL;
  uint64_t a = (low ^ high) * kMul;
  a ^= (a >> 47);
  uint64_t b = (high ^ a) * kMul;
  b ^= (b >> 47);
  b *= kMul;
  return b;
}

inline uint64_t hash_1to3_bytes(const char *s, size_t len, uint64_t seed) {
  uint8_t a = s[0];
  uint8_t b = s[len >> 1];
  uint8_t c = s[len - 1];
  uint32_t y = static_cast<uint32_t>(a) + (static_cast<uint32_t>(b) << 8);
  uint32_t z = static_cast<uint32_t>(len) + (static_cast<uint32_t>(c) << 2);
  return shift_mix(y * k2 ^ z * k3 ^ seed) * k2;
}

inline uint64_t hash_4to8_bytes(const char *s, size_t len, uint64_t seed) {
  uint64_t a = fetch32(s);
  return hash_16_bytes(len + (a << 3), seed ^ fetch32(s + len - 4));
}

inline uint64_t hash_9to16_bytes(const char *s, size_t len, uint64_t seed) {
  uint64_t a = fetch64(s);
  uint64_t b = fetch64(s + len - 8);
  return hash_16_bytes(seed ^ a, rotate(b + len, len)) ^ b;
}

inline uint64_t hash_17to32_bytes(const char *s, size_t len, uint64_t seed) {
  uint64_t a = fetch64(s) * k1;
  uint64_t b = fetch64(s + 8);
  uint64_t c = fetch64(s + len - 8) * k2;
  uint64_t d = fetch64(s + len - 16) * k0;
  return hash_16_bytes(rotate(a - b, 43) + rotate(c ^ seed, 30) + d,
                       a + rotate(b ^ k3, 20) - c + len + seed);
}

inline uint64_t hash_33to64_bytes(const char *s, size_t len, uint64_t seed) {
  uint64_t z = fetch64(s + 24);
  uint64_t a = fetch64(s) + (len + fetch64(s + len - 16)) * k0;
  uint64_t b = rotate(a + z, 52);
  uint64_t c = rotate(a, 37);
  a += fetch64(s + 8);
  c += rotate(a, 7);
  a += fetch64(s + 16);
  uint64_t vf = a + z;
  uint64_t vs = b + rotate(a, 31) + c;
  a = fetch64(s + 16) + fetch64(s + len - 32);
  z = fetch64(s + len - 8);
  b = rotate(a + z, 52);
  c = rotate(a, 37);
  a += fetch64(s + len - 24);
  c += rotate(a, 7);
  a += fetch64(s + len - 16);
  uint64_t wf = a + z;
  uint64_t ws = b + rotate(a, 31) + c;
  uint64_t r = shift_mix((vf + ws) * k2 + (wf + vs) * k0);
  return shift_mix((seed ^ (r * k0)) + vs) * k2;
}

inline uint64_t hash_short(const char *s, size_t length, uint64_t seed) {
  if (length >= 4 && length <= 8)
    return hash_4to8_bytes(s, length, seed);
  if (length > 8 && length <= 16)
    return hash_9to16_bytes(s, length, seed);
  if (length > 16 && length <= 32)
    return hash_17to32_bytes(s, length, seed);
  if (length > 32)
    return hash_33to64_bytes(s, length, seed);
  if (length != 0)
    return hash_1to3_bytes(s, length, seed);

  return k2 ^ seed;
}

/// The intermediate state used during hashing.
/// Currently, the algorithm for computing hash codes is based on CityHash and
/// keeps 56 bytes of arbitrary state.
struct hash_state {
  uint64_t h0 = 0, h1 = 0, h2 = 0, h3 = 0, h4 = 0, h5 = 0, h6 = 0;

  /// Create a new hash_state structure and initialize it based on the
  /// seed and the first 64-byte chunk.
  /// This effectively performs the initial mix.
  static hash_state create(const char *s, uint64_t seed) {
    hash_state state = {
      0, seed, hash_16_bytes(seed, k1), rotate(seed ^ k1, 49),
      seed * k1, shift_mix(seed), 0 };
    state.h6 = hash_16_bytes(state.h4, state.h5);
    state.mix(s);
    return state;
  }

  /// Mix 32-bytes from the input sequence into the 16-bytes of 'a'
  /// and 'b', including whatever is already in 'a' and 'b'.
  static void mix_32_bytes(const char *s, uint64_t &a, uint64_t &b) {
    a += fetch64(s);
    uint64_t c = fetch64(s + 24);
    b = rotate(b + a + c, 21);
    uint64_t d = a;
    a += fetch64(s + 8) + fetch64(s + 16);
    b += rotate(a, 44) + d;
    a += c;
  }

  /// Mix in a 64-byte buffer of data.
  /// We mix all 64 bytes even when the chunk length is smaller, but we
  /// record the actual length.
  void mix(const char *s) {
    h0 = rotate(h0 + h1 + h3 + fetch64(s + 8), 37) * k1;
    h1 = rotate(h1 + h4 + fetch64(s + 48), 42) * k1;
    h0 ^= h6;
    h1 += h3 + fetch64(s + 40);
    h2 = rotate(h2 + h5, 33) * k1;
    h3 = h4 * k1;
    h4 = h0 + h5;
    mix_32_bytes(s, h3, h4);
    h5 = h2 + h6;
    h6 = h1 + fetch64(s + 16);
    mix_32_bytes(s + 32, h5, h6);
    std::swap(h2, h0);
  }

  /// Compute the final 64-bit hash code value based on the current
  /// state and the length of bytes hashed.
  uint64_t finalize(size_t length) {
    return hash_16_bytes(hash_16_bytes(h3, h5) + shift_mix(h1) * k1 + h2,
                         hash_16_bytes(h4, h6) + shift_mix(length) * k1 + h0);
  }
};


/// A global, fixed seed-override variable.
///
/// This variable can be set using the \see llvm::set_fixed_execution_seed
/// function. See that function for details. Do not, under any circumstances,
/// set or read this variable.
extern uint64_t fixed_seed_override;

inline uint64_t get_execution_seed() {
  // FIXME: This needs to be a per-execution seed. This is just a placeholder
  // implementation. Switching to a per-execution seed is likely to flush out
  // instability bugs and so will happen as its own commit.
  //
  // However, if there is a fixed seed override set the first time this is
  // called, return that instead of the per-execution seed.
  const uint64_t seed_prime = 0xff51afd7ed558ccdULL;
  static uint64_t seed = fixed_seed_override ? fixed_seed_override : seed_prime;
  return seed;
}


/// Trait to indicate whether a type's bits can be hashed directly.
///
/// A type trait which is true if we want to combine values for hashing by
/// reading the underlying data. It is false if values of this type must
/// first be passed to hash_value, and the resulting hash_codes combined.
//
// FIXME: We want to replace is_integral_or_enum and is_pointer here with
// a predicate which asserts that comparing the underlying storage of two
// values of the type for equality is equivalent to comparing the two values
// for equality. For all the platforms we care about, this holds for integers
// and pointers, but there are platforms where it doesn't and we would like to
// support user-defined types which happen to satisfy this property.
template <typename T> struct is_hashable_data
  : std::integral_constant<bool, ((is_integral_or_enum<T>::value ||
                                   std::is_pointer<T>::value) &&
                                  64 % sizeof(T) == 0)> {};

// Special case std::pair to detect when both types are viable and when there
// is no alignment-derived padding in the pair. This is a bit of a lie because
// std::pair isn't truly POD, but it's close enough in all reasonable
// implementations for our use case of hashing the underlying data.
template <typename T, typename U> struct is_hashable_data<std::pair<T, U> >
  : std::integral_constant<bool, (is_hashable_data<T>::value &&
                                  is_hashable_data<U>::value &&
                                  (sizeof(T) + sizeof(U)) ==
                                   sizeof(std::pair<T, U>))> {};

/// Helper to get the hashable data representation for a type.
/// This variant is enabled when the type itself can be used.
template <typename T>
std::enable_if_t<is_hashable_data<T>::value, T>
get_hashable_data(const T &value) {
  return value;
}
/// Helper to get the hashable data representation for a type.
/// This variant is enabled when we must first call hash_value and use the
/// result as our data.
template <typename T>
std::enable_if_t<!is_hashable_data<T>::value, size_t>
get_hashable_data(const T &value) {
  using ::llvm::hash_value;
  return hash_value(value);
}

/// Helper to store data from a value into a buffer and advance the
/// pointer into that buffer.
///
/// This routine first checks whether there is enough space in the provided
/// buffer, and if not immediately returns false. If there is space, it
/// copies the underlying bytes of value into the buffer, advances the
/// buffer_ptr past the copied bytes, and returns true.
template <typename T>
bool store_and_advance(char *&buffer_ptr, char *buffer_end, const T& value,
                       size_t offset = 0) {
  size_t store_size = sizeof(value) - offset;
  if (buffer_ptr + store_size > buffer_end)
    return false;
  const char *value_data = reinterpret_cast<const char *>(&value);
  memcpy(buffer_ptr, value_data + offset, store_size);
  buffer_ptr += store_size;
  return true;
}

/// Implement the combining of integral values into a hash_code.
///
/// This overload is selected when the value type of the iterator is
/// integral. Rather than computing a hash_code for each object and then
/// combining them, this (as an optimization) directly combines the integers.
template <typename InputIteratorT>
hash_code hash_combine_range_impl(InputIteratorT first, InputIteratorT last) {
  const uint64_t seed = get_execution_seed();
  char buffer[64], *buffer_ptr = buffer;
  char *const buffer_end = std::end(buffer);
  while (first != last && store_and_advance(buffer_ptr, buffer_end,
                                            get_hashable_data(*first)))
    ++first;
  if (first == last)
    return hash_short(buffer, buffer_ptr - buffer, seed);
  assert(buffer_ptr == buffer_end);

  hash_state state = state.create(buffer, seed);
  size_t length = 64;
  while (first != last) {
    // Fill up the buffer. We don't clear it, which re-mixes the last round
    // when only a partial 64-byte chunk is left.
    buffer_ptr = buffer;
    while (first != last && store_and_advance(buffer_ptr, buffer_end,
                                              get_hashable_data(*first)))
      ++first;

    // Rotate the buffer if we did a partial fill in order to simulate doing
    // a mix of the last 64-bytes. That is how the algorithm works when we
    // have a contiguous byte sequence, and we want to emulate that here.
    std::rotate(buffer, buffer_ptr, buffer_end);

    // Mix this chunk into the current state.
    state.mix(buffer);
    length += buffer_ptr - buffer;
  };

  return state.finalize(length);
}

/// Implement the combining of integral values into a hash_code.
///
/// This overload is selected when the value type of the iterator is integral
/// and when the input iterator is actually a pointer. Rather than computing
/// a hash_code for each object and then combining them, this (as an
/// optimization) directly combines the integers. Also, because the integers
/// are stored in contiguous memory, this routine avoids copying each value
/// and directly reads from the underlying memory.
template <typename ValueT>
std::enable_if_t<is_hashable_data<ValueT>::value, hash_code>
hash_combine_range_impl(ValueT *first, ValueT *last) {
  const uint64_t seed = get_execution_seed();
  const char *s_begin = reinterpret_cast<const char *>(first);
  const char *s_end = reinterpret_cast<const char *>(last);
  const size_t length = std::distance(s_begin, s_end);
  if (length <= 64)
    return hash_short(s_begin, length, seed);

  const char *s_aligned_end = s_begin + (length & ~63);
  hash_state state = state.create(s_begin, seed);
  s_begin += 64;
  while (s_begin != s_aligned_end) {
    state.mix(s_begin);
    s_begin += 64;
  }
  if (length & 63)
    state.mix(s_end - 64);

  return state.finalize(length);
}

} // namespace detail
} // namespace hashing


/// Compute a hash_code for a sequence of values.
///
/// This hashes a sequence of values. It produces the same hash_code as
/// 'hash_combine(a, b, c, ...)', but can run over arbitrary sized sequences
/// and is significantly faster given pointers and types which can be hashed as
/// a sequence of bytes.
template <typename InputIteratorT>
hash_code hash_combine_range(InputIteratorT first, InputIteratorT last) {
  return ::llvm::hashing::detail::hash_combine_range_impl(first, last);
}


// Implementation details for hash_combine.
namespace hashing {
namespace detail {

/// Helper class to manage the recursive combining of hash_combine
/// arguments.
///
/// This class exists to manage the state and various calls involved in the
/// recursive combining of arguments used in hash_combine. It is particularly
/// useful at minimizing the code in the recursive calls to ease the pain
/// caused by a lack of variadic functions.
struct hash_combine_recursive_helper {
  char buffer[64] = {};
  hash_state state;
  const uint64_t seed;

public:
  /// Construct a recursive hash combining helper.
  ///
  /// This sets up the state for a recursive hash combine, including getting
  /// the seed and buffer setup.
  hash_combine_recursive_helper()
    : seed(get_execution_seed()) {}

  /// Combine one chunk of data into the current in-flight hash.
  ///
  /// This merges one chunk of data into the hash. First it tries to buffer
  /// the data. If the buffer is full, it hashes the buffer into its
  /// hash_state, empties it, and then merges the new chunk in. This also
  /// handles cases where the data straddles the end of the buffer.
  template <typename T>
  char *combine_data(size_t &length, char *buffer_ptr, char *buffer_end, T data) {
    if (!store_and_advance(buffer_ptr, buffer_end, data)) {
      // Check for skew which prevents the buffer from being packed, and do
      // a partial store into the buffer to fill it. This is only a concern
      // with the variadic combine because that formation can have varying
      // argument types.
      size_t partial_store_size = buffer_end - buffer_ptr;
      memcpy(buffer_ptr, &data, partial_store_size);

      // If the store fails, our buffer is full and ready to hash. We have to
      // either initialize the hash state (on the first full buffer) or mix
      // this buffer into the existing hash state. Length tracks the *hashed*
      // length, not the buffered length.
      if (length == 0) {
        state = state.create(buffer, seed);
        length = 64;
      } else {
        // Mix this chunk into the current state and bump length up by 64.
        state.mix(buffer);
        length += 64;
      }
      // Reset the buffer_ptr to the head of the buffer for the next chunk of
      // data.
      buffer_ptr = buffer;

      // Try again to store into the buffer -- this cannot fail as we only
      // store types smaller than the buffer.
      if (!store_and_advance(buffer_ptr, buffer_end, data,
                             partial_store_size))
        llvm_unreachable("buffer smaller than stored type");
    }
    return buffer_ptr;
  }

  /// Recursive, variadic combining method.
  ///
  /// This function recurses through each argument, combining that argument
  /// into a single hash.
  template <typename T, typename ...Ts>
  hash_code combine(size_t length, char *buffer_ptr, char *buffer_end,
                    const T &arg, const Ts &...args) {
    buffer_ptr = combine_data(length, buffer_ptr, buffer_end, get_hashable_data(arg));

    // Recurse to the next argument.
    return combine(length, buffer_ptr, buffer_end, args...);
  }

  /// Base case for recursive, variadic combining.
  ///
  /// The base case when combining arguments recursively is reached when all
  /// arguments have been handled. It flushes the remaining buffer and
  /// constructs a hash_code.
  hash_code combine(size_t length, char *buffer_ptr, char *buffer_end) {
    // Check whether the entire set of values fit in the buffer. If so, we'll
    // use the optimized short hashing routine and skip state entirely.
    if (length == 0)
      return hash_short(buffer, buffer_ptr - buffer, seed);

    // Mix the final buffer, rotating it if we did a partial fill in order to
    // simulate doing a mix of the last 64-bytes. That is how the algorithm
    // works when we have a contiguous byte sequence, and we want to emulate
    // that here.
    std::rotate(buffer, buffer_ptr, buffer_end);

    // Mix this chunk into the current state.
    state.mix(buffer);
    length += buffer_ptr - buffer;

    return state.finalize(length);
  }
};

} // namespace detail
} // namespace hashing

/// Combine values into a single hash_code.
///
/// This routine accepts a varying number of arguments of any type. It will
/// attempt to combine them into a single hash_code. For user-defined types it
/// attempts to call a \see hash_value overload (via ADL) for the type. For
/// integer and pointer types it directly combines their data into the
/// resulting hash_code.
///
/// The result is suitable for returning from a user's hash_value
/// *implementation* for their user-defined type. Consumers of a type should
/// *not* call this routine, they should instead call 'hash_value'.
template <typename ...Ts> hash_code hash_combine(const Ts &...args) {
  // Recursively hash each argument using a helper class.
  ::llvm::hashing::detail::hash_combine_recursive_helper helper;
  return helper.combine(0, helper.buffer, helper.buffer + 64, args...);
}

// Implementation details for implementations of hash_value overloads provided
// here.
namespace hashing {
namespace detail {

/// Helper to hash the value of a single integer.
///
/// Overloads for smaller integer types are not provided to ensure consistent
/// behavior in the presence of integral promotions. Essentially,
/// "hash_value('4')" and "hash_value('0' + 4)" should be the same.
inline hash_code hash_integer_value(uint64_t value) {
  // Similar to hash_4to8_bytes but using a seed instead of length.
  const uint64_t seed = get_execution_seed();
  const char *s = reinterpret_cast<const char *>(&value);
  const uint64_t a = fetch32(s);
  return hash_16_bytes(seed + (a << 3), fetch32(s + 4));
}

} // namespace detail
} // namespace hashing

// Declared and documented above, but defined here so that any of the hashing
// infrastructure is available.
template <typename T>
std::enable_if_t<is_integral_or_enum<T>::value, hash_code> hash_value(T value) {
  return ::llvm::hashing::detail::hash_integer_value(
      static_cast<uint64_t>(value));
}

// Declared and documented above, but defined here so that any of the hashing
// infrastructure is available.
template <typename T> hash_code hash_value(const T *ptr) {
  return ::llvm::hashing::detail::hash_integer_value(
    reinterpret_cast<uintptr_t>(ptr));
}

// Declared and documented above, but defined here so that any of the hashing
// infrastructure is available.
template <typename T, typename U>
hash_code hash_value(const std::pair<T, U> &arg) {
  return hash_combine(arg.first, arg.second);
}

// Declared and documented above, but defined here so that any of the hashing
// infrastructure is available.
template <typename T>
hash_code hash_value(const std::basic_string<T> &arg) {
  return hash_combine_range(arg.begin(), arg.end());
}

} // namespace llvm

#endif
# 658 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Hashing.h"
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/None.h"
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h" 1
//===- llvm/ADT/SmallVector.h - 'Normally small' vectors --------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the SmallVector class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_SMALLVECTOR_H
#define LLVM_ADT_SMALLVECTOR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator_range.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/AlignOf.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AlignOf.h" 1
//===--- AlignOf.h - Portable calculation of type alignment -----*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the AlignedCharArrayUnion class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_ALIGNOF_H
#define LLVM_SUPPORT_ALIGNOF_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AlignOf.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AlignOf.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AlignOf.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AlignOf.h"

namespace llvm {

namespace detail {

template <typename T, typename... Ts> class AlignerImpl {
  T t;
  AlignerImpl<Ts...> rest;
  AlignerImpl() = delete;
};

template <typename T> class AlignerImpl<T> {
  T t;
  AlignerImpl() = delete;
};

template <typename T, typename... Ts> union SizerImpl {
  char arr[sizeof(T)];
  SizerImpl<Ts...> rest;
};

template <typename T> union SizerImpl<T> { char arr[sizeof(T)]; };
} // end namespace detail

/// A suitably aligned and sized character array member which can hold elements
/// of any type.
///
/// These types may be arrays, structs, or any other types. This exposes a
/// `buffer` member which can be used as suitable storage for a placement new of
/// any of these types.
template <typename T, typename... Ts> struct AlignedCharArrayUnion {
  alignas(::llvm::detail::AlignerImpl<T, Ts...>) char buffer[sizeof(
      llvm::detail::SizerImpl<T, Ts...>)];
};

} // end namespace llvm

#endif // LLVM_SUPPORT_ALIGNOF_H
# 56 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AlignOf.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MathExtras.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h" 1
//===-- llvm/Support/MathExtras.h - Useful math functions -------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file contains some functions that are useful for math stuff.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_MATHEXTRAS_H
#define LLVM_SUPPORT_MATHEXTRAS_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/SwapByteOrder.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <climits>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"

#ifdef __ANDROID_NDK__
#if 0 /* expanded by -frewrite-includes */
#include <android/api-level.h>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#endif
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"

#ifdef _MSC_VER
// Declare these intrinsics manually rather including intrin.h. It's very
// expensive, and MathExtras.h is popular.
// #include <intrin.h>
extern "C" {
unsigned char _BitScanForward(unsigned long *_Index, unsigned long _Mask);
unsigned char _BitScanForward64(unsigned long *_Index, unsigned __int64 _Mask);
unsigned char _BitScanReverse(unsigned long *_Index, unsigned long _Mask);
unsigned char _BitScanReverse64(unsigned long *_Index, unsigned __int64 _Mask);
}
#endif
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"

namespace llvm {

/// The behavior an operation has on an input of 0.
enum ZeroBehavior {
  /// The returned value is undefined.
  ZB_Undefined,
  /// The returned value is numeric_limits<T>::max()
  ZB_Max,
  /// The returned value is numeric_limits<T>::digits
  ZB_Width
};

/// Mathematical constants.
namespace numbers {
// TODO: Track C++20 std::numbers.
// TODO: Favor using the hexadecimal FP constants (requires C++17).
constexpr double e          = 2.7182818284590452354, // (0x1.5bf0a8b145749P+1) https://oeis.org/A001113
                 egamma     = .57721566490153286061, // (0x1.2788cfc6fb619P-1) https://oeis.org/A001620
                 ln2        = .69314718055994530942, // (0x1.62e42fefa39efP-1) https://oeis.org/A002162
                 ln10       = 2.3025850929940456840, // (0x1.24bb1bbb55516P+1) https://oeis.org/A002392
                 log2e      = 1.4426950408889634074, // (0x1.71547652b82feP+0)
                 log10e     = .43429448190325182765, // (0x1.bcb7b1526e50eP-2)
                 pi         = 3.1415926535897932385, // (0x1.921fb54442d18P+1) https://oeis.org/A000796
                 inv_pi     = .31830988618379067154, // (0x1.45f306bc9c883P-2) https://oeis.org/A049541
                 sqrtpi     = 1.7724538509055160273, // (0x1.c5bf891b4ef6bP+0) https://oeis.org/A002161
                 inv_sqrtpi = .56418958354775628695, // (0x1.20dd750429b6dP-1) https://oeis.org/A087197
                 sqrt2      = 1.4142135623730950488, // (0x1.6a09e667f3bcdP+0) https://oeis.org/A00219
                 inv_sqrt2  = .70710678118654752440, // (0x1.6a09e667f3bcdP-1)
                 sqrt3      = 1.7320508075688772935, // (0x1.bb67ae8584caaP+0) https://oeis.org/A002194
                 inv_sqrt3  = .57735026918962576451, // (0x1.279a74590331cP-1)
                 phi        = 1.6180339887498948482; // (0x1.9e3779b97f4a8P+0) https://oeis.org/A001622
constexpr float ef          = 2.71828183F, // (0x1.5bf0a8P+1) https://oeis.org/A001113
                egammaf     = .577215665F, // (0x1.2788d0P-1) https://oeis.org/A001620
                ln2f        = .693147181F, // (0x1.62e430P-1) https://oeis.org/A002162
                ln10f       = 2.30258509F, // (0x1.26bb1cP+1) https://oeis.org/A002392
                log2ef      = 1.44269504F, // (0x1.715476P+0)
                log10ef     = .434294482F, // (0x1.bcb7b2P-2)
                pif         = 3.14159265F, // (0x1.921fb6P+1) https://oeis.org/A000796
                inv_pif     = .318309886F, // (0x1.45f306P-2) https://oeis.org/A049541
                sqrtpif     = 1.77245385F, // (0x1.c5bf8aP+0) https://oeis.org/A002161
                inv_sqrtpif = .564189584F, // (0x1.20dd76P-1) https://oeis.org/A087197
                sqrt2f      = 1.41421356F, // (0x1.6a09e6P+0) https://oeis.org/A002193
                inv_sqrt2f  = .707106781F, // (0x1.6a09e6P-1)
                sqrt3f      = 1.73205081F, // (0x1.bb67aeP+0) https://oeis.org/A002194
                inv_sqrt3f  = .577350269F, // (0x1.279a74P-1)
                phif        = 1.61803399F; // (0x1.9e377aP+0) https://oeis.org/A001622
} // namespace numbers

namespace detail {
template <typename T, std::size_t SizeOfT> struct TrailingZerosCounter {
  static unsigned count(T Val, ZeroBehavior) {
    if (!Val)
      return std::numeric_limits<T>::digits;
    if (Val & 0x1)
      return 0;

    // Bisection method.
    unsigned ZeroBits = 0;
    T Shift = std::numeric_limits<T>::digits >> 1;
    T Mask = std::numeric_limits<T>::max() >> Shift;
    while (Shift) {
      if ((Val & Mask) == 0) {
        Val >>= Shift;
        ZeroBits |= Shift;
      }
      Shift >>= 1;
      Mask >>= Shift;
    }
    return ZeroBits;
  }
};

#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__) || defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 114 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
template <typename T> struct TrailingZerosCounter<T, 4> {
  static unsigned count(T Val, ZeroBehavior ZB) {
    if (ZB != ZB_Undefined && Val == 0)
      return 32;

#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_ctz) || defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 120 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    return __builtin_ctz(Val);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 122 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    unsigned long Index;
    _BitScanForward(&Index, Val);
    return Index;
#endif
# 126 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  }
};

#if 0 /* disabled by -frewrite-includes */
#if !defined(_MSC_VER) || defined(_M_X64)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 130 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
template <typename T> struct TrailingZerosCounter<T, 8> {
  static unsigned count(T Val, ZeroBehavior ZB) {
    if (ZB != ZB_Undefined && Val == 0)
      return 64;

#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_ctzll) || defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 136 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    return __builtin_ctzll(Val);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 138 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    unsigned long Index;
    _BitScanForward64(&Index, Val);
    return Index;
#endif
# 142 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  }
};
#endif
# 145 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#endif
# 146 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
} // namespace detail

/// Count number of 0's from the least significant bit to the most
///   stopping at the first 1.
///
/// Only unsigned integral types are allowed.
///
/// \param ZB the behavior on an input of 0. Only ZB_Width and ZB_Undefined are
///   valid arguments.
template <typename T>
unsigned countTrailingZeros(T Val, ZeroBehavior ZB = ZB_Width) {
  static_assert(std::numeric_limits<T>::is_integer &&
                    !std::numeric_limits<T>::is_signed,
                "Only unsigned integral types are allowed.");
  return llvm::detail::TrailingZerosCounter<T, sizeof(T)>::count(Val, ZB);
}

namespace detail {
template <typename T, std::size_t SizeOfT> struct LeadingZerosCounter {
  static unsigned count(T Val, ZeroBehavior) {
    if (!Val)
      return std::numeric_limits<T>::digits;

    // Bisection method.
    unsigned ZeroBits = 0;
    for (T Shift = std::numeric_limits<T>::digits >> 1; Shift; Shift >>= 1) {
      T Tmp = Val >> Shift;
      if (Tmp)
        Val = Tmp;
      else
        ZeroBits |= Shift;
    }
    return ZeroBits;
  }
};

#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__) || defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 183 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
template <typename T> struct LeadingZerosCounter<T, 4> {
  static unsigned count(T Val, ZeroBehavior ZB) {
    if (ZB != ZB_Undefined && Val == 0)
      return 32;

#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_clz) || defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 189 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    return __builtin_clz(Val);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 191 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    unsigned long Index;
    _BitScanReverse(&Index, Val);
    return Index ^ 31;
#endif
# 195 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  }
};

#if 0 /* disabled by -frewrite-includes */
#if !defined(_MSC_VER) || defined(_M_X64)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 199 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
template <typename T> struct LeadingZerosCounter<T, 8> {
  static unsigned count(T Val, ZeroBehavior ZB) {
    if (ZB != ZB_Undefined && Val == 0)
      return 64;

#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_clzll) || defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 205 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    return __builtin_clzll(Val);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_MSC_VER)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 207 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    unsigned long Index;
    _BitScanReverse64(&Index, Val);
    return Index ^ 63;
#endif
# 211 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  }
};
#endif
# 214 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
#endif
# 215 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
} // namespace detail

/// Count number of 0's from the most significant bit to the least
///   stopping at the first 1.
///
/// Only unsigned integral types are allowed.
///
/// \param ZB the behavior on an input of 0. Only ZB_Width and ZB_Undefined are
///   valid arguments.
template <typename T>
unsigned countLeadingZeros(T Val, ZeroBehavior ZB = ZB_Width) {
  static_assert(std::numeric_limits<T>::is_integer &&
                    !std::numeric_limits<T>::is_signed,
                "Only unsigned integral types are allowed.");
  return llvm::detail::LeadingZerosCounter<T, sizeof(T)>::count(Val, ZB);
}

/// Get the index of the first set bit starting from the least
///   significant bit.
///
/// Only unsigned integral types are allowed.
///
/// \param ZB the behavior on an input of 0. Only ZB_Max and ZB_Undefined are
///   valid arguments.
template <typename T> T findFirstSet(T Val, ZeroBehavior ZB = ZB_Max) {
  if (ZB == ZB_Max && Val == 0)
    return std::numeric_limits<T>::max();

  return countTrailingZeros(Val, ZB_Undefined);
}

/// Create a bitmask with the N right-most bits set to 1, and all other
/// bits set to 0.  Only unsigned types are allowed.
template <typename T> T maskTrailingOnes(unsigned N) {
  static_assert(std::is_unsigned<T>::value, "Invalid type!");
  const unsigned Bits = CHAR_BIT * sizeof(T);
  assert(N <= Bits && "Invalid bit index");
  return N == 0 ? 0 : (T(-1) >> (Bits - N));
}

/// Create a bitmask with the N left-most bits set to 1, and all other
/// bits set to 0.  Only unsigned types are allowed.
template <typename T> T maskLeadingOnes(unsigned N) {
  return ~maskTrailingOnes<T>(CHAR_BIT * sizeof(T) - N);
}

/// Create a bitmask with the N right-most bits set to 0, and all other
/// bits set to 1.  Only unsigned types are allowed.
template <typename T> T maskTrailingZeros(unsigned N) {
  return maskLeadingOnes<T>(CHAR_BIT * sizeof(T) - N);
}

/// Create a bitmask with the N left-most bits set to 0, and all other
/// bits set to 1.  Only unsigned types are allowed.
template <typename T> T maskLeadingZeros(unsigned N) {
  return maskTrailingOnes<T>(CHAR_BIT * sizeof(T) - N);
}

/// Get the index of the last set bit starting from the least
///   significant bit.
///
/// Only unsigned integral types are allowed.
///
/// \param ZB the behavior on an input of 0. Only ZB_Max and ZB_Undefined are
///   valid arguments.
template <typename T> T findLastSet(T Val, ZeroBehavior ZB = ZB_Max) {
  if (ZB == ZB_Max && Val == 0)
    return std::numeric_limits<T>::max();

  // Use ^ instead of - because both gcc and llvm can remove the associated ^
  // in the __builtin_clz intrinsic on x86.
  return countLeadingZeros(Val, ZB_Undefined) ^
         (std::numeric_limits<T>::digits - 1);
}

/// Macro compressed bit reversal table for 256 bits.
///
/// http://graphics.stanford.edu/~seander/bithacks.html#BitReverseTable
static const unsigned char BitReverseTable256[256] = {
#define R2(n) n, n + 2 * 64, n + 1 * 64, n + 3 * 64
#define R4(n) R2(n), R2(n + 2 * 16), R2(n + 1 * 16), R2(n + 3 * 16)
#define R6(n) R4(n), R4(n + 2 * 4), R4(n + 1 * 4), R4(n + 3 * 4)
  R6(0), R6(2), R6(1), R6(3)
#undef R2
#undef R4
#undef R6
};

/// Reverse the bits in \p Val.
template <typename T>
T reverseBits(T Val) {
  unsigned char in[sizeof(Val)];
  unsigned char out[sizeof(Val)];
  std::memcpy(in, &Val, sizeof(Val));
  for (unsigned i = 0; i < sizeof(Val); ++i)
    out[(sizeof(Val) - i) - 1] = BitReverseTable256[in[i]];
  std::memcpy(&Val, out, sizeof(Val));
  return Val;
}

// NOTE: The following support functions use the _32/_64 extensions instead of
// type overloading so that signed and unsigned integers can be used without
// ambiguity.

/// Return the high 32 bits of a 64 bit value.
constexpr inline uint32_t Hi_32(uint64_t Value) {
  return static_cast<uint32_t>(Value >> 32);
}

/// Return the low 32 bits of a 64 bit value.
constexpr inline uint32_t Lo_32(uint64_t Value) {
  return static_cast<uint32_t>(Value);
}

/// Make a 64-bit integer from a high / low pair of 32-bit integers.
constexpr inline uint64_t Make_64(uint32_t High, uint32_t Low) {
  return ((uint64_t)High << 32) | (uint64_t)Low;
}

/// Checks if an integer fits into the given bit width.
template <unsigned N> constexpr inline bool isInt(int64_t x) {
  return N >= 64 || (-(INT64_C(1)<<(N-1)) <= x && x < (INT64_C(1)<<(N-1)));
}
// Template specializations to get better code for common cases.
template <> constexpr inline bool isInt<8>(int64_t x) {
  return static_cast<int8_t>(x) == x;
}
template <> constexpr inline bool isInt<16>(int64_t x) {
  return static_cast<int16_t>(x) == x;
}
template <> constexpr inline bool isInt<32>(int64_t x) {
  return static_cast<int32_t>(x) == x;
}

/// Checks if a signed integer is an N bit number shifted left by S.
template <unsigned N, unsigned S>
constexpr inline bool isShiftedInt(int64_t x) {
  static_assert(
      N > 0, "isShiftedInt<0> doesn't make sense (refers to a 0-bit number.");
  static_assert(N + S <= 64, "isShiftedInt<N, S> with N + S > 64 is too wide.");
  return isInt<N + S>(x) && (x % (UINT64_C(1) << S) == 0);
}

/// Checks if an unsigned integer fits into the given bit width.
///
/// This is written as two functions rather than as simply
///
///   return N >= 64 || X < (UINT64_C(1) << N);
///
/// to keep MSVC from (incorrectly) warning on isUInt<64> that we're shifting
/// left too many places.
template <unsigned N>
constexpr inline std::enable_if_t<(N < 64), bool> isUInt(uint64_t X) {
  static_assert(N > 0, "isUInt<0> doesn't make sense");
  return X < (UINT64_C(1) << (N));
}
template <unsigned N>
constexpr inline std::enable_if_t<N >= 64, bool> isUInt(uint64_t X) {
  return true;
}

// Template specializations to get better code for common cases.
template <> constexpr inline bool isUInt<8>(uint64_t x) {
  return static_cast<uint8_t>(x) == x;
}
template <> constexpr inline bool isUInt<16>(uint64_t x) {
  return static_cast<uint16_t>(x) == x;
}
template <> constexpr inline bool isUInt<32>(uint64_t x) {
  return static_cast<uint32_t>(x) == x;
}

/// Checks if a unsigned integer is an N bit number shifted left by S.
template <unsigned N, unsigned S>
constexpr inline bool isShiftedUInt(uint64_t x) {
  static_assert(
      N > 0, "isShiftedUInt<0> doesn't make sense (refers to a 0-bit number)");
  static_assert(N + S <= 64,
                "isShiftedUInt<N, S> with N + S > 64 is too wide.");
  // Per the two static_asserts above, S must be strictly less than 64.  So
  // 1 << S is not undefined behavior.
  return isUInt<N + S>(x) && (x % (UINT64_C(1) << S) == 0);
}

/// Gets the maximum value for a N-bit unsigned integer.
inline uint64_t maxUIntN(uint64_t N) {
  assert(N > 0 && N <= 64 && "integer width out of range");

  // uint64_t(1) << 64 is undefined behavior, so we can't do
  //   (uint64_t(1) << N) - 1
  // without checking first that N != 64.  But this works and doesn't have a
  // branch.
  return UINT64_MAX >> (64 - N);
}

/// Gets the minimum value for a N-bit signed integer.
inline int64_t minIntN(int64_t N) {
  assert(N > 0 && N <= 64 && "integer width out of range");

  return -(UINT64_C(1)<<(N-1));
}

/// Gets the maximum value for a N-bit signed integer.
inline int64_t maxIntN(int64_t N) {
  assert(N > 0 && N <= 64 && "integer width out of range");

  // This relies on two's complement wraparound when N == 64, so we convert to
  // int64_t only at the very end to avoid UB.
  return (UINT64_C(1) << (N - 1)) - 1;
}

/// Checks if an unsigned integer fits into the given (dynamic) bit width.
inline bool isUIntN(unsigned N, uint64_t x) {
  return N >= 64 || x <= maxUIntN(N);
}

/// Checks if an signed integer fits into the given (dynamic) bit width.
inline bool isIntN(unsigned N, int64_t x) {
  return N >= 64 || (minIntN(N) <= x && x <= maxIntN(N));
}

/// Return true if the argument is a non-empty sequence of ones starting at the
/// least significant bit with the remainder zero (32 bit version).
/// Ex. isMask_32(0x0000FFFFU) == true.
constexpr inline bool isMask_32(uint32_t Value) {
  return Value && ((Value + 1) & Value) == 0;
}

/// Return true if the argument is a non-empty sequence of ones starting at the
/// least significant bit with the remainder zero (64 bit version).
constexpr inline bool isMask_64(uint64_t Value) {
  return Value && ((Value + 1) & Value) == 0;
}

/// Return true if the argument contains a non-empty sequence of ones with the
/// remainder zero (32 bit version.) Ex. isShiftedMask_32(0x0000FF00U) == true.
constexpr inline bool isShiftedMask_32(uint32_t Value) {
  return Value && isMask_32((Value - 1) | Value);
}

/// Return true if the argument contains a non-empty sequence of ones with the
/// remainder zero (64 bit version.)
constexpr inline bool isShiftedMask_64(uint64_t Value) {
  return Value && isMask_64((Value - 1) | Value);
}

/// Return true if the argument is a power of two > 0.
/// Ex. isPowerOf2_32(0x00100000U) == true (32 bit edition.)
constexpr inline bool isPowerOf2_32(uint32_t Value) {
  return Value && !(Value & (Value - 1));
}

/// Return true if the argument is a power of two > 0 (64 bit edition.)
constexpr inline bool isPowerOf2_64(uint64_t Value) {
  return Value && !(Value & (Value - 1));
}

/// Return a byte-swapped representation of the 16-bit argument.
inline uint16_t ByteSwap_16(uint16_t Value) {
  return sys::SwapByteOrder_16(Value);
}

/// Return a byte-swapped representation of the 32-bit argument.
inline uint32_t ByteSwap_32(uint32_t Value) {
  return sys::SwapByteOrder_32(Value);
}

/// Return a byte-swapped representation of the 64-bit argument.
inline uint64_t ByteSwap_64(uint64_t Value) {
  return sys::SwapByteOrder_64(Value);
}

/// Count the number of ones from the most significant bit to the first
/// zero bit.
///
/// Ex. countLeadingOnes(0xFF0FFF00) == 8.
/// Only unsigned integral types are allowed.
///
/// \param ZB the behavior on an input of all ones. Only ZB_Width and
/// ZB_Undefined are valid arguments.
template <typename T>
unsigned countLeadingOnes(T Value, ZeroBehavior ZB = ZB_Width) {
  static_assert(std::numeric_limits<T>::is_integer &&
                    !std::numeric_limits<T>::is_signed,
                "Only unsigned integral types are allowed.");
  return countLeadingZeros<T>(~Value, ZB);
}

/// Count the number of ones from the least significant bit to the first
/// zero bit.
///
/// Ex. countTrailingOnes(0x00FF00FF) == 8.
/// Only unsigned integral types are allowed.
///
/// \param ZB the behavior on an input of all ones. Only ZB_Width and
/// ZB_Undefined are valid arguments.
template <typename T>
unsigned countTrailingOnes(T Value, ZeroBehavior ZB = ZB_Width) {
  static_assert(std::numeric_limits<T>::is_integer &&
                    !std::numeric_limits<T>::is_signed,
                "Only unsigned integral types are allowed.");
  return countTrailingZeros<T>(~Value, ZB);
}

namespace detail {
template <typename T, std::size_t SizeOfT> struct PopulationCounter {
  static unsigned count(T Value) {
    // Generic version, forward to 32 bits.
    static_assert(SizeOfT <= 4, "Not implemented!");
#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 525 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    return __builtin_popcount(Value);
#else
# 527 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    uint32_t v = Value;
    v = v - ((v >> 1) & 0x55555555);
    v = (v & 0x33333333) + ((v >> 2) & 0x33333333);
    return ((v + (v >> 4) & 0xF0F0F0F) * 0x1010101) >> 24;
#endif
# 532 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  }
};

template <typename T> struct PopulationCounter<T, 8> {
  static unsigned count(T Value) {
#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 538 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    return __builtin_popcountll(Value);
#else
# 540 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
    uint64_t v = Value;
    v = v - ((v >> 1) & 0x5555555555555555ULL);
    v = (v & 0x3333333333333333ULL) + ((v >> 2) & 0x3333333333333333ULL);
    v = (v + (v >> 4)) & 0x0F0F0F0F0F0F0F0FULL;
    return unsigned((uint64_t)(v * 0x0101010101010101ULL) >> 56);
#endif
# 546 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  }
};
} // namespace detail

/// Count the number of set bits in a value.
/// Ex. countPopulation(0xF000F000) = 8
/// Returns 0 if the word is zero.
template <typename T>
inline unsigned countPopulation(T Value) {
  static_assert(std::numeric_limits<T>::is_integer &&
                    !std::numeric_limits<T>::is_signed,
                "Only unsigned integral types are allowed.");
  return detail::PopulationCounter<T, sizeof(T)>::count(Value);
}

/// Compile time Log2.
/// Valid only for positive powers of two.
template <size_t kValue> constexpr inline size_t CTLog2() {
  static_assert(kValue > 0 && llvm::isPowerOf2_64(kValue),
                "Value is not a valid power of 2");
  return 1 + CTLog2<kValue / 2>();
}

template <> constexpr inline size_t CTLog2<1>() { return 0; }

/// Return the log base 2 of the specified value.
inline double Log2(double Value) {
#if 0 /* disabled by -frewrite-includes */
#if defined(__ANDROID_API__) && __ANDROID_API__ < 18
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 574 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  return __builtin_log(Value) / __builtin_log(2.0);
#else
# 576 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  return log2(Value);
#endif
# 578 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
}

/// Return the floor log base 2 of the specified value, -1 if the value is zero.
/// (32 bit edition.)
/// Ex. Log2_32(32) == 5, Log2_32(1) == 0, Log2_32(0) == -1, Log2_32(6) == 2
inline unsigned Log2_32(uint32_t Value) {
  return 31 - countLeadingZeros(Value);
}

/// Return the floor log base 2 of the specified value, -1 if the value is zero.
/// (64 bit edition.)
inline unsigned Log2_64(uint64_t Value) {
  return 63 - countLeadingZeros(Value);
}

/// Return the ceil log base 2 of the specified value, 32 if the value is zero.
/// (32 bit edition).
/// Ex. Log2_32_Ceil(32) == 5, Log2_32_Ceil(1) == 0, Log2_32_Ceil(6) == 3
inline unsigned Log2_32_Ceil(uint32_t Value) {
  return 32 - countLeadingZeros(Value - 1);
}

/// Return the ceil log base 2 of the specified value, 64 if the value is zero.
/// (64 bit edition.)
inline unsigned Log2_64_Ceil(uint64_t Value) {
  return 64 - countLeadingZeros(Value - 1);
}

/// Return the greatest common divisor of the values using Euclid's algorithm.
template <typename T>
inline T greatestCommonDivisor(T A, T B) {
  while (B) {
    T Tmp = B;
    B = A % B;
    A = Tmp;
  }
  return A;
}

inline uint64_t GreatestCommonDivisor64(uint64_t A, uint64_t B) {
  return greatestCommonDivisor<uint64_t>(A, B);
}

/// This function takes a 64-bit integer and returns the bit equivalent double.
inline double BitsToDouble(uint64_t Bits) {
  double D;
  static_assert(sizeof(uint64_t) == sizeof(double), "Unexpected type sizes");
  memcpy(&D, &Bits, sizeof(Bits));
  return D;
}

/// This function takes a 32-bit integer and returns the bit equivalent float.
inline float BitsToFloat(uint32_t Bits) {
  float F;
  static_assert(sizeof(uint32_t) == sizeof(float), "Unexpected type sizes");
  memcpy(&F, &Bits, sizeof(Bits));
  return F;
}

/// This function takes a double and returns the bit equivalent 64-bit integer.
/// Note that copying doubles around changes the bits of NaNs on some hosts,
/// notably x86, so this routine cannot be used if these bits are needed.
inline uint64_t DoubleToBits(double Double) {
  uint64_t Bits;
  static_assert(sizeof(uint64_t) == sizeof(double), "Unexpected type sizes");
  memcpy(&Bits, &Double, sizeof(Double));
  return Bits;
}

/// This function takes a float and returns the bit equivalent 32-bit integer.
/// Note that copying floats around changes the bits of NaNs on some hosts,
/// notably x86, so this routine cannot be used if these bits are needed.
inline uint32_t FloatToBits(float Float) {
  uint32_t Bits;
  static_assert(sizeof(uint32_t) == sizeof(float), "Unexpected type sizes");
  memcpy(&Bits, &Float, sizeof(Float));
  return Bits;
}

/// A and B are either alignments or offsets. Return the minimum alignment that
/// may be assumed after adding the two together.
constexpr inline uint64_t MinAlign(uint64_t A, uint64_t B) {
  // The largest power of 2 that divides both A and B.
  //
  // Replace "-Value" by "1+~Value" in the following commented code to avoid
  // MSVC warning C4146
  //    return (A | B) & -(A | B);
  return (A | B) & (1 + ~(A | B));
}

/// Returns the next power of two (in 64-bits) that is strictly greater than A.
/// Returns zero on overflow.
inline uint64_t NextPowerOf2(uint64_t A) {
  A |= (A >> 1);
  A |= (A >> 2);
  A |= (A >> 4);
  A |= (A >> 8);
  A |= (A >> 16);
  A |= (A >> 32);
  return A + 1;
}

/// Returns the power of two which is less than or equal to the given value.
/// Essentially, it is a floor operation across the domain of powers of two.
inline uint64_t PowerOf2Floor(uint64_t A) {
  if (!A) return 0;
  return 1ull << (63 - countLeadingZeros(A, ZB_Undefined));
}

/// Returns the power of two which is greater than or equal to the given value.
/// Essentially, it is a ceil operation across the domain of powers of two.
inline uint64_t PowerOf2Ceil(uint64_t A) {
  if (!A)
    return 0;
  return NextPowerOf2(A - 1);
}

/// Returns the next integer (mod 2**64) that is greater than or equal to
/// \p Value and is a multiple of \p Align. \p Align must be non-zero.
///
/// If non-zero \p Skew is specified, the return value will be a minimal
/// integer that is greater than or equal to \p Value and equal to
/// \p Align * N + \p Skew for some integer N. If \p Skew is larger than
/// \p Align, its value is adjusted to '\p Skew mod \p Align'.
///
/// Examples:
/// \code
///   alignTo(5, 8) = 8
///   alignTo(17, 8) = 24
///   alignTo(~0LL, 8) = 0
///   alignTo(321, 255) = 510
///
///   alignTo(5, 8, 7) = 7
///   alignTo(17, 8, 1) = 17
///   alignTo(~0LL, 8, 3) = 3
///   alignTo(321, 255, 42) = 552
/// \endcode
inline uint64_t alignTo(uint64_t Value, uint64_t Align, uint64_t Skew = 0) {
  assert(Align != 0u && "Align can't be 0.");
  Skew %= Align;
  return (Value + Align - 1 - Skew) / Align * Align + Skew;
}

/// Returns the next integer (mod 2**64) that is greater than or equal to
/// \p Value and is a multiple of \c Align. \c Align must be non-zero.
template <uint64_t Align> constexpr inline uint64_t alignTo(uint64_t Value) {
  static_assert(Align != 0u, "Align must be non-zero");
  return (Value + Align - 1) / Align * Align;
}

/// Returns the integer ceil(Numerator / Denominator).
inline uint64_t divideCeil(uint64_t Numerator, uint64_t Denominator) {
  return alignTo(Numerator, Denominator) / Denominator;
}

/// Returns the integer nearest(Numerator / Denominator).
inline uint64_t divideNearest(uint64_t Numerator, uint64_t Denominator) {
  return (Numerator + (Denominator / 2)) / Denominator;
}

/// Returns the largest uint64_t less than or equal to \p Value and is
/// \p Skew mod \p Align. \p Align must be non-zero
inline uint64_t alignDown(uint64_t Value, uint64_t Align, uint64_t Skew = 0) {
  assert(Align != 0u && "Align can't be 0.");
  Skew %= Align;
  return (Value - Skew) / Align * Align + Skew;
}

/// Sign-extend the number in the bottom B bits of X to a 32-bit integer.
/// Requires 0 < B <= 32.
template <unsigned B> constexpr inline int32_t SignExtend32(uint32_t X) {
  static_assert(B > 0, "Bit width can't be 0.");
  static_assert(B <= 32, "Bit width out of range.");
  return int32_t(X << (32 - B)) >> (32 - B);
}

/// Sign-extend the number in the bottom B bits of X to a 32-bit integer.
/// Requires 0 < B < 32.
inline int32_t SignExtend32(uint32_t X, unsigned B) {
  assert(B > 0 && "Bit width can't be 0.");
  assert(B <= 32 && "Bit width out of range.");
  return int32_t(X << (32 - B)) >> (32 - B);
}

/// Sign-extend the number in the bottom B bits of X to a 64-bit integer.
/// Requires 0 < B < 64.
template <unsigned B> constexpr inline int64_t SignExtend64(uint64_t x) {
  static_assert(B > 0, "Bit width can't be 0.");
  static_assert(B <= 64, "Bit width out of range.");
  return int64_t(x << (64 - B)) >> (64 - B);
}

/// Sign-extend the number in the bottom B bits of X to a 64-bit integer.
/// Requires 0 < B < 64.
inline int64_t SignExtend64(uint64_t X, unsigned B) {
  assert(B > 0 && "Bit width can't be 0.");
  assert(B <= 64 && "Bit width out of range.");
  return int64_t(X << (64 - B)) >> (64 - B);
}

/// Subtract two unsigned integers, X and Y, of type T and return the absolute
/// value of the result.
template <typename T>
std::enable_if_t<std::is_unsigned<T>::value, T> AbsoluteDifference(T X, T Y) {
  return std::max(X, Y) - std::min(X, Y);
}

/// Add two unsigned integers, X and Y, of type T.  Clamp the result to the
/// maximum representable value of T on overflow.  ResultOverflowed indicates if
/// the result is larger than the maximum representable value of type T.
template <typename T>
std::enable_if_t<std::is_unsigned<T>::value, T>
SaturatingAdd(T X, T Y, bool *ResultOverflowed = nullptr) {
  bool Dummy;
  bool &Overflowed = ResultOverflowed ? *ResultOverflowed : Dummy;
  // Hacker's Delight, p. 29
  T Z = X + Y;
  Overflowed = (Z < X || Z < Y);
  if (Overflowed)
    return std::numeric_limits<T>::max();
  else
    return Z;
}

/// Multiply two unsigned integers, X and Y, of type T.  Clamp the result to the
/// maximum representable value of T on overflow.  ResultOverflowed indicates if
/// the result is larger than the maximum representable value of type T.
template <typename T>
std::enable_if_t<std::is_unsigned<T>::value, T>
SaturatingMultiply(T X, T Y, bool *ResultOverflowed = nullptr) {
  bool Dummy;
  bool &Overflowed = ResultOverflowed ? *ResultOverflowed : Dummy;

  // Hacker's Delight, p. 30 has a different algorithm, but we don't use that
  // because it fails for uint16_t (where multiplication can have undefined
  // behavior due to promotion to int), and requires a division in addition
  // to the multiplication.

  Overflowed = false;

  // Log2(Z) would be either Log2Z or Log2Z + 1.
  // Special case: if X or Y is 0, Log2_64 gives -1, and Log2Z
  // will necessarily be less than Log2Max as desired.
  int Log2Z = Log2_64(X) + Log2_64(Y);
  const T Max = std::numeric_limits<T>::max();
  int Log2Max = Log2_64(Max);
  if (Log2Z < Log2Max) {
    return X * Y;
  }
  if (Log2Z > Log2Max) {
    Overflowed = true;
    return Max;
  }

  // We're going to use the top bit, and maybe overflow one
  // bit past it. Multiply all but the bottom bit then add
  // that on at the end.
  T Z = (X >> 1) * Y;
  if (Z & ~(Max >> 1)) {
    Overflowed = true;
    return Max;
  }
  Z <<= 1;
  if (X & 1)
    return SaturatingAdd(Z, Y, ResultOverflowed);

  return Z;
}

/// Multiply two unsigned integers, X and Y, and add the unsigned integer, A to
/// the product. Clamp the result to the maximum representable value of T on
/// overflow. ResultOverflowed indicates if the result is larger than the
/// maximum representable value of type T.
template <typename T>
std::enable_if_t<std::is_unsigned<T>::value, T>
SaturatingMultiplyAdd(T X, T Y, T A, bool *ResultOverflowed = nullptr) {
  bool Dummy;
  bool &Overflowed = ResultOverflowed ? *ResultOverflowed : Dummy;

  T Product = SaturatingMultiply(X, Y, &Overflowed);
  if (Overflowed)
    return Product;

  return SaturatingAdd(A, Product, &Overflowed);
}

/// Use this rather than HUGE_VALF; the latter causes warnings on MSVC.
extern const float huge_valf;


/// Add two signed integers, computing the two's complement truncated result,
/// returning true if overflow occured.
template <typename T>
std::enable_if_t<std::is_signed<T>::value, T> AddOverflow(T X, T Y, T &Result) {
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_add_overflow)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 873 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  return __builtin_add_overflow(X, Y, &Result);
#else
# 875 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  // Perform the unsigned addition.
  using U = std::make_unsigned_t<T>;
  const U UX = static_cast<U>(X);
  const U UY = static_cast<U>(Y);
  const U UResult = UX + UY;

  // Convert to signed.
  Result = static_cast<T>(UResult);

  // Adding two positive numbers should result in a positive number.
  if (X > 0 && Y > 0)
    return Result <= 0;
  // Adding two negatives should result in a negative number.
  if (X < 0 && Y < 0)
    return Result >= 0;
  return false;
#endif
# 892 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
}

/// Subtract two signed integers, computing the two's complement truncated
/// result, returning true if an overflow ocurred.
template <typename T>
std::enable_if_t<std::is_signed<T>::value, T> SubOverflow(T X, T Y, T &Result) {
#if 0 /* disabled by -frewrite-includes */
#if __has_builtin(__builtin_sub_overflow)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 899 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  return __builtin_sub_overflow(X, Y, &Result);
#else
# 901 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
  // Perform the unsigned addition.
  using U = std::make_unsigned_t<T>;
  const U UX = static_cast<U>(X);
  const U UY = static_cast<U>(Y);
  const U UResult = UX - UY;

  // Convert to signed.
  Result = static_cast<T>(UResult);

  // Subtracting a positive number from a negative results in a negative number.
  if (X <= 0 && Y > 0)
    return Result >= 0;
  // Subtracting a negative number from a positive results in a positive number.
  if (X >= 0 && Y < 0)
    return Result <= 0;
  return false;
#endif
# 918 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
}

/// Multiply two signed integers, computing the two's complement truncated
/// result, returning true if an overflow ocurred.
template <typename T>
std::enable_if_t<std::is_signed<T>::value, T> MulOverflow(T X, T Y, T &Result) {
  // Perform the unsigned multiplication on absolute values.
  using U = std::make_unsigned_t<T>;
  const U UX = X < 0 ? (0 - static_cast<U>(X)) : static_cast<U>(X);
  const U UY = Y < 0 ? (0 - static_cast<U>(Y)) : static_cast<U>(Y);
  const U UResult = UX * UY;

  // Convert to signed.
  const bool IsNegative = (X < 0) ^ (Y < 0);
  Result = IsNegative ? (0 - UResult) : UResult;

  // If any of the args was 0, result is 0 and no overflow occurs.
  if (UX == 0 || UY == 0)
    return false;

  // UX and UY are in [1, 2^n], where n is the number of digits.
  // Check how the max allowed absolute value (2^n for negative, 2^(n-1) for
  // positive) divided by an argument compares to the other.
  if (IsNegative)
    return UX > (static_cast<U>(std::numeric_limits<T>::max()) + U(1)) / UY;
  else
    return UX > (static_cast<U>(std::numeric_limits<T>::max())) / UY;
}

} // End llvm namespace

#endif
# 950 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MathExtras.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MemAlloc.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemAlloc.h" 1
//===- MemAlloc.h - Memory allocation functions -----------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
/// \file
///
/// This file defines counterparts of C library allocation functions defined in
/// the namespace 'std'. The new allocation functions crash on allocation
/// failure instead of returning null pointer.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_MEMALLOC_H
#define LLVM_SUPPORT_MEMALLOC_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemAlloc.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemAlloc.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemAlloc.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemAlloc.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemAlloc.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemAlloc.h"

namespace llvm {

LLVM_ATTRIBUTE_RETURNS_NONNULL inline void *safe_malloc(size_t Sz) {
  void *Result = std::malloc(Sz);
  if (Result == nullptr) {
    // It is implementation-defined whether allocation occurs if the space
    // requested is zero (ISO/IEC 9899:2018 7.22.3). Retry, requesting
    // non-zero, if the space requested was zero.
    if (Sz == 0)
      return safe_malloc(1);
    report_bad_alloc_error("Allocation failed");
  }
  return Result;
}

LLVM_ATTRIBUTE_RETURNS_NONNULL inline void *safe_calloc(size_t Count,
                                                        size_t Sz) {
  void *Result = std::calloc(Count, Sz);
  if (Result == nullptr) {
    // It is implementation-defined whether allocation occurs if the space
    // requested is zero (ISO/IEC 9899:2018 7.22.3). Retry, requesting
    // non-zero, if the space requested was zero.
    if (Count == 0 || Sz == 0)
      return safe_malloc(1);
    report_bad_alloc_error("Allocation failed");
  }
  return Result;
}

LLVM_ATTRIBUTE_RETURNS_NONNULL inline void *safe_realloc(void *Ptr, size_t Sz) {
  void *Result = std::realloc(Ptr, Sz);
  if (Result == nullptr) {
    // It is implementation-defined whether allocation occurs if the space
    // requested is zero (ISO/IEC 9899:2018 7.22.3). Retry, requesting
    // non-zero, if the space requested was zero.
    if (Sz == 0)
      return safe_malloc(1);
    report_bad_alloc_error("Allocation failed");
  }
  return Result;
}

}
#endif
# 67 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemAlloc.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/type_traits.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"

namespace llvm {

/// This is all the non-templated stuff common to all SmallVectors.
class SmallVectorBase {
protected:
  void *BeginX;
  unsigned Size = 0, Capacity;

  SmallVectorBase() = delete;
  SmallVectorBase(void *FirstEl, size_t TotalCapacity)
      : BeginX(FirstEl), Capacity(TotalCapacity) {}

  /// This is an implementation of the grow() method which only works
  /// on POD-like data types and is out of line to reduce code duplication.
  void grow_pod(void *FirstEl, size_t MinCapacity, size_t TSize);

public:
  size_t size() const { return Size; }
  size_t capacity() const { return Capacity; }

  LLVM_NODISCARD bool empty() const { return !Size; }

  /// Set the array size to \p N, which the current array must have enough
  /// capacity for.
  ///
  /// This does not construct or destroy any elements in the vector.
  ///
  /// Clients can use this in conjunction with capacity() to write past the end
  /// of the buffer when they know that more elements are available, and only
  /// update the size later. This avoids the cost of value initializing elements
  /// which will only be overwritten.
  void set_size(size_t N) {
    assert(N <= capacity());
    Size = N;
  }
};

/// Figure out the offset of the first element.
template <class T, typename = void> struct SmallVectorAlignmentAndSize {
  AlignedCharArrayUnion<SmallVectorBase> Base;
  AlignedCharArrayUnion<T> FirstEl;
};

/// This is the part of SmallVectorTemplateBase which does not depend on whether
/// the type T is a POD. The extra dummy template argument is used by ArrayRef
/// to avoid unnecessarily requiring T to be complete.
template <typename T, typename = void>
class SmallVectorTemplateCommon : public SmallVectorBase {
  /// Find the address of the first element.  For this pointer math to be valid
  /// with small-size of 0 for T with lots of alignment, it's important that
  /// SmallVectorStorage is properly-aligned even for small-size of 0.
  void *getFirstEl() const {
    return const_cast<void *>(reinterpret_cast<const void *>(
        reinterpret_cast<const char *>(this) +
        offsetof(SmallVectorAlignmentAndSize<T>, FirstEl)));
  }
  // Space after 'FirstEl' is clobbered, do not add any instance vars after it.

protected:
  SmallVectorTemplateCommon(size_t Size)
      : SmallVectorBase(getFirstEl(), Size) {}

  void grow_pod(size_t MinCapacity, size_t TSize) {
    SmallVectorBase::grow_pod(getFirstEl(), MinCapacity, TSize);
  }

  /// Return true if this is a smallvector which has not had dynamic
  /// memory allocated for it.
  bool isSmall() const { return BeginX == getFirstEl(); }

  /// Put this vector in a state of being small.
  void resetToSmall() {
    BeginX = getFirstEl();
    Size = Capacity = 0; // FIXME: Setting Capacity to 0 is suspect.
  }

public:
  using size_type = size_t;
  using difference_type = ptrdiff_t;
  using value_type = T;
  using iterator = T *;
  using const_iterator = const T *;

  using const_reverse_iterator = std::reverse_iterator<const_iterator>;
  using reverse_iterator = std::reverse_iterator<iterator>;

  using reference = T &;
  using const_reference = const T &;
  using pointer = T *;
  using const_pointer = const T *;

  // forward iterator creation methods.
  iterator begin() { return (iterator)this->BeginX; }
  const_iterator begin() const { return (const_iterator)this->BeginX; }
  iterator end() { return begin() + size(); }
  const_iterator end() const { return begin() + size(); }

  // reverse iterator creation methods.
  reverse_iterator rbegin()            { return reverse_iterator(end()); }
  const_reverse_iterator rbegin() const{ return const_reverse_iterator(end()); }
  reverse_iterator rend()              { return reverse_iterator(begin()); }
  const_reverse_iterator rend() const { return const_reverse_iterator(begin());}

  size_type size_in_bytes() const { return size() * sizeof(T); }
  size_type max_size() const { return size_type(-1) / sizeof(T); }

  size_t capacity_in_bytes() const { return capacity() * sizeof(T); }

  /// Return a pointer to the vector's buffer, even if empty().
  pointer data() { return pointer(begin()); }
  /// Return a pointer to the vector's buffer, even if empty().
  const_pointer data() const { return const_pointer(begin()); }

  reference operator[](size_type idx) {
    assert(idx < size());
    return begin()[idx];
  }
  const_reference operator[](size_type idx) const {
    assert(idx < size());
    return begin()[idx];
  }

  reference front() {
    assert(!empty());
    return begin()[0];
  }
  const_reference front() const {
    assert(!empty());
    return begin()[0];
  }

  reference back() {
    assert(!empty());
    return end()[-1];
  }
  const_reference back() const {
    assert(!empty());
    return end()[-1];
  }
};

/// SmallVectorTemplateBase<TriviallyCopyable = false> - This is where we put method
/// implementations that are designed to work with non-POD-like T's.
template <typename T, bool = is_trivially_copyable<T>::value>
class SmallVectorTemplateBase : public SmallVectorTemplateCommon<T> {
protected:
  SmallVectorTemplateBase(size_t Size) : SmallVectorTemplateCommon<T>(Size) {}

  static void destroy_range(T *S, T *E) {
    while (S != E) {
      --E;
      E->~T();
    }
  }

  /// Move the range [I, E) into the uninitialized memory starting with "Dest",
  /// constructing elements as needed.
  template<typename It1, typename It2>
  static void uninitialized_move(It1 I, It1 E, It2 Dest) {
    std::uninitialized_copy(std::make_move_iterator(I),
                            std::make_move_iterator(E), Dest);
  }

  /// Copy the range [I, E) onto the uninitialized memory starting with "Dest",
  /// constructing elements as needed.
  template<typename It1, typename It2>
  static void uninitialized_copy(It1 I, It1 E, It2 Dest) {
    std::uninitialized_copy(I, E, Dest);
  }

  /// Grow the allocated memory (without initializing new elements), doubling
  /// the size of the allocated memory. Guarantees space for at least one more
  /// element, or MinSize more elements if specified.
  void grow(size_t MinSize = 0);

public:
  void push_back(const T &Elt) {
    if (LLVM_UNLIKELY(this->size() >= this->capacity()))
      this->grow();
    ::new ((void*) this->end()) T(Elt);
    this->set_size(this->size() + 1);
  }

  void push_back(T &&Elt) {
    if (LLVM_UNLIKELY(this->size() >= this->capacity()))
      this->grow();
    ::new ((void*) this->end()) T(::std::move(Elt));
    this->set_size(this->size() + 1);
  }

  void pop_back() {
    this->set_size(this->size() - 1);
    this->end()->~T();
  }
};

// Define this out-of-line to dissuade the C++ compiler from inlining it.
template <typename T, bool TriviallyCopyable>
void SmallVectorTemplateBase<T, TriviallyCopyable>::grow(size_t MinSize) {
  if (MinSize > UINT32_MAX)
    report_bad_alloc_error("SmallVector capacity overflow during allocation");

  // Always grow, even from zero.
  size_t NewCapacity = size_t(NextPowerOf2(this->capacity() + 2));
  NewCapacity = std::min(std::max(NewCapacity, MinSize), size_t(UINT32_MAX));
  T *NewElts = static_cast<T*>(llvm::safe_malloc(NewCapacity*sizeof(T)));

  // Move the elements over.
  this->uninitialized_move(this->begin(), this->end(), NewElts);

  // Destroy the original elements.
  destroy_range(this->begin(), this->end());

  // If this wasn't grown from the inline copy, deallocate the old space.
  if (!this->isSmall())
    free(this->begin());

  this->BeginX = NewElts;
  this->Capacity = NewCapacity;
}

/// SmallVectorTemplateBase<TriviallyCopyable = true> - This is where we put
/// method implementations that are designed to work with POD-like T's.
template <typename T>
class SmallVectorTemplateBase<T, true> : public SmallVectorTemplateCommon<T> {
protected:
  SmallVectorTemplateBase(size_t Size) : SmallVectorTemplateCommon<T>(Size) {}

  // No need to do a destroy loop for POD's.
  static void destroy_range(T *, T *) {}

  /// Move the range [I, E) onto the uninitialized memory
  /// starting with "Dest", constructing elements into it as needed.
  template<typename It1, typename It2>
  static void uninitialized_move(It1 I, It1 E, It2 Dest) {
    // Just do a copy.
    uninitialized_copy(I, E, Dest);
  }

  /// Copy the range [I, E) onto the uninitialized memory
  /// starting with "Dest", constructing elements into it as needed.
  template<typename It1, typename It2>
  static void uninitialized_copy(It1 I, It1 E, It2 Dest) {
    // Arbitrary iterator types; just use the basic implementation.
    std::uninitialized_copy(I, E, Dest);
  }

  /// Copy the range [I, E) onto the uninitialized memory
  /// starting with "Dest", constructing elements into it as needed.
  template <typename T1, typename T2>
  static void uninitialized_copy(
      T1 *I, T1 *E, T2 *Dest,
      std::enable_if_t<std::is_same<typename std::remove_const<T1>::type,
                                    T2>::value> * = nullptr) {
    // Use memcpy for PODs iterated by pointers (which includes SmallVector
    // iterators): std::uninitialized_copy optimizes to memmove, but we can
    // use memcpy here. Note that I and E are iterators and thus might be
    // invalid for memcpy if they are equal.
    if (I != E)
      memcpy(reinterpret_cast<void *>(Dest), I, (E - I) * sizeof(T));
  }

  /// Double the size of the allocated memory, guaranteeing space for at
  /// least one more element or MinSize if specified.
  void grow(size_t MinSize = 0) { this->grow_pod(MinSize, sizeof(T)); }

public:
  void push_back(const T &Elt) {
    if (LLVM_UNLIKELY(this->size() >= this->capacity()))
      this->grow();
    memcpy(reinterpret_cast<void *>(this->end()), &Elt, sizeof(T));
    this->set_size(this->size() + 1);
  }

  void pop_back() { this->set_size(this->size() - 1); }
};

/// This class consists of common code factored out of the SmallVector class to
/// reduce code duplication based on the SmallVector 'N' template parameter.
template <typename T>
class SmallVectorImpl : public SmallVectorTemplateBase<T> {
  using SuperClass = SmallVectorTemplateBase<T>;

public:
  using iterator = typename SuperClass::iterator;
  using const_iterator = typename SuperClass::const_iterator;
  using reference = typename SuperClass::reference;
  using size_type = typename SuperClass::size_type;

protected:
  // Default ctor - Initialize to empty.
  explicit SmallVectorImpl(unsigned N)
      : SmallVectorTemplateBase<T>(N) {}

public:
  SmallVectorImpl(const SmallVectorImpl &) = delete;

  ~SmallVectorImpl() {
    // Subclass has already destructed this vector's elements.
    // If this wasn't grown from the inline copy, deallocate the old space.
    if (!this->isSmall())
      free(this->begin());
  }

  void clear() {
    this->destroy_range(this->begin(), this->end());
    this->Size = 0;
  }

  void resize(size_type N) {
    if (N < this->size()) {
      this->destroy_range(this->begin()+N, this->end());
      this->set_size(N);
    } else if (N > this->size()) {
      if (this->capacity() < N)
        this->grow(N);
      for (auto I = this->end(), E = this->begin() + N; I != E; ++I)
        new (&*I) T();
      this->set_size(N);
    }
  }

  void resize(size_type N, const T &NV) {
    if (N < this->size()) {
      this->destroy_range(this->begin()+N, this->end());
      this->set_size(N);
    } else if (N > this->size()) {
      if (this->capacity() < N)
        this->grow(N);
      std::uninitialized_fill(this->end(), this->begin()+N, NV);
      this->set_size(N);
    }
  }

  void reserve(size_type N) {
    if (this->capacity() < N)
      this->grow(N);
  }

  LLVM_NODISCARD T pop_back_val() {
    T Result = ::std::move(this->back());
    this->pop_back();
    return Result;
  }

  void swap(SmallVectorImpl &RHS);

  /// Add the specified range to the end of the SmallVector.
  template <typename in_iter,
            typename = std::enable_if_t<std::is_convertible<
                typename std::iterator_traits<in_iter>::iterator_category,
                std::input_iterator_tag>::value>>
  void append(in_iter in_start, in_iter in_end) {
    size_type NumInputs = std::distance(in_start, in_end);
    if (NumInputs > this->capacity() - this->size())
      this->grow(this->size()+NumInputs);

    this->uninitialized_copy(in_start, in_end, this->end());
    this->set_size(this->size() + NumInputs);
  }

  /// Append \p NumInputs copies of \p Elt to the end.
  void append(size_type NumInputs, const T &Elt) {
    if (NumInputs > this->capacity() - this->size())
      this->grow(this->size()+NumInputs);

    std::uninitialized_fill_n(this->end(), NumInputs, Elt);
    this->set_size(this->size() + NumInputs);
  }

  void append(std::initializer_list<T> IL) {
    append(IL.begin(), IL.end());
  }

  // FIXME: Consider assigning over existing elements, rather than clearing &
  // re-initializing them - for all assign(...) variants.

  void assign(size_type NumElts, const T &Elt) {
    clear();
    if (this->capacity() < NumElts)
      this->grow(NumElts);
    this->set_size(NumElts);
    std::uninitialized_fill(this->begin(), this->end(), Elt);
  }

  template <typename in_iter,
            typename = std::enable_if_t<std::is_convertible<
                typename std::iterator_traits<in_iter>::iterator_category,
                std::input_iterator_tag>::value>>
  void assign(in_iter in_start, in_iter in_end) {
    clear();
    append(in_start, in_end);
  }

  void assign(std::initializer_list<T> IL) {
    clear();
    append(IL);
  }

  iterator erase(const_iterator CI) {
    // Just cast away constness because this is a non-const member function.
    iterator I = const_cast<iterator>(CI);

    assert(I >= this->begin() && "Iterator to erase is out of bounds.");
    assert(I < this->end() && "Erasing at past-the-end iterator.");

    iterator N = I;
    // Shift all elts down one.
    std::move(I+1, this->end(), I);
    // Drop the last elt.
    this->pop_back();
    return(N);
  }

  iterator erase(const_iterator CS, const_iterator CE) {
    // Just cast away constness because this is a non-const member function.
    iterator S = const_cast<iterator>(CS);
    iterator E = const_cast<iterator>(CE);

    assert(S >= this->begin() && "Range to erase is out of bounds.");
    assert(S <= E && "Trying to erase invalid range.");
    assert(E <= this->end() && "Trying to erase past the end.");

    iterator N = S;
    // Shift all elts down.
    iterator I = std::move(E, this->end(), S);
    // Drop the last elts.
    this->destroy_range(I, this->end());
    this->set_size(I - this->begin());
    return(N);
  }

  iterator insert(iterator I, T &&Elt) {
    if (I == this->end()) {  // Important special case for empty vector.
      this->push_back(::std::move(Elt));
      return this->end()-1;
    }

    assert(I >= this->begin() && "Insertion iterator is out of bounds.");
    assert(I <= this->end() && "Inserting past the end of the vector.");

    if (this->size() >= this->capacity()) {
      size_t EltNo = I-this->begin();
      this->grow();
      I = this->begin()+EltNo;
    }

    ::new ((void*) this->end()) T(::std::move(this->back()));
    // Push everything else over.
    std::move_backward(I, this->end()-1, this->end());
    this->set_size(this->size() + 1);

    // If we just moved the element we're inserting, be sure to update
    // the reference.
    T *EltPtr = &Elt;
    if (I <= EltPtr && EltPtr < this->end())
      ++EltPtr;

    *I = ::std::move(*EltPtr);
    return I;
  }

  iterator insert(iterator I, const T &Elt) {
    if (I == this->end()) {  // Important special case for empty vector.
      this->push_back(Elt);
      return this->end()-1;
    }

    assert(I >= this->begin() && "Insertion iterator is out of bounds.");
    assert(I <= this->end() && "Inserting past the end of the vector.");

    if (this->size() >= this->capacity()) {
      size_t EltNo = I-this->begin();
      this->grow();
      I = this->begin()+EltNo;
    }
    ::new ((void*) this->end()) T(std::move(this->back()));
    // Push everything else over.
    std::move_backward(I, this->end()-1, this->end());
    this->set_size(this->size() + 1);

    // If we just moved the element we're inserting, be sure to update
    // the reference.
    const T *EltPtr = &Elt;
    if (I <= EltPtr && EltPtr < this->end())
      ++EltPtr;

    *I = *EltPtr;
    return I;
  }

  iterator insert(iterator I, size_type NumToInsert, const T &Elt) {
    // Convert iterator to elt# to avoid invalidating iterator when we reserve()
    size_t InsertElt = I - this->begin();

    if (I == this->end()) {  // Important special case for empty vector.
      append(NumToInsert, Elt);
      return this->begin()+InsertElt;
    }

    assert(I >= this->begin() && "Insertion iterator is out of bounds.");
    assert(I <= this->end() && "Inserting past the end of the vector.");

    // Ensure there is enough space.
    reserve(this->size() + NumToInsert);

    // Uninvalidate the iterator.
    I = this->begin()+InsertElt;

    // If there are more elements between the insertion point and the end of the
    // range than there are being inserted, we can use a simple approach to
    // insertion.  Since we already reserved space, we know that this won't
    // reallocate the vector.
    if (size_t(this->end()-I) >= NumToInsert) {
      T *OldEnd = this->end();
      append(std::move_iterator<iterator>(this->end() - NumToInsert),
             std::move_iterator<iterator>(this->end()));

      // Copy the existing elements that get replaced.
      std::move_backward(I, OldEnd-NumToInsert, OldEnd);

      std::fill_n(I, NumToInsert, Elt);
      return I;
    }

    // Otherwise, we're inserting more elements than exist already, and we're
    // not inserting at the end.

    // Move over the elements that we're about to overwrite.
    T *OldEnd = this->end();
    this->set_size(this->size() + NumToInsert);
    size_t NumOverwritten = OldEnd-I;
    this->uninitialized_move(I, OldEnd, this->end()-NumOverwritten);

    // Replace the overwritten part.
    std::fill_n(I, NumOverwritten, Elt);

    // Insert the non-overwritten middle part.
    std::uninitialized_fill_n(OldEnd, NumToInsert-NumOverwritten, Elt);
    return I;
  }

  template <typename ItTy,
            typename = std::enable_if_t<std::is_convertible<
                typename std::iterator_traits<ItTy>::iterator_category,
                std::input_iterator_tag>::value>>
  iterator insert(iterator I, ItTy From, ItTy To) {
    // Convert iterator to elt# to avoid invalidating iterator when we reserve()
    size_t InsertElt = I - this->begin();

    if (I == this->end()) {  // Important special case for empty vector.
      append(From, To);
      return this->begin()+InsertElt;
    }

    assert(I >= this->begin() && "Insertion iterator is out of bounds.");
    assert(I <= this->end() && "Inserting past the end of the vector.");

    size_t NumToInsert = std::distance(From, To);

    // Ensure there is enough space.
    reserve(this->size() + NumToInsert);

    // Uninvalidate the iterator.
    I = this->begin()+InsertElt;

    // If there are more elements between the insertion point and the end of the
    // range than there are being inserted, we can use a simple approach to
    // insertion.  Since we already reserved space, we know that this won't
    // reallocate the vector.
    if (size_t(this->end()-I) >= NumToInsert) {
      T *OldEnd = this->end();
      append(std::move_iterator<iterator>(this->end() - NumToInsert),
             std::move_iterator<iterator>(this->end()));

      // Copy the existing elements that get replaced.
      std::move_backward(I, OldEnd-NumToInsert, OldEnd);

      std::copy(From, To, I);
      return I;
    }

    // Otherwise, we're inserting more elements than exist already, and we're
    // not inserting at the end.

    // Move over the elements that we're about to overwrite.
    T *OldEnd = this->end();
    this->set_size(this->size() + NumToInsert);
    size_t NumOverwritten = OldEnd-I;
    this->uninitialized_move(I, OldEnd, this->end()-NumOverwritten);

    // Replace the overwritten part.
    for (T *J = I; NumOverwritten > 0; --NumOverwritten) {
      *J = *From;
      ++J; ++From;
    }

    // Insert the non-overwritten middle part.
    this->uninitialized_copy(From, To, OldEnd);
    return I;
  }

  void insert(iterator I, std::initializer_list<T> IL) {
    insert(I, IL.begin(), IL.end());
  }

  template <typename... ArgTypes> reference emplace_back(ArgTypes &&... Args) {
    if (LLVM_UNLIKELY(this->size() >= this->capacity()))
      this->grow();
    ::new ((void *)this->end()) T(std::forward<ArgTypes>(Args)...);
    this->set_size(this->size() + 1);
    return this->back();
  }

  SmallVectorImpl &operator=(const SmallVectorImpl &RHS);

  SmallVectorImpl &operator=(SmallVectorImpl &&RHS);

  bool operator==(const SmallVectorImpl &RHS) const {
    if (this->size() != RHS.size()) return false;
    return std::equal(this->begin(), this->end(), RHS.begin());
  }
  bool operator!=(const SmallVectorImpl &RHS) const {
    return !(*this == RHS);
  }

  bool operator<(const SmallVectorImpl &RHS) const {
    return std::lexicographical_compare(this->begin(), this->end(),
                                        RHS.begin(), RHS.end());
  }
};

template <typename T>
void SmallVectorImpl<T>::swap(SmallVectorImpl<T> &RHS) {
  if (this == &RHS) return;

  // We can only avoid copying elements if neither vector is small.
  if (!this->isSmall() && !RHS.isSmall()) {
    std::swap(this->BeginX, RHS.BeginX);
    std::swap(this->Size, RHS.Size);
    std::swap(this->Capacity, RHS.Capacity);
    return;
  }
  if (RHS.size() > this->capacity())
    this->grow(RHS.size());
  if (this->size() > RHS.capacity())
    RHS.grow(this->size());

  // Swap the shared elements.
  size_t NumShared = this->size();
  if (NumShared > RHS.size()) NumShared = RHS.size();
  for (size_type i = 0; i != NumShared; ++i)
    std::swap((*this)[i], RHS[i]);

  // Copy over the extra elts.
  if (this->size() > RHS.size()) {
    size_t EltDiff = this->size() - RHS.size();
    this->uninitialized_copy(this->begin()+NumShared, this->end(), RHS.end());
    RHS.set_size(RHS.size() + EltDiff);
    this->destroy_range(this->begin()+NumShared, this->end());
    this->set_size(NumShared);
  } else if (RHS.size() > this->size()) {
    size_t EltDiff = RHS.size() - this->size();
    this->uninitialized_copy(RHS.begin()+NumShared, RHS.end(), this->end());
    this->set_size(this->size() + EltDiff);
    this->destroy_range(RHS.begin()+NumShared, RHS.end());
    RHS.set_size(NumShared);
  }
}

template <typename T>
SmallVectorImpl<T> &SmallVectorImpl<T>::
  operator=(const SmallVectorImpl<T> &RHS) {
  // Avoid self-assignment.
  if (this == &RHS) return *this;

  // If we already have sufficient space, assign the common elements, then
  // destroy any excess.
  size_t RHSSize = RHS.size();
  size_t CurSize = this->size();
  if (CurSize >= RHSSize) {
    // Assign common elements.
    iterator NewEnd;
    if (RHSSize)
      NewEnd = std::copy(RHS.begin(), RHS.begin()+RHSSize, this->begin());
    else
      NewEnd = this->begin();

    // Destroy excess elements.
    this->destroy_range(NewEnd, this->end());

    // Trim.
    this->set_size(RHSSize);
    return *this;
  }

  // If we have to grow to have enough elements, destroy the current elements.
  // This allows us to avoid copying them during the grow.
  // FIXME: don't do this if they're efficiently moveable.
  if (this->capacity() < RHSSize) {
    // Destroy current elements.
    this->destroy_range(this->begin(), this->end());
    this->set_size(0);
    CurSize = 0;
    this->grow(RHSSize);
  } else if (CurSize) {
    // Otherwise, use assignment for the already-constructed elements.
    std::copy(RHS.begin(), RHS.begin()+CurSize, this->begin());
  }

  // Copy construct the new elements in place.
  this->uninitialized_copy(RHS.begin()+CurSize, RHS.end(),
                           this->begin()+CurSize);

  // Set end.
  this->set_size(RHSSize);
  return *this;
}

template <typename T>
SmallVectorImpl<T> &SmallVectorImpl<T>::operator=(SmallVectorImpl<T> &&RHS) {
  // Avoid self-assignment.
  if (this == &RHS) return *this;

  // If the RHS isn't small, clear this vector and then steal its buffer.
  if (!RHS.isSmall()) {
    this->destroy_range(this->begin(), this->end());
    if (!this->isSmall()) free(this->begin());
    this->BeginX = RHS.BeginX;
    this->Size = RHS.Size;
    this->Capacity = RHS.Capacity;
    RHS.resetToSmall();
    return *this;
  }

  // If we already have sufficient space, assign the common elements, then
  // destroy any excess.
  size_t RHSSize = RHS.size();
  size_t CurSize = this->size();
  if (CurSize >= RHSSize) {
    // Assign common elements.
    iterator NewEnd = this->begin();
    if (RHSSize)
      NewEnd = std::move(RHS.begin(), RHS.end(), NewEnd);

    // Destroy excess elements and trim the bounds.
    this->destroy_range(NewEnd, this->end());
    this->set_size(RHSSize);

    // Clear the RHS.
    RHS.clear();

    return *this;
  }

  // If we have to grow to have enough elements, destroy the current elements.
  // This allows us to avoid copying them during the grow.
  // FIXME: this may not actually make any sense if we can efficiently move
  // elements.
  if (this->capacity() < RHSSize) {
    // Destroy current elements.
    this->destroy_range(this->begin(), this->end());
    this->set_size(0);
    CurSize = 0;
    this->grow(RHSSize);
  } else if (CurSize) {
    // Otherwise, use assignment for the already-constructed elements.
    std::move(RHS.begin(), RHS.begin()+CurSize, this->begin());
  }

  // Move-construct the new elements in place.
  this->uninitialized_move(RHS.begin()+CurSize, RHS.end(),
                           this->begin()+CurSize);

  // Set end.
  this->set_size(RHSSize);

  RHS.clear();
  return *this;
}

/// Storage for the SmallVector elements.  This is specialized for the N=0 case
/// to avoid allocating unnecessary storage.
template <typename T, unsigned N>
struct SmallVectorStorage {
  AlignedCharArrayUnion<T> InlineElts[N];
};

/// We need the storage to be properly aligned even for small-size of 0 so that
/// the pointer math in \a SmallVectorTemplateCommon::getFirstEl() is
/// well-defined.
template <typename T> struct alignas(alignof(T)) SmallVectorStorage<T, 0> {};

/// This is a 'vector' (really, a variable-sized array), optimized
/// for the case when the array is small.  It contains some number of elements
/// in-place, which allows it to avoid heap allocation when the actual number of
/// elements is below that threshold.  This allows normal "small" cases to be
/// fast without losing generality for large inputs.
///
/// Note that this does not attempt to be exception safe.
///
template <typename T, unsigned N>
class SmallVector : public SmallVectorImpl<T>, SmallVectorStorage<T, N> {
public:
  SmallVector() : SmallVectorImpl<T>(N) {}

  ~SmallVector() {
    // Destroy the constructed elements in the vector.
    this->destroy_range(this->begin(), this->end());
  }

  explicit SmallVector(size_t Size, const T &Value = T())
    : SmallVectorImpl<T>(N) {
    this->assign(Size, Value);
  }

  template <typename ItTy,
            typename = std::enable_if_t<std::is_convertible<
                typename std::iterator_traits<ItTy>::iterator_category,
                std::input_iterator_tag>::value>>
  SmallVector(ItTy S, ItTy E) : SmallVectorImpl<T>(N) {
    this->append(S, E);
  }

  template <typename RangeTy>
  explicit SmallVector(const iterator_range<RangeTy> &R)
      : SmallVectorImpl<T>(N) {
    this->append(R.begin(), R.end());
  }

  SmallVector(std::initializer_list<T> IL) : SmallVectorImpl<T>(N) {
    this->assign(IL);
  }

  SmallVector(const SmallVector &RHS) : SmallVectorImpl<T>(N) {
    if (!RHS.empty())
      SmallVectorImpl<T>::operator=(RHS);
  }

  const SmallVector &operator=(const SmallVector &RHS) {
    SmallVectorImpl<T>::operator=(RHS);
    return *this;
  }

  SmallVector(SmallVector &&RHS) : SmallVectorImpl<T>(N) {
    if (!RHS.empty())
      SmallVectorImpl<T>::operator=(::std::move(RHS));
  }

  SmallVector(SmallVectorImpl<T> &&RHS) : SmallVectorImpl<T>(N) {
    if (!RHS.empty())
      SmallVectorImpl<T>::operator=(::std::move(RHS));
  }

  const SmallVector &operator=(SmallVector &&RHS) {
    SmallVectorImpl<T>::operator=(::std::move(RHS));
    return *this;
  }

  const SmallVector &operator=(SmallVectorImpl<T> &&RHS) {
    SmallVectorImpl<T>::operator=(::std::move(RHS));
    return *this;
  }

  const SmallVector &operator=(std::initializer_list<T> IL) {
    this->assign(IL);
    return *this;
  }
};

template <typename T, unsigned N>
inline size_t capacity_in_bytes(const SmallVector<T, N> &X) {
  return X.capacity_in_bytes();
}

/// Given a range of type R, iterate the entire range and return a
/// SmallVector with elements of the vector.  This is useful, for example,
/// when you want to iterate a range and then sort the results.
template <unsigned Size, typename R>
SmallVector<typename std::remove_const<typename std::remove_reference<
                decltype(*std::begin(std::declval<R &>()))>::type>::type,
            Size>
to_vector(R &&Range) {
  return {std::begin(Range), std::end(Range)};
}

} // end namespace llvm

namespace std {

  /// Implement std::swap in terms of SmallVector swap.
  template<typename T>
  inline void
  swap(llvm::SmallVectorImpl<T> &LHS, llvm::SmallVectorImpl<T> &RHS) {
    LHS.swap(RHS);
  }

  /// Implement std::swap in terms of SmallVector swap.
  template<typename T, unsigned N>
  inline void
  swap(llvm::SmallVector<T, N> &LHS, llvm::SmallVector<T, N> &RHS) {
    LHS.swap(RHS);
  }

} // end namespace std

#endif // LLVM_ADT_SMALLVECTOR_H
# 942 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallVector.h"
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/STLExtras.h"
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <array>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 1 3
// -*- C++ -*-
//===---------------------------- array -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_ARRAY
#define _LIBCPP_ARRAY

/*
    array synopsis

namespace std
{
template <class T, size_t N >
struct array
{
    // types:
    typedef T & reference;
    typedef const T & const_reference;
    typedef implementation defined iterator;
    typedef implementation defined const_iterator;
    typedef size_t size_type;
    typedef ptrdiff_t difference_type;
    typedef T value_type;
    typedef T* pointer;
    typedef const T* const_pointer;
    typedef std::reverse_iterator<iterator> reverse_iterator;
    typedef std::reverse_iterator<const_iterator> const_reverse_iterator;

    // No explicit construct/copy/destroy for aggregate type
    void fill(const T& u);
    void swap(array& a) noexcept(is_nothrow_swappable_v<T>);

    // iterators:
    iterator begin() noexcept;
    const_iterator begin() const noexcept;
    iterator end() noexcept;
    const_iterator end() const noexcept;

    reverse_iterator rbegin() noexcept;
    const_reverse_iterator rbegin() const noexcept;
    reverse_iterator rend() noexcept;
    const_reverse_iterator rend() const noexcept;

    const_iterator cbegin() const noexcept;
    const_iterator cend() const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend() const noexcept;

    // capacity:
    constexpr size_type size() const noexcept;
    constexpr size_type max_size() const noexcept;
    constexpr bool empty() const noexcept;

    // element access:
    reference operator[](size_type n);
    const_reference operator[](size_type n) const; // constexpr in C++14
    const_reference at(size_type n) const; // constexpr in C++14
    reference at(size_type n);

    reference front();
    const_reference front() const; // constexpr in C++14
    reference back();
    const_reference back() const; // constexpr in C++14

    T* data() noexcept;
    const T* data() const noexcept;
};

  template <class T, class... U>
    array(T, U...) -> array<T, 1 + sizeof...(U)>;

template <class T, size_t N>
  bool operator==(const array<T,N>& x, const array<T,N>& y);
template <class T, size_t N>
  bool operator!=(const array<T,N>& x, const array<T,N>& y);
template <class T, size_t N>
  bool operator<(const array<T,N>& x, const array<T,N>& y);
template <class T, size_t N>
  bool operator>(const array<T,N>& x, const array<T,N>& y);
template <class T, size_t N>
  bool operator<=(const array<T,N>& x, const array<T,N>& y);
template <class T, size_t N>
  bool operator>=(const array<T,N>& x, const array<T,N>& y);

template <class T, size_t N >
  void swap(array<T,N>& x, array<T,N>& y) noexcept(noexcept(x.swap(y))); // C++17

template <class T> struct tuple_size;
template <size_t I, class T> struct tuple_element;
template <class T, size_t N> struct tuple_size<array<T, N>>;
template <size_t I, class T, size_t N> struct tuple_element<I, array<T, N>>;
template <size_t I, class T, size_t N> T& get(array<T, N>&) noexcept; // constexpr in C++14
template <size_t I, class T, size_t N> const T& get(const array<T, N>&) noexcept; // constexpr in C++14
template <size_t I, class T, size_t N> T&& get(array<T, N>&&) noexcept; // constexpr in C++14
template <size_t I, class T, size_t N> const T&& get(const array<T, N>&&) noexcept; // constexpr in C++14

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 106 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <__tuple>
#endif /* expanded by -frewrite-includes */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 110 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 111 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 113 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib> // for _LIBCPP_UNREACHABLE
#endif /* expanded by -frewrite-includes */
# 113 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 114 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 115 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 115 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 116 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
#endif
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3



_LIBCPP_BEGIN_NAMESPACE_STD


template <class _Tp, size_t _Size>
struct _LIBCPP_TEMPLATE_VIS array
{
    // types:
    typedef array __self;
    typedef _Tp                                   value_type;
    typedef value_type&                           reference;
    typedef const value_type&                     const_reference;
    typedef value_type*                           iterator;
    typedef const value_type*                     const_iterator;
    typedef value_type*                           pointer;
    typedef const value_type*                     const_pointer;
    typedef size_t                                size_type;
    typedef ptrdiff_t                             difference_type;
    typedef std::reverse_iterator<iterator>       reverse_iterator;
    typedef std::reverse_iterator<const_iterator> const_reverse_iterator;

    _Tp __elems_[_Size];

    // No explicit construct/copy/destroy for aggregate type
    _LIBCPP_INLINE_VISIBILITY void fill(const value_type& __u) {
      _VSTD::fill_n(__elems_, _Size, __u);
    }

    _LIBCPP_INLINE_VISIBILITY
    void swap(array& __a) _NOEXCEPT_(__is_nothrow_swappable<_Tp>::value) {
      std::swap_ranges(__elems_, __elems_ + _Size, __a.__elems_);
    }

    // iterators:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    iterator begin() _NOEXCEPT {return iterator(data());}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const_iterator begin() const _NOEXCEPT {return const_iterator(data());}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    iterator end() _NOEXCEPT {return iterator(data() + _Size);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const_iterator end() const _NOEXCEPT {return const_iterator(data() + _Size);}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator rbegin() _NOEXCEPT {return reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const_reverse_iterator rbegin() const _NOEXCEPT {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reverse_iterator rend() _NOEXCEPT {return reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const_reverse_iterator rend() const _NOEXCEPT {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const_iterator cbegin() const _NOEXCEPT {return begin();}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const_iterator cend() const _NOEXCEPT {return end();}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const_reverse_iterator crbegin() const _NOEXCEPT {return rbegin();}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const_reverse_iterator crend() const _NOEXCEPT {return rend();}

    // capacity:
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR size_type size() const _NOEXCEPT {return _Size;}
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR size_type max_size() const _NOEXCEPT {return _Size;}
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR bool empty() const _NOEXCEPT {return false; }

    // element access:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    reference operator[](size_type __n)             _NOEXCEPT {return __elems_[__n];}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const_reference operator[](size_type __n) const _NOEXCEPT {return __elems_[__n];}

    _LIBCPP_CONSTEXPR_AFTER_CXX14       reference at(size_type __n);
    _LIBCPP_CONSTEXPR_AFTER_CXX11 const_reference at(size_type __n) const;

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 reference front()             _NOEXCEPT {return __elems_[0];}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 const_reference front() const _NOEXCEPT {return __elems_[0];}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 reference back()              _NOEXCEPT {return __elems_[_Size - 1];}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 const_reference back() const  _NOEXCEPT {return __elems_[_Size - 1];}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    value_type* data() _NOEXCEPT {return __elems_;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14
    const value_type* data() const _NOEXCEPT {return __elems_;}
};


template <class _Tp, size_t _Size>
_LIBCPP_CONSTEXPR_AFTER_CXX14
typename array<_Tp, _Size>::reference
array<_Tp, _Size>::at(size_type __n)
{
    if (__n >= _Size)
        __throw_out_of_range("array::at");

    return __elems_[__n];
}

template <class _Tp, size_t _Size>
_LIBCPP_CONSTEXPR_AFTER_CXX11
typename array<_Tp, _Size>::const_reference
array<_Tp, _Size>::at(size_type __n) const
{
    if (__n >= _Size)
        __throw_out_of_range("array::at");
    return __elems_[__n];
}

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS array<_Tp, 0>
{
    // types:
    typedef array __self;
    typedef _Tp                                   value_type;
    typedef value_type&                           reference;
    typedef const value_type&                     const_reference;
    typedef value_type*                           iterator;
    typedef const value_type*                     const_iterator;
    typedef value_type*                           pointer;
    typedef const value_type*                     const_pointer;
    typedef size_t                                size_type;
    typedef ptrdiff_t                             difference_type;
    typedef std::reverse_iterator<iterator>       reverse_iterator;
    typedef std::reverse_iterator<const_iterator> const_reverse_iterator;

    typedef typename conditional<is_const<_Tp>::value, const char,
                                char>::type _CharType;

    struct  _ArrayInStructT { _Tp __data_[1]; };
    _ALIGNAS_TYPE(_ArrayInStructT) _CharType __elems_[sizeof(_ArrayInStructT)];

    // No explicit construct/copy/destroy for aggregate type
    _LIBCPP_INLINE_VISIBILITY void fill(const value_type&) {
      static_assert(!is_const<_Tp>::value,
                    "cannot fill zero-sized array of type 'const T'");
    }

    _LIBCPP_INLINE_VISIBILITY
    void swap(array&) _NOEXCEPT {
      static_assert(!is_const<_Tp>::value,
                    "cannot swap zero-sized array of type 'const T'");
    }

    // iterators:
    _LIBCPP_INLINE_VISIBILITY
    iterator begin() _NOEXCEPT {return iterator(data());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT {return const_iterator(data());}
    _LIBCPP_INLINE_VISIBILITY
    iterator end() _NOEXCEPT {return iterator(data());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT {return const_iterator(data());}

    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator rbegin() _NOEXCEPT {return reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin() const _NOEXCEPT {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator rend() _NOEXCEPT {return reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend() const _NOEXCEPT {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY
    const_iterator cbegin() const _NOEXCEPT {return begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator cend() const _NOEXCEPT {return end();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT {return rbegin();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend() const _NOEXCEPT {return rend();}

    // capacity:
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR size_type size() const _NOEXCEPT {return 0; }
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR size_type max_size() const _NOEXCEPT {return 0;}
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR bool empty() const _NOEXCEPT {return true;}

    // element access:
    _LIBCPP_INLINE_VISIBILITY
    reference operator[](size_type) _NOEXCEPT {
      _LIBCPP_ASSERT(false, "cannot call array<T, 0>::operator[] on a zero-sized array");
      _LIBCPP_UNREACHABLE();
    }

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const_reference operator[](size_type) const _NOEXCEPT {
      _LIBCPP_ASSERT(false, "cannot call array<T, 0>::operator[] on a zero-sized array");
      _LIBCPP_UNREACHABLE();
    }

    _LIBCPP_INLINE_VISIBILITY
    reference at(size_type) {
      __throw_out_of_range("array<T, 0>::at");
      _LIBCPP_UNREACHABLE();
    }

    _LIBCPP_INLINE_VISIBILITY
    const_reference at(size_type) const {
      __throw_out_of_range("array<T, 0>::at");
      _LIBCPP_UNREACHABLE();
    }

    _LIBCPP_INLINE_VISIBILITY
    reference front() _NOEXCEPT {
      _LIBCPP_ASSERT(false, "cannot call array<T, 0>::front() on a zero-sized array");
      _LIBCPP_UNREACHABLE();
    }

    _LIBCPP_INLINE_VISIBILITY
    const_reference front() const _NOEXCEPT {
      _LIBCPP_ASSERT(false, "cannot call array<T, 0>::front() on a zero-sized array");
      _LIBCPP_UNREACHABLE();
    }

    _LIBCPP_INLINE_VISIBILITY
    reference back() _NOEXCEPT {
      _LIBCPP_ASSERT(false, "cannot call array<T, 0>::back() on a zero-sized array");
      _LIBCPP_UNREACHABLE();
    }

    _LIBCPP_INLINE_VISIBILITY
    const_reference back() const _NOEXCEPT {
      _LIBCPP_ASSERT(false, "cannot call array<T, 0>::back() on a zero-sized array");
      _LIBCPP_UNREACHABLE();
    }

    _LIBCPP_INLINE_VISIBILITY
    value_type* data() _NOEXCEPT {return reinterpret_cast<value_type*>(__elems_);}
    _LIBCPP_INLINE_VISIBILITY
    const value_type* data() const _NOEXCEPT {return reinterpret_cast<const value_type*>(__elems_);}
};


#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _Tp, class... _Args,
         class = typename enable_if<(is_same_v<_Tp, _Args> && ...), void>::type
         >
array(_Tp, _Args...)
  -> array<_Tp, 1 + sizeof...(_Args)>;
#endif
# 367 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3

template <class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
operator==(const array<_Tp, _Size>& __x, const array<_Tp, _Size>& __y)
{
    return _VSTD::equal(__x.begin(), __x.end(), __y.begin());
}

template <class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
operator!=(const array<_Tp, _Size>& __x, const array<_Tp, _Size>& __y)
{
    return !(__x == __y);
}

template <class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
operator<(const array<_Tp, _Size>& __x, const array<_Tp, _Size>& __y)
{
    return _VSTD::lexicographical_compare(__x.begin(), __x.end(),
                                          __y.begin(), __y.end());
}

template <class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
operator>(const array<_Tp, _Size>& __x, const array<_Tp, _Size>& __y)
{
    return __y < __x;
}

template <class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
operator<=(const array<_Tp, _Size>& __x, const array<_Tp, _Size>& __y)
{
    return !(__y < __x);
}

template <class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX17 bool
operator>=(const array<_Tp, _Size>& __x, const array<_Tp, _Size>& __y)
{
    return !(__x < __y);
}

template <class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    _Size == 0 ||
    __is_swappable<_Tp>::value,
    void
>::type
swap(array<_Tp, _Size>& __x, array<_Tp, _Size>& __y)
                                  _NOEXCEPT_(noexcept(__x.swap(__y)))
{
    __x.swap(__y);
}

template <class _Tp, size_t _Size>
struct _LIBCPP_TEMPLATE_VIS tuple_size<array<_Tp, _Size> >
    : public integral_constant<size_t, _Size> {};

template <size_t _Ip, class _Tp, size_t _Size>
struct _LIBCPP_TEMPLATE_VIS tuple_element<_Ip, array<_Tp, _Size> >
{
    static_assert(_Ip < _Size, "Index out of bounds in std::tuple_element<> (std::array)");
    typedef _Tp type;
};

template <size_t _Ip, class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp&
get(array<_Tp, _Size>& __a) _NOEXCEPT
{
    static_assert(_Ip < _Size, "Index out of bounds in std::get<> (std::array)");
    return __a.__elems_[_Ip];
}

template <size_t _Ip, class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&
get(const array<_Tp, _Size>& __a) _NOEXCEPT
{
    static_assert(_Ip < _Size, "Index out of bounds in std::get<> (const std::array)");
    return __a.__elems_[_Ip];
}

#ifndef _LIBCPP_CXX03_LANG

template <size_t _Ip, class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp&&
get(array<_Tp, _Size>&& __a) _NOEXCEPT
{
    static_assert(_Ip < _Size, "Index out of bounds in std::get<> (std::array &&)");
    return _VSTD::move(__a.__elems_[_Ip]);
}

template <size_t _Ip, class _Tp, size_t _Size>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&&
get(const array<_Tp, _Size>&& __a) _NOEXCEPT
{
    static_assert(_Ip < _Size, "Index out of bounds in std::get<> (const std::array &&)");
    return _VSTD::move(__a.__elems_[_Ip]);
}

#endif  // !_LIBCPP_CXX03_LANG
# 481 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 483 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3

template <typename _Tp, size_t _Size, size_t... _Index>
_LIBCPP_INLINE_VISIBILITY constexpr array<remove_cv_t<_Tp>, _Size>
__to_array_lvalue_impl(_Tp (&__arr)[_Size], index_sequence<_Index...>) {
  return {{__arr[_Index]...}};
}

template <typename _Tp, size_t _Size, size_t... _Index>
_LIBCPP_INLINE_VISIBILITY constexpr array<remove_cv_t<_Tp>, _Size>
__to_array_rvalue_impl(_Tp(&&__arr)[_Size], index_sequence<_Index...>) {
  return {{_VSTD::move(__arr[_Index])...}};
}

template <typename _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY constexpr array<remove_cv_t<_Tp>, _Size>
to_array(_Tp (&__arr)[_Size]) noexcept(is_nothrow_constructible_v<_Tp, _Tp&>) {
  static_assert(
      !is_array_v<_Tp>,
      "[array.creation]/1: to_array does not accept multidimensional arrays.");
  static_assert(
      is_constructible_v<_Tp, _Tp&>,
      "[array.creation]/1: to_array requires copy constructible elements.");
  return __to_array_lvalue_impl(__arr, make_index_sequence<_Size>());
}

template <typename _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY constexpr array<remove_cv_t<_Tp>, _Size>
to_array(_Tp(&&__arr)[_Size]) noexcept(is_nothrow_move_constructible_v<_Tp>) {
  static_assert(
      !is_array_v<_Tp>,
      "[array.creation]/4: to_array does not accept multidimensional arrays.");
  static_assert(
      is_move_constructible_v<_Tp>,
      "[array.creation]/4: to_array requires move constructible elements.");
  return __to_array_rvalue_impl(_VSTD::move(__arr),
                                make_index_sequence<_Size>());
}

#endif // _LIBCPP_STD_VER > 17
# 522 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_ARRAY
# 526 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/array" 3
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"

namespace llvm {

  /// ArrayRef - Represent a constant reference to an array (0 or more elements
  /// consecutively in memory), i.e. a start pointer and a length.  It allows
  /// various APIs to take consecutive elements easily and conveniently.
  ///
  /// This class does not own the underlying data, it is expected to be used in
  /// situations where the data resides in some other buffer, whose lifetime
  /// extends past that of the ArrayRef. For this reason, it is not in general
  /// safe to store an ArrayRef.
  ///
  /// This is intended to be trivially copyable, so it should be passed by
  /// value.
  template<typename T>
  class LLVM_NODISCARD ArrayRef {
  public:
    using iterator = const T *;
    using const_iterator = const T *;
    using size_type = size_t;
    using reverse_iterator = std::reverse_iterator<iterator>;

  private:
    /// The start of the array, in an external buffer.
    const T *Data = nullptr;

    /// The number of elements.
    size_type Length = 0;

  public:
    /// @name Constructors
    /// @{

    /// Construct an empty ArrayRef.
    /*implicit*/ ArrayRef() = default;

    /// Construct an empty ArrayRef from None.
    /*implicit*/ ArrayRef(NoneType) {}

    /// Construct an ArrayRef from a single element.
    /*implicit*/ ArrayRef(const T &OneElt)
      : Data(&OneElt), Length(1) {}

    /// Construct an ArrayRef from a pointer and length.
    /*implicit*/ ArrayRef(const T *data, size_t length)
      : Data(data), Length(length) {}

    /// Construct an ArrayRef from a range.
    ArrayRef(const T *begin, const T *end)
      : Data(begin), Length(end - begin) {}

    /// Construct an ArrayRef from a SmallVector. This is templated in order to
    /// avoid instantiating SmallVectorTemplateCommon<T> whenever we
    /// copy-construct an ArrayRef.
    template<typename U>
    /*implicit*/ ArrayRef(const SmallVectorTemplateCommon<T, U> &Vec)
      : Data(Vec.data()), Length(Vec.size()) {
    }

    /// Construct an ArrayRef from a std::vector.
    template<typename A>
    /*implicit*/ ArrayRef(const std::vector<T, A> &Vec)
      : Data(Vec.data()), Length(Vec.size()) {}

    /// Construct an ArrayRef from a std::array
    template <size_t N>
    /*implicit*/ constexpr ArrayRef(const std::array<T, N> &Arr)
        : Data(Arr.data()), Length(N) {}

    /// Construct an ArrayRef from a C array.
    template <size_t N>
    /*implicit*/ constexpr ArrayRef(const T (&Arr)[N]) : Data(Arr), Length(N) {}

    /// Construct an ArrayRef from a std::initializer_list.
#if 0 /* disabled by -frewrite-includes */
#if LLVM_GNUC_PREREQ(9, 0, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 101 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
// Disable gcc's warning in this constructor as it generates an enormous amount
// of messages. Anyone using ArrayRef should already be aware of the fact that
// it does not do lifetime extension.
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Winit-list-lifetime"
#endif
# 107 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
    /*implicit*/ ArrayRef(const std::initializer_list<T> &Vec)
    : Data(Vec.begin() == Vec.end() ? (T*)nullptr : Vec.begin()),
      Length(Vec.size()) {}
#if 0 /* disabled by -frewrite-includes */
#if LLVM_GNUC_PREREQ(9, 0, 0)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 111 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
#pragma GCC diagnostic pop
#endif
# 113 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"

    /// Construct an ArrayRef<const T*> from ArrayRef<T*>. This uses SFINAE to
    /// ensure that only ArrayRefs of pointers can be converted.
    template <typename U>
    ArrayRef(const ArrayRef<U *> &A,
             std::enable_if_t<std::is_convertible<U *const *, T const *>::value>
                 * = nullptr)
        : Data(A.data()), Length(A.size()) {}

    /// Construct an ArrayRef<const T*> from a SmallVector<T*>. This is
    /// templated in order to avoid instantiating SmallVectorTemplateCommon<T>
    /// whenever we copy-construct an ArrayRef.
    template <typename U, typename DummyT>
    /*implicit*/ ArrayRef(
        const SmallVectorTemplateCommon<U *, DummyT> &Vec,
        std::enable_if_t<std::is_convertible<U *const *, T const *>::value> * =
            nullptr)
        : Data(Vec.data()), Length(Vec.size()) {}

    /// Construct an ArrayRef<const T*> from std::vector<T*>. This uses SFINAE
    /// to ensure that only vectors of pointers can be converted.
    template <typename U, typename A>
    ArrayRef(const std::vector<U *, A> &Vec,
             std::enable_if_t<std::is_convertible<U *const *, T const *>::value>
                 * = 0)
        : Data(Vec.data()), Length(Vec.size()) {}

    /// @}
    /// @name Simple Operations
    /// @{

    iterator begin() const { return Data; }
    iterator end() const { return Data + Length; }

    reverse_iterator rbegin() const { return reverse_iterator(end()); }
    reverse_iterator rend() const { return reverse_iterator(begin()); }

    /// empty - Check if the array is empty.
    bool empty() const { return Length == 0; }

    const T *data() const { return Data; }

    /// size - Get the array size.
    size_t size() const { return Length; }

    /// front - Get the first element.
    const T &front() const {
      assert(!empty());
      return Data[0];
    }

    /// back - Get the last element.
    const T &back() const {
      assert(!empty());
      return Data[Length-1];
    }

    // copy - Allocate copy in Allocator and return ArrayRef<T> to it.
    template <typename Allocator> ArrayRef<T> copy(Allocator &A) {
      T *Buff = A.template Allocate<T>(Length);
      std::uninitialized_copy(begin(), end(), Buff);
      return ArrayRef<T>(Buff, Length);
    }

    /// equals - Check for element-wise equality.
    bool equals(ArrayRef RHS) const {
      if (Length != RHS.Length)
        return false;
      return std::equal(begin(), end(), RHS.begin());
    }

    /// slice(n, m) - Chop off the first N elements of the array, and keep M
    /// elements in the array.
    ArrayRef<T> slice(size_t N, size_t M) const {
      assert(N+M <= size() && "Invalid specifier");
      return ArrayRef<T>(data()+N, M);
    }

    /// slice(n) - Chop off the first N elements of the array.
    ArrayRef<T> slice(size_t N) const { return slice(N, size() - N); }

    /// Drop the first \p N elements of the array.
    ArrayRef<T> drop_front(size_t N = 1) const {
      assert(size() >= N && "Dropping more elements than exist");
      return slice(N, size() - N);
    }

    /// Drop the last \p N elements of the array.
    ArrayRef<T> drop_back(size_t N = 1) const {
      assert(size() >= N && "Dropping more elements than exist");
      return slice(0, size() - N);
    }

    /// Return a copy of *this with the first N elements satisfying the
    /// given predicate removed.
    template <class PredicateT> ArrayRef<T> drop_while(PredicateT Pred) const {
      return ArrayRef<T>(find_if_not(*this, Pred), end());
    }

    /// Return a copy of *this with the first N elements not satisfying
    /// the given predicate removed.
    template <class PredicateT> ArrayRef<T> drop_until(PredicateT Pred) const {
      return ArrayRef<T>(find_if(*this, Pred), end());
    }

    /// Return a copy of *this with only the first \p N elements.
    ArrayRef<T> take_front(size_t N = 1) const {
      if (N >= size())
        return *this;
      return drop_back(size() - N);
    }

    /// Return a copy of *this with only the last \p N elements.
    ArrayRef<T> take_back(size_t N = 1) const {
      if (N >= size())
        return *this;
      return drop_front(size() - N);
    }

    /// Return the first N elements of this Array that satisfy the given
    /// predicate.
    template <class PredicateT> ArrayRef<T> take_while(PredicateT Pred) const {
      return ArrayRef<T>(begin(), find_if_not(*this, Pred));
    }

    /// Return the first N elements of this Array that don't satisfy the
    /// given predicate.
    template <class PredicateT> ArrayRef<T> take_until(PredicateT Pred) const {
      return ArrayRef<T>(begin(), find_if(*this, Pred));
    }

    /// @}
    /// @name Operator Overloads
    /// @{
    const T &operator[](size_t Index) const {
      assert(Index < Length && "Invalid index!");
      return Data[Index];
    }

    /// Disallow accidental assignment from a temporary.
    ///
    /// The declaration here is extra complicated so that "arrayRef = {}"
    /// continues to select the move assignment operator.
    template <typename U>
    std::enable_if_t<std::is_same<U, T>::value, ArrayRef<T>> &
    operator=(U &&Temporary) = delete;

    /// Disallow accidental assignment from a temporary.
    ///
    /// The declaration here is extra complicated so that "arrayRef = {}"
    /// continues to select the move assignment operator.
    template <typename U>
    std::enable_if_t<std::is_same<U, T>::value, ArrayRef<T>> &
    operator=(std::initializer_list<U>) = delete;

    /// @}
    /// @name Expensive Operations
    /// @{
    std::vector<T> vec() const {
      return std::vector<T>(Data, Data+Length);
    }

    /// @}
    /// @name Conversion operators
    /// @{
    operator std::vector<T>() const {
      return std::vector<T>(Data, Data+Length);
    }

    /// @}
  };

  /// MutableArrayRef - Represent a mutable reference to an array (0 or more
  /// elements consecutively in memory), i.e. a start pointer and a length.  It
  /// allows various APIs to take and modify consecutive elements easily and
  /// conveniently.
  ///
  /// This class does not own the underlying data, it is expected to be used in
  /// situations where the data resides in some other buffer, whose lifetime
  /// extends past that of the MutableArrayRef. For this reason, it is not in
  /// general safe to store a MutableArrayRef.
  ///
  /// This is intended to be trivially copyable, so it should be passed by
  /// value.
  template<typename T>
  class LLVM_NODISCARD MutableArrayRef : public ArrayRef<T> {
  public:
    using iterator = T *;
    using reverse_iterator = std::reverse_iterator<iterator>;

    /// Construct an empty MutableArrayRef.
    /*implicit*/ MutableArrayRef() = default;

    /// Construct an empty MutableArrayRef from None.
    /*implicit*/ MutableArrayRef(NoneType) : ArrayRef<T>() {}

    /// Construct a MutableArrayRef from a single element.
    /*implicit*/ MutableArrayRef(T &OneElt) : ArrayRef<T>(OneElt) {}

    /// Construct a MutableArrayRef from a pointer and length.
    /*implicit*/ MutableArrayRef(T *data, size_t length)
      : ArrayRef<T>(data, length) {}

    /// Construct a MutableArrayRef from a range.
    MutableArrayRef(T *begin, T *end) : ArrayRef<T>(begin, end) {}

    /// Construct a MutableArrayRef from a SmallVector.
    /*implicit*/ MutableArrayRef(SmallVectorImpl<T> &Vec)
    : ArrayRef<T>(Vec) {}

    /// Construct a MutableArrayRef from a std::vector.
    /*implicit*/ MutableArrayRef(std::vector<T> &Vec)
    : ArrayRef<T>(Vec) {}

    /// Construct a MutableArrayRef from a std::array
    template <size_t N>
    /*implicit*/ constexpr MutableArrayRef(std::array<T, N> &Arr)
        : ArrayRef<T>(Arr) {}

    /// Construct a MutableArrayRef from a C array.
    template <size_t N>
    /*implicit*/ constexpr MutableArrayRef(T (&Arr)[N]) : ArrayRef<T>(Arr) {}

    T *data() const { return const_cast<T*>(ArrayRef<T>::data()); }

    iterator begin() const { return data(); }
    iterator end() const { return data() + this->size(); }

    reverse_iterator rbegin() const { return reverse_iterator(end()); }
    reverse_iterator rend() const { return reverse_iterator(begin()); }

    /// front - Get the first element.
    T &front() const {
      assert(!this->empty());
      return data()[0];
    }

    /// back - Get the last element.
    T &back() const {
      assert(!this->empty());
      return data()[this->size()-1];
    }

    /// slice(n, m) - Chop off the first N elements of the array, and keep M
    /// elements in the array.
    MutableArrayRef<T> slice(size_t N, size_t M) const {
      assert(N + M <= this->size() && "Invalid specifier");
      return MutableArrayRef<T>(this->data() + N, M);
    }

    /// slice(n) - Chop off the first N elements of the array.
    MutableArrayRef<T> slice(size_t N) const {
      return slice(N, this->size() - N);
    }

    /// Drop the first \p N elements of the array.
    MutableArrayRef<T> drop_front(size_t N = 1) const {
      assert(this->size() >= N && "Dropping more elements than exist");
      return slice(N, this->size() - N);
    }

    MutableArrayRef<T> drop_back(size_t N = 1) const {
      assert(this->size() >= N && "Dropping more elements than exist");
      return slice(0, this->size() - N);
    }

    /// Return a copy of *this with the first N elements satisfying the
    /// given predicate removed.
    template <class PredicateT>
    MutableArrayRef<T> drop_while(PredicateT Pred) const {
      return MutableArrayRef<T>(find_if_not(*this, Pred), end());
    }

    /// Return a copy of *this with the first N elements not satisfying
    /// the given predicate removed.
    template <class PredicateT>
    MutableArrayRef<T> drop_until(PredicateT Pred) const {
      return MutableArrayRef<T>(find_if(*this, Pred), end());
    }

    /// Return a copy of *this with only the first \p N elements.
    MutableArrayRef<T> take_front(size_t N = 1) const {
      if (N >= this->size())
        return *this;
      return drop_back(this->size() - N);
    }

    /// Return a copy of *this with only the last \p N elements.
    MutableArrayRef<T> take_back(size_t N = 1) const {
      if (N >= this->size())
        return *this;
      return drop_front(this->size() - N);
    }

    /// Return the first N elements of this Array that satisfy the given
    /// predicate.
    template <class PredicateT>
    MutableArrayRef<T> take_while(PredicateT Pred) const {
      return MutableArrayRef<T>(begin(), find_if_not(*this, Pred));
    }

    /// Return the first N elements of this Array that don't satisfy the
    /// given predicate.
    template <class PredicateT>
    MutableArrayRef<T> take_until(PredicateT Pred) const {
      return MutableArrayRef<T>(begin(), find_if(*this, Pred));
    }

    /// @}
    /// @name Operator Overloads
    /// @{
    T &operator[](size_t Index) const {
      assert(Index < this->size() && "Invalid index!");
      return data()[Index];
    }
  };

  /// This is a MutableArrayRef that owns its array.
  template <typename T> class OwningArrayRef : public MutableArrayRef<T> {
  public:
    OwningArrayRef() = default;
    OwningArrayRef(size_t Size) : MutableArrayRef<T>(new T[Size], Size) {}

    OwningArrayRef(ArrayRef<T> Data)
        : MutableArrayRef<T>(new T[Data.size()], Data.size()) {
      std::copy(Data.begin(), Data.end(), this->begin());
    }

    OwningArrayRef(OwningArrayRef &&Other) { *this = std::move(Other); }

    OwningArrayRef &operator=(OwningArrayRef &&Other) {
      delete[] this->data();
      this->MutableArrayRef<T>::operator=(Other);
      Other.MutableArrayRef<T>::operator=(MutableArrayRef<T>());
      return *this;
    }

    ~OwningArrayRef() { delete[] this->data(); }
  };

  /// @name ArrayRef Convenience constructors
  /// @{

  /// Construct an ArrayRef from a single element.
  template<typename T>
  ArrayRef<T> makeArrayRef(const T &OneElt) {
    return OneElt;
  }

  /// Construct an ArrayRef from a pointer and length.
  template<typename T>
  ArrayRef<T> makeArrayRef(const T *data, size_t length) {
    return ArrayRef<T>(data, length);
  }

  /// Construct an ArrayRef from a range.
  template<typename T>
  ArrayRef<T> makeArrayRef(const T *begin, const T *end) {
    return ArrayRef<T>(begin, end);
  }

  /// Construct an ArrayRef from a SmallVector.
  template <typename T>
  ArrayRef<T> makeArrayRef(const SmallVectorImpl<T> &Vec) {
    return Vec;
  }

  /// Construct an ArrayRef from a SmallVector.
  template <typename T, unsigned N>
  ArrayRef<T> makeArrayRef(const SmallVector<T, N> &Vec) {
    return Vec;
  }

  /// Construct an ArrayRef from a std::vector.
  template<typename T>
  ArrayRef<T> makeArrayRef(const std::vector<T> &Vec) {
    return Vec;
  }

  /// Construct an ArrayRef from a std::array.
  template <typename T, std::size_t N>
  ArrayRef<T> makeArrayRef(const std::array<T, N> &Arr) {
    return Arr;
  }

  /// Construct an ArrayRef from an ArrayRef (no-op) (const)
  template <typename T> ArrayRef<T> makeArrayRef(const ArrayRef<T> &Vec) {
    return Vec;
  }

  /// Construct an ArrayRef from an ArrayRef (no-op)
  template <typename T> ArrayRef<T> &makeArrayRef(ArrayRef<T> &Vec) {
    return Vec;
  }

  /// Construct an ArrayRef from a C array.
  template<typename T, size_t N>
  ArrayRef<T> makeArrayRef(const T (&Arr)[N]) {
    return ArrayRef<T>(Arr);
  }

  /// Construct a MutableArrayRef from a single element.
  template<typename T>
  MutableArrayRef<T> makeMutableArrayRef(T &OneElt) {
    return OneElt;
  }

  /// Construct a MutableArrayRef from a pointer and length.
  template<typename T>
  MutableArrayRef<T> makeMutableArrayRef(T *data, size_t length) {
    return MutableArrayRef<T>(data, length);
  }

  /// @}
  /// @name ArrayRef Comparison Operators
  /// @{

  template<typename T>
  inline bool operator==(ArrayRef<T> LHS, ArrayRef<T> RHS) {
    return LHS.equals(RHS);
  }

  template<typename T>
  inline bool operator!=(ArrayRef<T> LHS, ArrayRef<T> RHS) {
    return !(LHS == RHS);
  }

  /// @}

  template <typename T> hash_code hash_value(ArrayRef<T> S) {
    return hash_combine_range(S.begin(), S.end());
  }

} // end namespace llvm

#endif // LLVM_ADT_ARRAYREF_H
# 549 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/ArrayRef.h"
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMap.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h" 1
//===- llvm/ADT/DenseMap.h - Dense probed hash table ------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the DenseMap class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_DENSEMAP_H
#define LLVM_ADT_DENSEMAP_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMapInfo.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h" 1
//===- llvm/ADT/DenseMapInfo.h - Type traits for DenseMap -------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines DenseMapInfo traits for DenseMap.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_DENSEMAPINFO_H
#define LLVM_ADT_DENSEMAPINFO_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/ArrayRef.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Hashing.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/PointerLikeTypeTraits.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"

namespace llvm {

template<typename T>
struct DenseMapInfo {
  //static inline T getEmptyKey();
  //static inline T getTombstoneKey();
  //static unsigned getHashValue(const T &Val);
  //static bool isEqual(const T &LHS, const T &RHS);
};

// Provide DenseMapInfo for all pointers.
template<typename T>
struct DenseMapInfo<T*> {
  static inline T* getEmptyKey() {
    uintptr_t Val = static_cast<uintptr_t>(-1);
    Val <<= PointerLikeTypeTraits<T*>::NumLowBitsAvailable;
    return reinterpret_cast<T*>(Val);
  }

  static inline T* getTombstoneKey() {
    uintptr_t Val = static_cast<uintptr_t>(-2);
    Val <<= PointerLikeTypeTraits<T*>::NumLowBitsAvailable;
    return reinterpret_cast<T*>(Val);
  }

  static unsigned getHashValue(const T *PtrVal) {
    return (unsigned((uintptr_t)PtrVal) >> 4) ^
           (unsigned((uintptr_t)PtrVal) >> 9);
  }

  static bool isEqual(const T *LHS, const T *RHS) { return LHS == RHS; }
};

// Provide DenseMapInfo for chars.
template<> struct DenseMapInfo<char> {
  static inline char getEmptyKey() { return ~0; }
  static inline char getTombstoneKey() { return ~0 - 1; }
  static unsigned getHashValue(const char& Val) { return Val * 37U; }

  static bool isEqual(const char &LHS, const char &RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for unsigned chars.
template <> struct DenseMapInfo<unsigned char> {
  static inline unsigned char getEmptyKey() { return ~0; }
  static inline unsigned char getTombstoneKey() { return ~0 - 1; }
  static unsigned getHashValue(const unsigned char &Val) { return Val * 37U; }

  static bool isEqual(const unsigned char &LHS, const unsigned char &RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for unsigned shorts.
template <> struct DenseMapInfo<unsigned short> {
  static inline unsigned short getEmptyKey() { return 0xFFFF; }
  static inline unsigned short getTombstoneKey() { return 0xFFFF - 1; }
  static unsigned getHashValue(const unsigned short &Val) { return Val * 37U; }

  static bool isEqual(const unsigned short &LHS, const unsigned short &RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for unsigned ints.
template<> struct DenseMapInfo<unsigned> {
  static inline unsigned getEmptyKey() { return ~0U; }
  static inline unsigned getTombstoneKey() { return ~0U - 1; }
  static unsigned getHashValue(const unsigned& Val) { return Val * 37U; }

  static bool isEqual(const unsigned& LHS, const unsigned& RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for unsigned longs.
template<> struct DenseMapInfo<unsigned long> {
  static inline unsigned long getEmptyKey() { return ~0UL; }
  static inline unsigned long getTombstoneKey() { return ~0UL - 1L; }

  static unsigned getHashValue(const unsigned long& Val) {
    return (unsigned)(Val * 37UL);
  }

  static bool isEqual(const unsigned long& LHS, const unsigned long& RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for unsigned long longs.
template<> struct DenseMapInfo<unsigned long long> {
  static inline unsigned long long getEmptyKey() { return ~0ULL; }
  static inline unsigned long long getTombstoneKey() { return ~0ULL - 1ULL; }

  static unsigned getHashValue(const unsigned long long& Val) {
    return (unsigned)(Val * 37ULL);
  }

  static bool isEqual(const unsigned long long& LHS,
                      const unsigned long long& RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for shorts.
template <> struct DenseMapInfo<short> {
  static inline short getEmptyKey() { return 0x7FFF; }
  static inline short getTombstoneKey() { return -0x7FFF - 1; }
  static unsigned getHashValue(const short &Val) { return Val * 37U; }
  static bool isEqual(const short &LHS, const short &RHS) { return LHS == RHS; }
};

// Provide DenseMapInfo for ints.
template<> struct DenseMapInfo<int> {
  static inline int getEmptyKey() { return 0x7fffffff; }
  static inline int getTombstoneKey() { return -0x7fffffff - 1; }
  static unsigned getHashValue(const int& Val) { return (unsigned)(Val * 37U); }

  static bool isEqual(const int& LHS, const int& RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for longs.
template<> struct DenseMapInfo<long> {
  static inline long getEmptyKey() {
    return (1UL << (sizeof(long) * 8 - 1)) - 1UL;
  }

  static inline long getTombstoneKey() { return getEmptyKey() - 1L; }

  static unsigned getHashValue(const long& Val) {
    return (unsigned)(Val * 37UL);
  }

  static bool isEqual(const long& LHS, const long& RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for long longs.
template<> struct DenseMapInfo<long long> {
  static inline long long getEmptyKey() { return 0x7fffffffffffffffLL; }
  static inline long long getTombstoneKey() { return -0x7fffffffffffffffLL-1; }

  static unsigned getHashValue(const long long& Val) {
    return (unsigned)(Val * 37ULL);
  }

  static bool isEqual(const long long& LHS,
                      const long long& RHS) {
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for all pairs whose members have info.
template<typename T, typename U>
struct DenseMapInfo<std::pair<T, U>> {
  using Pair = std::pair<T, U>;
  using FirstInfo = DenseMapInfo<T>;
  using SecondInfo = DenseMapInfo<U>;

  static inline Pair getEmptyKey() {
    return std::make_pair(FirstInfo::getEmptyKey(),
                          SecondInfo::getEmptyKey());
  }

  static inline Pair getTombstoneKey() {
    return std::make_pair(FirstInfo::getTombstoneKey(),
                          SecondInfo::getTombstoneKey());
  }

  static unsigned getHashValue(const Pair& PairVal) {
    uint64_t key = (uint64_t)FirstInfo::getHashValue(PairVal.first) << 32
          | (uint64_t)SecondInfo::getHashValue(PairVal.second);
    key += ~(key << 32);
    key ^= (key >> 22);
    key += ~(key << 13);
    key ^= (key >> 8);
    key += (key << 3);
    key ^= (key >> 15);
    key += ~(key << 27);
    key ^= (key >> 31);
    return (unsigned)key;
  }

  static bool isEqual(const Pair &LHS, const Pair &RHS) {
    return FirstInfo::isEqual(LHS.first, RHS.first) &&
           SecondInfo::isEqual(LHS.second, RHS.second);
  }
};

// Provide DenseMapInfo for StringRefs.
template <> struct DenseMapInfo<StringRef> {
  static inline StringRef getEmptyKey() {
    return StringRef(reinterpret_cast<const char *>(~static_cast<uintptr_t>(0)),
                     0);
  }

  static inline StringRef getTombstoneKey() {
    return StringRef(reinterpret_cast<const char *>(~static_cast<uintptr_t>(1)),
                     0);
  }

  static unsigned getHashValue(StringRef Val) {
    assert(Val.data() != getEmptyKey().data() && "Cannot hash the empty key!");
    assert(Val.data() != getTombstoneKey().data() &&
           "Cannot hash the tombstone key!");
    return (unsigned)(hash_value(Val));
  }

  static bool isEqual(StringRef LHS, StringRef RHS) {
    if (RHS.data() == getEmptyKey().data())
      return LHS.data() == getEmptyKey().data();
    if (RHS.data() == getTombstoneKey().data())
      return LHS.data() == getTombstoneKey().data();
    return LHS == RHS;
  }
};

// Provide DenseMapInfo for ArrayRefs.
template <typename T> struct DenseMapInfo<ArrayRef<T>> {
  static inline ArrayRef<T> getEmptyKey() {
    return ArrayRef<T>(reinterpret_cast<const T *>(~static_cast<uintptr_t>(0)),
                       size_t(0));
  }

  static inline ArrayRef<T> getTombstoneKey() {
    return ArrayRef<T>(reinterpret_cast<const T *>(~static_cast<uintptr_t>(1)),
                       size_t(0));
  }

  static unsigned getHashValue(ArrayRef<T> Val) {
    assert(Val.data() != getEmptyKey().data() && "Cannot hash the empty key!");
    assert(Val.data() != getTombstoneKey().data() &&
           "Cannot hash the tombstone key!");
    return (unsigned)(hash_value(Val));
  }

  static bool isEqual(ArrayRef<T> LHS, ArrayRef<T> RHS) {
    if (RHS.data() == getEmptyKey().data())
      return LHS.data() == getEmptyKey().data();
    if (RHS.data() == getTombstoneKey().data())
      return LHS.data() == getTombstoneKey().data();
    return LHS == RHS;
  }
};

template <> struct DenseMapInfo<hash_code> {
  static inline hash_code getEmptyKey() { return hash_code(-1); }
  static inline hash_code getTombstoneKey() { return hash_code(-2); }
  static unsigned getHashValue(hash_code val) { return val; }
  static bool isEqual(hash_code LHS, hash_code RHS) { return LHS == RHS; }
};

} // end namespace llvm

#endif // LLVM_ADT_DENSEMAPINFO_H
# 285 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMapInfo.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/EpochTracker.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h" 1
//===- llvm/ADT/EpochTracker.h - ADT epoch tracking --------------*- C++ -*-==//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the DebugEpochBase and DebugEpochBase::HandleBase classes.
// These can be used to write iterators that are fail-fast when LLVM is built
// with asserts enabled.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_EPOCH_TRACKER_H
#define LLVM_ADT_EPOCH_TRACKER_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Config/abi-breaking.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h"

#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h"

namespace llvm {

#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h"

/// A base class for data structure classes wishing to make iterators
/// ("handles") pointing into themselves fail-fast.  When building without
/// asserts, this class is empty and does nothing.
///
/// DebugEpochBase does not by itself track handles pointing into itself.  The
/// expectation is that routines touching the handles will poll on
/// isHandleInSync at appropriate points to assert that the handle they're using
/// is still valid.
///
class DebugEpochBase {
  uint64_t Epoch;

public:
  DebugEpochBase() : Epoch(0) {}

  /// Calling incrementEpoch invalidates all handles pointing into the
  /// calling instance.
  void incrementEpoch() { ++Epoch; }

  /// The destructor calls incrementEpoch to make use-after-free bugs
  /// more likely to crash deterministically.
  ~DebugEpochBase() { incrementEpoch(); }

  /// A base class for iterator classes ("handles") that wish to poll for
  /// iterator invalidating modifications in the underlying data structure.
  /// When LLVM is built without asserts, this class is empty and does nothing.
  ///
  /// HandleBase does not track the parent data structure by itself.  It expects
  /// the routines modifying the data structure to call incrementEpoch when they
  /// make an iterator-invalidating modification.
  ///
  class HandleBase {
    const uint64_t *EpochAddress;
    uint64_t EpochAtCreation;

  public:
    HandleBase() : EpochAddress(nullptr), EpochAtCreation(UINT64_MAX) {}

    explicit HandleBase(const DebugEpochBase *Parent)
        : EpochAddress(&Parent->Epoch), EpochAtCreation(Parent->Epoch) {}

    /// Returns true if the DebugEpochBase this Handle is linked to has
    /// not called incrementEpoch on itself since the creation of this
    /// HandleBase instance.
    bool isHandleInSync() const { return *EpochAddress == EpochAtCreation; }

    /// Returns a pointer to the epoch word stored in the data structure
    /// this handle points into.  Can be used to check if two iterators point
    /// into the same data structure.
    const void *getEpochAddress() const { return EpochAddress; }
  };
};

#else
# 80 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h"

class DebugEpochBase {
public:
  void incrementEpoch() {}

  class HandleBase {
  public:
    HandleBase() = default;
    explicit HandleBase(const DebugEpochBase *) {}
    bool isHandleInSync() const { return true; }
    const void *getEpochAddress() const { return nullptr; }
  };
};

#endif // LLVM_ENABLE_ABI_BREAKING_CHECKS
# 95 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h"

} // namespace llvm

#endif
# 99 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/EpochTracker.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/AlignOf.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MathExtras.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ReverseIteration.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h" 1
#ifndef LLVM_SUPPORT_REVERSEITERATION_H
#define LLVM_SUPPORT_REVERSEITERATION_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Config/abi-breaking.h"
#endif /* expanded by -frewrite-includes */
# 4 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h"
# 5 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/PointerLikeTypeTraits.h"
#endif /* expanded by -frewrite-includes */
# 5 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h"
# 6 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h"

namespace llvm {

template<class T = void *>
bool shouldReverseIterate() {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_REVERSE_ITERATION
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h"
  return detail::IsPointerLike<T>::value;
#else
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h"
  return false;
#endif
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h"
}

}
#endif
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ReverseIteration.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/type_traits.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"

namespace llvm {

namespace detail {

// We extend a pair to allow users to override the bucket type with their own
// implementation without requiring two members.
template <typename KeyT, typename ValueT>
struct DenseMapPair : public std::pair<KeyT, ValueT> {
  using std::pair<KeyT, ValueT>::pair;

  KeyT &getFirst() { return std::pair<KeyT, ValueT>::first; }
  const KeyT &getFirst() const { return std::pair<KeyT, ValueT>::first; }
  ValueT &getSecond() { return std::pair<KeyT, ValueT>::second; }
  const ValueT &getSecond() const { return std::pair<KeyT, ValueT>::second; }
};

} // end namespace detail

template <typename KeyT, typename ValueT,
          typename KeyInfoT = DenseMapInfo<KeyT>,
          typename Bucket = llvm::detail::DenseMapPair<KeyT, ValueT>,
          bool IsConst = false>
class DenseMapIterator;

template <typename DerivedT, typename KeyT, typename ValueT, typename KeyInfoT,
          typename BucketT>
class DenseMapBase : public DebugEpochBase {
  template <typename T>
  using const_arg_type_t = typename const_pointer_or_const_ref<T>::type;

public:
  using size_type = unsigned;
  using key_type = KeyT;
  using mapped_type = ValueT;
  using value_type = BucketT;

  using iterator = DenseMapIterator<KeyT, ValueT, KeyInfoT, BucketT>;
  using const_iterator =
      DenseMapIterator<KeyT, ValueT, KeyInfoT, BucketT, true>;

  inline iterator begin() {
    // When the map is empty, avoid the overhead of advancing/retreating past
    // empty buckets.
    if (empty())
      return end();
    if (shouldReverseIterate<KeyT>())
      return makeIterator(getBucketsEnd() - 1, getBuckets(), *this);
    return makeIterator(getBuckets(), getBucketsEnd(), *this);
  }
  inline iterator end() {
    return makeIterator(getBucketsEnd(), getBucketsEnd(), *this, true);
  }
  inline const_iterator begin() const {
    if (empty())
      return end();
    if (shouldReverseIterate<KeyT>())
      return makeConstIterator(getBucketsEnd() - 1, getBuckets(), *this);
    return makeConstIterator(getBuckets(), getBucketsEnd(), *this);
  }
  inline const_iterator end() const {
    return makeConstIterator(getBucketsEnd(), getBucketsEnd(), *this, true);
  }

  LLVM_NODISCARD bool empty() const {
    return getNumEntries() == 0;
  }
  unsigned size() const { return getNumEntries(); }

  /// Grow the densemap so that it can contain at least \p NumEntries items
  /// before resizing again.
  void reserve(size_type NumEntries) {
    auto NumBuckets = getMinBucketToReserveForEntries(NumEntries);
    incrementEpoch();
    if (NumBuckets > getNumBuckets())
      grow(NumBuckets);
  }

  void clear() {
    incrementEpoch();
    if (getNumEntries() == 0 && getNumTombstones() == 0) return;

    // If the capacity of the array is huge, and the # elements used is small,
    // shrink the array.
    if (getNumEntries() * 4 < getNumBuckets() && getNumBuckets() > 64) {
      shrink_and_clear();
      return;
    }

    const KeyT EmptyKey = getEmptyKey(), TombstoneKey = getTombstoneKey();
    if (is_trivially_copyable<KeyT>::value &&
        is_trivially_copyable<ValueT>::value) {
      // Use a simpler loop when these are trivial types.
      for (BucketT *P = getBuckets(), *E = getBucketsEnd(); P != E; ++P)
        P->getFirst() = EmptyKey;
    } else {
      unsigned NumEntries = getNumEntries();
      for (BucketT *P = getBuckets(), *E = getBucketsEnd(); P != E; ++P) {
        if (!KeyInfoT::isEqual(P->getFirst(), EmptyKey)) {
          if (!KeyInfoT::isEqual(P->getFirst(), TombstoneKey)) {
            P->getSecond().~ValueT();
            --NumEntries;
          }
          P->getFirst() = EmptyKey;
        }
      }
      assert(NumEntries == 0 && "Node count imbalance!");
    }
    setNumEntries(0);
    setNumTombstones(0);
  }

  /// Return 1 if the specified key is in the map, 0 otherwise.
  size_type count(const_arg_type_t<KeyT> Val) const {
    const BucketT *TheBucket;
    return LookupBucketFor(Val, TheBucket) ? 1 : 0;
  }

  iterator find(const_arg_type_t<KeyT> Val) {
    BucketT *TheBucket;
    if (LookupBucketFor(Val, TheBucket))
      return makeIterator(TheBucket, getBucketsEnd(), *this, true);
    return end();
  }
  const_iterator find(const_arg_type_t<KeyT> Val) const {
    const BucketT *TheBucket;
    if (LookupBucketFor(Val, TheBucket))
      return makeConstIterator(TheBucket, getBucketsEnd(), *this, true);
    return end();
  }

  /// Alternate version of find() which allows a different, and possibly
  /// less expensive, key type.
  /// The DenseMapInfo is responsible for supplying methods
  /// getHashValue(LookupKeyT) and isEqual(LookupKeyT, KeyT) for each key
  /// type used.
  template<class LookupKeyT>
  iterator find_as(const LookupKeyT &Val) {
    BucketT *TheBucket;
    if (LookupBucketFor(Val, TheBucket))
      return makeIterator(TheBucket, getBucketsEnd(), *this, true);
    return end();
  }
  template<class LookupKeyT>
  const_iterator find_as(const LookupKeyT &Val) const {
    const BucketT *TheBucket;
    if (LookupBucketFor(Val, TheBucket))
      return makeConstIterator(TheBucket, getBucketsEnd(), *this, true);
    return end();
  }

  /// lookup - Return the entry for the specified key, or a default
  /// constructed value if no such entry exists.
  ValueT lookup(const_arg_type_t<KeyT> Val) const {
    const BucketT *TheBucket;
    if (LookupBucketFor(Val, TheBucket))
      return TheBucket->getSecond();
    return ValueT();
  }

  // Inserts key,value pair into the map if the key isn't already in the map.
  // If the key is already in the map, it returns false and doesn't update the
  // value.
  std::pair<iterator, bool> insert(const std::pair<KeyT, ValueT> &KV) {
    return try_emplace(KV.first, KV.second);
  }

  // Inserts key,value pair into the map if the key isn't already in the map.
  // If the key is already in the map, it returns false and doesn't update the
  // value.
  std::pair<iterator, bool> insert(std::pair<KeyT, ValueT> &&KV) {
    return try_emplace(std::move(KV.first), std::move(KV.second));
  }

  // Inserts key,value pair into the map if the key isn't already in the map.
  // The value is constructed in-place if the key is not in the map, otherwise
  // it is not moved.
  template <typename... Ts>
  std::pair<iterator, bool> try_emplace(KeyT &&Key, Ts &&... Args) {
    BucketT *TheBucket;
    if (LookupBucketFor(Key, TheBucket))
      return std::make_pair(
               makeIterator(TheBucket, getBucketsEnd(), *this, true),
               false); // Already in map.

    // Otherwise, insert the new element.
    TheBucket =
        InsertIntoBucket(TheBucket, std::move(Key), std::forward<Ts>(Args)...);
    return std::make_pair(
             makeIterator(TheBucket, getBucketsEnd(), *this, true),
             true);
  }

  // Inserts key,value pair into the map if the key isn't already in the map.
  // The value is constructed in-place if the key is not in the map, otherwise
  // it is not moved.
  template <typename... Ts>
  std::pair<iterator, bool> try_emplace(const KeyT &Key, Ts &&... Args) {
    BucketT *TheBucket;
    if (LookupBucketFor(Key, TheBucket))
      return std::make_pair(
               makeIterator(TheBucket, getBucketsEnd(), *this, true),
               false); // Already in map.

    // Otherwise, insert the new element.
    TheBucket = InsertIntoBucket(TheBucket, Key, std::forward<Ts>(Args)...);
    return std::make_pair(
             makeIterator(TheBucket, getBucketsEnd(), *this, true),
             true);
  }

  /// Alternate version of insert() which allows a different, and possibly
  /// less expensive, key type.
  /// The DenseMapInfo is responsible for supplying methods
  /// getHashValue(LookupKeyT) and isEqual(LookupKeyT, KeyT) for each key
  /// type used.
  template <typename LookupKeyT>
  std::pair<iterator, bool> insert_as(std::pair<KeyT, ValueT> &&KV,
                                      const LookupKeyT &Val) {
    BucketT *TheBucket;
    if (LookupBucketFor(Val, TheBucket))
      return std::make_pair(
               makeIterator(TheBucket, getBucketsEnd(), *this, true),
               false); // Already in map.

    // Otherwise, insert the new element.
    TheBucket = InsertIntoBucketWithLookup(TheBucket, std::move(KV.first),
                                           std::move(KV.second), Val);
    return std::make_pair(
             makeIterator(TheBucket, getBucketsEnd(), *this, true),
             true);
  }

  /// insert - Range insertion of pairs.
  template<typename InputIt>
  void insert(InputIt I, InputIt E) {
    for (; I != E; ++I)
      insert(*I);
  }

  bool erase(const KeyT &Val) {
    BucketT *TheBucket;
    if (!LookupBucketFor(Val, TheBucket))
      return false; // not in map.

    TheBucket->getSecond().~ValueT();
    TheBucket->getFirst() = getTombstoneKey();
    decrementNumEntries();
    incrementNumTombstones();
    return true;
  }
  void erase(iterator I) {
    BucketT *TheBucket = &*I;
    TheBucket->getSecond().~ValueT();
    TheBucket->getFirst() = getTombstoneKey();
    decrementNumEntries();
    incrementNumTombstones();
  }

  value_type& FindAndConstruct(const KeyT &Key) {
    BucketT *TheBucket;
    if (LookupBucketFor(Key, TheBucket))
      return *TheBucket;

    return *InsertIntoBucket(TheBucket, Key);
  }

  ValueT &operator[](const KeyT &Key) {
    return FindAndConstruct(Key).second;
  }

  value_type& FindAndConstruct(KeyT &&Key) {
    BucketT *TheBucket;
    if (LookupBucketFor(Key, TheBucket))
      return *TheBucket;

    return *InsertIntoBucket(TheBucket, std::move(Key));
  }

  ValueT &operator[](KeyT &&Key) {
    return FindAndConstruct(std::move(Key)).second;
  }

  /// isPointerIntoBucketsArray - Return true if the specified pointer points
  /// somewhere into the DenseMap's array of buckets (i.e. either to a key or
  /// value in the DenseMap).
  bool isPointerIntoBucketsArray(const void *Ptr) const {
    return Ptr >= getBuckets() && Ptr < getBucketsEnd();
  }

  /// getPointerIntoBucketsArray() - Return an opaque pointer into the buckets
  /// array.  In conjunction with the previous method, this can be used to
  /// determine whether an insertion caused the DenseMap to reallocate.
  const void *getPointerIntoBucketsArray() const { return getBuckets(); }

protected:
  DenseMapBase() = default;

  void destroyAll() {
    if (getNumBuckets() == 0) // Nothing to do.
      return;

    const KeyT EmptyKey = getEmptyKey(), TombstoneKey = getTombstoneKey();
    for (BucketT *P = getBuckets(), *E = getBucketsEnd(); P != E; ++P) {
      if (!KeyInfoT::isEqual(P->getFirst(), EmptyKey) &&
          !KeyInfoT::isEqual(P->getFirst(), TombstoneKey))
        P->getSecond().~ValueT();
      P->getFirst().~KeyT();
    }
  }

  void initEmpty() {
    setNumEntries(0);
    setNumTombstones(0);

    assert((getNumBuckets() & (getNumBuckets()-1)) == 0 &&
           "# initial buckets must be a power of two!");
    const KeyT EmptyKey = getEmptyKey();
    for (BucketT *B = getBuckets(), *E = getBucketsEnd(); B != E; ++B)
      ::new (&B->getFirst()) KeyT(EmptyKey);
  }

  /// Returns the number of buckets to allocate to ensure that the DenseMap can
  /// accommodate \p NumEntries without need to grow().
  unsigned getMinBucketToReserveForEntries(unsigned NumEntries) {
    // Ensure that "NumEntries * 4 < NumBuckets * 3"
    if (NumEntries == 0)
      return 0;
    // +1 is required because of the strict equality.
    // For example if NumEntries is 48, we need to return 401.
    return NextPowerOf2(NumEntries * 4 / 3 + 1);
  }

  void moveFromOldBuckets(BucketT *OldBucketsBegin, BucketT *OldBucketsEnd) {
    initEmpty();

    // Insert all the old elements.
    const KeyT EmptyKey = getEmptyKey();
    const KeyT TombstoneKey = getTombstoneKey();
    for (BucketT *B = OldBucketsBegin, *E = OldBucketsEnd; B != E; ++B) {
      if (!KeyInfoT::isEqual(B->getFirst(), EmptyKey) &&
          !KeyInfoT::isEqual(B->getFirst(), TombstoneKey)) {
        // Insert the key/value into the new table.
        BucketT *DestBucket;
        bool FoundVal = LookupBucketFor(B->getFirst(), DestBucket);
        (void)FoundVal; // silence warning.
        assert(!FoundVal && "Key already in new map?");
        DestBucket->getFirst() = std::move(B->getFirst());
        ::new (&DestBucket->getSecond()) ValueT(std::move(B->getSecond()));
        incrementNumEntries();

        // Free the value.
        B->getSecond().~ValueT();
      }
      B->getFirst().~KeyT();
    }
  }

  template <typename OtherBaseT>
  void copyFrom(
      const DenseMapBase<OtherBaseT, KeyT, ValueT, KeyInfoT, BucketT> &other) {
    assert(&other != this);
    assert(getNumBuckets() == other.getNumBuckets());

    setNumEntries(other.getNumEntries());
    setNumTombstones(other.getNumTombstones());

    if (is_trivially_copyable<KeyT>::value &&
        is_trivially_copyable<ValueT>::value)
      memcpy(reinterpret_cast<void *>(getBuckets()), other.getBuckets(),
             getNumBuckets() * sizeof(BucketT));
    else
      for (size_t i = 0; i < getNumBuckets(); ++i) {
        ::new (&getBuckets()[i].getFirst())
            KeyT(other.getBuckets()[i].getFirst());
        if (!KeyInfoT::isEqual(getBuckets()[i].getFirst(), getEmptyKey()) &&
            !KeyInfoT::isEqual(getBuckets()[i].getFirst(), getTombstoneKey()))
          ::new (&getBuckets()[i].getSecond())
              ValueT(other.getBuckets()[i].getSecond());
      }
  }

  static unsigned getHashValue(const KeyT &Val) {
    return KeyInfoT::getHashValue(Val);
  }

  template<typename LookupKeyT>
  static unsigned getHashValue(const LookupKeyT &Val) {
    return KeyInfoT::getHashValue(Val);
  }

  static const KeyT getEmptyKey() {
    static_assert(std::is_base_of<DenseMapBase, DerivedT>::value,
                  "Must pass the derived type to this template!");
    return KeyInfoT::getEmptyKey();
  }

  static const KeyT getTombstoneKey() {
    return KeyInfoT::getTombstoneKey();
  }

private:
  iterator makeIterator(BucketT *P, BucketT *E,
                        DebugEpochBase &Epoch,
                        bool NoAdvance=false) {
    if (shouldReverseIterate<KeyT>()) {
      BucketT *B = P == getBucketsEnd() ? getBuckets() : P + 1;
      return iterator(B, E, Epoch, NoAdvance);
    }
    return iterator(P, E, Epoch, NoAdvance);
  }

  const_iterator makeConstIterator(const BucketT *P, const BucketT *E,
                                   const DebugEpochBase &Epoch,
                                   const bool NoAdvance=false) const {
    if (shouldReverseIterate<KeyT>()) {
      const BucketT *B = P == getBucketsEnd() ? getBuckets() : P + 1;
      return const_iterator(B, E, Epoch, NoAdvance);
    }
    return const_iterator(P, E, Epoch, NoAdvance);
  }

  unsigned getNumEntries() const {
    return static_cast<const DerivedT *>(this)->getNumEntries();
  }

  void setNumEntries(unsigned Num) {
    static_cast<DerivedT *>(this)->setNumEntries(Num);
  }

  void incrementNumEntries() {
    setNumEntries(getNumEntries() + 1);
  }

  void decrementNumEntries() {
    setNumEntries(getNumEntries() - 1);
  }

  unsigned getNumTombstones() const {
    return static_cast<const DerivedT *>(this)->getNumTombstones();
  }

  void setNumTombstones(unsigned Num) {
    static_cast<DerivedT *>(this)->setNumTombstones(Num);
  }

  void incrementNumTombstones() {
    setNumTombstones(getNumTombstones() + 1);
  }

  void decrementNumTombstones() {
    setNumTombstones(getNumTombstones() - 1);
  }

  const BucketT *getBuckets() const {
    return static_cast<const DerivedT *>(this)->getBuckets();
  }

  BucketT *getBuckets() {
    return static_cast<DerivedT *>(this)->getBuckets();
  }

  unsigned getNumBuckets() const {
    return static_cast<const DerivedT *>(this)->getNumBuckets();
  }

  BucketT *getBucketsEnd() {
    return getBuckets() + getNumBuckets();
  }

  const BucketT *getBucketsEnd() const {
    return getBuckets() + getNumBuckets();
  }

  void grow(unsigned AtLeast) {
    static_cast<DerivedT *>(this)->grow(AtLeast);
  }

  void shrink_and_clear() {
    static_cast<DerivedT *>(this)->shrink_and_clear();
  }

  template <typename KeyArg, typename... ValueArgs>
  BucketT *InsertIntoBucket(BucketT *TheBucket, KeyArg &&Key,
                            ValueArgs &&... Values) {
    TheBucket = InsertIntoBucketImpl(Key, Key, TheBucket);

    TheBucket->getFirst() = std::forward<KeyArg>(Key);
    ::new (&TheBucket->getSecond()) ValueT(std::forward<ValueArgs>(Values)...);
    return TheBucket;
  }

  template <typename LookupKeyT>
  BucketT *InsertIntoBucketWithLookup(BucketT *TheBucket, KeyT &&Key,
                                      ValueT &&Value, LookupKeyT &Lookup) {
    TheBucket = InsertIntoBucketImpl(Key, Lookup, TheBucket);

    TheBucket->getFirst() = std::move(Key);
    ::new (&TheBucket->getSecond()) ValueT(std::move(Value));
    return TheBucket;
  }

  template <typename LookupKeyT>
  BucketT *InsertIntoBucketImpl(const KeyT &Key, const LookupKeyT &Lookup,
                                BucketT *TheBucket) {
    incrementEpoch();

    // If the load of the hash table is more than 3/4, or if fewer than 1/8 of
    // the buckets are empty (meaning that many are filled with tombstones),
    // grow the table.
    //
    // The later case is tricky.  For example, if we had one empty bucket with
    // tons of tombstones, failing lookups (e.g. for insertion) would have to
    // probe almost the entire table until it found the empty bucket.  If the
    // table completely filled with tombstones, no lookup would ever succeed,
    // causing infinite loops in lookup.
    unsigned NewNumEntries = getNumEntries() + 1;
    unsigned NumBuckets = getNumBuckets();
    if (LLVM_UNLIKELY(NewNumEntries * 4 >= NumBuckets * 3)) {
      this->grow(NumBuckets * 2);
      LookupBucketFor(Lookup, TheBucket);
      NumBuckets = getNumBuckets();
    } else if (LLVM_UNLIKELY(NumBuckets-(NewNumEntries+getNumTombstones()) <=
                             NumBuckets/8)) {
      this->grow(NumBuckets);
      LookupBucketFor(Lookup, TheBucket);
    }
    assert(TheBucket);

    // Only update the state after we've grown our bucket space appropriately
    // so that when growing buckets we have self-consistent entry count.
    incrementNumEntries();

    // If we are writing over a tombstone, remember this.
    const KeyT EmptyKey = getEmptyKey();
    if (!KeyInfoT::isEqual(TheBucket->getFirst(), EmptyKey))
      decrementNumTombstones();

    return TheBucket;
  }

  /// LookupBucketFor - Lookup the appropriate bucket for Val, returning it in
  /// FoundBucket.  If the bucket contains the key and a value, this returns
  /// true, otherwise it returns a bucket with an empty marker or tombstone and
  /// returns false.
  template<typename LookupKeyT>
  bool LookupBucketFor(const LookupKeyT &Val,
                       const BucketT *&FoundBucket) const {
    const BucketT *BucketsPtr = getBuckets();
    const unsigned NumBuckets = getNumBuckets();

    if (NumBuckets == 0) {
      FoundBucket = nullptr;
      return false;
    }

    // FoundTombstone - Keep track of whether we find a tombstone while probing.
    const BucketT *FoundTombstone = nullptr;
    const KeyT EmptyKey = getEmptyKey();
    const KeyT TombstoneKey = getTombstoneKey();
    assert(!KeyInfoT::isEqual(Val, EmptyKey) &&
           !KeyInfoT::isEqual(Val, TombstoneKey) &&
           "Empty/Tombstone value shouldn't be inserted into map!");

    unsigned BucketNo = getHashValue(Val) & (NumBuckets-1);
    unsigned ProbeAmt = 1;
    while (true) {
      const BucketT *ThisBucket = BucketsPtr + BucketNo;
      // Found Val's bucket?  If so, return it.
      if (LLVM_LIKELY(KeyInfoT::isEqual(Val, ThisBucket->getFirst()))) {
        FoundBucket = ThisBucket;
        return true;
      }

      // If we found an empty bucket, the key doesn't exist in the set.
      // Insert it and return the default value.
      if (LLVM_LIKELY(KeyInfoT::isEqual(ThisBucket->getFirst(), EmptyKey))) {
        // If we've already seen a tombstone while probing, fill it in instead
        // of the empty bucket we eventually probed to.
        FoundBucket = FoundTombstone ? FoundTombstone : ThisBucket;
        return false;
      }

      // If this is a tombstone, remember it.  If Val ends up not in the map, we
      // prefer to return it than something that would require more probing.
      if (KeyInfoT::isEqual(ThisBucket->getFirst(), TombstoneKey) &&
          !FoundTombstone)
        FoundTombstone = ThisBucket;  // Remember the first tombstone found.

      // Otherwise, it's a hash collision or a tombstone, continue quadratic
      // probing.
      BucketNo += ProbeAmt++;
      BucketNo &= (NumBuckets-1);
    }
  }

  template <typename LookupKeyT>
  bool LookupBucketFor(const LookupKeyT &Val, BucketT *&FoundBucket) {
    const BucketT *ConstFoundBucket;
    bool Result = const_cast<const DenseMapBase *>(this)
      ->LookupBucketFor(Val, ConstFoundBucket);
    FoundBucket = const_cast<BucketT *>(ConstFoundBucket);
    return Result;
  }

public:
  /// Return the approximate size (in bytes) of the actual map.
  /// This is just the raw memory used by DenseMap.
  /// If entries are pointers to objects, the size of the referenced objects
  /// are not included.
  size_t getMemorySize() const {
    return getNumBuckets() * sizeof(BucketT);
  }
};

/// Equality comparison for DenseMap.
///
/// Iterates over elements of LHS confirming that each (key, value) pair in LHS
/// is also in RHS, and that no additional pairs are in RHS.
/// Equivalent to N calls to RHS.find and N value comparisons. Amortized
/// complexity is linear, worst case is O(N^2) (if every hash collides).
template <typename DerivedT, typename KeyT, typename ValueT, typename KeyInfoT,
          typename BucketT>
bool operator==(
    const DenseMapBase<DerivedT, KeyT, ValueT, KeyInfoT, BucketT> &LHS,
    const DenseMapBase<DerivedT, KeyT, ValueT, KeyInfoT, BucketT> &RHS) {
  if (LHS.size() != RHS.size())
    return false;

  for (auto &KV : LHS) {
    auto I = RHS.find(KV.first);
    if (I == RHS.end() || I->second != KV.second)
      return false;
  }

  return true;
}

/// Inequality comparison for DenseMap.
///
/// Equivalent to !(LHS == RHS). See operator== for performance notes.
template <typename DerivedT, typename KeyT, typename ValueT, typename KeyInfoT,
          typename BucketT>
bool operator!=(
    const DenseMapBase<DerivedT, KeyT, ValueT, KeyInfoT, BucketT> &LHS,
    const DenseMapBase<DerivedT, KeyT, ValueT, KeyInfoT, BucketT> &RHS) {
  return !(LHS == RHS);
}

template <typename KeyT, typename ValueT,
          typename KeyInfoT = DenseMapInfo<KeyT>,
          typename BucketT = llvm::detail::DenseMapPair<KeyT, ValueT>>
class DenseMap : public DenseMapBase<DenseMap<KeyT, ValueT, KeyInfoT, BucketT>,
                                     KeyT, ValueT, KeyInfoT, BucketT> {
  friend class DenseMapBase<DenseMap, KeyT, ValueT, KeyInfoT, BucketT>;

  // Lift some types from the dependent base class into this class for
  // simplicity of referring to them.
  using BaseT = DenseMapBase<DenseMap, KeyT, ValueT, KeyInfoT, BucketT>;

  BucketT *Buckets;
  unsigned NumEntries;
  unsigned NumTombstones;
  unsigned NumBuckets;

public:
  /// Create a DenseMap wth an optional \p InitialReserve that guarantee that
  /// this number of elements can be inserted in the map without grow()
  explicit DenseMap(unsigned InitialReserve = 0) { init(InitialReserve); }

  DenseMap(const DenseMap &other) : BaseT() {
    init(0);
    copyFrom(other);
  }

  DenseMap(DenseMap &&other) : BaseT() {
    init(0);
    swap(other);
  }

  template<typename InputIt>
  DenseMap(const InputIt &I, const InputIt &E) {
    init(std::distance(I, E));
    this->insert(I, E);
  }

  DenseMap(std::initializer_list<typename BaseT::value_type> Vals) {
    init(Vals.size());
    this->insert(Vals.begin(), Vals.end());
  }

  ~DenseMap() {
    this->destroyAll();
    deallocate_buffer(Buckets, sizeof(BucketT) * NumBuckets, alignof(BucketT));
  }

  void swap(DenseMap& RHS) {
    this->incrementEpoch();
    RHS.incrementEpoch();
    std::swap(Buckets, RHS.Buckets);
    std::swap(NumEntries, RHS.NumEntries);
    std::swap(NumTombstones, RHS.NumTombstones);
    std::swap(NumBuckets, RHS.NumBuckets);
  }

  DenseMap& operator=(const DenseMap& other) {
    if (&other != this)
      copyFrom(other);
    return *this;
  }

  DenseMap& operator=(DenseMap &&other) {
    this->destroyAll();
    deallocate_buffer(Buckets, sizeof(BucketT) * NumBuckets, alignof(BucketT));
    init(0);
    swap(other);
    return *this;
  }

  void copyFrom(const DenseMap& other) {
    this->destroyAll();
    deallocate_buffer(Buckets, sizeof(BucketT) * NumBuckets, alignof(BucketT));
    if (allocateBuckets(other.NumBuckets)) {
      this->BaseT::copyFrom(other);
    } else {
      NumEntries = 0;
      NumTombstones = 0;
    }
  }

  void init(unsigned InitNumEntries) {
    auto InitBuckets = BaseT::getMinBucketToReserveForEntries(InitNumEntries);
    if (allocateBuckets(InitBuckets)) {
      this->BaseT::initEmpty();
    } else {
      NumEntries = 0;
      NumTombstones = 0;
    }
  }

  void grow(unsigned AtLeast) {
    unsigned OldNumBuckets = NumBuckets;
    BucketT *OldBuckets = Buckets;

    allocateBuckets(std::max<unsigned>(64, static_cast<unsigned>(NextPowerOf2(AtLeast-1))));
    assert(Buckets);
    if (!OldBuckets) {
      this->BaseT::initEmpty();
      return;
    }

    this->moveFromOldBuckets(OldBuckets, OldBuckets+OldNumBuckets);

    // Free the old table.
    deallocate_buffer(OldBuckets, sizeof(BucketT) * OldNumBuckets,
                      alignof(BucketT));
  }

  void shrink_and_clear() {
    unsigned OldNumBuckets = NumBuckets;
    unsigned OldNumEntries = NumEntries;
    this->destroyAll();

    // Reduce the number of buckets.
    unsigned NewNumBuckets = 0;
    if (OldNumEntries)
      NewNumBuckets = std::max(64, 1 << (Log2_32_Ceil(OldNumEntries) + 1));
    if (NewNumBuckets == NumBuckets) {
      this->BaseT::initEmpty();
      return;
    }

    deallocate_buffer(Buckets, sizeof(BucketT) * OldNumBuckets,
                      alignof(BucketT));
    init(NewNumBuckets);
  }

private:
  unsigned getNumEntries() const {
    return NumEntries;
  }

  void setNumEntries(unsigned Num) {
    NumEntries = Num;
  }

  unsigned getNumTombstones() const {
    return NumTombstones;
  }

  void setNumTombstones(unsigned Num) {
    NumTombstones = Num;
  }

  BucketT *getBuckets() const {
    return Buckets;
  }

  unsigned getNumBuckets() const {
    return NumBuckets;
  }

  bool allocateBuckets(unsigned Num) {
    NumBuckets = Num;
    if (NumBuckets == 0) {
      Buckets = nullptr;
      return false;
    }

    Buckets = static_cast<BucketT *>(
        allocate_buffer(sizeof(BucketT) * NumBuckets, alignof(BucketT)));
    return true;
  }
};

template <typename KeyT, typename ValueT, unsigned InlineBuckets = 4,
          typename KeyInfoT = DenseMapInfo<KeyT>,
          typename BucketT = llvm::detail::DenseMapPair<KeyT, ValueT>>
class SmallDenseMap
    : public DenseMapBase<
          SmallDenseMap<KeyT, ValueT, InlineBuckets, KeyInfoT, BucketT>, KeyT,
          ValueT, KeyInfoT, BucketT> {
  friend class DenseMapBase<SmallDenseMap, KeyT, ValueT, KeyInfoT, BucketT>;

  // Lift some types from the dependent base class into this class for
  // simplicity of referring to them.
  using BaseT = DenseMapBase<SmallDenseMap, KeyT, ValueT, KeyInfoT, BucketT>;

  static_assert(isPowerOf2_64(InlineBuckets),
                "InlineBuckets must be a power of 2.");

  unsigned Small : 1;
  unsigned NumEntries : 31;
  unsigned NumTombstones;

  struct LargeRep {
    BucketT *Buckets;
    unsigned NumBuckets;
  };

  /// A "union" of an inline bucket array and the struct representing
  /// a large bucket. This union will be discriminated by the 'Small' bit.
  AlignedCharArrayUnion<BucketT[InlineBuckets], LargeRep> storage;

public:
  explicit SmallDenseMap(unsigned NumInitBuckets = 0) {
    init(NumInitBuckets);
  }

  SmallDenseMap(const SmallDenseMap &other) : BaseT() {
    init(0);
    copyFrom(other);
  }

  SmallDenseMap(SmallDenseMap &&other) : BaseT() {
    init(0);
    swap(other);
  }

  template<typename InputIt>
  SmallDenseMap(const InputIt &I, const InputIt &E) {
    init(NextPowerOf2(std::distance(I, E)));
    this->insert(I, E);
  }

  ~SmallDenseMap() {
    this->destroyAll();
    deallocateBuckets();
  }

  void swap(SmallDenseMap& RHS) {
    unsigned TmpNumEntries = RHS.NumEntries;
    RHS.NumEntries = NumEntries;
    NumEntries = TmpNumEntries;
    std::swap(NumTombstones, RHS.NumTombstones);

    const KeyT EmptyKey = this->getEmptyKey();
    const KeyT TombstoneKey = this->getTombstoneKey();
    if (Small && RHS.Small) {
      // If we're swapping inline bucket arrays, we have to cope with some of
      // the tricky bits of DenseMap's storage system: the buckets are not
      // fully initialized. Thus we swap every key, but we may have
      // a one-directional move of the value.
      for (unsigned i = 0, e = InlineBuckets; i != e; ++i) {
        BucketT *LHSB = &getInlineBuckets()[i],
                *RHSB = &RHS.getInlineBuckets()[i];
        bool hasLHSValue = (!KeyInfoT::isEqual(LHSB->getFirst(), EmptyKey) &&
                            !KeyInfoT::isEqual(LHSB->getFirst(), TombstoneKey));
        bool hasRHSValue = (!KeyInfoT::isEqual(RHSB->getFirst(), EmptyKey) &&
                            !KeyInfoT::isEqual(RHSB->getFirst(), TombstoneKey));
        if (hasLHSValue && hasRHSValue) {
          // Swap together if we can...
          std::swap(*LHSB, *RHSB);
          continue;
        }
        // Swap separately and handle any assymetry.
        std::swap(LHSB->getFirst(), RHSB->getFirst());
        if (hasLHSValue) {
          ::new (&RHSB->getSecond()) ValueT(std::move(LHSB->getSecond()));
          LHSB->getSecond().~ValueT();
        } else if (hasRHSValue) {
          ::new (&LHSB->getSecond()) ValueT(std::move(RHSB->getSecond()));
          RHSB->getSecond().~ValueT();
        }
      }
      return;
    }
    if (!Small && !RHS.Small) {
      std::swap(getLargeRep()->Buckets, RHS.getLargeRep()->Buckets);
      std::swap(getLargeRep()->NumBuckets, RHS.getLargeRep()->NumBuckets);
      return;
    }

    SmallDenseMap &SmallSide = Small ? *this : RHS;
    SmallDenseMap &LargeSide = Small ? RHS : *this;

    // First stash the large side's rep and move the small side across.
    LargeRep TmpRep = std::move(*LargeSide.getLargeRep());
    LargeSide.getLargeRep()->~LargeRep();
    LargeSide.Small = true;
    // This is similar to the standard move-from-old-buckets, but the bucket
    // count hasn't actually rotated in this case. So we have to carefully
    // move construct the keys and values into their new locations, but there
    // is no need to re-hash things.
    for (unsigned i = 0, e = InlineBuckets; i != e; ++i) {
      BucketT *NewB = &LargeSide.getInlineBuckets()[i],
              *OldB = &SmallSide.getInlineBuckets()[i];
      ::new (&NewB->getFirst()) KeyT(std::move(OldB->getFirst()));
      OldB->getFirst().~KeyT();
      if (!KeyInfoT::isEqual(NewB->getFirst(), EmptyKey) &&
          !KeyInfoT::isEqual(NewB->getFirst(), TombstoneKey)) {
        ::new (&NewB->getSecond()) ValueT(std::move(OldB->getSecond()));
        OldB->getSecond().~ValueT();
      }
    }

    // The hard part of moving the small buckets across is done, just move
    // the TmpRep into its new home.
    SmallSide.Small = false;
    new (SmallSide.getLargeRep()) LargeRep(std::move(TmpRep));
  }

  SmallDenseMap& operator=(const SmallDenseMap& other) {
    if (&other != this)
      copyFrom(other);
    return *this;
  }

  SmallDenseMap& operator=(SmallDenseMap &&other) {
    this->destroyAll();
    deallocateBuckets();
    init(0);
    swap(other);
    return *this;
  }

  void copyFrom(const SmallDenseMap& other) {
    this->destroyAll();
    deallocateBuckets();
    Small = true;
    if (other.getNumBuckets() > InlineBuckets) {
      Small = false;
      new (getLargeRep()) LargeRep(allocateBuckets(other.getNumBuckets()));
    }
    this->BaseT::copyFrom(other);
  }

  void init(unsigned InitBuckets) {
    Small = true;
    if (InitBuckets > InlineBuckets) {
      Small = false;
      new (getLargeRep()) LargeRep(allocateBuckets(InitBuckets));
    }
    this->BaseT::initEmpty();
  }

  void grow(unsigned AtLeast) {
    if (AtLeast > InlineBuckets)
      AtLeast = std::max<unsigned>(64, NextPowerOf2(AtLeast-1));

    if (Small) {
      // First move the inline buckets into a temporary storage.
      AlignedCharArrayUnion<BucketT[InlineBuckets]> TmpStorage;
      BucketT *TmpBegin = reinterpret_cast<BucketT *>(TmpStorage.buffer);
      BucketT *TmpEnd = TmpBegin;

      // Loop over the buckets, moving non-empty, non-tombstones into the
      // temporary storage. Have the loop move the TmpEnd forward as it goes.
      const KeyT EmptyKey = this->getEmptyKey();
      const KeyT TombstoneKey = this->getTombstoneKey();
      for (BucketT *P = getBuckets(), *E = P + InlineBuckets; P != E; ++P) {
        if (!KeyInfoT::isEqual(P->getFirst(), EmptyKey) &&
            !KeyInfoT::isEqual(P->getFirst(), TombstoneKey)) {
          assert(size_t(TmpEnd - TmpBegin) < InlineBuckets &&
                 "Too many inline buckets!");
          ::new (&TmpEnd->getFirst()) KeyT(std::move(P->getFirst()));
          ::new (&TmpEnd->getSecond()) ValueT(std::move(P->getSecond()));
          ++TmpEnd;
          P->getSecond().~ValueT();
        }
        P->getFirst().~KeyT();
      }

      // AtLeast == InlineBuckets can happen if there are many tombstones,
      // and grow() is used to remove them. Usually we always switch to the
      // large rep here.
      if (AtLeast > InlineBuckets) {
        Small = false;
        new (getLargeRep()) LargeRep(allocateBuckets(AtLeast));
      }
      this->moveFromOldBuckets(TmpBegin, TmpEnd);
      return;
    }

    LargeRep OldRep = std::move(*getLargeRep());
    getLargeRep()->~LargeRep();
    if (AtLeast <= InlineBuckets) {
      Small = true;
    } else {
      new (getLargeRep()) LargeRep(allocateBuckets(AtLeast));
    }

    this->moveFromOldBuckets(OldRep.Buckets, OldRep.Buckets+OldRep.NumBuckets);

    // Free the old table.
    deallocate_buffer(OldRep.Buckets, sizeof(BucketT) * OldRep.NumBuckets,
                      alignof(BucketT));
  }

  void shrink_and_clear() {
    unsigned OldSize = this->size();
    this->destroyAll();

    // Reduce the number of buckets.
    unsigned NewNumBuckets = 0;
    if (OldSize) {
      NewNumBuckets = 1 << (Log2_32_Ceil(OldSize) + 1);
      if (NewNumBuckets > InlineBuckets && NewNumBuckets < 64u)
        NewNumBuckets = 64;
    }
    if ((Small && NewNumBuckets <= InlineBuckets) ||
        (!Small && NewNumBuckets == getLargeRep()->NumBuckets)) {
      this->BaseT::initEmpty();
      return;
    }

    deallocateBuckets();
    init(NewNumBuckets);
  }

private:
  unsigned getNumEntries() const {
    return NumEntries;
  }

  void setNumEntries(unsigned Num) {
    // NumEntries is hardcoded to be 31 bits wide.
    assert(Num < (1U << 31) && "Cannot support more than 1<<31 entries");
    NumEntries = Num;
  }

  unsigned getNumTombstones() const {
    return NumTombstones;
  }

  void setNumTombstones(unsigned Num) {
    NumTombstones = Num;
  }

  const BucketT *getInlineBuckets() const {
    assert(Small);
    // Note that this cast does not violate aliasing rules as we assert that
    // the memory's dynamic type is the small, inline bucket buffer, and the
    // 'storage.buffer' static type is 'char *'.
    return reinterpret_cast<const BucketT *>(storage.buffer);
  }

  BucketT *getInlineBuckets() {
    return const_cast<BucketT *>(
      const_cast<const SmallDenseMap *>(this)->getInlineBuckets());
  }

  const LargeRep *getLargeRep() const {
    assert(!Small);
    // Note, same rule about aliasing as with getInlineBuckets.
    return reinterpret_cast<const LargeRep *>(storage.buffer);
  }

  LargeRep *getLargeRep() {
    return const_cast<LargeRep *>(
      const_cast<const SmallDenseMap *>(this)->getLargeRep());
  }

  const BucketT *getBuckets() const {
    return Small ? getInlineBuckets() : getLargeRep()->Buckets;
  }

  BucketT *getBuckets() {
    return const_cast<BucketT *>(
      const_cast<const SmallDenseMap *>(this)->getBuckets());
  }

  unsigned getNumBuckets() const {
    return Small ? InlineBuckets : getLargeRep()->NumBuckets;
  }

  void deallocateBuckets() {
    if (Small)
      return;

    deallocate_buffer(getLargeRep()->Buckets,
                      sizeof(BucketT) * getLargeRep()->NumBuckets,
                      alignof(BucketT));
    getLargeRep()->~LargeRep();
  }

  LargeRep allocateBuckets(unsigned Num) {
    assert(Num > InlineBuckets && "Must allocate more buckets than are inline");
    LargeRep Rep = {static_cast<BucketT *>(allocate_buffer(
                        sizeof(BucketT) * Num, alignof(BucketT))),
                    Num};
    return Rep;
  }
};

template <typename KeyT, typename ValueT, typename KeyInfoT, typename Bucket,
          bool IsConst>
class DenseMapIterator : DebugEpochBase::HandleBase {
  friend class DenseMapIterator<KeyT, ValueT, KeyInfoT, Bucket, true>;
  friend class DenseMapIterator<KeyT, ValueT, KeyInfoT, Bucket, false>;

  using ConstIterator = DenseMapIterator<KeyT, ValueT, KeyInfoT, Bucket, true>;

public:
  using difference_type = ptrdiff_t;
  using value_type =
      typename std::conditional<IsConst, const Bucket, Bucket>::type;
  using pointer = value_type *;
  using reference = value_type &;
  using iterator_category = std::forward_iterator_tag;

private:
  pointer Ptr = nullptr;
  pointer End = nullptr;

public:
  DenseMapIterator() = default;

  DenseMapIterator(pointer Pos, pointer E, const DebugEpochBase &Epoch,
                   bool NoAdvance = false)
      : DebugEpochBase::HandleBase(&Epoch), Ptr(Pos), End(E) {
    assert(isHandleInSync() && "invalid construction!");

    if (NoAdvance) return;
    if (shouldReverseIterate<KeyT>()) {
      RetreatPastEmptyBuckets();
      return;
    }
    AdvancePastEmptyBuckets();
  }

  // Converting ctor from non-const iterators to const iterators. SFINAE'd out
  // for const iterator destinations so it doesn't end up as a user defined copy
  // constructor.
  template <bool IsConstSrc,
            typename = std::enable_if_t<!IsConstSrc && IsConst>>
  DenseMapIterator(
      const DenseMapIterator<KeyT, ValueT, KeyInfoT, Bucket, IsConstSrc> &I)
      : DebugEpochBase::HandleBase(I), Ptr(I.Ptr), End(I.End) {}

  reference operator*() const {
    assert(isHandleInSync() && "invalid iterator access!");
    if (shouldReverseIterate<KeyT>())
      return Ptr[-1];
    return *Ptr;
  }
  pointer operator->() const {
    assert(isHandleInSync() && "invalid iterator access!");
    if (shouldReverseIterate<KeyT>())
      return &(Ptr[-1]);
    return Ptr;
  }

  bool operator==(const ConstIterator &RHS) const {
    assert((!Ptr || isHandleInSync()) && "handle not in sync!");
    assert((!RHS.Ptr || RHS.isHandleInSync()) && "handle not in sync!");
    assert(getEpochAddress() == RHS.getEpochAddress() &&
           "comparing incomparable iterators!");
    return Ptr == RHS.Ptr;
  }
  bool operator!=(const ConstIterator &RHS) const {
    assert((!Ptr || isHandleInSync()) && "handle not in sync!");
    assert((!RHS.Ptr || RHS.isHandleInSync()) && "handle not in sync!");
    assert(getEpochAddress() == RHS.getEpochAddress() &&
           "comparing incomparable iterators!");
    return Ptr != RHS.Ptr;
  }

  inline DenseMapIterator& operator++() {  // Preincrement
    assert(isHandleInSync() && "invalid iterator access!");
    if (shouldReverseIterate<KeyT>()) {
      --Ptr;
      RetreatPastEmptyBuckets();
      return *this;
    }
    ++Ptr;
    AdvancePastEmptyBuckets();
    return *this;
  }
  DenseMapIterator operator++(int) {  // Postincrement
    assert(isHandleInSync() && "invalid iterator access!");
    DenseMapIterator tmp = *this; ++*this; return tmp;
  }

private:
  void AdvancePastEmptyBuckets() {
    assert(Ptr <= End);
    const KeyT Empty = KeyInfoT::getEmptyKey();
    const KeyT Tombstone = KeyInfoT::getTombstoneKey();

    while (Ptr != End && (KeyInfoT::isEqual(Ptr->getFirst(), Empty) ||
                          KeyInfoT::isEqual(Ptr->getFirst(), Tombstone)))
      ++Ptr;
  }

  void RetreatPastEmptyBuckets() {
    assert(Ptr >= End);
    const KeyT Empty = KeyInfoT::getEmptyKey();
    const KeyT Tombstone = KeyInfoT::getTombstoneKey();

    while (Ptr != End && (KeyInfoT::isEqual(Ptr[-1].getFirst(), Empty) ||
                          KeyInfoT::isEqual(Ptr[-1].getFirst(), Tombstone)))
      --Ptr;
  }
};

template <typename KeyT, typename ValueT, typename KeyInfoT>
inline size_t capacity_in_bytes(const DenseMap<KeyT, ValueT, KeyInfoT> &X) {
  return X.getMemorySize();
}

} // end namespace llvm

#endif // LLVM_ADT_DENSEMAP_H
# 1276 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseMap.h"
# 23 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/IntrusiveRefCntPtr.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 25 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 26 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator_range.h"
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 27 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 28 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Error.h"
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h" 1
//===- llvm/Support/Error.h - Recoverable error handling --------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines an API used to report recoverable errors.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_ERROR_H
#define LLVM_SUPPORT_ERROR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/Error.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Error.h" 1
/*===------- llvm-c/Error.h - llvm::Error class C Interface -------*- C -*-===*\
|*                                                                            *|
|* Part of the LLVM Project, under the Apache License v2.0 with LLVM          *|
|* Exceptions.                                                                *|
|* See https://llvm.org/LICENSE.txt for license information.                  *|
|* SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception                    *|
|*                                                                            *|
|*===----------------------------------------------------------------------===*|
|*                                                                            *|
|* This file defines the C interface to LLVM's Error class.                   *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_C_ERROR_H
#define LLVM_C_ERROR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/ExternC.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Error.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/ExternC.h" 1
/*===- llvm-c/ExternC.h - Wrapper for 'extern "C"' ----------------*- C -*-===*\
|*                                                                            *|
|* Part of the LLVM Project, under the Apache License v2.0 with LLVM          *|
|* Exceptions.                                                                *|
|* See https://llvm.org/LICENSE.txt for license information.                  *|
|* SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception                    *|
|*                                                                            *|
|*===----------------------------------------------------------------------===*|
|*                                                                            *|
|* This file defines an 'extern "C"' wrapper                                  *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_C_EXTERN_C_H
#define LLVM_C_EXTERN_C_H

#ifdef __clang__
#define LLVM_C_STRICT_PROTOTYPES_BEGIN                                         \
  _Pragma("clang diagnostic push")                                             \
      _Pragma("clang diagnostic error \"-Wstrict-prototypes\"")
#define LLVM_C_STRICT_PROTOTYPES_END _Pragma("clang diagnostic pop")
#else
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/ExternC.h"
#define LLVM_C_STRICT_PROTOTYPES_BEGIN
#define LLVM_C_STRICT_PROTOTYPES_END
#endif
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/ExternC.h"

#ifdef __cplusplus
#define LLVM_C_EXTERN_C_BEGIN                                                  \
  extern "C" {                                                                 \
  LLVM_C_STRICT_PROTOTYPES_BEGIN
#define LLVM_C_EXTERN_C_END                                                    \
  LLVM_C_STRICT_PROTOTYPES_END                                                 \
  }
#else
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/ExternC.h"
#define LLVM_C_EXTERN_C_BEGIN LLVM_C_STRICT_PROTOTYPES_BEGIN
#define LLVM_C_EXTERN_C_END LLVM_C_STRICT_PROTOTYPES_END
#endif
# 38 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/ExternC.h"

#endif
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/ExternC.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Error.h" 2

LLVM_C_EXTERN_C_BEGIN

#define LLVMErrorSuccess 0

/**
 * Opaque reference to an error instance. Null serves as the 'success' value.
 */
typedef struct LLVMOpaqueError *LLVMErrorRef;

/**
 * Error type identifier.
 */
typedef const void *LLVMErrorTypeId;

/**
 * Returns the type id for the given error instance, which must be a failure
 * value (i.e. non-null).
 */
LLVMErrorTypeId LLVMGetErrorTypeId(LLVMErrorRef Err);

/**
 * Dispose of the given error without handling it. This operation consumes the
 * error, and the given LLVMErrorRef value is not usable once this call returns.
 * Note: This method *only* needs to be called if the error is not being passed
 * to some other consuming operation, e.g. LLVMGetErrorMessage.
 */
void LLVMConsumeError(LLVMErrorRef Err);

/**
 * Returns the given string's error message. This operation consumes the error,
 * and the given LLVMErrorRef value is not usable once this call returns.
 * The caller is responsible for disposing of the string by calling
 * LLVMDisposeErrorMessage.
 */
char *LLVMGetErrorMessage(LLVMErrorRef Err);

/**
 * Dispose of the given error message.
 */
void LLVMDisposeErrorMessage(char *ErrMsg);

/**
 * Returns the type id for llvm StringError.
 */
LLVMErrorTypeId LLVMGetStringErrorTypeId(void);

LLVM_C_EXTERN_C_END

#endif
# 68 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Error.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/STLExtras.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringExtras.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h" 1
//===- llvm/ADT/StringExtras.h - Useful string functions --------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file contains some functions that are useful when dealing with strings.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_STRINGEXTRAS_H
#define LLVM_ADT_STRINGEXTRAS_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/ArrayRef.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallString.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallString.h" 1
//===- llvm/ADT/SmallString.h - 'Normally small' strings --------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the SmallString class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_SMALLSTRING_H
#define LLVM_ADT_SMALLSTRING_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallString.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallString.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallString.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallString.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallString.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallString.h"

namespace llvm {

/// SmallString - A SmallString is just a SmallVector with methods and accessors
/// that make it work better as a string (e.g. operator+ etc).
template<unsigned InternalLen>
class SmallString : public SmallVector<char, InternalLen> {
public:
  /// Default ctor - Initialize to empty.
  SmallString() = default;

  /// Initialize from a StringRef.
  SmallString(StringRef S) : SmallVector<char, InternalLen>(S.begin(), S.end()) {}

  /// Initialize with a range.
  template<typename ItTy>
  SmallString(ItTy S, ItTy E) : SmallVector<char, InternalLen>(S, E) {}

  // Note that in order to add new overloads for append & assign, we have to
  // duplicate the inherited versions so as not to inadvertently hide them.

  /// @}
  /// @name String Assignment
  /// @{

  /// Assign from a repeated element.
  void assign(size_t NumElts, char Elt) {
    this->SmallVectorImpl<char>::assign(NumElts, Elt);
  }

  /// Assign from an iterator pair.
  template<typename in_iter>
  void assign(in_iter S, in_iter E) {
    this->clear();
    SmallVectorImpl<char>::append(S, E);
  }

  /// Assign from a StringRef.
  void assign(StringRef RHS) {
    this->clear();
    SmallVectorImpl<char>::append(RHS.begin(), RHS.end());
  }

  /// Assign from a SmallVector.
  void assign(const SmallVectorImpl<char> &RHS) {
    this->clear();
    SmallVectorImpl<char>::append(RHS.begin(), RHS.end());
  }

  /// @}
  /// @name String Concatenation
  /// @{

  /// Append from an iterator pair.
  template<typename in_iter>
  void append(in_iter S, in_iter E) {
    SmallVectorImpl<char>::append(S, E);
  }

  void append(size_t NumInputs, char Elt) {
    SmallVectorImpl<char>::append(NumInputs, Elt);
  }

  /// Append from a StringRef.
  void append(StringRef RHS) {
    SmallVectorImpl<char>::append(RHS.begin(), RHS.end());
  }

  /// Append from a SmallVector.
  void append(const SmallVectorImpl<char> &RHS) {
    SmallVectorImpl<char>::append(RHS.begin(), RHS.end());
  }

  /// @}
  /// @name String Comparison
  /// @{

  /// Check for string equality.  This is more efficient than compare() when
  /// the relative ordering of inequal strings isn't needed.
  bool equals(StringRef RHS) const {
    return str().equals(RHS);
  }

  /// Check for string equality, ignoring case.
  bool equals_lower(StringRef RHS) const {
    return str().equals_lower(RHS);
  }

  /// Compare two strings; the result is -1, 0, or 1 if this string is
  /// lexicographically less than, equal to, or greater than the \p RHS.
  int compare(StringRef RHS) const {
    return str().compare(RHS);
  }

  /// compare_lower - Compare two strings, ignoring case.
  int compare_lower(StringRef RHS) const {
    return str().compare_lower(RHS);
  }

  /// compare_numeric - Compare two strings, treating sequences of digits as
  /// numbers.
  int compare_numeric(StringRef RHS) const {
    return str().compare_numeric(RHS);
  }

  /// @}
  /// @name String Predicates
  /// @{

  /// startswith - Check if this string starts with the given \p Prefix.
  bool startswith(StringRef Prefix) const {
    return str().startswith(Prefix);
  }

  /// endswith - Check if this string ends with the given \p Suffix.
  bool endswith(StringRef Suffix) const {
    return str().endswith(Suffix);
  }

  /// @}
  /// @name String Searching
  /// @{

  /// find - Search for the first character \p C in the string.
  ///
  /// \return - The index of the first occurrence of \p C, or npos if not
  /// found.
  size_t find(char C, size_t From = 0) const {
    return str().find(C, From);
  }

  /// Search for the first string \p Str in the string.
  ///
  /// \returns The index of the first occurrence of \p Str, or npos if not
  /// found.
  size_t find(StringRef Str, size_t From = 0) const {
    return str().find(Str, From);
  }

  /// Search for the last character \p C in the string.
  ///
  /// \returns The index of the last occurrence of \p C, or npos if not
  /// found.
  size_t rfind(char C, size_t From = StringRef::npos) const {
    return str().rfind(C, From);
  }

  /// Search for the last string \p Str in the string.
  ///
  /// \returns The index of the last occurrence of \p Str, or npos if not
  /// found.
  size_t rfind(StringRef Str) const {
    return str().rfind(Str);
  }

  /// Find the first character in the string that is \p C, or npos if not
  /// found. Same as find.
  size_t find_first_of(char C, size_t From = 0) const {
    return str().find_first_of(C, From);
  }

  /// Find the first character in the string that is in \p Chars, or npos if
  /// not found.
  ///
  /// Complexity: O(size() + Chars.size())
  size_t find_first_of(StringRef Chars, size_t From = 0) const {
    return str().find_first_of(Chars, From);
  }

  /// Find the first character in the string that is not \p C or npos if not
  /// found.
  size_t find_first_not_of(char C, size_t From = 0) const {
    return str().find_first_not_of(C, From);
  }

  /// Find the first character in the string that is not in the string
  /// \p Chars, or npos if not found.
  ///
  /// Complexity: O(size() + Chars.size())
  size_t find_first_not_of(StringRef Chars, size_t From = 0) const {
    return str().find_first_not_of(Chars, From);
  }

  /// Find the last character in the string that is \p C, or npos if not
  /// found.
  size_t find_last_of(char C, size_t From = StringRef::npos) const {
    return str().find_last_of(C, From);
  }

  /// Find the last character in the string that is in \p C, or npos if not
  /// found.
  ///
  /// Complexity: O(size() + Chars.size())
  size_t find_last_of(
      StringRef Chars, size_t From = StringRef::npos) const {
    return str().find_last_of(Chars, From);
  }

  /// @}
  /// @name Helpful Algorithms
  /// @{

  /// Return the number of occurrences of \p C in the string.
  size_t count(char C) const {
    return str().count(C);
  }

  /// Return the number of non-overlapped occurrences of \p Str in the
  /// string.
  size_t count(StringRef Str) const {
    return str().count(Str);
  }

  /// @}
  /// @name Substring Operations
  /// @{

  /// Return a reference to the substring from [Start, Start + N).
  ///
  /// \param Start The index of the starting character in the substring; if
  /// the index is npos or greater than the length of the string then the
  /// empty substring will be returned.
  ///
  /// \param N The number of characters to included in the substring. If \p N
  /// exceeds the number of characters remaining in the string, the string
  /// suffix (starting with \p Start) will be returned.
  StringRef substr(size_t Start, size_t N = StringRef::npos) const {
    return str().substr(Start, N);
  }

  /// Return a reference to the substring from [Start, End).
  ///
  /// \param Start The index of the starting character in the substring; if
  /// the index is npos or greater than the length of the string then the
  /// empty substring will be returned.
  ///
  /// \param End The index following the last character to include in the
  /// substring. If this is npos, or less than \p Start, or exceeds the
  /// number of characters remaining in the string, the string suffix
  /// (starting with \p Start) will be returned.
  StringRef slice(size_t Start, size_t End) const {
    return str().slice(Start, End);
  }

  // Extra methods.

  /// Explicit conversion to StringRef.
  StringRef str() const { return StringRef(this->data(), this->size()); }

  // TODO: Make this const, if it's safe...
  const char* c_str() {
    this->push_back(0);
    this->pop_back();
    return this->data();
  }

  /// Implicit conversion to StringRef.
  operator StringRef() const { return str(); }

  explicit operator std::string() const {
    return std::string(this->data(), this->size());
  }

  // Extra operators.
  const SmallString &operator=(StringRef RHS) {
    this->clear();
    return *this += RHS;
  }

  SmallString &operator+=(StringRef RHS) {
    this->append(RHS.begin(), RHS.end());
    return *this;
  }
  SmallString &operator+=(char C) {
    this->push_back(C);
    return *this;
  }
};

} // end namespace llvm

#endif // LLVM_ADT_SMALLSTRING_H
# 301 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/SmallString.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Twine.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h" 1
//===- Twine.h - Fast Temporary String Concatenation ------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_TWINE_H
#define LLVM_ADT_TWINE_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"

namespace llvm {

  class formatv_object_base;
  class raw_ostream;

  /// Twine - A lightweight data structure for efficiently representing the
  /// concatenation of temporary values as strings.
  ///
  /// A Twine is a kind of rope, it represents a concatenated string using a
  /// binary-tree, where the string is the preorder of the nodes. Since the
  /// Twine can be efficiently rendered into a buffer when its result is used,
  /// it avoids the cost of generating temporary values for intermediate string
  /// results -- particularly in cases when the Twine result is never
  /// required. By explicitly tracking the type of leaf nodes, we can also avoid
  /// the creation of temporary strings for conversions operations (such as
  /// appending an integer to a string).
  ///
  /// A Twine is not intended for use directly and should not be stored, its
  /// implementation relies on the ability to store pointers to temporary stack
  /// objects which may be deallocated at the end of a statement. Twines should
  /// only be used accepted as const references in arguments, when an API wishes
  /// to accept possibly-concatenated strings.
  ///
  /// Twines support a special 'null' value, which always concatenates to form
  /// itself, and renders as an empty string. This can be returned from APIs to
  /// effectively nullify any concatenations performed on the result.
  ///
  /// \b Implementation
  ///
  /// Given the nature of a Twine, it is not possible for the Twine's
  /// concatenation method to construct interior nodes; the result must be
  /// represented inside the returned value. For this reason a Twine object
  /// actually holds two values, the left- and right-hand sides of a
  /// concatenation. We also have nullary Twine objects, which are effectively
  /// sentinel values that represent empty strings.
  ///
  /// Thus, a Twine can effectively have zero, one, or two children. The \see
  /// isNullary(), \see isUnary(), and \see isBinary() predicates exist for
  /// testing the number of children.
  ///
  /// We maintain a number of invariants on Twine objects (FIXME: Why):
  ///  - Nullary twines are always represented with their Kind on the left-hand
  ///    side, and the Empty kind on the right-hand side.
  ///  - Unary twines are always represented with the value on the left-hand
  ///    side, and the Empty kind on the right-hand side.
  ///  - If a Twine has another Twine as a child, that child should always be
  ///    binary (otherwise it could have been folded into the parent).
  ///
  /// These invariants are check by \see isValid().
  ///
  /// \b Efficiency Considerations
  ///
  /// The Twine is designed to yield efficient and small code for common
  /// situations. For this reason, the concat() method is inlined so that
  /// concatenations of leaf nodes can be optimized into stores directly into a
  /// single stack allocated object.
  ///
  /// In practice, not all compilers can be trusted to optimize concat() fully,
  /// so we provide two additional methods (and accompanying operator+
  /// overloads) to guarantee that particularly important cases (cstring plus
  /// StringRef) codegen as desired.
  class Twine {
    /// NodeKind - Represent the type of an argument.
    enum NodeKind : unsigned char {
      /// An empty string; the result of concatenating anything with it is also
      /// empty.
      NullKind,

      /// The empty string.
      EmptyKind,

      /// A pointer to a Twine instance.
      TwineKind,

      /// A pointer to a C string instance.
      CStringKind,

      /// A pointer to an std::string instance.
      StdStringKind,

      /// A pointer to a StringRef instance.
      StringRefKind,

      /// A pointer to a SmallString instance.
      SmallStringKind,

      /// A pointer to a formatv_object_base instance.
      FormatvObjectKind,

      /// A char value, to render as a character.
      CharKind,

      /// An unsigned int value, to render as an unsigned decimal integer.
      DecUIKind,

      /// An int value, to render as a signed decimal integer.
      DecIKind,

      /// A pointer to an unsigned long value, to render as an unsigned decimal
      /// integer.
      DecULKind,

      /// A pointer to a long value, to render as a signed decimal integer.
      DecLKind,

      /// A pointer to an unsigned long long value, to render as an unsigned
      /// decimal integer.
      DecULLKind,

      /// A pointer to a long long value, to render as a signed decimal integer.
      DecLLKind,

      /// A pointer to a uint64_t value, to render as an unsigned hexadecimal
      /// integer.
      UHexKind
    };

    union Child
    {
      const Twine *twine;
      const char *cString;
      const std::string *stdString;
      const StringRef *stringRef;
      const SmallVectorImpl<char> *smallString;
      const formatv_object_base *formatvObject;
      char character;
      unsigned int decUI;
      int decI;
      const unsigned long *decUL;
      const long *decL;
      const unsigned long long *decULL;
      const long long *decLL;
      const uint64_t *uHex;
    };

    /// LHS - The prefix in the concatenation, which may be uninitialized for
    /// Null or Empty kinds.
    Child LHS = {0};

    /// RHS - The suffix in the concatenation, which may be uninitialized for
    /// Null or Empty kinds.
    Child RHS = {0};

    /// LHSKind - The NodeKind of the left hand side, \see getLHSKind().
    NodeKind LHSKind = EmptyKind;

    /// RHSKind - The NodeKind of the right hand side, \see getRHSKind().
    NodeKind RHSKind = EmptyKind;

    /// Construct a nullary twine; the kind must be NullKind or EmptyKind.
    explicit Twine(NodeKind Kind) : LHSKind(Kind) {
      assert(isNullary() && "Invalid kind!");
    }

    /// Construct a binary twine.
    explicit Twine(const Twine &LHS, const Twine &RHS)
        : LHSKind(TwineKind), RHSKind(TwineKind) {
      this->LHS.twine = &LHS;
      this->RHS.twine = &RHS;
      assert(isValid() && "Invalid twine!");
    }

    /// Construct a twine from explicit values.
    explicit Twine(Child LHS, NodeKind LHSKind, Child RHS, NodeKind RHSKind)
        : LHS(LHS), RHS(RHS), LHSKind(LHSKind), RHSKind(RHSKind) {
      assert(isValid() && "Invalid twine!");
    }

    /// Check for the null twine.
    bool isNull() const {
      return getLHSKind() == NullKind;
    }

    /// Check for the empty twine.
    bool isEmpty() const {
      return getLHSKind() == EmptyKind;
    }

    /// Check if this is a nullary twine (null or empty).
    bool isNullary() const {
      return isNull() || isEmpty();
    }

    /// Check if this is a unary twine.
    bool isUnary() const {
      return getRHSKind() == EmptyKind && !isNullary();
    }

    /// Check if this is a binary twine.
    bool isBinary() const {
      return getLHSKind() != NullKind && getRHSKind() != EmptyKind;
    }

    /// Check if this is a valid twine (satisfying the invariants on
    /// order and number of arguments).
    bool isValid() const {
      // Nullary twines always have Empty on the RHS.
      if (isNullary() && getRHSKind() != EmptyKind)
        return false;

      // Null should never appear on the RHS.
      if (getRHSKind() == NullKind)
        return false;

      // The RHS cannot be non-empty if the LHS is empty.
      if (getRHSKind() != EmptyKind && getLHSKind() == EmptyKind)
        return false;

      // A twine child should always be binary.
      if (getLHSKind() == TwineKind &&
          !LHS.twine->isBinary())
        return false;
      if (getRHSKind() == TwineKind &&
          !RHS.twine->isBinary())
        return false;

      return true;
    }

    /// Get the NodeKind of the left-hand side.
    NodeKind getLHSKind() const { return LHSKind; }

    /// Get the NodeKind of the right-hand side.
    NodeKind getRHSKind() const { return RHSKind; }

    /// Print one child from a twine.
    void printOneChild(raw_ostream &OS, Child Ptr, NodeKind Kind) const;

    /// Print the representation of one child from a twine.
    void printOneChildRepr(raw_ostream &OS, Child Ptr,
                           NodeKind Kind) const;

  public:
    /// @name Constructors
    /// @{

    /// Construct from an empty string.
    /*implicit*/ Twine() {
      assert(isValid() && "Invalid twine!");
    }

    Twine(const Twine &) = default;

    /// Construct from a C string.
    ///
    /// We take care here to optimize "" into the empty twine -- this will be
    /// optimized out for string constants. This allows Twine arguments have
    /// default "" values, without introducing unnecessary string constants.
    /*implicit*/ Twine(const char *Str) {
      if (Str[0] != '\0') {
        LHS.cString = Str;
        LHSKind = CStringKind;
      } else
        LHSKind = EmptyKind;

      assert(isValid() && "Invalid twine!");
    }
    /// Delete the implicit conversion from nullptr as Twine(const char *)
    /// cannot take nullptr.
    /*implicit*/ Twine(std::nullptr_t) = delete;

    /// Construct from an std::string.
    /*implicit*/ Twine(const std::string &Str) : LHSKind(StdStringKind) {
      LHS.stdString = &Str;
      assert(isValid() && "Invalid twine!");
    }

    /// Construct from a StringRef.
    /*implicit*/ Twine(const StringRef &Str) : LHSKind(StringRefKind) {
      LHS.stringRef = &Str;
      assert(isValid() && "Invalid twine!");
    }

    /// Construct from a SmallString.
    /*implicit*/ Twine(const SmallVectorImpl<char> &Str)
        : LHSKind(SmallStringKind) {
      LHS.smallString = &Str;
      assert(isValid() && "Invalid twine!");
    }

    /// Construct from a formatv_object_base.
    /*implicit*/ Twine(const formatv_object_base &Fmt)
        : LHSKind(FormatvObjectKind) {
      LHS.formatvObject = &Fmt;
      assert(isValid() && "Invalid twine!");
    }

    /// Construct from a char.
    explicit Twine(char Val) : LHSKind(CharKind) {
      LHS.character = Val;
    }

    /// Construct from a signed char.
    explicit Twine(signed char Val) : LHSKind(CharKind) {
      LHS.character = static_cast<char>(Val);
    }

    /// Construct from an unsigned char.
    explicit Twine(unsigned char Val) : LHSKind(CharKind) {
      LHS.character = static_cast<char>(Val);
    }

    /// Construct a twine to print \p Val as an unsigned decimal integer.
    explicit Twine(unsigned Val) : LHSKind(DecUIKind) {
      LHS.decUI = Val;
    }

    /// Construct a twine to print \p Val as a signed decimal integer.
    explicit Twine(int Val) : LHSKind(DecIKind) {
      LHS.decI = Val;
    }

    /// Construct a twine to print \p Val as an unsigned decimal integer.
    explicit Twine(const unsigned long &Val) : LHSKind(DecULKind) {
      LHS.decUL = &Val;
    }

    /// Construct a twine to print \p Val as a signed decimal integer.
    explicit Twine(const long &Val) : LHSKind(DecLKind) {
      LHS.decL = &Val;
    }

    /// Construct a twine to print \p Val as an unsigned decimal integer.
    explicit Twine(const unsigned long long &Val) : LHSKind(DecULLKind) {
      LHS.decULL = &Val;
    }

    /// Construct a twine to print \p Val as a signed decimal integer.
    explicit Twine(const long long &Val) : LHSKind(DecLLKind) {
      LHS.decLL = &Val;
    }

    // FIXME: Unfortunately, to make sure this is as efficient as possible we
    // need extra binary constructors from particular types. We can't rely on
    // the compiler to be smart enough to fold operator+()/concat() down to the
    // right thing. Yet.

    /// Construct as the concatenation of a C string and a StringRef.
    /*implicit*/ Twine(const char *LHS, const StringRef &RHS)
        : LHSKind(CStringKind), RHSKind(StringRefKind) {
      this->LHS.cString = LHS;
      this->RHS.stringRef = &RHS;
      assert(isValid() && "Invalid twine!");
    }

    /// Construct as the concatenation of a StringRef and a C string.
    /*implicit*/ Twine(const StringRef &LHS, const char *RHS)
        : LHSKind(StringRefKind), RHSKind(CStringKind) {
      this->LHS.stringRef = &LHS;
      this->RHS.cString = RHS;
      assert(isValid() && "Invalid twine!");
    }

    /// Since the intended use of twines is as temporary objects, assignments
    /// when concatenating might cause undefined behavior or stack corruptions
    Twine &operator=(const Twine &) = delete;

    /// Create a 'null' string, which is an empty string that always
    /// concatenates to form another empty string.
    static Twine createNull() {
      return Twine(NullKind);
    }

    /// @}
    /// @name Numeric Conversions
    /// @{

    // Construct a twine to print \p Val as an unsigned hexadecimal integer.
    static Twine utohexstr(const uint64_t &Val) {
      Child LHS, RHS;
      LHS.uHex = &Val;
      RHS.twine = nullptr;
      return Twine(LHS, UHexKind, RHS, EmptyKind);
    }

    /// @}
    /// @name Predicate Operations
    /// @{

    /// Check if this twine is trivially empty; a false return value does not
    /// necessarily mean the twine is empty.
    bool isTriviallyEmpty() const {
      return isNullary();
    }

    /// Return true if this twine can be dynamically accessed as a single
    /// StringRef value with getSingleStringRef().
    bool isSingleStringRef() const {
      if (getRHSKind() != EmptyKind) return false;

      switch (getLHSKind()) {
      case EmptyKind:
      case CStringKind:
      case StdStringKind:
      case StringRefKind:
      case SmallStringKind:
        return true;
      default:
        return false;
      }
    }

    /// @}
    /// @name String Operations
    /// @{

    Twine concat(const Twine &Suffix) const;

    /// @}
    /// @name Output & Conversion.
    /// @{

    /// Return the twine contents as a std::string.
    std::string str() const;

    /// Append the concatenated string into the given SmallString or SmallVector.
    void toVector(SmallVectorImpl<char> &Out) const;

    /// This returns the twine as a single StringRef.  This method is only valid
    /// if isSingleStringRef() is true.
    StringRef getSingleStringRef() const {
      assert(isSingleStringRef() &&"This cannot be had as a single stringref!");
      switch (getLHSKind()) {
      default: llvm_unreachable("Out of sync with isSingleStringRef");
      case EmptyKind:      return StringRef();
      case CStringKind:    return StringRef(LHS.cString);
      case StdStringKind:  return StringRef(*LHS.stdString);
      case StringRefKind:  return *LHS.stringRef;
      case SmallStringKind:
        return StringRef(LHS.smallString->data(), LHS.smallString->size());
      }
    }

    /// This returns the twine as a single StringRef if it can be
    /// represented as such. Otherwise the twine is written into the given
    /// SmallVector and a StringRef to the SmallVector's data is returned.
    StringRef toStringRef(SmallVectorImpl<char> &Out) const {
      if (isSingleStringRef())
        return getSingleStringRef();
      toVector(Out);
      return StringRef(Out.data(), Out.size());
    }

    /// This returns the twine as a single null terminated StringRef if it
    /// can be represented as such. Otherwise the twine is written into the
    /// given SmallVector and a StringRef to the SmallVector's data is returned.
    ///
    /// The returned StringRef's size does not include the null terminator.
    StringRef toNullTerminatedStringRef(SmallVectorImpl<char> &Out) const;

    /// Write the concatenated string represented by this twine to the
    /// stream \p OS.
    void print(raw_ostream &OS) const;

    /// Dump the concatenated string represented by this twine to stderr.
    void dump() const;

    /// Write the representation of this twine to the stream \p OS.
    void printRepr(raw_ostream &OS) const;

    /// Dump the representation of this twine to stderr.
    void dumpRepr() const;

    /// @}
  };

  /// @name Twine Inline Implementations
  /// @{

  inline Twine Twine::concat(const Twine &Suffix) const {
    // Concatenation with null is null.
    if (isNull() || Suffix.isNull())
      return Twine(NullKind);

    // Concatenation with empty yields the other side.
    if (isEmpty())
      return Suffix;
    if (Suffix.isEmpty())
      return *this;

    // Otherwise we need to create a new node, taking care to fold in unary
    // twines.
    Child NewLHS, NewRHS;
    NewLHS.twine = this;
    NewRHS.twine = &Suffix;
    NodeKind NewLHSKind = TwineKind, NewRHSKind = TwineKind;
    if (isUnary()) {
      NewLHS = LHS;
      NewLHSKind = getLHSKind();
    }
    if (Suffix.isUnary()) {
      NewRHS = Suffix.LHS;
      NewRHSKind = Suffix.getLHSKind();
    }

    return Twine(NewLHS, NewLHSKind, NewRHS, NewRHSKind);
  }

  inline Twine operator+(const Twine &LHS, const Twine &RHS) {
    return LHS.concat(RHS);
  }

  /// Additional overload to guarantee simplified codegen; this is equivalent to
  /// concat().

  inline Twine operator+(const char *LHS, const StringRef &RHS) {
    return Twine(LHS, RHS);
  }

  /// Additional overload to guarantee simplified codegen; this is equivalent to
  /// concat().

  inline Twine operator+(const StringRef &LHS, const char *RHS) {
    return Twine(LHS, RHS);
  }

  inline raw_ostream &operator<<(raw_ostream &OS, const Twine &RHS) {
    RHS.print(OS);
    return OS;
  }

  /// @}

} // end namespace llvm

#endif // LLVM_ADT_TWINE_H
# 545 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/Twine.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"

namespace llvm {

template<typename T> class SmallVectorImpl;
class raw_ostream;

/// hexdigit - Return the hexadecimal character for the
/// given number \p X (which should be less than 16).
inline char hexdigit(unsigned X, bool LowerCase = false) {
  const char HexChar = LowerCase ? 'a' : 'A';
  return X < 10 ? '0' + X : HexChar + X - 10;
}

/// Given an array of c-style strings terminated by a null pointer, construct
/// a vector of StringRefs representing the same strings without the terminating
/// null string.
inline std::vector<StringRef> toStringRefArray(const char *const *Strings) {
  std::vector<StringRef> Result;
  while (*Strings)
    Result.push_back(*Strings++);
  return Result;
}

/// Construct a string ref from a boolean.
inline StringRef toStringRef(bool B) { return StringRef(B ? "true" : "false"); }

/// Construct a string ref from an array ref of unsigned chars.
inline StringRef toStringRef(ArrayRef<uint8_t> Input) {
  return StringRef(reinterpret_cast<const char *>(Input.begin()), Input.size());
}

/// Construct a string ref from an array ref of unsigned chars.
inline ArrayRef<uint8_t> arrayRefFromStringRef(StringRef Input) {
  return {Input.bytes_begin(), Input.bytes_end()};
}

/// Interpret the given character \p C as a hexadecimal digit and return its
/// value.
///
/// If \p C is not a valid hex digit, -1U is returned.
inline unsigned hexDigitValue(char C) {
  if (C >= '0' && C <= '9') return C-'0';
  if (C >= 'a' && C <= 'f') return C-'a'+10U;
  if (C >= 'A' && C <= 'F') return C-'A'+10U;
  return -1U;
}

/// Checks if character \p C is one of the 10 decimal digits.
inline bool isDigit(char C) { return C >= '0' && C <= '9'; }

/// Checks if character \p C is a hexadecimal numeric character.
inline bool isHexDigit(char C) { return hexDigitValue(C) != -1U; }

/// Checks if character \p C is a valid letter as classified by "C" locale.
inline bool isAlpha(char C) {
  return ('a' <= C && C <= 'z') || ('A' <= C && C <= 'Z');
}

/// Checks whether character \p C is either a decimal digit or an uppercase or
/// lowercase letter as classified by "C" locale.
inline bool isAlnum(char C) { return isAlpha(C) || isDigit(C); }

/// Checks whether character \p C is valid ASCII (high bit is zero).
inline bool isASCII(char C) { return static_cast<unsigned char>(C) <= 127; }

/// Checks whether all characters in S are ASCII.
inline bool isASCII(llvm::StringRef S) {
  for (char C : S)
    if (LLVM_UNLIKELY(!isASCII(C)))
      return false;
  return true;
}

/// Checks whether character \p C is printable.
///
/// Locale-independent version of the C standard library isprint whose results
/// may differ on different platforms.
inline bool isPrint(char C) {
  unsigned char UC = static_cast<unsigned char>(C);
  return (0x20 <= UC) && (UC <= 0x7E);
}

/// Returns the corresponding lowercase character if \p x is uppercase.
inline char toLower(char x) {
  if (x >= 'A' && x <= 'Z')
    return x - 'A' + 'a';
  return x;
}

/// Returns the corresponding uppercase character if \p x is lowercase.
inline char toUpper(char x) {
  if (x >= 'a' && x <= 'z')
    return x - 'a' + 'A';
  return x;
}

inline std::string utohexstr(uint64_t X, bool LowerCase = false) {
  char Buffer[17];
  char *BufPtr = std::end(Buffer);

  if (X == 0) *--BufPtr = '0';

  while (X) {
    unsigned char Mod = static_cast<unsigned char>(X) & 15;
    *--BufPtr = hexdigit(Mod, LowerCase);
    X >>= 4;
  }

  return std::string(BufPtr, std::end(Buffer));
}

/// Convert buffer \p Input to its hexadecimal representation.
/// The returned string is double the size of \p Input.
inline std::string toHex(StringRef Input, bool LowerCase = false) {
  static const char *const LUT = "0123456789ABCDEF";
  const uint8_t Offset = LowerCase ? 32 : 0;
  size_t Length = Input.size();

  std::string Output;
  Output.reserve(2 * Length);
  for (size_t i = 0; i < Length; ++i) {
    const unsigned char c = Input[i];
    Output.push_back(LUT[c >> 4] | Offset);
    Output.push_back(LUT[c & 15] | Offset);
  }
  return Output;
}

inline std::string toHex(ArrayRef<uint8_t> Input, bool LowerCase = false) {
  return toHex(toStringRef(Input), LowerCase);
}

inline uint8_t hexFromNibbles(char MSB, char LSB) {
  unsigned U1 = hexDigitValue(MSB);
  unsigned U2 = hexDigitValue(LSB);
  assert(U1 != -1U && U2 != -1U);

  return static_cast<uint8_t>((U1 << 4) | U2);
}

/// Convert hexadecimal string \p Input to its binary representation.
/// The return string is half the size of \p Input.
inline std::string fromHex(StringRef Input) {
  if (Input.empty())
    return std::string();

  std::string Output;
  Output.reserve((Input.size() + 1) / 2);
  if (Input.size() % 2 == 1) {
    Output.push_back(hexFromNibbles('0', Input.front()));
    Input = Input.drop_front();
  }

  assert(Input.size() % 2 == 0);
  while (!Input.empty()) {
    uint8_t Hex = hexFromNibbles(Input[0], Input[1]);
    Output.push_back(Hex);
    Input = Input.drop_front(2);
  }
  return Output;
}

/// Convert the string \p S to an integer of the specified type using
/// the radix \p Base.  If \p Base is 0, auto-detects the radix.
/// Returns true if the number was successfully converted, false otherwise.
template <typename N> bool to_integer(StringRef S, N &Num, unsigned Base = 0) {
  return !S.getAsInteger(Base, Num);
}

namespace detail {
template <typename N>
inline bool to_float(const Twine &T, N &Num, N (*StrTo)(const char *, char **)) {
  SmallString<32> Storage;
  StringRef S = T.toNullTerminatedStringRef(Storage);
  char *End;
  N Temp = StrTo(S.data(), &End);
  if (*End != '\0')
    return false;
  Num = Temp;
  return true;
}
}

inline bool to_float(const Twine &T, float &Num) {
  return detail::to_float(T, Num, strtof);
}

inline bool to_float(const Twine &T, double &Num) {
  return detail::to_float(T, Num, strtod);
}

inline bool to_float(const Twine &T, long double &Num) {
  return detail::to_float(T, Num, strtold);
}

inline std::string utostr(uint64_t X, bool isNeg = false) {
  char Buffer[21];
  char *BufPtr = std::end(Buffer);

  if (X == 0) *--BufPtr = '0';  // Handle special case...

  while (X) {
    *--BufPtr = '0' + char(X % 10);
    X /= 10;
  }

  if (isNeg) *--BufPtr = '-';   // Add negative sign...
  return std::string(BufPtr, std::end(Buffer));
}

inline std::string itostr(int64_t X) {
  if (X < 0)
    return utostr(static_cast<uint64_t>(-X), true);
  else
    return utostr(static_cast<uint64_t>(X));
}

/// StrInStrNoCase - Portable version of strcasestr.  Locates the first
/// occurrence of string 's1' in string 's2', ignoring case.  Returns
/// the offset of s2 in s1 or npos if s2 cannot be found.
StringRef::size_type StrInStrNoCase(StringRef s1, StringRef s2);

/// getToken - This function extracts one token from source, ignoring any
/// leading characters that appear in the Delimiters string, and ending the
/// token at any of the characters that appear in the Delimiters string.  If
/// there are no tokens in the source string, an empty string is returned.
/// The function returns a pair containing the extracted token and the
/// remaining tail string.
std::pair<StringRef, StringRef> getToken(StringRef Source,
                                         StringRef Delimiters = " \t\n\v\f\r");

/// SplitString - Split up the specified string according to the specified
/// delimiters, appending the result fragments to the output list.
void SplitString(StringRef Source,
                 SmallVectorImpl<StringRef> &OutFragments,
                 StringRef Delimiters = " \t\n\v\f\r");

/// Returns the English suffix for an ordinal integer (-st, -nd, -rd, -th).
inline StringRef getOrdinalSuffix(unsigned Val) {
  // It is critically important that we do this perfectly for
  // user-written sequences with over 100 elements.
  switch (Val % 100) {
  case 11:
  case 12:
  case 13:
    return "th";
  default:
    switch (Val % 10) {
      case 1: return "st";
      case 2: return "nd";
      case 3: return "rd";
      default: return "th";
    }
  }
}

/// Print each character of the specified string, escaping it if it is not
/// printable or if it is an escape char.
void printEscapedString(StringRef Name, raw_ostream &Out);

/// Print each character of the specified string, escaping HTML special
/// characters.
void printHTMLEscaped(StringRef String, raw_ostream &Out);

/// printLowerCase - Print each character as lowercase if it is uppercase.
void printLowerCase(StringRef String, raw_ostream &Out);

namespace detail {

template <typename IteratorT>
inline std::string join_impl(IteratorT Begin, IteratorT End,
                             StringRef Separator, std::input_iterator_tag) {
  std::string S;
  if (Begin == End)
    return S;

  S += (*Begin);
  while (++Begin != End) {
    S += Separator;
    S += (*Begin);
  }
  return S;
}

template <typename IteratorT>
inline std::string join_impl(IteratorT Begin, IteratorT End,
                             StringRef Separator, std::forward_iterator_tag) {
  std::string S;
  if (Begin == End)
    return S;

  size_t Len = (std::distance(Begin, End) - 1) * Separator.size();
  for (IteratorT I = Begin; I != End; ++I)
    Len += (*Begin).size();
  S.reserve(Len);
  S += (*Begin);
  while (++Begin != End) {
    S += Separator;
    S += (*Begin);
  }
  return S;
}

template <typename Sep>
inline void join_items_impl(std::string &Result, Sep Separator) {}

template <typename Sep, typename Arg>
inline void join_items_impl(std::string &Result, Sep Separator,
                            const Arg &Item) {
  Result += Item;
}

template <typename Sep, typename Arg1, typename... Args>
inline void join_items_impl(std::string &Result, Sep Separator, const Arg1 &A1,
                            Args &&... Items) {
  Result += A1;
  Result += Separator;
  join_items_impl(Result, Separator, std::forward<Args>(Items)...);
}

inline size_t join_one_item_size(char) { return 1; }
inline size_t join_one_item_size(const char *S) { return S ? ::strlen(S) : 0; }

template <typename T> inline size_t join_one_item_size(const T &Str) {
  return Str.size();
}

inline size_t join_items_size() { return 0; }

template <typename A1> inline size_t join_items_size(const A1 &A) {
  return join_one_item_size(A);
}
template <typename A1, typename... Args>
inline size_t join_items_size(const A1 &A, Args &&... Items) {
  return join_one_item_size(A) + join_items_size(std::forward<Args>(Items)...);
}

} // end namespace detail

/// Joins the strings in the range [Begin, End), adding Separator between
/// the elements.
template <typename IteratorT>
inline std::string join(IteratorT Begin, IteratorT End, StringRef Separator) {
  using tag = typename std::iterator_traits<IteratorT>::iterator_category;
  return detail::join_impl(Begin, End, Separator, tag());
}

/// Joins the strings in the range [R.begin(), R.end()), adding Separator
/// between the elements.
template <typename Range>
inline std::string join(Range &&R, StringRef Separator) {
  return join(R.begin(), R.end(), Separator);
}

/// Joins the strings in the parameter pack \p Items, adding \p Separator
/// between the elements.  All arguments must be implicitly convertible to
/// std::string, or there should be an overload of std::string::operator+=()
/// that accepts the argument explicitly.
template <typename Sep, typename... Args>
inline std::string join_items(Sep Separator, Args &&... Items) {
  std::string Result;
  if (sizeof...(Items) == 0)
    return Result;

  size_t NS = detail::join_one_item_size(Separator);
  size_t NI = detail::join_items_size(std::forward<Args>(Items)...);
  Result.reserve(NI + (sizeof...(Items) - 1) * NS + 1);
  detail::join_items_impl(Result, Separator, std::forward<Args>(Items)...);
  return Result;
}

} // end namespace llvm

#endif // LLVM_ADT_STRINGEXTRAS_H
# 402 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringExtras.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Twine.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Config/abi-breaking.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/AlignOf.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Debug.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Debug.h" 1
//===- llvm/Support/Debug.h - Easy way to add debug output ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file implements a handy way of adding debugging information to your
// code, without it being enabled all of the time, and without having to add
// command line options to enable it.
//
// In particular, just wrap your code with the LLVM_DEBUG() macro, and it will
// be enabled automatically if you specify '-debug' on the command-line.
// LLVM_DEBUG() requires the DEBUG_TYPE macro to be defined. Set it to "foo"
// specify that your debug code belongs to class "foo". Be careful that you only
// do this after including Debug.h and not around any #include of headers.
// Headers should define and undef the macro acround the code that needs to use
// the LLVM_DEBUG() macro. Then, on the command line, you can specify
// '-debug-only=foo' to enable JUST the debug information for the foo class.
//
// When compiling without assertions, the -debug-* options and all code in
// LLVM_DEBUG() statements disappears, so it does not affect the runtime of the
// code.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_DEBUG_H
#define LLVM_SUPPORT_DEBUG_H

namespace llvm {

class raw_ostream;

#ifndef NDEBUG

/// isCurrentDebugType - Return true if the specified string is the debug type
/// specified on the command line, or if none was specified on the command line
/// with the -debug-only=X option.
///
bool isCurrentDebugType(const char *Type);

/// setCurrentDebugType - Set the current debug type, as if the -debug-only=X
/// option were specified.  Note that DebugFlag also needs to be set to true for
/// debug output to be produced.
///
void setCurrentDebugType(const char *Type);

/// setCurrentDebugTypes - Set the current debug type, as if the
/// -debug-only=X,Y,Z option were specified. Note that DebugFlag
/// also needs to be set to true for debug output to be produced.
///
void setCurrentDebugTypes(const char **Types, unsigned Count);

/// DEBUG_WITH_TYPE macro - This macro should be used by passes to emit debug
/// information.  In the '-debug' option is specified on the commandline, and if
/// this is a debug build, then the code specified as the option to the macro
/// will be executed.  Otherwise it will not be.  Example:
///
/// DEBUG_WITH_TYPE("bitset", dbgs() << "Bitset contains: " << Bitset << "\n");
///
/// This will emit the debug information if -debug is present, and -debug-only
/// is not specified, or is specified as "bitset".
#define DEBUG_WITH_TYPE(TYPE, X)                                        \
  do { if (::llvm::DebugFlag && ::llvm::isCurrentDebugType(TYPE)) { X; } \
  } while (false)

#else
# 69 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Debug.h"
#define isCurrentDebugType(X) (false)
#define setCurrentDebugType(X)
#define setCurrentDebugTypes(X, N)
#define DEBUG_WITH_TYPE(TYPE, X) do { } while (false)
#endif
# 74 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Debug.h"

/// This boolean is set to true if the '-debug' command line option
/// is specified.  This should probably not be referenced directly, instead, use
/// the DEBUG macro below.
///
extern bool DebugFlag;

/// \name Verification flags.
///
/// These flags turns on/off that are expensive and are turned off by default,
/// unless macro EXPENSIVE_CHECKS is defined. The flags allow selectively
/// turning the checks on without need to recompile.
/// \{

/// Enables verification of dominator trees.
///
extern bool VerifyDomInfo;

/// Enables verification of loop info.
///
extern bool VerifyLoopInfo;

/// Enables verification of MemorySSA.
///
extern bool VerifyMemorySSA;

///\}

/// EnableDebugBuffering - This defaults to false.  If true, the debug
/// stream will install signal handlers to dump any buffered debug
/// output.  It allows clients to selectively allow the debug stream
/// to install signal handlers if they are certain there will be no
/// conflict.
///
extern bool EnableDebugBuffering;

/// dbgs() - This returns a reference to a raw_ostream for debugging
/// messages.  If debugging is disabled it returns errs().  Use it
/// like: dbgs() << "foo" << "bar";
raw_ostream &dbgs();

// DEBUG macro - This macro should be used by passes to emit debug information.
// In the '-debug' option is specified on the commandline, and if this is a
// debug build, then the code specified as the option to the macro will be
// executed.  Otherwise it will not be.  Example:
//
// LLVM_DEBUG(dbgs() << "Bitset contains: " << Bitset << "\n");
//
#define LLVM_DEBUG(X) DEBUG_WITH_TYPE(DEBUG_TYPE, X)

} // end namespace llvm

#endif // LLVM_SUPPORT_DEBUG_H
# 127 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Debug.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorOr.h"
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h" 1
//===- llvm/Support/ErrorOr.h - Error Smart Pointer -------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
///
/// \file
///
/// Provides ErrorOr<T> smart pointer.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_ERROROR_H
#define LLVM_SUPPORT_ERROROR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/AlignOf.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <system_error>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 1 3
// -*- C++ -*-
//===---------------------------- system_error ----------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_SYSTEM_ERROR
#define _LIBCPP_SYSTEM_ERROR

/*
    system_error synopsis

namespace std
{

class error_category
{
public:
    virtual ~error_category() noexcept;

    constexpr error_category();
    error_category(const error_category&) = delete;
    error_category& operator=(const error_category&) = delete;

    virtual const char* name() const noexcept = 0;
    virtual error_condition default_error_condition(int ev) const noexcept;
    virtual bool equivalent(int code, const error_condition& condition) const noexcept;
    virtual bool equivalent(const error_code& code, int condition) const noexcept;
    virtual string message(int ev) const = 0;

    bool operator==(const error_category& rhs) const noexcept;
    bool operator!=(const error_category& rhs) const noexcept;
    bool operator<(const error_category& rhs) const noexcept;
};

const error_category& generic_category() noexcept;
const error_category& system_category() noexcept;

template <class T> struct is_error_code_enum
    : public false_type {};

template <class T> struct is_error_condition_enum
    : public false_type {};

template <class _Tp>
inline constexpr size_t is_error_condition_enum_v = is_error_condition_enum<_Tp>::value; // C++17

template <class _Tp>
inline constexpr size_t is_error_code_enum_v = is_error_code_enum<_Tp>::value; // C++17

class error_code
{
public:
    // constructors:
    error_code() noexcept;
    error_code(int val, const error_category& cat) noexcept;
    template <class ErrorCodeEnum>
        error_code(ErrorCodeEnum e) noexcept;

    // modifiers:
    void assign(int val, const error_category& cat) noexcept;
    template <class ErrorCodeEnum>
        error_code& operator=(ErrorCodeEnum e) noexcept;
    void clear() noexcept;

    // observers:
    int value() const noexcept;
    const error_category& category() const noexcept;
    error_condition default_error_condition() const noexcept;
    string message() const;
    explicit operator bool() const noexcept;
};

// non-member functions:
bool operator<(const error_code& lhs, const error_code& rhs) noexcept;
template <class charT, class traits>
    basic_ostream<charT,traits>&
    operator<<(basic_ostream<charT,traits>& os, const error_code& ec);

class error_condition
{
public:
    // constructors:
    error_condition() noexcept;
    error_condition(int val, const error_category& cat) noexcept;
    template <class ErrorConditionEnum>
        error_condition(ErrorConditionEnum e) noexcept;

    // modifiers:
    void assign(int val, const error_category& cat) noexcept;
    template <class ErrorConditionEnum>
        error_condition& operator=(ErrorConditionEnum e) noexcept;
    void clear() noexcept;

    // observers:
    int value() const noexcept;
    const error_category& category() const noexcept;
    string message() const noexcept;
    explicit operator bool() const noexcept;
};

bool operator<(const error_condition& lhs, const error_condition& rhs) noexcept;

class system_error
    : public runtime_error
{
public:
    system_error(error_code ec, const string& what_arg);
    system_error(error_code ec, const char* what_arg);
    system_error(error_code ec);
    system_error(int ev, const error_category& ecat, const string& what_arg);
    system_error(int ev, const error_category& ecat, const char* what_arg);
    system_error(int ev, const error_category& ecat);

    const error_code& code() const noexcept;
    const char* what() const noexcept;
};

template <> struct is_error_condition_enum<errc>
    : true_type { }

error_code make_error_code(errc e) noexcept;
error_condition make_error_condition(errc e) noexcept;

// Comparison operators:
bool operator==(const error_code& lhs, const error_code& rhs) noexcept;
bool operator==(const error_code& lhs, const error_condition& rhs) noexcept;
bool operator==(const error_condition& lhs, const error_code& rhs) noexcept;
bool operator==(const error_condition& lhs, const error_condition& rhs) noexcept;
bool operator!=(const error_code& lhs, const error_code& rhs) noexcept;
bool operator!=(const error_code& lhs, const error_condition& rhs) noexcept;
bool operator!=(const error_condition& lhs, const error_code& rhs) noexcept;
bool operator!=(const error_condition& lhs, const error_condition& rhs) noexcept;

template <> struct hash<std::error_code>;
template <> struct hash<std::error_condition>;

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__errc>
#endif /* expanded by -frewrite-includes */
# 145 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 1 3
// -*- C++ -*-
//===---------------------------- __errc ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___ERRC
#define _LIBCPP___ERRC

/*
    system_error synopsis

namespace std
{

enum class errc
{
    address_family_not_supported,       // EAFNOSUPPORT
    address_in_use,                     // EADDRINUSE
    address_not_available,              // EADDRNOTAVAIL
    already_connected,                  // EISCONN
    argument_list_too_long,             // E2BIG
    argument_out_of_domain,             // EDOM
    bad_address,                        // EFAULT
    bad_file_descriptor,                // EBADF
    bad_message,                        // EBADMSG
    broken_pipe,                        // EPIPE
    connection_aborted,                 // ECONNABORTED
    connection_already_in_progress,     // EALREADY
    connection_refused,                 // ECONNREFUSED
    connection_reset,                   // ECONNRESET
    cross_device_link,                  // EXDEV
    destination_address_required,       // EDESTADDRREQ
    device_or_resource_busy,            // EBUSY
    directory_not_empty,                // ENOTEMPTY
    executable_format_error,            // ENOEXEC
    file_exists,                        // EEXIST
    file_too_large,                     // EFBIG
    filename_too_long,                  // ENAMETOOLONG
    function_not_supported,             // ENOSYS
    host_unreachable,                   // EHOSTUNREACH
    identifier_removed,                 // EIDRM
    illegal_byte_sequence,              // EILSEQ
    inappropriate_io_control_operation, // ENOTTY
    interrupted,                        // EINTR
    invalid_argument,                   // EINVAL
    invalid_seek,                       // ESPIPE
    io_error,                           // EIO
    is_a_directory,                     // EISDIR
    message_size,                       // EMSGSIZE
    network_down,                       // ENETDOWN
    network_reset,                      // ENETRESET
    network_unreachable,                // ENETUNREACH
    no_buffer_space,                    // ENOBUFS
    no_child_process,                   // ECHILD
    no_link,                            // ENOLINK
    no_lock_available,                  // ENOLCK
    no_message_available,               // ENODATA
    no_message,                         // ENOMSG
    no_protocol_option,                 // ENOPROTOOPT
    no_space_on_device,                 // ENOSPC
    no_stream_resources,                // ENOSR
    no_such_device_or_address,          // ENXIO
    no_such_device,                     // ENODEV
    no_such_file_or_directory,          // ENOENT
    no_such_process,                    // ESRCH
    not_a_directory,                    // ENOTDIR
    not_a_socket,                       // ENOTSOCK
    not_a_stream,                       // ENOSTR
    not_connected,                      // ENOTCONN
    not_enough_memory,                  // ENOMEM
    not_supported,                      // ENOTSUP
    operation_canceled,                 // ECANCELED
    operation_in_progress,              // EINPROGRESS
    operation_not_permitted,            // EPERM
    operation_not_supported,            // EOPNOTSUPP
    operation_would_block,              // EWOULDBLOCK
    owner_dead,                         // EOWNERDEAD
    permission_denied,                  // EACCES
    protocol_error,                     // EPROTO
    protocol_not_supported,             // EPROTONOSUPPORT
    read_only_file_system,              // EROFS
    resource_deadlock_would_occur,      // EDEADLK
    resource_unavailable_try_again,     // EAGAIN
    result_out_of_range,                // ERANGE
    state_not_recoverable,              // ENOTRECOVERABLE
    stream_timeout,                     // ETIME
    text_file_busy,                     // ETXTBSY
    timed_out,                          // ETIMEDOUT
    too_many_files_open_in_system,      // ENFILE
    too_many_files_open,                // EMFILE
    too_many_links,                     // EMLINK
    too_many_symbolic_link_levels,      // ELOOP
    value_too_large,                    // EOVERFLOW
    wrong_protocol_type                 // EPROTOTYPE
};

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 103 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
#if 0 /* expanded by -frewrite-includes */
#include <cerrno>
#endif /* expanded by -frewrite-includes */
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 1 3
// -*- C++ -*-
//===-------------------------- cerrno ------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CERRNO
#define _LIBCPP_CERRNO

/*
    cerrno synopsis

Macros:

    EDOM
    EILSEQ  // C99
    ERANGE
    errno

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 3
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 3
#if 0 /* expanded by -frewrite-includes */
#include <errno.h>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 1 3
// -*- C++ -*-
//===-------------------------- errno.h -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_ERRNO_H
#define _LIBCPP_ERRNO_H

/*
    errno.h synopsis

Macros:

    EDOM
    EILSEQ  // C99
    ERANGE
    errno

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 28 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3
#endif
# 30 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <errno.h>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/errno.h" 1 3 4
/*
 * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/errno.h>
#endif /* expanded by -frewrite-includes */
# 23 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/errno.h" 3 4
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 1 3 4
/*
 * Copyright (c) 2000-2012 Apple, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
/* Copyright (c) 1995 NeXT Computer, Inc. All Rights Reserved */
/*
 * Copyright (c) 1982, 1986, 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)errno.h	8.5 (Berkeley) 1/21/94
 */

#ifndef _SYS_ERRNO_H_
#define _SYS_ERRNO_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 72 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
# 73 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4


#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_WANT_LIB_EXT1__) && __STDC_WANT_LIB_EXT1__ >= 1
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types/_errno_t.h>
#endif /* expanded by -frewrite-includes */
# 76 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
# 77 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#endif
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

__BEGIN_DECLS
extern int * __error(void);
#define errno (*__error())
__END_DECLS

/*
 * Error codes
 */

#define EPERM           1               /* Operation not permitted */
#define ENOENT          2               /* No such file or directory */
#define ESRCH           3               /* No such process */
#define EINTR           4               /* Interrupted system call */
#define EIO             5               /* Input/output error */
#define ENXIO           6               /* Device not configured */
#define E2BIG           7               /* Argument list too long */
#define ENOEXEC         8               /* Exec format error */
#define EBADF           9               /* Bad file descriptor */
#define ECHILD          10              /* No child processes */
#define EDEADLK         11              /* Resource deadlock avoided */
                                        /* 11 was EAGAIN */
#define ENOMEM          12              /* Cannot allocate memory */
#define EACCES          13              /* Permission denied */
#define EFAULT          14              /* Bad address */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 104 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define ENOTBLK         15              /* Block device required */
#endif
# 106 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EBUSY           16              /* Device / Resource busy */
#define EEXIST          17              /* File exists */
#define EXDEV           18              /* Cross-device link */
#define ENODEV          19              /* Operation not supported by device */
#define ENOTDIR         20              /* Not a directory */
#define EISDIR          21              /* Is a directory */
#define EINVAL          22              /* Invalid argument */
#define ENFILE          23              /* Too many open files in system */
#define EMFILE          24              /* Too many open files */
#define ENOTTY          25              /* Inappropriate ioctl for device */
#define ETXTBSY         26              /* Text file busy */
#define EFBIG           27              /* File too large */
#define ENOSPC          28              /* No space left on device */
#define ESPIPE          29              /* Illegal seek */
#define EROFS           30              /* Read-only file system */
#define EMLINK          31              /* Too many links */
#define EPIPE           32              /* Broken pipe */

/* math software */
#define EDOM            33              /* Numerical argument out of domain */
#define ERANGE          34              /* Result too large */

/* non-blocking and interrupt i/o */
#define EAGAIN          35              /* Resource temporarily unavailable */
#define EWOULDBLOCK     EAGAIN          /* Operation would block */
#define EINPROGRESS     36              /* Operation now in progress */
#define EALREADY        37              /* Operation already in progress */

/* ipc/network software -- argument errors */
#define ENOTSOCK        38              /* Socket operation on non-socket */
#define EDESTADDRREQ    39              /* Destination address required */
#define EMSGSIZE        40              /* Message too long */
#define EPROTOTYPE      41              /* Protocol wrong type for socket */
#define ENOPROTOOPT     42              /* Protocol not available */
#define EPROTONOSUPPORT 43              /* Protocol not supported */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 142 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define ESOCKTNOSUPPORT 44              /* Socket type not supported */
#endif
# 144 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define ENOTSUP         45              /* Operation not supported */
#if 0 /* disabled by -frewrite-includes */
#if !__DARWIN_UNIX03 && !defined(KERNEL)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 146 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
/*
 * This is the same for binary and source copmpatability, unless compiling
 * the kernel itself, or compiling __DARWIN_UNIX03; if compiling for the
 * kernel, the correct value will be returned.  If compiling non-POSIX
 * source, the kernel return value will be converted by a stub in libc, and
 * if compiling source with __DARWIN_UNIX03, the conversion in libc is not
 * done, and the caller gets the expected (discrete) value.
 */
#define EOPNOTSUPP       ENOTSUP        /* Operation not supported on socket */
#endif /* !__DARWIN_UNIX03 && !KERNEL */
# 156 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 158 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EPFNOSUPPORT    46              /* Protocol family not supported */
#endif
# 160 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EAFNOSUPPORT    47              /* Address family not supported by protocol family */
#define EADDRINUSE      48              /* Address already in use */
#define EADDRNOTAVAIL   49              /* Can't assign requested address */

/* ipc/network software -- operational errors */
#define ENETDOWN        50              /* Network is down */
#define ENETUNREACH     51              /* Network is unreachable */
#define ENETRESET       52              /* Network dropped connection on reset */
#define ECONNABORTED    53              /* Software caused connection abort */
#define ECONNRESET      54              /* Connection reset by peer */
#define ENOBUFS         55              /* No buffer space available */
#define EISCONN         56              /* Socket is already connected */
#define ENOTCONN        57              /* Socket is not connected */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 174 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define ESHUTDOWN       58              /* Can't send after socket shutdown */
#define ETOOMANYREFS    59              /* Too many references: can't splice */
#endif
# 177 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define ETIMEDOUT       60              /* Operation timed out */
#define ECONNREFUSED    61              /* Connection refused */

#define ELOOP           62              /* Too many levels of symbolic links */
#define ENAMETOOLONG    63              /* File name too long */

/* should be rearranged */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 185 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EHOSTDOWN       64              /* Host is down */
#endif
# 187 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EHOSTUNREACH    65              /* No route to host */
#define ENOTEMPTY       66              /* Directory not empty */

/* quotas & mush */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 192 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EPROCLIM        67              /* Too many processes */
#define EUSERS          68              /* Too many users */
#endif
# 195 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EDQUOT          69              /* Disc quota exceeded */

/* Network File System */
#define ESTALE          70              /* Stale NFS file handle */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 200 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EREMOTE         71              /* Too many levels of remote in path */
#define EBADRPC         72              /* RPC struct is bad */
#define ERPCMISMATCH    73              /* RPC version wrong */
#define EPROGUNAVAIL    74              /* RPC prog. not avail */
#define EPROGMISMATCH   75              /* Program version wrong */
#define EPROCUNAVAIL    76              /* Bad procedure for program */
#endif
# 207 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

#define ENOLCK          77              /* No locks available */
#define ENOSYS          78              /* Function not implemented */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 212 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EFTYPE          79              /* Inappropriate file type or format */
#define EAUTH           80              /* Authentication error */
#define ENEEDAUTH       81              /* Need authenticator */

/* Intelligent device errors */
#define EPWROFF         82      /* Device power is off */
#define EDEVERR         83      /* Device error, e.g. paper out */
#endif
# 220 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

#define EOVERFLOW       84              /* Value too large to be stored in data type */

/* Program loading errors */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 225 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EBADEXEC        85      /* Bad executable */
#define EBADARCH        86      /* Bad CPU type in executable */
#define ESHLIBVERS      87      /* Shared library version mismatch */
#define EBADMACHO       88      /* Malformed Macho file */
#endif
# 230 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

#define ECANCELED       89              /* Operation canceled */

#define EIDRM           90              /* Identifier removed */
#define ENOMSG          91              /* No message of desired type */
#define EILSEQ          92              /* Illegal byte sequence */
#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 237 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define ENOATTR         93              /* Attribute not found */
#endif
# 239 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

#define EBADMSG         94              /* Bad message */
#define EMULTIHOP       95              /* Reserved */
#define ENODATA         96              /* No message available on STREAM */
#define ENOLINK         97              /* Reserved */
#define ENOSR           98              /* No STREAM resources */
#define ENOSTR          99              /* Not a STREAM */
#define EPROTO          100             /* Protocol error */
#define ETIME           101             /* STREAM ioctl timeout */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03 || defined(KERNEL)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 250 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
/* This value is only discrete when compiling __DARWIN_UNIX03, or KERNEL */
#define EOPNOTSUPP      102             /* Operation not supported on socket */
#endif /* __DARWIN_UNIX03 || KERNEL */
# 253 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

#define ENOPOLICY       103             /* No such policy registered */

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= 200809L
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 257 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define ENOTRECOVERABLE 104             /* State not recoverable */
#define EOWNERDEAD      105             /* Previous owner died */
#endif
# 260 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_C_LEVEL >= __DARWIN_C_FULL
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 262 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
#define EQFULL          106             /* Interface output queue is full */
#define ELAST           106             /* Must be equal largest errno */
#endif
# 265 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4

#endif /* _SYS_ERRNO_H_ */
# 267 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/sys/errno.h" 3 4
# 24 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/errno.h" 2 3 4

# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 2 3

#ifdef __cplusplus

#if 0 /* disabled by -frewrite-includes */
#if !defined(EOWNERDEAD) || !defined(ENOTRECOVERABLE)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 36 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifdef ELAST

static const int __elast1 = ELAST+1;
static const int __elast2 = ELAST+2;

#else
# 43 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

static const int __elast1 = 104;
static const int __elast2 = 105;

#endif
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifdef ENOTRECOVERABLE

#define EOWNERDEAD __elast1

#ifdef ELAST
#undef ELAST
#define ELAST EOWNERDEAD
#endif
# 57 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(EOWNERDEAD)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 59 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#define ENOTRECOVERABLE __elast1
#ifdef ELAST
#undef ELAST
#define ELAST ENOTRECOVERABLE
#endif
# 65 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#else  // defined(EOWNERDEAD)
# 67 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#define EOWNERDEAD __elast1
#define ENOTRECOVERABLE __elast2
#ifdef ELAST
#undef ELAST
#define ELAST ENOTRECOVERABLE
#endif
# 74 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#endif  // defined(EOWNERDEAD)
# 76 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#endif  // !defined(EOWNERDEAD) || !defined(ENOTRECOVERABLE)
# 78 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

//  supply errno values likely to be missing, particularly on Windows

#ifndef EAFNOSUPPORT
#define EAFNOSUPPORT 9901
#endif
# 84 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EADDRINUSE
#define EADDRINUSE 9902
#endif
# 88 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EADDRNOTAVAIL
#define EADDRNOTAVAIL 9903
#endif
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EISCONN
#define EISCONN 9904
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EBADMSG
#define EBADMSG 9905
#endif
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ECONNABORTED
#define ECONNABORTED 9906
#endif
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EALREADY
#define EALREADY 9907
#endif
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ECONNREFUSED
#define ECONNREFUSED 9908
#endif
# 112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ECONNRESET
#define ECONNRESET 9909
#endif
# 116 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EDESTADDRREQ
#define EDESTADDRREQ 9910
#endif
# 120 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EHOSTUNREACH
#define EHOSTUNREACH 9911
#endif
# 124 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EIDRM
#define EIDRM 9912
#endif
# 128 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EMSGSIZE
#define EMSGSIZE 9913
#endif
# 132 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENETDOWN
#define ENETDOWN 9914
#endif
# 136 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENETRESET
#define ENETRESET 9915
#endif
# 140 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENETUNREACH
#define ENETUNREACH 9916
#endif
# 144 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOBUFS
#define ENOBUFS 9917
#endif
# 148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOLINK
#define ENOLINK 9918
#endif
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENODATA
#define ENODATA 9919
#endif
# 156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOMSG
#define ENOMSG 9920
#endif
# 160 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOPROTOOPT
#define ENOPROTOOPT 9921
#endif
# 164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOSR
#define ENOSR 9922
#endif
# 168 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOTSOCK
#define ENOTSOCK 9923
#endif
# 172 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOSTR
#define ENOSTR 9924
#endif
# 176 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOTCONN
#define ENOTCONN 9925
#endif
# 180 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOTSUP
#define ENOTSUP 9926
#endif
# 184 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ECANCELED
#define ECANCELED 9927
#endif
# 188 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EINPROGRESS
#define EINPROGRESS 9928
#endif
# 192 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EOPNOTSUPP
#define EOPNOTSUPP 9929
#endif
# 196 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EWOULDBLOCK
#define EWOULDBLOCK 9930
#endif
# 200 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EOWNERDEAD
#define EOWNERDEAD  9931
#endif
# 204 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EPROTO
#define EPROTO 9932
#endif
# 208 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EPROTONOSUPPORT
#define EPROTONOSUPPORT 9933
#endif
# 212 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOTRECOVERABLE
#define ENOTRECOVERABLE 9934
#endif
# 216 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ETIME
#define ETIME 9935
#endif
# 220 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ETXTBSY
#define ETXTBSY 9936
#endif
# 224 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ETIMEDOUT
#define ETIMEDOUT 9938
#endif
# 228 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ELOOP
#define ELOOP 9939
#endif
# 232 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EOVERFLOW
#define EOVERFLOW 9940
#endif
# 236 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EPROTOTYPE
#define EPROTOTYPE 9941
#endif
# 240 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOSYS
#define ENOSYS 9942
#endif
# 244 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EINVAL
#define EINVAL 9943
#endif
# 248 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ERANGE
#define ERANGE 9944
#endif
# 252 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EILSEQ
#define EILSEQ 9945
#endif
# 256 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

//  Windows Mobile doesn't appear to define these:

#ifndef E2BIG
#define E2BIG 9946
#endif
# 262 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EDOM
#define EDOM 9947
#endif
# 266 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EFAULT
#define EFAULT 9948
#endif
# 270 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EBADF
#define EBADF 9949
#endif
# 274 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EPIPE
#define EPIPE 9950
#endif
# 278 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EXDEV
#define EXDEV 9951
#endif
# 282 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EBUSY
#define EBUSY 9952
#endif
# 286 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOTEMPTY
#define ENOTEMPTY 9953
#endif
# 290 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOEXEC
#define ENOEXEC 9954
#endif
# 294 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EEXIST
#define EEXIST 9955
#endif
# 298 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EFBIG
#define EFBIG 9956
#endif
# 302 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENAMETOOLONG
#define ENAMETOOLONG 9957
#endif
# 306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOTTY
#define ENOTTY 9958
#endif
# 310 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EINTR
#define EINTR 9959
#endif
# 314 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ESPIPE
#define ESPIPE 9960
#endif
# 318 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EIO
#define EIO 9961
#endif
# 322 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EISDIR
#define EISDIR 9962
#endif
# 326 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ECHILD
#define ECHILD 9963
#endif
# 330 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOLCK
#define ENOLCK 9964
#endif
# 334 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOSPC
#define ENOSPC 9965
#endif
# 338 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENXIO
#define ENXIO 9966
#endif
# 342 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENODEV
#define ENODEV 9967
#endif
# 346 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOENT
#define ENOENT 9968
#endif
# 350 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ESRCH
#define ESRCH 9969
#endif
# 354 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOTDIR
#define ENOTDIR 9970
#endif
# 358 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENOMEM
#define ENOMEM 9971
#endif
# 362 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EPERM
#define EPERM 9972
#endif
# 366 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EACCES
#define EACCES 9973
#endif
# 370 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EROFS
#define EROFS 9974
#endif
# 374 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EDEADLK
#define EDEADLK 9975
#endif
# 378 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EAGAIN
#define EAGAIN 9976
#endif
# 382 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef ENFILE
#define ENFILE 9977
#endif
# 386 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EMFILE
#define EMFILE 9978
#endif
# 390 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#ifndef EMLINK
#define EMLINK 9979
#endif
# 394 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#endif // __cplusplus
# 396 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3

#endif  // _LIBCPP_ERRNO_H
# 398 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/errno.h" 3
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 3
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 3

#endif  // _LIBCPP_CERRNO
# 33 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cerrno" 3
# 105 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 107 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 108 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
#endif
# 109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3

_LIBCPP_BEGIN_NAMESPACE_STD

// Some error codes are not present on all platforms, so we provide equivalents
// for them:

//enum class errc
_LIBCPP_DECLARE_STRONG_ENUM(errc)
{
    address_family_not_supported        = EAFNOSUPPORT,
    address_in_use                      = EADDRINUSE,
    address_not_available               = EADDRNOTAVAIL,
    already_connected                   = EISCONN,
    argument_list_too_long              = E2BIG,
    argument_out_of_domain              = EDOM,
    bad_address                         = EFAULT,
    bad_file_descriptor                 = EBADF,
    bad_message                         = EBADMSG,
    broken_pipe                         = EPIPE,
    connection_aborted                  = ECONNABORTED,
    connection_already_in_progress      = EALREADY,
    connection_refused                  = ECONNREFUSED,
    connection_reset                    = ECONNRESET,
    cross_device_link                   = EXDEV,
    destination_address_required        = EDESTADDRREQ,
    device_or_resource_busy             = EBUSY,
    directory_not_empty                 = ENOTEMPTY,
    executable_format_error             = ENOEXEC,
    file_exists                         = EEXIST,
    file_too_large                      = EFBIG,
    filename_too_long                   = ENAMETOOLONG,
    function_not_supported              = ENOSYS,
    host_unreachable                    = EHOSTUNREACH,
    identifier_removed                  = EIDRM,
    illegal_byte_sequence               = EILSEQ,
    inappropriate_io_control_operation  = ENOTTY,
    interrupted                         = EINTR,
    invalid_argument                    = EINVAL,
    invalid_seek                        = ESPIPE,
    io_error                            = EIO,
    is_a_directory                      = EISDIR,
    message_size                        = EMSGSIZE,
    network_down                        = ENETDOWN,
    network_reset                       = ENETRESET,
    network_unreachable                 = ENETUNREACH,
    no_buffer_space                     = ENOBUFS,
    no_child_process                    = ECHILD,
    no_link                             = ENOLINK,
    no_lock_available                   = ENOLCK,
#ifdef ENODATA
    no_message_available                = ENODATA,
#else
# 161 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
    no_message_available                = ENOMSG,
#endif
# 163 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
    no_message                          = ENOMSG,
    no_protocol_option                  = ENOPROTOOPT,
    no_space_on_device                  = ENOSPC,
#ifdef ENOSR
    no_stream_resources                 = ENOSR,
#else
# 169 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
    no_stream_resources                 = ENOMEM,
#endif
# 171 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
    no_such_device_or_address           = ENXIO,
    no_such_device                      = ENODEV,
    no_such_file_or_directory           = ENOENT,
    no_such_process                     = ESRCH,
    not_a_directory                     = ENOTDIR,
    not_a_socket                        = ENOTSOCK,
#ifdef ENOSTR
    not_a_stream                        = ENOSTR,
#else
# 180 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
    not_a_stream                        = EINVAL,
#endif
# 182 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
    not_connected                       = ENOTCONN,
    not_enough_memory                   = ENOMEM,
    not_supported                       = ENOTSUP,
    operation_canceled                  = ECANCELED,
    operation_in_progress               = EINPROGRESS,
    operation_not_permitted             = EPERM,
    operation_not_supported             = EOPNOTSUPP,
    operation_would_block               = EWOULDBLOCK,
    owner_dead                          = EOWNERDEAD,
    permission_denied                   = EACCES,
    protocol_error                      = EPROTO,
    protocol_not_supported              = EPROTONOSUPPORT,
    read_only_file_system               = EROFS,
    resource_deadlock_would_occur       = EDEADLK,
    resource_unavailable_try_again      = EAGAIN,
    result_out_of_range                 = ERANGE,
    state_not_recoverable               = ENOTRECOVERABLE,
#ifdef ETIME
    stream_timeout                      = ETIME,
#else
# 202 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
    stream_timeout                      = ETIMEDOUT,
#endif
# 204 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
    text_file_busy                      = ETXTBSY,
    timed_out                           = ETIMEDOUT,
    too_many_files_open_in_system       = ENFILE,
    too_many_files_open                 = EMFILE,
    too_many_links                      = EMLINK,
    too_many_symbolic_link_levels       = ELOOP,
    value_too_large                     = EOVERFLOW,
    wrong_protocol_type                 = EPROTOTYPE
};
_LIBCPP_DECLARE_STRONG_ENUM_EPILOG(errc)

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP___ERRC
# 218 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__errc" 3
# 146 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 146 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
# 147 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 147 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
# 148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
# 149 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 149 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
# 150 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 153 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
#endif
# 154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3

_LIBCPP_BEGIN_NAMESPACE_STD

// is_error_code_enum

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_error_code_enum
    : public false_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
template <class _Tp>
_LIBCPP_INLINE_VAR constexpr size_t is_error_code_enum_v = is_error_code_enum<_Tp>::value;
#endif
# 167 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3

// is_error_condition_enum

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS is_error_condition_enum
    : public false_type {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 175 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
template <class _Tp>
_LIBCPP_INLINE_VAR constexpr size_t is_error_condition_enum_v = is_error_condition_enum<_Tp>::value;
#endif
# 178 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3

template <>
struct _LIBCPP_TEMPLATE_VIS is_error_condition_enum<errc>
    : true_type { };

#ifdef _LIBCPP_HAS_NO_STRONG_ENUMS
template <>
struct _LIBCPP_TEMPLATE_VIS is_error_condition_enum<errc::__lx>
    : true_type { };
#endif
# 188 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3

class _LIBCPP_TYPE_VIS error_condition;
class _LIBCPP_TYPE_VIS error_code;

// class error_category

class _LIBCPP_HIDDEN __do_message;

class _LIBCPP_TYPE_VIS error_category
{
public:
    virtual ~error_category() _NOEXCEPT;

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_BUILDING_LIBRARY) && \
    defined(_LIBCPP_DEPRECATED_ABI_LEGACY_LIBRARY_DEFINITIONS_FOR_INLINE_FUNCTIONS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 203 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
    error_category() _NOEXCEPT;
#else
# 205 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR_AFTER_CXX11 error_category() _NOEXCEPT _LIBCPP_DEFAULT
#endif
# 208 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
private:
    error_category(const error_category&);// = delete;
    error_category& operator=(const error_category&);// = delete;

public:
    virtual const char* name() const _NOEXCEPT = 0;
    virtual error_condition default_error_condition(int __ev) const _NOEXCEPT;
    virtual bool equivalent(int __code, const error_condition& __condition) const _NOEXCEPT;
    virtual bool equivalent(const error_code& __code, int __condition) const _NOEXCEPT;
    virtual string message(int __ev) const = 0;

    _LIBCPP_INLINE_VISIBILITY
    bool operator==(const error_category& __rhs) const _NOEXCEPT {return this == &__rhs;}

    _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const error_category& __rhs) const _NOEXCEPT {return !(*this == __rhs);}

    _LIBCPP_INLINE_VISIBILITY
    bool operator< (const error_category& __rhs) const _NOEXCEPT {return this < &__rhs;}

    friend class _LIBCPP_HIDDEN __do_message;
};

class _LIBCPP_HIDDEN __do_message
    : public error_category
{
public:
    virtual string message(int ev) const;
};

_LIBCPP_FUNC_VIS const error_category& generic_category() _NOEXCEPT;
_LIBCPP_FUNC_VIS const error_category& system_category() _NOEXCEPT;

class _LIBCPP_TYPE_VIS error_condition
{
    int __val_;
    const error_category* __cat_;
public:
    _LIBCPP_INLINE_VISIBILITY
    error_condition() _NOEXCEPT : __val_(0), __cat_(&generic_category()) {}

    _LIBCPP_INLINE_VISIBILITY
    error_condition(int __val, const error_category& __cat) _NOEXCEPT
        : __val_(__val), __cat_(&__cat) {}

    template <class _Ep>
        _LIBCPP_INLINE_VISIBILITY
        error_condition(_Ep __e,
              typename enable_if<is_error_condition_enum<_Ep>::value>::type* = 0
                                                                     ) _NOEXCEPT
            {*this = make_error_condition(__e);}

    _LIBCPP_INLINE_VISIBILITY
    void assign(int __val, const error_category& __cat) _NOEXCEPT
    {
        __val_ = __val;
        __cat_ = &__cat;
    }

    template <class _Ep>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            is_error_condition_enum<_Ep>::value,
            error_condition&
        >::type
        operator=(_Ep __e) _NOEXCEPT
            {*this = make_error_condition(__e); return *this;}

    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT
    {
        __val_ = 0;
        __cat_ = &generic_category();
    }

    _LIBCPP_INLINE_VISIBILITY
    int value() const _NOEXCEPT {return __val_;}

    _LIBCPP_INLINE_VISIBILITY
    const error_category& category() const _NOEXCEPT {return *__cat_;}
    string message() const;

    _LIBCPP_INLINE_VISIBILITY
        _LIBCPP_EXPLICIT
        operator bool() const _NOEXCEPT {return __val_ != 0;}
};

inline _LIBCPP_INLINE_VISIBILITY
error_condition
make_error_condition(errc __e) _NOEXCEPT
{
    return error_condition(static_cast<int>(__e), generic_category());
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const error_condition& __x, const error_condition& __y) _NOEXCEPT
{
    return __x.category() < __y.category()
        || (__x.category() == __y.category() && __x.value() < __y.value());
}

// error_code

class _LIBCPP_TYPE_VIS error_code
{
    int __val_;
    const error_category* __cat_;
public:
    _LIBCPP_INLINE_VISIBILITY
    error_code() _NOEXCEPT : __val_(0), __cat_(&system_category()) {}

    _LIBCPP_INLINE_VISIBILITY
    error_code(int __val, const error_category& __cat) _NOEXCEPT
        : __val_(__val), __cat_(&__cat) {}

    template <class _Ep>
        _LIBCPP_INLINE_VISIBILITY
        error_code(_Ep __e,
                   typename enable_if<is_error_code_enum<_Ep>::value>::type* = 0
                                                                     ) _NOEXCEPT
            {*this = make_error_code(__e);}

    _LIBCPP_INLINE_VISIBILITY
    void assign(int __val, const error_category& __cat) _NOEXCEPT
    {
        __val_ = __val;
        __cat_ = &__cat;
    }

    template <class _Ep>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            is_error_code_enum<_Ep>::value,
            error_code&
        >::type
        operator=(_Ep __e) _NOEXCEPT
            {*this = make_error_code(__e); return *this;}

    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT
    {
        __val_ = 0;
        __cat_ = &system_category();
    }

    _LIBCPP_INLINE_VISIBILITY
    int value() const _NOEXCEPT {return __val_;}

    _LIBCPP_INLINE_VISIBILITY
    const error_category& category() const _NOEXCEPT {return *__cat_;}

    _LIBCPP_INLINE_VISIBILITY
    error_condition default_error_condition() const _NOEXCEPT
        {return __cat_->default_error_condition(__val_);}

    string message() const;

    _LIBCPP_INLINE_VISIBILITY
        _LIBCPP_EXPLICIT
        operator bool() const _NOEXCEPT {return __val_ != 0;}
};

inline _LIBCPP_INLINE_VISIBILITY
error_code
make_error_code(errc __e) _NOEXCEPT
{
    return error_code(static_cast<int>(__e), generic_category());
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const error_code& __x, const error_code& __y) _NOEXCEPT
{
    return __x.category() < __y.category()
        || (__x.category() == __y.category() && __x.value() < __y.value());
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const error_code& __x, const error_code& __y) _NOEXCEPT
{
    return __x.category() == __y.category() && __x.value() == __y.value();
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const error_code& __x, const error_condition& __y) _NOEXCEPT
{
    return __x.category().equivalent(__x.value(), __y)
        || __y.category().equivalent(__x, __y.value());
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const error_condition& __x, const error_code& __y) _NOEXCEPT
{
    return __y == __x;
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const error_condition& __x, const error_condition& __y) _NOEXCEPT
{
    return __x.category() == __y.category() && __x.value() == __y.value();
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const error_code& __x, const error_code& __y) _NOEXCEPT
{return !(__x == __y);}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const error_code& __x, const error_condition& __y) _NOEXCEPT
{return !(__x == __y);}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const error_condition& __x, const error_code& __y) _NOEXCEPT
{return !(__x == __y);}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const error_condition& __x, const error_condition& __y) _NOEXCEPT
{return !(__x == __y);}

template <>
struct _LIBCPP_TEMPLATE_VIS hash<error_code>
    : public unary_function<error_code, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(const error_code& __ec) const _NOEXCEPT
    {
        return static_cast<size_t>(__ec.value());
    }
};

template <>
struct _LIBCPP_TEMPLATE_VIS hash<error_condition>
    : public unary_function<error_condition, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(const error_condition& __ec) const _NOEXCEPT
    {
        return static_cast<size_t>(__ec.value());
    }
};

// system_error

class _LIBCPP_TYPE_VIS system_error
    : public runtime_error
{
    error_code __ec_;
public:
    system_error(error_code __ec, const string& __what_arg);
    system_error(error_code __ec, const char* __what_arg);
    system_error(error_code __ec);
    system_error(int __ev, const error_category& __ecat, const string& __what_arg);
    system_error(int __ev, const error_category& __ecat, const char* __what_arg);
    system_error(int __ev, const error_category& __ecat);
    ~system_error() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    const error_code& code() const _NOEXCEPT {return __ec_;}

private:
    static string __init(const error_code&, string);
};

_LIBCPP_NORETURN _LIBCPP_FUNC_VIS
void __throw_system_error(int ev, const char* what_arg);

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_SYSTEM_ERROR
# 487 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/system_error" 3
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"

namespace llvm {

/// Represents either an error or a value T.
///
/// ErrorOr<T> is a pointer-like class that represents the result of an
/// operation. The result is either an error, or a value of type T. This is
/// designed to emulate the usage of returning a pointer where nullptr indicates
/// failure. However instead of just knowing that the operation failed, we also
/// have an error_code and optional user data that describes why it failed.
///
/// It is used like the following.
/// \code
///   ErrorOr<Buffer> getBuffer();
///
///   auto buffer = getBuffer();
///   if (error_code ec = buffer.getError())
///     return ec;
///   buffer->write("adena");
/// \endcode
///
///
/// Implicit conversion to bool returns true if there is a usable value. The
/// unary * and -> operators provide pointer like access to the value. Accessing
/// the value when there is an error has undefined behavior.
///
/// When T is a reference type the behavior is slightly different. The reference
/// is held in a std::reference_wrapper<std::remove_reference<T>::type>, and
/// there is special handling to make operator -> work as if T was not a
/// reference.
///
/// T cannot be a rvalue reference.
template<class T>
class ErrorOr {
  template <class OtherT> friend class ErrorOr;

  static const bool isRef = std::is_reference<T>::value;

  using wrap = std::reference_wrapper<std::remove_reference_t<T>>;

public:
  using storage_type = std::conditional_t<isRef, wrap, T>;

private:
  using reference = std::remove_reference_t<T> &;
  using const_reference = const std::remove_reference_t<T> &;
  using pointer = std::remove_reference_t<T> *;
  using const_pointer = const std::remove_reference_t<T> *;

public:
  template <class E>
  ErrorOr(E ErrorCode,
          std::enable_if_t<std::is_error_code_enum<E>::value ||
                               std::is_error_condition_enum<E>::value,
                           void *> = nullptr)
      : HasError(true) {
    new (getErrorStorage()) std::error_code(make_error_code(ErrorCode));
  }

  ErrorOr(std::error_code EC) : HasError(true) {
    new (getErrorStorage()) std::error_code(EC);
  }

  template <class OtherT>
  ErrorOr(OtherT &&Val,
          std::enable_if_t<std::is_convertible<OtherT, T>::value> * = nullptr)
      : HasError(false) {
    new (getStorage()) storage_type(std::forward<OtherT>(Val));
  }

  ErrorOr(const ErrorOr &Other) {
    copyConstruct(Other);
  }

  template <class OtherT>
  ErrorOr(const ErrorOr<OtherT> &Other,
          std::enable_if_t<std::is_convertible<OtherT, T>::value> * = nullptr) {
    copyConstruct(Other);
  }

  template <class OtherT>
  explicit ErrorOr(
      const ErrorOr<OtherT> &Other,
      std::enable_if_t<!std::is_convertible<OtherT, const T &>::value> * =
          nullptr) {
    copyConstruct(Other);
  }

  ErrorOr(ErrorOr &&Other) {
    moveConstruct(std::move(Other));
  }

  template <class OtherT>
  ErrorOr(ErrorOr<OtherT> &&Other,
          std::enable_if_t<std::is_convertible<OtherT, T>::value> * = nullptr) {
    moveConstruct(std::move(Other));
  }

  // This might eventually need SFINAE but it's more complex than is_convertible
  // & I'm too lazy to write it right now.
  template <class OtherT>
  explicit ErrorOr(
      ErrorOr<OtherT> &&Other,
      std::enable_if_t<!std::is_convertible<OtherT, T>::value> * = nullptr) {
    moveConstruct(std::move(Other));
  }

  ErrorOr &operator=(const ErrorOr &Other) {
    copyAssign(Other);
    return *this;
  }

  ErrorOr &operator=(ErrorOr &&Other) {
    moveAssign(std::move(Other));
    return *this;
  }

  ~ErrorOr() {
    if (!HasError)
      getStorage()->~storage_type();
  }

  /// Return false if there is an error.
  explicit operator bool() const {
    return !HasError;
  }

  reference get() { return *getStorage(); }
  const_reference get() const { return const_cast<ErrorOr<T> *>(this)->get(); }

  std::error_code getError() const {
    return HasError ? *getErrorStorage() : std::error_code();
  }

  pointer operator ->() {
    return toPointer(getStorage());
  }

  const_pointer operator->() const { return toPointer(getStorage()); }

  reference operator *() {
    return *getStorage();
  }

  const_reference operator*() const { return *getStorage(); }

private:
  template <class OtherT>
  void copyConstruct(const ErrorOr<OtherT> &Other) {
    if (!Other.HasError) {
      // Get the other value.
      HasError = false;
      new (getStorage()) storage_type(*Other.getStorage());
    } else {
      // Get other's error.
      HasError = true;
      new (getErrorStorage()) std::error_code(Other.getError());
    }
  }

  template <class T1>
  static bool compareThisIfSameType(const T1 &a, const T1 &b) {
    return &a == &b;
  }

  template <class T1, class T2>
  static bool compareThisIfSameType(const T1 &a, const T2 &b) {
    return false;
  }

  template <class OtherT>
  void copyAssign(const ErrorOr<OtherT> &Other) {
    if (compareThisIfSameType(*this, Other))
      return;

    this->~ErrorOr();
    new (this) ErrorOr(Other);
  }

  template <class OtherT>
  void moveConstruct(ErrorOr<OtherT> &&Other) {
    if (!Other.HasError) {
      // Get the other value.
      HasError = false;
      new (getStorage()) storage_type(std::move(*Other.getStorage()));
    } else {
      // Get other's error.
      HasError = true;
      new (getErrorStorage()) std::error_code(Other.getError());
    }
  }

  template <class OtherT>
  void moveAssign(ErrorOr<OtherT> &&Other) {
    if (compareThisIfSameType(*this, Other))
      return;

    this->~ErrorOr();
    new (this) ErrorOr(std::move(Other));
  }

  pointer toPointer(pointer Val) {
    return Val;
  }

  const_pointer toPointer(const_pointer Val) const { return Val; }

  pointer toPointer(wrap *Val) {
    return &Val->get();
  }

  const_pointer toPointer(const wrap *Val) const { return &Val->get(); }

  storage_type *getStorage() {
    assert(!HasError && "Cannot get value when an error exists!");
    return reinterpret_cast<storage_type*>(TStorage.buffer);
  }

  const storage_type *getStorage() const {
    assert(!HasError && "Cannot get value when an error exists!");
    return reinterpret_cast<const storage_type*>(TStorage.buffer);
  }

  std::error_code *getErrorStorage() {
    assert(HasError && "Cannot get error when a value exists!");
    return reinterpret_cast<std::error_code *>(ErrorStorage.buffer);
  }

  const std::error_code *getErrorStorage() const {
    return const_cast<ErrorOr<T> *>(this)->getErrorStorage();
  }

  union {
    AlignedCharArrayUnion<storage_type> TStorage;
    AlignedCharArrayUnion<std::error_code> ErrorStorage;
  };
  bool HasError : 1;
};

template <class T, class E>
std::enable_if_t<std::is_error_code_enum<E>::value ||
                     std::is_error_condition_enum<E>::value,
                 bool>
operator==(const ErrorOr<T> &Err, E Code) {
  return Err.getError() == Code;
}

} // end namespace llvm

#endif // LLVM_SUPPORT_ERROROR_H
# 273 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/ErrorOr.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Format.h"
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h" 1
//===- Format.h - Efficient printf-style formatting for streams -*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file implements the format() function, which can be used with other
// LLVM subsystems to provide printf-style formatting.  This gives all the power
// and risk of printf.  This can be used like this (with raw_ostreams as an
// example):
//
//    OS << "mynumber: " << format("%4.5f", 1234.412) << '\n';
//
// Or if you prefer:
//
//  OS << format("mynumber: %4.5f\n", 1234.412);
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_FORMAT_H
#define LLVM_SUPPORT_FORMAT_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/ArrayRef.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/STLExtras.h"
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h" 1
//===-- llvm/Support/DataTypes.h - Define fixed size types ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// Due to layering constraints (Support depends on llvm-c) this is a thin
// wrapper around the implementation that lives in llvm-c, though most clients
// can/should think of this as being provided by Support for simplicity (not
// many clients are aware of their dependency on llvm-c).
//
//===----------------------------------------------------------------------===//

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdio>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"

namespace llvm {

/// This is a helper class used for handling formatted output.  It is the
/// abstract base class of a templated derived class.
class format_object_base {
protected:
  const char *Fmt;
  ~format_object_base() = default; // Disallow polymorphic deletion.
  format_object_base(const format_object_base &) = default;
  virtual void home(); // Out of line virtual method.

  /// Call snprintf() for this object, on the given buffer and size.
  virtual int snprint(char *Buffer, unsigned BufferSize) const = 0;

public:
  format_object_base(const char *fmt) : Fmt(fmt) {}

  /// Format the object into the specified buffer.  On success, this returns
  /// the length of the formatted string.  If the buffer is too small, this
  /// returns a length to retry with, which will be larger than BufferSize.
  unsigned print(char *Buffer, unsigned BufferSize) const {
    assert(BufferSize && "Invalid buffer size!");

    // Print the string, leaving room for the terminating null.
    int N = snprint(Buffer, BufferSize);

    // VC++ and old GlibC return negative on overflow, just double the size.
    if (N < 0)
      return BufferSize * 2;

    // Other implementations yield number of bytes needed, not including the
    // final '\0'.
    if (unsigned(N) >= BufferSize)
      return N + 1;

    // Otherwise N is the length of output (not including the final '\0').
    return N;
  }
};

/// These are templated helper classes used by the format function that
/// capture the object to be formatted and the format string. When actually
/// printed, this synthesizes the string into a temporary buffer provided and
/// returns whether or not it is big enough.

// Helper to validate that format() parameters are scalars or pointers.
template <typename... Args> struct validate_format_parameters;
template <typename Arg, typename... Args>
struct validate_format_parameters<Arg, Args...> {
  static_assert(std::is_scalar<Arg>::value,
                "format can't be used with non fundamental / non pointer type");
  validate_format_parameters() { validate_format_parameters<Args...>(); }
};
template <> struct validate_format_parameters<> {};

template <typename... Ts>
class format_object final : public format_object_base {
  std::tuple<Ts...> Vals;

  template <std::size_t... Is>
  int snprint_tuple(char *Buffer, unsigned BufferSize,
                    std::index_sequence<Is...>) const {
#ifdef _MSC_VER
    return _snprintf(Buffer, BufferSize, Fmt, std::get<Is>(Vals)...);
#else
# 99 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
    return snprintf(Buffer, BufferSize, Fmt, std::get<Is>(Vals)...);
#endif
# 101 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
  }

public:
  format_object(const char *fmt, const Ts &... vals)
      : format_object_base(fmt), Vals(vals...) {
    validate_format_parameters<Ts...>();
  }

  int snprint(char *Buffer, unsigned BufferSize) const override {
    return snprint_tuple(Buffer, BufferSize, std::index_sequence_for<Ts...>());
  }
};

/// These are helper functions used to produce formatted output.  They use
/// template type deduction to construct the appropriate instance of the
/// format_object class to simplify their construction.
///
/// This is typically used like:
/// \code
///   OS << format("%0.4f", myfloat) << '\n';
/// \endcode

template <typename... Ts>
inline format_object<Ts...> format(const char *Fmt, const Ts &... Vals) {
  return format_object<Ts...>(Fmt, Vals...);
}

/// This is a helper class for left_justify, right_justify, and center_justify.
class FormattedString {
public:
  enum Justification { JustifyNone, JustifyLeft, JustifyRight, JustifyCenter };
  FormattedString(StringRef S, unsigned W, Justification J)
      : Str(S), Width(W), Justify(J) {}

private:
  StringRef Str;
  unsigned Width;
  Justification Justify;
  friend class raw_ostream;
};

/// left_justify - append spaces after string so total output is
/// \p Width characters.  If \p Str is larger that \p Width, full string
/// is written with no padding.
inline FormattedString left_justify(StringRef Str, unsigned Width) {
  return FormattedString(Str, Width, FormattedString::JustifyLeft);
}

/// right_justify - add spaces before string so total output is
/// \p Width characters.  If \p Str is larger that \p Width, full string
/// is written with no padding.
inline FormattedString right_justify(StringRef Str, unsigned Width) {
  return FormattedString(Str, Width, FormattedString::JustifyRight);
}

/// center_justify - add spaces before and after string so total output is
/// \p Width characters.  If \p Str is larger that \p Width, full string
/// is written with no padding.
inline FormattedString center_justify(StringRef Str, unsigned Width) {
  return FormattedString(Str, Width, FormattedString::JustifyCenter);
}

/// This is a helper class used for format_hex() and format_decimal().
class FormattedNumber {
  uint64_t HexValue;
  int64_t DecValue;
  unsigned Width;
  bool Hex;
  bool Upper;
  bool HexPrefix;
  friend class raw_ostream;

public:
  FormattedNumber(uint64_t HV, int64_t DV, unsigned W, bool H, bool U,
                  bool Prefix)
      : HexValue(HV), DecValue(DV), Width(W), Hex(H), Upper(U),
        HexPrefix(Prefix) {}
};

/// format_hex - Output \p N as a fixed width hexadecimal. If number will not
/// fit in width, full number is still printed.  Examples:
///   OS << format_hex(255, 4)              => 0xff
///   OS << format_hex(255, 4, true)        => 0xFF
///   OS << format_hex(255, 6)              => 0x00ff
///   OS << format_hex(255, 2)              => 0xff
inline FormattedNumber format_hex(uint64_t N, unsigned Width,
                                  bool Upper = false) {
  assert(Width <= 18 && "hex width must be <= 18");
  return FormattedNumber(N, 0, Width, true, Upper, true);
}

/// format_hex_no_prefix - Output \p N as a fixed width hexadecimal. Does not
/// prepend '0x' to the outputted string.  If number will not fit in width,
/// full number is still printed.  Examples:
///   OS << format_hex_no_prefix(255, 2)              => ff
///   OS << format_hex_no_prefix(255, 2, true)        => FF
///   OS << format_hex_no_prefix(255, 4)              => 00ff
///   OS << format_hex_no_prefix(255, 1)              => ff
inline FormattedNumber format_hex_no_prefix(uint64_t N, unsigned Width,
                                            bool Upper = false) {
  assert(Width <= 16 && "hex width must be <= 16");
  return FormattedNumber(N, 0, Width, true, Upper, false);
}

/// format_decimal - Output \p N as a right justified, fixed-width decimal. If
/// number will not fit in width, full number is still printed.  Examples:
///   OS << format_decimal(0, 5)     => "    0"
///   OS << format_decimal(255, 5)   => "  255"
///   OS << format_decimal(-1, 3)    => " -1"
///   OS << format_decimal(12345, 3) => "12345"
inline FormattedNumber format_decimal(int64_t N, unsigned Width) {
  return FormattedNumber(0, N, Width, false, false, false);
}

class FormattedBytes {
  ArrayRef<uint8_t> Bytes;

  // If not None, display offsets for each line relative to starting value.
  Optional<uint64_t> FirstByteOffset;
  uint32_t IndentLevel;  // Number of characters to indent each line.
  uint32_t NumPerLine;   // Number of bytes to show per line.
  uint8_t ByteGroupSize; // How many hex bytes are grouped without spaces
  bool Upper;            // Show offset and hex bytes as upper case.
  bool ASCII;            // Show the ASCII bytes for the hex bytes to the right.
  friend class raw_ostream;

public:
  FormattedBytes(ArrayRef<uint8_t> B, uint32_t IL, Optional<uint64_t> O,
                 uint32_t NPL, uint8_t BGS, bool U, bool A)
      : Bytes(B), FirstByteOffset(O), IndentLevel(IL), NumPerLine(NPL),
        ByteGroupSize(BGS), Upper(U), ASCII(A) {

    if (ByteGroupSize > NumPerLine)
      ByteGroupSize = NumPerLine;
  }
};

inline FormattedBytes
format_bytes(ArrayRef<uint8_t> Bytes, Optional<uint64_t> FirstByteOffset = None,
             uint32_t NumPerLine = 16, uint8_t ByteGroupSize = 4,
             uint32_t IndentLevel = 0, bool Upper = false) {
  return FormattedBytes(Bytes, IndentLevel, FirstByteOffset, NumPerLine,
                        ByteGroupSize, Upper, false);
}

inline FormattedBytes
format_bytes_with_ascii(ArrayRef<uint8_t> Bytes,
                        Optional<uint64_t> FirstByteOffset = None,
                        uint32_t NumPerLine = 16, uint8_t ByteGroupSize = 4,
                        uint32_t IndentLevel = 0, bool Upper = false) {
  return FormattedBytes(Bytes, IndentLevel, FirstByteOffset, NumPerLine,
                        ByteGroupSize, Upper, true);
}

} // end namespace llvm

#endif
# 258 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Format.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/raw_ostream.h"
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h" 1
//===--- raw_ostream.h - Raw output stream ----------------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
//  This file defines the raw_ostream class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_RAW_OSTREAM_H
#define LLVM_SUPPORT_RAW_OSTREAM_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
#if 0 /* expanded by -frewrite-includes */
#include <system_error>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"

namespace llvm {

class formatv_object_base;
class format_object_base;
class FormattedString;
class FormattedNumber;
class FormattedBytes;

namespace sys {
namespace fs {
enum FileAccess : unsigned;
enum OpenFlags : unsigned;
enum CreationDisposition : unsigned;
} // end namespace fs
} // end namespace sys

/// This class implements an extremely fast bulk output stream that can *only*
/// output to a stream.  It does not support seeking, reopening, rewinding, line
/// buffered disciplines etc. It is a simple buffer that outputs
/// a chunk at a time.
class raw_ostream {
private:
  /// The buffer is handled in such a way that the buffer is
  /// uninitialized, unbuffered, or out of space when OutBufCur >=
  /// OutBufEnd. Thus a single comparison suffices to determine if we
  /// need to take the slow path to write a single character.
  ///
  /// The buffer is in one of three states:
  ///  1. Unbuffered (BufferMode == Unbuffered)
  ///  1. Uninitialized (BufferMode != Unbuffered && OutBufStart == 0).
  ///  2. Buffered (BufferMode != Unbuffered && OutBufStart != 0 &&
  ///               OutBufEnd - OutBufStart >= 1).
  ///
  /// If buffered, then the raw_ostream owns the buffer if (BufferMode ==
  /// InternalBuffer); otherwise the buffer has been set via SetBuffer and is
  /// managed by the subclass.
  ///
  /// If a subclass installs an external buffer using SetBuffer then it can wait
  /// for a \see write_impl() call to handle the data which has been put into
  /// this buffer.
  char *OutBufStart, *OutBufEnd, *OutBufCur;

  enum class BufferKind {
    Unbuffered = 0,
    InternalBuffer,
    ExternalBuffer
  } BufferMode;

public:
  // color order matches ANSI escape sequence, don't change
  enum class Colors {
    BLACK = 0,
    RED,
    GREEN,
    YELLOW,
    BLUE,
    MAGENTA,
    CYAN,
    WHITE,
    SAVEDCOLOR,
    RESET,
  };

  static const Colors BLACK = Colors::BLACK;
  static const Colors RED = Colors::RED;
  static const Colors GREEN = Colors::GREEN;
  static const Colors YELLOW = Colors::YELLOW;
  static const Colors BLUE = Colors::BLUE;
  static const Colors MAGENTA = Colors::MAGENTA;
  static const Colors CYAN = Colors::CYAN;
  static const Colors WHITE = Colors::WHITE;
  static const Colors SAVEDCOLOR = Colors::SAVEDCOLOR;
  static const Colors RESET = Colors::RESET;

  explicit raw_ostream(bool unbuffered = false)
      : BufferMode(unbuffered ? BufferKind::Unbuffered
                              : BufferKind::InternalBuffer) {
    // Start out ready to flush.
    OutBufStart = OutBufEnd = OutBufCur = nullptr;
  }

  raw_ostream(const raw_ostream &) = delete;
  void operator=(const raw_ostream &) = delete;

  virtual ~raw_ostream();

  /// tell - Return the current offset with the file.
  uint64_t tell() const { return current_pos() + GetNumBytesInBuffer(); }

  //===--------------------------------------------------------------------===//
  // Configuration Interface
  //===--------------------------------------------------------------------===//

  /// Set the stream to be buffered, with an automatically determined buffer
  /// size.
  void SetBuffered();

  /// Set the stream to be buffered, using the specified buffer size.
  void SetBufferSize(size_t Size) {
    flush();
    SetBufferAndMode(new char[Size], Size, BufferKind::InternalBuffer);
  }

  size_t GetBufferSize() const {
    // If we're supposed to be buffered but haven't actually gotten around
    // to allocating the buffer yet, return the value that would be used.
    if (BufferMode != BufferKind::Unbuffered && OutBufStart == nullptr)
      return preferred_buffer_size();

    // Otherwise just return the size of the allocated buffer.
    return OutBufEnd - OutBufStart;
  }

  /// Set the stream to be unbuffered. When unbuffered, the stream will flush
  /// after every write. This routine will also flush the buffer immediately
  /// when the stream is being set to unbuffered.
  void SetUnbuffered() {
    flush();
    SetBufferAndMode(nullptr, 0, BufferKind::Unbuffered);
  }

  size_t GetNumBytesInBuffer() const {
    return OutBufCur - OutBufStart;
  }

  //===--------------------------------------------------------------------===//
  // Data Output Interface
  //===--------------------------------------------------------------------===//

  void flush() {
    if (OutBufCur != OutBufStart)
      flush_nonempty();
  }

  raw_ostream &operator<<(char C) {
    if (OutBufCur >= OutBufEnd)
      return write(C);
    *OutBufCur++ = C;
    return *this;
  }

  raw_ostream &operator<<(unsigned char C) {
    if (OutBufCur >= OutBufEnd)
      return write(C);
    *OutBufCur++ = C;
    return *this;
  }

  raw_ostream &operator<<(signed char C) {
    if (OutBufCur >= OutBufEnd)
      return write(C);
    *OutBufCur++ = C;
    return *this;
  }

  raw_ostream &operator<<(StringRef Str) {
    // Inline fast path, particularly for strings with a known length.
    size_t Size = Str.size();

    // Make sure we can use the fast path.
    if (Size > (size_t)(OutBufEnd - OutBufCur))
      return write(Str.data(), Size);

    if (Size) {
      memcpy(OutBufCur, Str.data(), Size);
      OutBufCur += Size;
    }
    return *this;
  }

  raw_ostream &operator<<(const char *Str) {
    // Inline fast path, particularly for constant strings where a sufficiently
    // smart compiler will simplify strlen.

    return this->operator<<(StringRef(Str));
  }

  raw_ostream &operator<<(const std::string &Str) {
    // Avoid the fast path, it would only increase code size for a marginal win.
    return write(Str.data(), Str.length());
  }

  raw_ostream &operator<<(const SmallVectorImpl<char> &Str) {
    return write(Str.data(), Str.size());
  }

  raw_ostream &operator<<(unsigned long N);
  raw_ostream &operator<<(long N);
  raw_ostream &operator<<(unsigned long long N);
  raw_ostream &operator<<(long long N);
  raw_ostream &operator<<(const void *P);

  raw_ostream &operator<<(unsigned int N) {
    return this->operator<<(static_cast<unsigned long>(N));
  }

  raw_ostream &operator<<(int N) {
    return this->operator<<(static_cast<long>(N));
  }

  raw_ostream &operator<<(double N);

  /// Output \p N in hexadecimal, without any prefix or padding.
  raw_ostream &write_hex(unsigned long long N);

  // Change the foreground color of text.
  raw_ostream &operator<<(Colors C);

  /// Output a formatted UUID with dash separators.
  using uuid_t = uint8_t[16];
  raw_ostream &write_uuid(const uuid_t UUID);

  /// Output \p Str, turning '\\', '\t', '\n', '"', and anything that doesn't
  /// satisfy llvm::isPrint into an escape sequence.
  raw_ostream &write_escaped(StringRef Str, bool UseHexEscapes = false);

  raw_ostream &write(unsigned char C);
  raw_ostream &write(const char *Ptr, size_t Size);

  // Formatted output, see the format() function in Support/Format.h.
  raw_ostream &operator<<(const format_object_base &Fmt);

  // Formatted output, see the leftJustify() function in Support/Format.h.
  raw_ostream &operator<<(const FormattedString &);

  // Formatted output, see the formatHex() function in Support/Format.h.
  raw_ostream &operator<<(const FormattedNumber &);

  // Formatted output, see the formatv() function in Support/FormatVariadic.h.
  raw_ostream &operator<<(const formatv_object_base &);

  // Formatted output, see the format_bytes() function in Support/Format.h.
  raw_ostream &operator<<(const FormattedBytes &);

  /// indent - Insert 'NumSpaces' spaces.
  raw_ostream &indent(unsigned NumSpaces);

  /// write_zeros - Insert 'NumZeros' nulls.
  raw_ostream &write_zeros(unsigned NumZeros);

  /// Changes the foreground color of text that will be output from this point
  /// forward.
  /// @param Color ANSI color to use, the special SAVEDCOLOR can be used to
  /// change only the bold attribute, and keep colors untouched
  /// @param Bold bold/brighter text, default false
  /// @param BG if true change the background, default: change foreground
  /// @returns itself so it can be used within << invocations
  virtual raw_ostream &changeColor(enum Colors Color,
                                   bool Bold = false,
                                   bool BG = false) {
    (void)Color;
    (void)Bold;
    (void)BG;
    return *this;
  }

  /// Resets the colors to terminal defaults. Call this when you are done
  /// outputting colored text, or before program exit.
  virtual raw_ostream &resetColor() { return *this; }

  /// Reverses the foreground and background colors.
  virtual raw_ostream &reverseColor() { return *this; }

  /// This function determines if this stream is connected to a "tty" or
  /// "console" window. That is, the output would be displayed to the user
  /// rather than being put on a pipe or stored in a file.
  virtual bool is_displayed() const { return false; }

  /// This function determines if this stream is displayed and supports colors.
  virtual bool has_colors() const { return is_displayed(); }

  // Enable or disable colors. Once disable_colors() is called,
  // changeColor() has no effect until enable_colors() is called.
  virtual void enable_colors(bool /*enable*/) {}

  //===--------------------------------------------------------------------===//
  // Subclass Interface
  //===--------------------------------------------------------------------===//

private:
  /// The is the piece of the class that is implemented by subclasses.  This
  /// writes the \p Size bytes starting at
  /// \p Ptr to the underlying stream.
  ///
  /// This function is guaranteed to only be called at a point at which it is
  /// safe for the subclass to install a new buffer via SetBuffer.
  ///
  /// \param Ptr The start of the data to be written. For buffered streams this
  /// is guaranteed to be the start of the buffer.
  ///
  /// \param Size The number of bytes to be written.
  ///
  /// \invariant { Size > 0 }
  virtual void write_impl(const char *Ptr, size_t Size) = 0;

  /// Return the current position within the stream, not counting the bytes
  /// currently in the buffer.
  virtual uint64_t current_pos() const = 0;

protected:
  /// Use the provided buffer as the raw_ostream buffer. This is intended for
  /// use only by subclasses which can arrange for the output to go directly
  /// into the desired output buffer, instead of being copied on each flush.
  void SetBuffer(char *BufferStart, size_t Size) {
    SetBufferAndMode(BufferStart, Size, BufferKind::ExternalBuffer);
  }

  /// Return an efficient buffer size for the underlying output mechanism.
  virtual size_t preferred_buffer_size() const;

  /// Return the beginning of the current stream buffer, or 0 if the stream is
  /// unbuffered.
  const char *getBufferStart() const { return OutBufStart; }

  //===--------------------------------------------------------------------===//
  // Private Interface
  //===--------------------------------------------------------------------===//
private:
  /// Install the given buffer and mode.
  void SetBufferAndMode(char *BufferStart, size_t Size, BufferKind Mode);

  /// Flush the current buffer, which is known to be non-empty. This outputs the
  /// currently buffered data and resets the buffer to empty.
  void flush_nonempty();

  /// Copy data into the buffer. Size must not be greater than the number of
  /// unused bytes in the buffer.
  void copy_to_buffer(const char *Ptr, size_t Size);

  virtual void anchor();
};

/// Call the appropriate insertion operator, given an rvalue reference to a
/// raw_ostream object and return a stream of the same type as the argument.
template <typename OStream, typename T>
std::enable_if_t<!std::is_reference<OStream>::value &&
                     std::is_base_of<raw_ostream, OStream>::value,
                 OStream &&>
operator<<(OStream &&OS, const T &Value) {
  OS << Value;
  return std::move(OS);
}

/// An abstract base class for streams implementations that also support a
/// pwrite operation. This is useful for code that can mostly stream out data,
/// but needs to patch in a header that needs to know the output size.
class raw_pwrite_stream : public raw_ostream {
  virtual void pwrite_impl(const char *Ptr, size_t Size, uint64_t Offset) = 0;
  void anchor() override;

public:
  explicit raw_pwrite_stream(bool Unbuffered = false)
      : raw_ostream(Unbuffered) {}
  void pwrite(const char *Ptr, size_t Size, uint64_t Offset) {
#ifndef NDEBUG
    uint64_t Pos = tell();
    // /dev/null always reports a pos of 0, so we cannot perform this check
    // in that case.
    if (Pos)
      assert(Size + Offset <= Pos && "We don't support extending the stream");
#endif
# 387 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
    pwrite_impl(Ptr, Size, Offset);
  }
};

//===----------------------------------------------------------------------===//
// File Output Streams
//===----------------------------------------------------------------------===//

/// A raw_ostream that writes to a file descriptor.
///
class raw_fd_ostream : public raw_pwrite_stream {
  int FD;
  bool ShouldClose;
  bool SupportsSeeking = false;
  bool ColorEnabled = true;

#ifdef _WIN32
  /// True if this fd refers to a Windows console device. Mintty and other
  /// terminal emulators are TTYs, but they are not consoles.
  bool IsWindowsConsole = false;
#endif
# 408 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"

  std::error_code EC;

  uint64_t pos = 0;

  /// See raw_ostream::write_impl.
  void write_impl(const char *Ptr, size_t Size) override;

  void pwrite_impl(const char *Ptr, size_t Size, uint64_t Offset) override;

  /// Return the current position within the stream, not counting the bytes
  /// currently in the buffer.
  uint64_t current_pos() const override { return pos; }

  /// Determine an efficient buffer size.
  size_t preferred_buffer_size() const override;

  /// Set the flag indicating that an output error has been encountered.
  void error_detected(std::error_code EC) { this->EC = EC; }

  void anchor() override;

public:
  /// Open the specified file for writing. If an error occurs, information
  /// about the error is put into EC, and the stream should be immediately
  /// destroyed;
  /// \p Flags allows optional flags to control how the file will be opened.
  ///
  /// As a special case, if Filename is "-", then the stream will use
  /// STDOUT_FILENO instead of opening a file. This will not close the stdout
  /// descriptor.
  raw_fd_ostream(StringRef Filename, std::error_code &EC);
  raw_fd_ostream(StringRef Filename, std::error_code &EC,
                 sys::fs::CreationDisposition Disp);
  raw_fd_ostream(StringRef Filename, std::error_code &EC,
                 sys::fs::FileAccess Access);
  raw_fd_ostream(StringRef Filename, std::error_code &EC,
                 sys::fs::OpenFlags Flags);
  raw_fd_ostream(StringRef Filename, std::error_code &EC,
                 sys::fs::CreationDisposition Disp, sys::fs::FileAccess Access,
                 sys::fs::OpenFlags Flags);

  /// FD is the file descriptor that this writes to.  If ShouldClose is true,
  /// this closes the file when the stream is destroyed. If FD is for stdout or
  /// stderr, it will not be closed.
  raw_fd_ostream(int fd, bool shouldClose, bool unbuffered=false);

  ~raw_fd_ostream() override;

  /// Manually flush the stream and close the file. Note that this does not call
  /// fsync.
  void close();

  bool supportsSeeking() { return SupportsSeeking; }

  /// Flushes the stream and repositions the underlying file descriptor position
  /// to the offset specified from the beginning of the file.
  uint64_t seek(uint64_t off);

  raw_ostream &changeColor(enum Colors colors, bool bold=false,
                           bool bg=false) override;
  raw_ostream &resetColor() override;

  raw_ostream &reverseColor() override;

  bool is_displayed() const override;

  bool has_colors() const override;

  void enable_colors(bool enable) override { ColorEnabled = enable; }

  std::error_code error() const { return EC; }

  /// Return the value of the flag in this raw_fd_ostream indicating whether an
  /// output error has been encountered.
  /// This doesn't implicitly flush any pending output.  Also, it doesn't
  /// guarantee to detect all errors unless the stream has been closed.
  bool has_error() const { return bool(EC); }

  /// Set the flag read by has_error() to false. If the error flag is set at the
  /// time when this raw_ostream's destructor is called, report_fatal_error is
  /// called to report the error. Use clear_error() after handling the error to
  /// avoid this behavior.
  ///
  ///   "Errors should never pass silently.
  ///    Unless explicitly silenced."
  ///      - from The Zen of Python, by Tim Peters
  ///
  void clear_error() { EC = std::error_code(); }
};

/// This returns a reference to a raw_ostream for standard output. Use it like:
/// outs() << "foo" << "bar";
raw_ostream &outs();

/// This returns a reference to a raw_ostream for standard error. Use it like:
/// errs() << "foo" << "bar";
raw_ostream &errs();

/// This returns a reference to a raw_ostream which simply discards output.
raw_ostream &nulls();

//===----------------------------------------------------------------------===//
// Output Stream Adaptors
//===----------------------------------------------------------------------===//

/// A raw_ostream that writes to an std::string.  This is a simple adaptor
/// class. This class does not encounter output errors.
class raw_string_ostream : public raw_ostream {
  std::string &OS;

  /// See raw_ostream::write_impl.
  void write_impl(const char *Ptr, size_t Size) override;

  /// Return the current position within the stream, not counting the bytes
  /// currently in the buffer.
  uint64_t current_pos() const override { return OS.size(); }

public:
  explicit raw_string_ostream(std::string &O) : OS(O) {}
  ~raw_string_ostream() override;

  /// Flushes the stream contents to the target string and returns  the string's
  /// reference.
  std::string& str() {
    flush();
    return OS;
  }
};

/// A raw_ostream that writes to an SmallVector or SmallString.  This is a
/// simple adaptor class. This class does not encounter output errors.
/// raw_svector_ostream operates without a buffer, delegating all memory
/// management to the SmallString. Thus the SmallString is always up-to-date,
/// may be used directly and there is no need to call flush().
class raw_svector_ostream : public raw_pwrite_stream {
  SmallVectorImpl<char> &OS;

  /// See raw_ostream::write_impl.
  void write_impl(const char *Ptr, size_t Size) override;

  void pwrite_impl(const char *Ptr, size_t Size, uint64_t Offset) override;

  /// Return the current position within the stream.
  uint64_t current_pos() const override;

public:
  /// Construct a new raw_svector_ostream.
  ///
  /// \param O The vector to write to; this should generally have at least 128
  /// bytes free to avoid any extraneous memory overhead.
  explicit raw_svector_ostream(SmallVectorImpl<char> &O) : OS(O) {
    SetUnbuffered();
  }

  ~raw_svector_ostream() override = default;

  void flush() = delete;

  /// Return a StringRef for the vector contents.
  StringRef str() const { return StringRef(OS.data(), OS.size()); }
};

/// A raw_ostream that discards all output.
class raw_null_ostream : public raw_pwrite_stream {
  /// See raw_ostream::write_impl.
  void write_impl(const char *Ptr, size_t size) override;
  void pwrite_impl(const char *Ptr, size_t Size, uint64_t Offset) override;

  /// Return the current position within the stream, not counting the bytes
  /// currently in the buffer.
  uint64_t current_pos() const override;

public:
  explicit raw_null_ostream() = default;
  ~raw_null_ostream() override;
};

class buffer_ostream : public raw_svector_ostream {
  raw_ostream &OS;
  SmallVector<char, 0> Buffer;

  virtual void anchor() override;

public:
  buffer_ostream(raw_ostream &OS) : raw_svector_ostream(Buffer), OS(OS) {}
  ~buffer_ostream() override { OS << str(); }
};

} // end namespace llvm

#endif // LLVM_SUPPORT_RAW_OSTREAM_H
# 600 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/raw_ostream.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <functional>
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 37 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <system_error>
#endif /* expanded by -frewrite-includes */
# 37 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 38 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 38 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 39 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 39 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 41 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"

namespace llvm {

class ErrorSuccess;

/// Base class for error info classes. Do not extend this directly: Extend
/// the ErrorInfo template subclass instead.
class ErrorInfoBase {
public:
  virtual ~ErrorInfoBase() = default;

  /// Print an error message to an output stream.
  virtual void log(raw_ostream &OS) const = 0;

  /// Return the error message as a string.
  virtual std::string message() const {
    std::string Msg;
    raw_string_ostream OS(Msg);
    log(OS);
    return OS.str();
  }

  /// Convert this error to a std::error_code.
  ///
  /// This is a temporary crutch to enable interaction with code still
  /// using std::error_code. It will be removed in the future.
  virtual std::error_code convertToErrorCode() const = 0;

  // Returns the class ID for this type.
  static const void *classID() { return &ID; }

  // Returns the class ID for the dynamic type of this ErrorInfoBase instance.
  virtual const void *dynamicClassID() const = 0;

  // Check whether this instance is a subclass of the class identified by
  // ClassID.
  virtual bool isA(const void *const ClassID) const {
    return ClassID == classID();
  }

  // Check whether this instance is a subclass of ErrorInfoT.
  template <typename ErrorInfoT> bool isA() const {
    return isA(ErrorInfoT::classID());
  }

private:
  virtual void anchor();

  static char ID;
};

/// Lightweight error class with error context and mandatory checking.
///
/// Instances of this class wrap a ErrorInfoBase pointer. Failure states
/// are represented by setting the pointer to a ErrorInfoBase subclass
/// instance containing information describing the failure. Success is
/// represented by a null pointer value.
///
/// Instances of Error also contains a 'Checked' flag, which must be set
/// before the destructor is called, otherwise the destructor will trigger a
/// runtime error. This enforces at runtime the requirement that all Error
/// instances be checked or returned to the caller.
///
/// There are two ways to set the checked flag, depending on what state the
/// Error instance is in. For Error instances indicating success, it
/// is sufficient to invoke the boolean conversion operator. E.g.:
///
///   @code{.cpp}
///   Error foo(<...>);
///
///   if (auto E = foo(<...>))
///     return E; // <- Return E if it is in the error state.
///   // We have verified that E was in the success state. It can now be safely
///   // destroyed.
///   @endcode
///
/// A success value *can not* be dropped. For example, just calling 'foo(<...>)'
/// without testing the return value will raise a runtime error, even if foo
/// returns success.
///
/// For Error instances representing failure, you must use either the
/// handleErrors or handleAllErrors function with a typed handler. E.g.:
///
///   @code{.cpp}
///   class MyErrorInfo : public ErrorInfo<MyErrorInfo> {
///     // Custom error info.
///   };
///
///   Error foo(<...>) { return make_error<MyErrorInfo>(...); }
///
///   auto E = foo(<...>); // <- foo returns failure with MyErrorInfo.
///   auto NewE =
///     handleErrors(E,
///       [](const MyErrorInfo &M) {
///         // Deal with the error.
///       },
///       [](std::unique_ptr<OtherError> M) -> Error {
///         if (canHandle(*M)) {
///           // handle error.
///           return Error::success();
///         }
///         // Couldn't handle this error instance. Pass it up the stack.
///         return Error(std::move(M));
///       );
///   // Note - we must check or return NewE in case any of the handlers
///   // returned a new error.
///   @endcode
///
/// The handleAllErrors function is identical to handleErrors, except
/// that it has a void return type, and requires all errors to be handled and
/// no new errors be returned. It prevents errors (assuming they can all be
/// handled) from having to be bubbled all the way to the top-level.
///
/// *All* Error instances must be checked before destruction, even if
/// they're moved-assigned or constructed from Success values that have already
/// been checked. This enforces checking through all levels of the call stack.
class LLVM_NODISCARD Error {
  // ErrorList needs to be able to yank ErrorInfoBase pointers out of Errors
  // to add to the error list. It can't rely on handleErrors for this, since
  // handleErrors does not support ErrorList handlers.
  friend class ErrorList;

  // handleErrors needs to be able to set the Checked flag.
  template <typename... HandlerTs>
  friend Error handleErrors(Error E, HandlerTs &&... Handlers);

  // Expected<T> needs to be able to steal the payload when constructed from an
  // error.
  template <typename T> friend class Expected;

  // wrap needs to be able to steal the payload.
  friend LLVMErrorRef wrap(Error);

protected:
  /// Create a success value. Prefer using 'Error::success()' for readability
  Error() {
    setPtr(nullptr);
    setChecked(false);
  }

public:
  /// Create a success value.
  static ErrorSuccess success();

  // Errors are not copy-constructable.
  Error(const Error &Other) = delete;

  /// Move-construct an error value. The newly constructed error is considered
  /// unchecked, even if the source error had been checked. The original error
  /// becomes a checked Success value, regardless of its original state.
  Error(Error &&Other) {
    setChecked(true);
    *this = std::move(Other);
  }

  /// Create an error value. Prefer using the 'make_error' function, but
  /// this constructor can be useful when "re-throwing" errors from handlers.
  Error(std::unique_ptr<ErrorInfoBase> Payload) {
    setPtr(Payload.release());
    setChecked(false);
  }

  // Errors are not copy-assignable.
  Error &operator=(const Error &Other) = delete;

  /// Move-assign an error value. The current error must represent success, you
  /// you cannot overwrite an unhandled error. The current error is then
  /// considered unchecked. The source error becomes a checked success value,
  /// regardless of its original state.
  Error &operator=(Error &&Other) {
    // Don't allow overwriting of unchecked values.
    assertIsChecked();
    setPtr(Other.getPtr());

    // This Error is unchecked, even if the source error was checked.
    setChecked(false);

    // Null out Other's payload and set its checked bit.
    Other.setPtr(nullptr);
    Other.setChecked(true);

    return *this;
  }

  /// Destroy a Error. Fails with a call to abort() if the error is
  /// unchecked.
  ~Error() {
    assertIsChecked();
    delete getPtr();
  }

  /// Bool conversion. Returns true if this Error is in a failure state,
  /// and false if it is in an accept state. If the error is in a Success state
  /// it will be considered checked.
  explicit operator bool() {
    setChecked(getPtr() == nullptr);
    return getPtr() != nullptr;
  }

  /// Check whether one error is a subclass of another.
  template <typename ErrT> bool isA() const {
    return getPtr() && getPtr()->isA(ErrT::classID());
  }

  /// Returns the dynamic class id of this error, or null if this is a success
  /// value.
  const void* dynamicClassID() const {
    if (!getPtr())
      return nullptr;
    return getPtr()->dynamicClassID();
  }

private:
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 255 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  // assertIsChecked() happens very frequently, but under normal circumstances
  // is supposed to be a no-op.  So we want it to be inlined, but having a bunch
  // of debug prints can cause the function to be too large for inlining.  So
  // it's important that we define this function out of line so that it can't be
  // inlined.
  LLVM_ATTRIBUTE_NORETURN
  void fatalUncheckedError() const;
#endif
# 263 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"

  void assertIsChecked() {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 266 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    if (LLVM_UNLIKELY(!getChecked() || getPtr()))
      fatalUncheckedError();
#endif
# 269 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  }

  ErrorInfoBase *getPtr() const {
    return reinterpret_cast<ErrorInfoBase*>(
             reinterpret_cast<uintptr_t>(Payload) &
             ~static_cast<uintptr_t>(0x1));
  }

  void setPtr(ErrorInfoBase *EI) {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 279 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    Payload = reinterpret_cast<ErrorInfoBase*>(
                (reinterpret_cast<uintptr_t>(EI) &
                 ~static_cast<uintptr_t>(0x1)) |
                (reinterpret_cast<uintptr_t>(Payload) & 0x1));
#else
# 284 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    Payload = EI;
#endif
# 286 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  }

  bool getChecked() const {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 290 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    return (reinterpret_cast<uintptr_t>(Payload) & 0x1) == 0;
#else
# 292 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    return true;
#endif
# 294 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  }

  void setChecked(bool V) {
    Payload = reinterpret_cast<ErrorInfoBase*>(
                (reinterpret_cast<uintptr_t>(Payload) &
                  ~static_cast<uintptr_t>(0x1)) |
                  (V ? 0 : 1));
  }

  std::unique_ptr<ErrorInfoBase> takePayload() {
    std::unique_ptr<ErrorInfoBase> Tmp(getPtr());
    setPtr(nullptr);
    setChecked(true);
    return Tmp;
  }

  friend raw_ostream &operator<<(raw_ostream &OS, const Error &E) {
    if (auto P = E.getPtr())
      P->log(OS);
    else
      OS << "success";
    return OS;
  }

  ErrorInfoBase *Payload = nullptr;
};

/// Subclass of Error for the sole purpose of identifying the success path in
/// the type system. This allows to catch invalid conversion to Expected<T> at
/// compile time.
class ErrorSuccess final : public Error {};

inline ErrorSuccess Error::success() { return ErrorSuccess(); }

/// Make a Error instance representing failure using the given error info
/// type.
template <typename ErrT, typename... ArgTs> Error make_error(ArgTs &&... Args) {
  return Error(std::make_unique<ErrT>(std::forward<ArgTs>(Args)...));
}

/// Base class for user error types. Users should declare their error types
/// like:
///
/// class MyError : public ErrorInfo<MyError> {
///   ....
/// };
///
/// This class provides an implementation of the ErrorInfoBase::kind
/// method, which is used by the Error RTTI system.
template <typename ThisErrT, typename ParentErrT = ErrorInfoBase>
class ErrorInfo : public ParentErrT {
public:
  using ParentErrT::ParentErrT; // inherit constructors

  static const void *classID() { return &ThisErrT::ID; }

  const void *dynamicClassID() const override { return &ThisErrT::ID; }

  bool isA(const void *const ClassID) const override {
    return ClassID == classID() || ParentErrT::isA(ClassID);
  }
};

/// Special ErrorInfo subclass representing a list of ErrorInfos.
/// Instances of this class are constructed by joinError.
class ErrorList final : public ErrorInfo<ErrorList> {
  // handleErrors needs to be able to iterate the payload list of an
  // ErrorList.
  template <typename... HandlerTs>
  friend Error handleErrors(Error E, HandlerTs &&... Handlers);

  // joinErrors is implemented in terms of join.
  friend Error joinErrors(Error, Error);

public:
  void log(raw_ostream &OS) const override {
    OS << "Multiple errors:\n";
    for (auto &ErrPayload : Payloads) {
      ErrPayload->log(OS);
      OS << "\n";
    }
  }

  std::error_code convertToErrorCode() const override;

  // Used by ErrorInfo::classID.
  static char ID;

private:
  ErrorList(std::unique_ptr<ErrorInfoBase> Payload1,
            std::unique_ptr<ErrorInfoBase> Payload2) {
    assert(!Payload1->isA<ErrorList>() && !Payload2->isA<ErrorList>() &&
           "ErrorList constructor payloads should be singleton errors");
    Payloads.push_back(std::move(Payload1));
    Payloads.push_back(std::move(Payload2));
  }

  static Error join(Error E1, Error E2) {
    if (!E1)
      return E2;
    if (!E2)
      return E1;
    if (E1.isA<ErrorList>()) {
      auto &E1List = static_cast<ErrorList &>(*E1.getPtr());
      if (E2.isA<ErrorList>()) {
        auto E2Payload = E2.takePayload();
        auto &E2List = static_cast<ErrorList &>(*E2Payload);
        for (auto &Payload : E2List.Payloads)
          E1List.Payloads.push_back(std::move(Payload));
      } else
        E1List.Payloads.push_back(E2.takePayload());

      return E1;
    }
    if (E2.isA<ErrorList>()) {
      auto &E2List = static_cast<ErrorList &>(*E2.getPtr());
      E2List.Payloads.insert(E2List.Payloads.begin(), E1.takePayload());
      return E2;
    }
    return Error(std::unique_ptr<ErrorList>(
        new ErrorList(E1.takePayload(), E2.takePayload())));
  }

  std::vector<std::unique_ptr<ErrorInfoBase>> Payloads;
};

/// Concatenate errors. The resulting Error is unchecked, and contains the
/// ErrorInfo(s), if any, contained in E1, followed by the
/// ErrorInfo(s), if any, contained in E2.
inline Error joinErrors(Error E1, Error E2) {
  return ErrorList::join(std::move(E1), std::move(E2));
}

/// Tagged union holding either a T or a Error.
///
/// This class parallels ErrorOr, but replaces error_code with Error. Since
/// Error cannot be copied, this class replaces getError() with
/// takeError(). It also adds an bool errorIsA<ErrT>() method for testing the
/// error class type.
template <class T> class LLVM_NODISCARD Expected {
  template <class T1> friend class ExpectedAsOutParameter;
  template <class OtherT> friend class Expected;

  static const bool isRef = std::is_reference<T>::value;

  using wrap = std::reference_wrapper<std::remove_reference_t<T>>;

  using error_type = std::unique_ptr<ErrorInfoBase>;

public:
  using storage_type = std::conditional_t<isRef, wrap, T>;
  using value_type = T;

private:
  using reference = std::remove_reference_t<T> &;
  using const_reference = const std::remove_reference_t<T> &;
  using pointer = std::remove_reference_t<T> *;
  using const_pointer = const std::remove_reference_t<T> *;

public:
  /// Create an Expected<T> error value from the given Error.
  Expected(Error Err)
      : HasError(true)
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 458 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
        // Expected is unchecked upon construction in Debug builds.
        , Unchecked(true)
#endif
# 461 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  {
    assert(Err && "Cannot create Expected<T> from Error success value.");
    new (getErrorStorage()) error_type(Err.takePayload());
  }

  /// Forbid to convert from Error::success() implicitly, this avoids having
  /// Expected<T> foo() { return Error::success(); } which compiles otherwise
  /// but triggers the assertion above.
  Expected(ErrorSuccess) = delete;

  /// Create an Expected<T> success value from the given OtherT value, which
  /// must be convertible to T.
  template <typename OtherT>
  Expected(OtherT &&Val,
           std::enable_if_t<std::is_convertible<OtherT, T>::value> * = nullptr)
      : HasError(false)
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 478 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
        // Expected is unchecked upon construction in Debug builds.
        ,
        Unchecked(true)
#endif
# 482 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  {
    new (getStorage()) storage_type(std::forward<OtherT>(Val));
  }

  /// Move construct an Expected<T> value.
  Expected(Expected &&Other) { moveConstruct(std::move(Other)); }

  /// Move construct an Expected<T> value from an Expected<OtherT>, where OtherT
  /// must be convertible to T.
  template <class OtherT>
  Expected(
      Expected<OtherT> &&Other,
      std::enable_if_t<std::is_convertible<OtherT, T>::value> * = nullptr) {
    moveConstruct(std::move(Other));
  }

  /// Move construct an Expected<T> value from an Expected<OtherT>, where OtherT
  /// isn't convertible to T.
  template <class OtherT>
  explicit Expected(
      Expected<OtherT> &&Other,
      std::enable_if_t<!std::is_convertible<OtherT, T>::value> * = nullptr) {
    moveConstruct(std::move(Other));
  }

  /// Move-assign from another Expected<T>.
  Expected &operator=(Expected &&Other) {
    moveAssign(std::move(Other));
    return *this;
  }

  /// Destroy an Expected<T>.
  ~Expected() {
    assertIsChecked();
    if (!HasError)
      getStorage()->~storage_type();
    else
      getErrorStorage()->~error_type();
  }

  /// Return false if there is an error.
  explicit operator bool() {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 525 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    Unchecked = HasError;
#endif
# 527 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    return !HasError;
  }

  /// Returns a reference to the stored T value.
  reference get() {
    assertIsChecked();
    return *getStorage();
  }

  /// Returns a const reference to the stored T value.
  const_reference get() const {
    assertIsChecked();
    return const_cast<Expected<T> *>(this)->get();
  }

  /// Check that this Expected<T> is an error of type ErrT.
  template <typename ErrT> bool errorIsA() const {
    return HasError && (*getErrorStorage())->template isA<ErrT>();
  }

  /// Take ownership of the stored error.
  /// After calling this the Expected<T> is in an indeterminate state that can
  /// only be safely destructed. No further calls (beside the destructor) should
  /// be made on the Expected<T> value.
  Error takeError() {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 553 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    Unchecked = false;
#endif
# 555 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    return HasError ? Error(std::move(*getErrorStorage())) : Error::success();
  }

  /// Returns a pointer to the stored T value.
  pointer operator->() {
    assertIsChecked();
    return toPointer(getStorage());
  }

  /// Returns a const pointer to the stored T value.
  const_pointer operator->() const {
    assertIsChecked();
    return toPointer(getStorage());
  }

  /// Returns a reference to the stored T value.
  reference operator*() {
    assertIsChecked();
    return *getStorage();
  }

  /// Returns a const reference to the stored T value.
  const_reference operator*() const {
    assertIsChecked();
    return *getStorage();
  }

private:
  template <class T1>
  static bool compareThisIfSameType(const T1 &a, const T1 &b) {
    return &a == &b;
  }

  template <class T1, class T2>
  static bool compareThisIfSameType(const T1 &a, const T2 &b) {
    return false;
  }

  template <class OtherT> void moveConstruct(Expected<OtherT> &&Other) {
    HasError = Other.HasError;
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 596 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    Unchecked = true;
    Other.Unchecked = false;
#endif
# 599 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"

    if (!HasError)
      new (getStorage()) storage_type(std::move(*Other.getStorage()));
    else
      new (getErrorStorage()) error_type(std::move(*Other.getErrorStorage()));
  }

  template <class OtherT> void moveAssign(Expected<OtherT> &&Other) {
    assertIsChecked();

    if (compareThisIfSameType(*this, Other))
      return;

    this->~Expected();
    new (this) Expected(std::move(Other));
  }

  pointer toPointer(pointer Val) { return Val; }

  const_pointer toPointer(const_pointer Val) const { return Val; }

  pointer toPointer(wrap *Val) { return &Val->get(); }

  const_pointer toPointer(const wrap *Val) const { return &Val->get(); }

  storage_type *getStorage() {
    assert(!HasError && "Cannot get value when an error exists!");
    return reinterpret_cast<storage_type *>(TStorage.buffer);
  }

  const storage_type *getStorage() const {
    assert(!HasError && "Cannot get value when an error exists!");
    return reinterpret_cast<const storage_type *>(TStorage.buffer);
  }

  error_type *getErrorStorage() {
    assert(HasError && "Cannot get error when a value exists!");
    return reinterpret_cast<error_type *>(ErrorStorage.buffer);
  }

  const error_type *getErrorStorage() const {
    assert(HasError && "Cannot get error when a value exists!");
    return reinterpret_cast<const error_type *>(ErrorStorage.buffer);
  }

  // Used by ExpectedAsOutParameter to reset the checked flag.
  void setUnchecked() {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 647 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    Unchecked = true;
#endif
# 649 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  }

#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 652 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  LLVM_ATTRIBUTE_NORETURN
  LLVM_ATTRIBUTE_NOINLINE
  void fatalUncheckedExpected() const {
    dbgs() << "Expected<T> must be checked before access or destruction.\n";
    if (HasError) {
      dbgs() << "Unchecked Expected<T> contained error:\n";
      (*getErrorStorage())->log(dbgs());
    } else
      dbgs() << "Expected<T> value was in success state. (Note: Expected<T> "
                "values in success mode must still be checked prior to being "
                "destroyed).\n";
    abort();
  }
#endif
# 666 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"

  void assertIsChecked() {
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 669 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    if (LLVM_UNLIKELY(Unchecked))
      fatalUncheckedExpected();
#endif
# 672 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  }

  union {
    AlignedCharArrayUnion<storage_type> TStorage;
    AlignedCharArrayUnion<error_type> ErrorStorage;
  };
  bool HasError : 1;
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ENABLE_ABI_BREAKING_CHECKS
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 680 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
  bool Unchecked : 1;
#endif
# 682 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
};

/// Report a serious error, calling any installed error handler. See
/// ErrorHandling.h.
LLVM_ATTRIBUTE_NORETURN void report_fatal_error(Error Err,
                                                bool gen_crash_diag = true);

/// Report a fatal error if Err is a failure value.
///
/// This function can be used to wrap calls to fallible functions ONLY when it
/// is known that the Error will always be a success value. E.g.
///
///   @code{.cpp}
///   // foo only attempts the fallible operation if DoFallibleOperation is
///   // true. If DoFallibleOperation is false then foo always returns
///   // Error::success().
///   Error foo(bool DoFallibleOperation);
///
///   cantFail(foo(false));
///   @endcode
inline void cantFail(Error Err, const char *Msg = nullptr) {
  if (Err) {
    if (!Msg)
      Msg = "Failure value returned from cantFail wrapped call";
#ifndef NDEBUG
    std::string Str;
    raw_string_ostream OS(Str);
    OS << Msg << "\n" << Err;
    Msg = OS.str().c_str();
#endif
# 712 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    llvm_unreachable(Msg);
  }
}

/// Report a fatal error if ValOrErr is a failure value, otherwise unwraps and
/// returns the contained value.
///
/// This function can be used to wrap calls to fallible functions ONLY when it
/// is known that the Error will always be a success value. E.g.
///
///   @code{.cpp}
///   // foo only attempts the fallible operation if DoFallibleOperation is
///   // true. If DoFallibleOperation is false then foo always returns an int.
///   Expected<int> foo(bool DoFallibleOperation);
///
///   int X = cantFail(foo(false));
///   @endcode
template <typename T>
T cantFail(Expected<T> ValOrErr, const char *Msg = nullptr) {
  if (ValOrErr)
    return std::move(*ValOrErr);
  else {
    if (!Msg)
      Msg = "Failure value returned from cantFail wrapped call";
#ifndef NDEBUG
    std::string Str;
    raw_string_ostream OS(Str);
    auto E = ValOrErr.takeError();
    OS << Msg << "\n" << E;
    Msg = OS.str().c_str();
#endif
# 743 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    llvm_unreachable(Msg);
  }
}

/// Report a fatal error if ValOrErr is a failure value, otherwise unwraps and
/// returns the contained reference.
///
/// This function can be used to wrap calls to fallible functions ONLY when it
/// is known that the Error will always be a success value. E.g.
///
///   @code{.cpp}
///   // foo only attempts the fallible operation if DoFallibleOperation is
///   // true. If DoFallibleOperation is false then foo always returns a Bar&.
///   Expected<Bar&> foo(bool DoFallibleOperation);
///
///   Bar &X = cantFail(foo(false));
///   @endcode
template <typename T>
T& cantFail(Expected<T&> ValOrErr, const char *Msg = nullptr) {
  if (ValOrErr)
    return *ValOrErr;
  else {
    if (!Msg)
      Msg = "Failure value returned from cantFail wrapped call";
#ifndef NDEBUG
    std::string Str;
    raw_string_ostream OS(Str);
    auto E = ValOrErr.takeError();
    OS << Msg << "\n" << E;
    Msg = OS.str().c_str();
#endif
# 774 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
    llvm_unreachable(Msg);
  }
}

/// Helper for testing applicability of, and applying, handlers for
/// ErrorInfo types.
template <typename HandlerT>
class ErrorHandlerTraits
    : public ErrorHandlerTraits<decltype(
          &std::remove_reference<HandlerT>::type::operator())> {};

// Specialization functions of the form 'Error (const ErrT&)'.
template <typename ErrT> class ErrorHandlerTraits<Error (&)(ErrT &)> {
public:
  static bool appliesTo(const ErrorInfoBase &E) {
    return E.template isA<ErrT>();
  }

  template <typename HandlerT>
  static Error apply(HandlerT &&H, std::unique_ptr<ErrorInfoBase> E) {
    assert(appliesTo(*E) && "Applying incorrect handler");
    return H(static_cast<ErrT &>(*E));
  }
};

// Specialization functions of the form 'void (const ErrT&)'.
template <typename ErrT> class ErrorHandlerTraits<void (&)(ErrT &)> {
public:
  static bool appliesTo(const ErrorInfoBase &E) {
    return E.template isA<ErrT>();
  }

  template <typename HandlerT>
  static Error apply(HandlerT &&H, std::unique_ptr<ErrorInfoBase> E) {
    assert(appliesTo(*E) && "Applying incorrect handler");
    H(static_cast<ErrT &>(*E));
    return Error::success();
  }
};

/// Specialization for functions of the form 'Error (std::unique_ptr<ErrT>)'.
template <typename ErrT>
class ErrorHandlerTraits<Error (&)(std::unique_ptr<ErrT>)> {
public:
  static bool appliesTo(const ErrorInfoBase &E) {
    return E.template isA<ErrT>();
  }

  template <typename HandlerT>
  static Error apply(HandlerT &&H, std::unique_ptr<ErrorInfoBase> E) {
    assert(appliesTo(*E) && "Applying incorrect handler");
    std::unique_ptr<ErrT> SubE(static_cast<ErrT *>(E.release()));
    return H(std::move(SubE));
  }
};

/// Specialization for functions of the form 'void (std::unique_ptr<ErrT>)'.
template <typename ErrT>
class ErrorHandlerTraits<void (&)(std::unique_ptr<ErrT>)> {
public:
  static bool appliesTo(const ErrorInfoBase &E) {
    return E.template isA<ErrT>();
  }

  template <typename HandlerT>
  static Error apply(HandlerT &&H, std::unique_ptr<ErrorInfoBase> E) {
    assert(appliesTo(*E) && "Applying incorrect handler");
    std::unique_ptr<ErrT> SubE(static_cast<ErrT *>(E.release()));
    H(std::move(SubE));
    return Error::success();
  }
};

// Specialization for member functions of the form 'RetT (const ErrT&)'.
template <typename C, typename RetT, typename ErrT>
class ErrorHandlerTraits<RetT (C::*)(ErrT &)>
    : public ErrorHandlerTraits<RetT (&)(ErrT &)> {};

// Specialization for member functions of the form 'RetT (const ErrT&) const'.
template <typename C, typename RetT, typename ErrT>
class ErrorHandlerTraits<RetT (C::*)(ErrT &) const>
    : public ErrorHandlerTraits<RetT (&)(ErrT &)> {};

// Specialization for member functions of the form 'RetT (const ErrT&)'.
template <typename C, typename RetT, typename ErrT>
class ErrorHandlerTraits<RetT (C::*)(const ErrT &)>
    : public ErrorHandlerTraits<RetT (&)(ErrT &)> {};

// Specialization for member functions of the form 'RetT (const ErrT&) const'.
template <typename C, typename RetT, typename ErrT>
class ErrorHandlerTraits<RetT (C::*)(const ErrT &) const>
    : public ErrorHandlerTraits<RetT (&)(ErrT &)> {};

/// Specialization for member functions of the form
/// 'RetT (std::unique_ptr<ErrT>)'.
template <typename C, typename RetT, typename ErrT>
class ErrorHandlerTraits<RetT (C::*)(std::unique_ptr<ErrT>)>
    : public ErrorHandlerTraits<RetT (&)(std::unique_ptr<ErrT>)> {};

/// Specialization for member functions of the form
/// 'RetT (std::unique_ptr<ErrT>) const'.
template <typename C, typename RetT, typename ErrT>
class ErrorHandlerTraits<RetT (C::*)(std::unique_ptr<ErrT>) const>
    : public ErrorHandlerTraits<RetT (&)(std::unique_ptr<ErrT>)> {};

inline Error handleErrorImpl(std::unique_ptr<ErrorInfoBase> Payload) {
  return Error(std::move(Payload));
}

template <typename HandlerT, typename... HandlerTs>
Error handleErrorImpl(std::unique_ptr<ErrorInfoBase> Payload,
                      HandlerT &&Handler, HandlerTs &&... Handlers) {
  if (ErrorHandlerTraits<HandlerT>::appliesTo(*Payload))
    return ErrorHandlerTraits<HandlerT>::apply(std::forward<HandlerT>(Handler),
                                               std::move(Payload));
  return handleErrorImpl(std::move(Payload),
                         std::forward<HandlerTs>(Handlers)...);
}

/// Pass the ErrorInfo(s) contained in E to their respective handlers. Any
/// unhandled errors (or Errors returned by handlers) are re-concatenated and
/// returned.
/// Because this function returns an error, its result must also be checked
/// or returned. If you intend to handle all errors use handleAllErrors
/// (which returns void, and will abort() on unhandled errors) instead.
template <typename... HandlerTs>
Error handleErrors(Error E, HandlerTs &&... Hs) {
  if (!E)
    return Error::success();

  std::unique_ptr<ErrorInfoBase> Payload = E.takePayload();

  if (Payload->isA<ErrorList>()) {
    ErrorList &List = static_cast<ErrorList &>(*Payload);
    Error R;
    for (auto &P : List.Payloads)
      R = ErrorList::join(
          std::move(R),
          handleErrorImpl(std::move(P), std::forward<HandlerTs>(Hs)...));
    return R;
  }

  return handleErrorImpl(std::move(Payload), std::forward<HandlerTs>(Hs)...);
}

/// Behaves the same as handleErrors, except that by contract all errors
/// *must* be handled by the given handlers (i.e. there must be no remaining
/// errors after running the handlers, or llvm_unreachable is called).
template <typename... HandlerTs>
void handleAllErrors(Error E, HandlerTs &&... Handlers) {
  cantFail(handleErrors(std::move(E), std::forward<HandlerTs>(Handlers)...));
}

/// Check that E is a non-error, then drop it.
/// If E is an error, llvm_unreachable will be called.
inline void handleAllErrors(Error E) {
  cantFail(std::move(E));
}

/// Handle any errors (if present) in an Expected<T>, then try a recovery path.
///
/// If the incoming value is a success value it is returned unmodified. If it
/// is a failure value then it the contained error is passed to handleErrors.
/// If handleErrors is able to handle the error then the RecoveryPath functor
/// is called to supply the final result. If handleErrors is not able to
/// handle all errors then the unhandled errors are returned.
///
/// This utility enables the follow pattern:
///
///   @code{.cpp}
///   enum FooStrategy { Aggressive, Conservative };
///   Expected<Foo> foo(FooStrategy S);
///
///   auto ResultOrErr =
///     handleExpected(
///       foo(Aggressive),
///       []() { return foo(Conservative); },
///       [](AggressiveStrategyError&) {
///         // Implicitly conusme this - we'll recover by using a conservative
///         // strategy.
///       });
///
///   @endcode
template <typename T, typename RecoveryFtor, typename... HandlerTs>
Expected<T> handleExpected(Expected<T> ValOrErr, RecoveryFtor &&RecoveryPath,
                           HandlerTs &&... Handlers) {
  if (ValOrErr)
    return ValOrErr;

  if (auto Err = handleErrors(ValOrErr.takeError(),
                              std::forward<HandlerTs>(Handlers)...))
    return std::move(Err);

  return RecoveryPath();
}

/// Log all errors (if any) in E to OS. If there are any errors, ErrorBanner
/// will be printed before the first one is logged. A newline will be printed
/// after each error.
///
/// This function is compatible with the helpers from Support/WithColor.h. You
/// can pass any of them as the OS. Please consider using them instead of
/// including 'error: ' in the ErrorBanner.
///
/// This is useful in the base level of your program to allow clean termination
/// (allowing clean deallocation of resources, etc.), while reporting error
/// information to the user.
void logAllUnhandledErrors(Error E, raw_ostream &OS, Twine ErrorBanner = {});

/// Write all error messages (if any) in E to a string. The newline character
/// is used to separate error messages.
inline std::string toString(Error E) {
  SmallVector<std::string, 2> Errors;
  handleAllErrors(std::move(E), [&Errors](const ErrorInfoBase &EI) {
    Errors.push_back(EI.message());
  });
  return join(Errors.begin(), Errors.end(), "\n");
}

/// Consume a Error without doing anything. This method should be used
/// only where an error can be considered a reasonable and expected return
/// value.
///
/// Uses of this method are potentially indicative of design problems: If it's
/// legitimate to do nothing while processing an "error", the error-producer
/// might be more clearly refactored to return an Optional<T>.
inline void consumeError(Error Err) {
  handleAllErrors(std::move(Err), [](const ErrorInfoBase &) {});
}

/// Convert an Expected to an Optional without doing anything. This method
/// should be used only where an error can be considered a reasonable and
/// expected return value.
///
/// Uses of this method are potentially indicative of problems: perhaps the
/// error should be propagated further, or the error-producer should just
/// return an Optional in the first place.
template <typename T> Optional<T> expectedToOptional(Expected<T> &&E) {
  if (E)
    return std::move(*E);
  consumeError(E.takeError());
  return None;
}

/// Helper for converting an Error to a bool.
///
/// This method returns true if Err is in an error state, or false if it is
/// in a success state.  Puts Err in a checked state in both cases (unlike
/// Error::operator bool(), which only does this for success states).
inline bool errorToBool(Error Err) {
  bool IsError = static_cast<bool>(Err);
  if (IsError)
    consumeError(std::move(Err));
  return IsError;
}

/// Helper for Errors used as out-parameters.
///
/// This helper is for use with the Error-as-out-parameter idiom, where an error
/// is passed to a function or method by reference, rather than being returned.
/// In such cases it is helpful to set the checked bit on entry to the function
/// so that the error can be written to (unchecked Errors abort on assignment)
/// and clear the checked bit on exit so that clients cannot accidentally forget
/// to check the result. This helper performs these actions automatically using
/// RAII:
///
///   @code{.cpp}
///   Result foo(Error &Err) {
///     ErrorAsOutParameter ErrAsOutParam(&Err); // 'Checked' flag set
///     // <body of foo>
///     // <- 'Checked' flag auto-cleared when ErrAsOutParam is destructed.
///   }
///   @endcode
///
/// ErrorAsOutParameter takes an Error* rather than Error& so that it can be
/// used with optional Errors (Error pointers that are allowed to be null). If
/// ErrorAsOutParameter took an Error reference, an instance would have to be
/// created inside every condition that verified that Error was non-null. By
/// taking an Error pointer we can just create one instance at the top of the
/// function.
class ErrorAsOutParameter {
public:
  ErrorAsOutParameter(Error *Err) : Err(Err) {
    // Raise the checked bit if Err is success.
    if (Err)
      (void)!!*Err;
  }

  ~ErrorAsOutParameter() {
    // Clear the checked bit.
    if (Err && !*Err)
      *Err = Error::success();
  }

private:
  Error *Err;
};

/// Helper for Expected<T>s used as out-parameters.
///
/// See ErrorAsOutParameter.
template <typename T>
class ExpectedAsOutParameter {
public:
  ExpectedAsOutParameter(Expected<T> *ValOrErr)
    : ValOrErr(ValOrErr) {
    if (ValOrErr)
      (void)!!*ValOrErr;
  }

  ~ExpectedAsOutParameter() {
    if (ValOrErr)
      ValOrErr->setUnchecked();
  }

private:
  Expected<T> *ValOrErr;
};

/// This class wraps a std::error_code in a Error.
///
/// This is useful if you're writing an interface that returns a Error
/// (or Expected) and you want to call code that still returns
/// std::error_codes.
class ECError : public ErrorInfo<ECError> {
  friend Error errorCodeToError(std::error_code);

  virtual void anchor() override;

public:
  void setErrorCode(std::error_code EC) { this->EC = EC; }
  std::error_code convertToErrorCode() const override { return EC; }
  void log(raw_ostream &OS) const override { OS << EC.message(); }

  // Used by ErrorInfo::classID.
  static char ID;

protected:
  ECError() = default;
  ECError(std::error_code EC) : EC(EC) {}

  std::error_code EC;
};

/// The value returned by this function can be returned from convertToErrorCode
/// for Error values where no sensible translation to std::error_code exists.
/// It should only be used in this situation, and should never be used where a
/// sensible conversion to std::error_code is available, as attempts to convert
/// to/from this error will result in a fatal error. (i.e. it is a programmatic
///error to try to convert such a value).
std::error_code inconvertibleErrorCode();

/// Helper for converting an std::error_code to a Error.
Error errorCodeToError(std::error_code EC);

/// Helper for converting an ECError to a std::error_code.
///
/// This method requires that Err be Error() or an ECError, otherwise it
/// will trigger a call to abort().
std::error_code errorToErrorCode(Error Err);

/// Convert an ErrorOr<T> to an Expected<T>.
template <typename T> Expected<T> errorOrToExpected(ErrorOr<T> &&EO) {
  if (auto EC = EO.getError())
    return errorCodeToError(EC);
  return std::move(*EO);
}

/// Convert an Expected<T> to an ErrorOr<T>.
template <typename T> ErrorOr<T> expectedToErrorOr(Expected<T> &&E) {
  if (auto Err = E.takeError())
    return errorToErrorCode(std::move(Err));
  return std::move(*E);
}

/// This class wraps a string in an Error.
///
/// StringError is useful in cases where the client is not expected to be able
/// to consume the specific error message programmatically (for example, if the
/// error message is to be presented to the user).
///
/// StringError can also be used when additional information is to be printed
/// along with a error_code message. Depending on the constructor called, this
/// class can either display:
///    1. the error_code message (ECError behavior)
///    2. a string
///    3. the error_code message and a string
///
/// These behaviors are useful when subtyping is required; for example, when a
/// specific library needs an explicit error type. In the example below,
/// PDBError is derived from StringError:
///
///   @code{.cpp}
///   Expected<int> foo() {
///      return llvm::make_error<PDBError>(pdb_error_code::dia_failed_loading,
///                                        "Additional information");
///   }
///   @endcode
///
class StringError : public ErrorInfo<StringError> {
public:
  static char ID;

  // Prints EC + S and converts to EC
  StringError(std::error_code EC, const Twine &S = Twine());

  // Prints S and converts to EC
  StringError(const Twine &S, std::error_code EC);

  void log(raw_ostream &OS) const override;
  std::error_code convertToErrorCode() const override;

  const std::string &getMessage() const { return Msg; }

private:
  std::string Msg;
  std::error_code EC;
  const bool PrintMsgOnly = false;
};

/// Create formatted StringError object.
template <typename... Ts>
inline Error createStringError(std::error_code EC, char const *Fmt,
                               const Ts &... Vals) {
  std::string Buffer;
  raw_string_ostream Stream(Buffer);
  Stream << format(Fmt, Vals...);
  return make_error<StringError>(Stream.str(), EC);
}

Error createStringError(std::error_code EC, char const *Msg);

inline Error createStringError(std::error_code EC, const Twine &S) {
  return createStringError(EC, S.str().c_str());
}

template <typename... Ts>
inline Error createStringError(std::errc EC, char const *Fmt,
                               const Ts &... Vals) {
  return createStringError(std::make_error_code(EC), Fmt, Vals...);
}

/// This class wraps a filename and another Error.
///
/// In some cases, an error needs to live along a 'source' name, in order to
/// show more detailed information to the user.
class FileError final : public ErrorInfo<FileError> {

  friend Error createFileError(const Twine &, Error);
  friend Error createFileError(const Twine &, size_t, Error);

public:
  void log(raw_ostream &OS) const override {
    assert(Err && !FileName.empty() && "Trying to log after takeError().");
    OS << "'" << FileName << "': ";
    if (Line.hasValue())
      OS << "line " << Line.getValue() << ": ";
    Err->log(OS);
  }

  StringRef getFileName() { return FileName; }

  Error takeError() { return Error(std::move(Err)); }

  std::error_code convertToErrorCode() const override;

  // Used by ErrorInfo::classID.
  static char ID;

private:
  FileError(const Twine &F, Optional<size_t> LineNum,
            std::unique_ptr<ErrorInfoBase> E) {
    assert(E && "Cannot create FileError from Error success value.");
    assert(!F.isTriviallyEmpty() &&
           "The file name provided to FileError must not be empty.");
    FileName = F.str();
    Err = std::move(E);
    Line = std::move(LineNum);
  }

  static Error build(const Twine &F, Optional<size_t> Line, Error E) {
    std::unique_ptr<ErrorInfoBase> Payload;
    handleAllErrors(std::move(E),
                    [&](std::unique_ptr<ErrorInfoBase> EIB) -> Error {
                      Payload = std::move(EIB);
                      return Error::success();
                    });
    return Error(
        std::unique_ptr<FileError>(new FileError(F, Line, std::move(Payload))));
  }

  std::string FileName;
  Optional<size_t> Line;
  std::unique_ptr<ErrorInfoBase> Err;
};

/// Concatenate a source file path and/or name with an Error. The resulting
/// Error is unchecked.
inline Error createFileError(const Twine &F, Error E) {
  return FileError::build(F, Optional<size_t>(), std::move(E));
}

/// Concatenate a source file path and/or name with line number and an Error.
/// The resulting Error is unchecked.
inline Error createFileError(const Twine &F, size_t Line, Error E) {
  return FileError::build(F, Optional<size_t>(Line), std::move(E));
}

/// Concatenate a source file path and/or name with a std::error_code 
/// to form an Error object.
inline Error createFileError(const Twine &F, std::error_code EC) {
  return createFileError(F, errorCodeToError(EC));
}

/// Concatenate a source file path and/or name with line number and
/// std::error_code to form an Error object.
inline Error createFileError(const Twine &F, size_t Line, std::error_code EC) {
  return createFileError(F, Line, errorCodeToError(EC));
}

Error createFileError(const Twine &F, ErrorSuccess) = delete;

/// Helper for check-and-exit error handling.
///
/// For tool use only. NOT FOR USE IN LIBRARY CODE.
///
class ExitOnError {
public:
  /// Create an error on exit helper.
  ExitOnError(std::string Banner = "", int DefaultErrorExitCode = 1)
      : Banner(std::move(Banner)),
        GetExitCode([=](const Error &) { return DefaultErrorExitCode; }) {}

  /// Set the banner string for any errors caught by operator().
  void setBanner(std::string Banner) { this->Banner = std::move(Banner); }

  /// Set the exit-code mapper function.
  void setExitCodeMapper(std::function<int(const Error &)> GetExitCode) {
    this->GetExitCode = std::move(GetExitCode);
  }

  /// Check Err. If it's in a failure state log the error(s) and exit.
  void operator()(Error Err) const { checkError(std::move(Err)); }

  /// Check E. If it's in a success state then return the contained value. If
  /// it's in a failure state log the error(s) and exit.
  template <typename T> T operator()(Expected<T> &&E) const {
    checkError(E.takeError());
    return std::move(*E);
  }

  /// Check E. If it's in a success state then return the contained reference. If
  /// it's in a failure state log the error(s) and exit.
  template <typename T> T& operator()(Expected<T&> &&E) const {
    checkError(E.takeError());
    return *E;
  }

private:
  void checkError(Error Err) const {
    if (Err) {
      int ExitCode = GetExitCode(Err);
      logAllUnhandledErrors(std::move(Err), errs(), Banner);
      exit(ExitCode);
    }
  }

  std::string Banner;
  std::function<int(const Error &)> GetExitCode;
};

/// Conversion from Error to LLVMErrorRef for C error bindings.
inline LLVMErrorRef wrap(Error Err) {
  return reinterpret_cast<LLVMErrorRef>(Err.takePayload().release());
}

/// Conversion from LLVMErrorRef to Error for C error bindings.
inline Error unwrap(LLVMErrorRef ErrRef) {
  return Error(std::unique_ptr<ErrorInfoBase>(
      reinterpret_cast<ErrorInfoBase *>(ErrRef)));
}

} // end namespace llvm

#endif // LLVM_SUPPORT_ERROR_H
# 1359 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Error.h"
# 29 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 30 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 31 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 32 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include <list>
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 1 3
// -*- C++ -*-
//===---------------------------- list ------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_LIST
#define _LIBCPP_LIST

/*
    list synopsis

namespace std
{

template <class T, class Alloc = allocator<T> >
class list
{
public:

    // types:
    typedef T value_type;
    typedef Alloc allocator_type;
    typedef typename allocator_type::reference reference;
    typedef typename allocator_type::const_reference const_reference;
    typedef typename allocator_type::pointer pointer;
    typedef typename allocator_type::const_pointer const_pointer;
    typedef implementation-defined iterator;
    typedef implementation-defined const_iterator;
    typedef implementation-defined size_type;
    typedef implementation-defined difference_type;
    typedef reverse_iterator<iterator> reverse_iterator;
    typedef reverse_iterator<const_iterator> const_reverse_iterator;

    list()
        noexcept(is_nothrow_default_constructible<allocator_type>::value);
    explicit list(const allocator_type& a);
    explicit list(size_type n);
    explicit list(size_type n, const allocator_type& a); // C++14
    list(size_type n, const value_type& value);
    list(size_type n, const value_type& value, const allocator_type& a);
    template <class Iter>
        list(Iter first, Iter last);
    template <class Iter>
        list(Iter first, Iter last, const allocator_type& a);
    list(const list& x);
    list(const list&, const allocator_type& a);
    list(list&& x)
        noexcept(is_nothrow_move_constructible<allocator_type>::value);
    list(list&&, const allocator_type& a);
    list(initializer_list<value_type>);
    list(initializer_list<value_type>, const allocator_type& a);

    ~list();

    list& operator=(const list& x);
    list& operator=(list&& x)
        noexcept(
             allocator_type::propagate_on_container_move_assignment::value &&
             is_nothrow_move_assignable<allocator_type>::value);
    list& operator=(initializer_list<value_type>);
    template <class Iter>
        void assign(Iter first, Iter last);
    void assign(size_type n, const value_type& t);
    void assign(initializer_list<value_type>);

    allocator_type get_allocator() const noexcept;

    iterator begin() noexcept;
    const_iterator begin() const noexcept;
    iterator end() noexcept;
    const_iterator end() const noexcept;
    reverse_iterator rbegin() noexcept;
    const_reverse_iterator rbegin() const noexcept;
    reverse_iterator rend() noexcept;
    const_reverse_iterator rend() const noexcept;
    const_iterator cbegin() const noexcept;
    const_iterator cend() const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend() const noexcept;

    reference front();
    const_reference front() const;
    reference back();
    const_reference back() const;

    bool empty() const noexcept;
    size_type size() const noexcept;
    size_type max_size() const noexcept;

    template <class... Args>
        reference emplace_front(Args&&... args); // reference in C++17
    void pop_front();
    template <class... Args>
        reference emplace_back(Args&&... args);  // reference in C++17
    void pop_back();
    void push_front(const value_type& x);
    void push_front(value_type&& x);
    void push_back(const value_type& x);
    void push_back(value_type&& x);
    template <class... Args>
        iterator emplace(const_iterator position, Args&&... args);
    iterator insert(const_iterator position, const value_type& x);
    iterator insert(const_iterator position, value_type&& x);
    iterator insert(const_iterator position, size_type n, const value_type& x);
    template <class Iter>
        iterator insert(const_iterator position, Iter first, Iter last);
    iterator insert(const_iterator position, initializer_list<value_type> il);

    iterator erase(const_iterator position);
    iterator erase(const_iterator position, const_iterator last);

    void resize(size_type sz);
    void resize(size_type sz, const value_type& c);

    void swap(list&)
        noexcept(allocator_traits<allocator_type>::is_always_equal::value);  // C++17
    void clear() noexcept;

    void splice(const_iterator position, list& x);
    void splice(const_iterator position, list&& x);
    void splice(const_iterator position, list& x, const_iterator i);
    void splice(const_iterator position, list&& x, const_iterator i);
    void splice(const_iterator position, list& x, const_iterator first,
                                                  const_iterator last);
    void splice(const_iterator position, list&& x, const_iterator first,
                                                  const_iterator last);

    size_type remove(const value_type& value);       // void before C++20
    template <class Pred>
      size_type remove_if(Pred pred);                // void before C++20
    size_type unique();                              // void before C++20
    template <class BinaryPredicate>
      size_type unique(BinaryPredicate binary_pred); // void before C++20
    void merge(list& x);
    void merge(list&& x);
    template <class Compare>
        void merge(list& x, Compare comp);
    template <class Compare>
        void merge(list&& x, Compare comp);
    void sort();
    template <class Compare>
        void sort(Compare comp);
    void reverse() noexcept;
};


template <class InputIterator, class Allocator = allocator<typename iterator_traits<InputIterator>::value_type>>
    list(InputIterator, InputIterator, Allocator = Allocator())
    -> list<typename iterator_traits<InputIterator>::value_type, Allocator>;  // C++17

template <class T, class Alloc>
    bool operator==(const list<T,Alloc>& x, const list<T,Alloc>& y);
template <class T, class Alloc>
    bool operator< (const list<T,Alloc>& x, const list<T,Alloc>& y);
template <class T, class Alloc>
    bool operator!=(const list<T,Alloc>& x, const list<T,Alloc>& y);
template <class T, class Alloc>
    bool operator> (const list<T,Alloc>& x, const list<T,Alloc>& y);
template <class T, class Alloc>
    bool operator>=(const list<T,Alloc>& x, const list<T,Alloc>& y);
template <class T, class Alloc>
    bool operator<=(const list<T,Alloc>& x, const list<T,Alloc>& y);

template <class T, class Alloc>
    void swap(list<T,Alloc>& x, list<T,Alloc>& y)
         noexcept(noexcept(x.swap(y)));

template <class T, class Allocator, class U>
    void erase(list<T, Allocator>& c, const U& value);       // C++20
template <class T, class Allocator, class Predicate>
    void erase_if(list<T, Allocator>& c, Predicate pred);    // C++20

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 181 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 182 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 183 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 184 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 184 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 185 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 185 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 186 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 186 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 187 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 187 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 188 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 188 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 189 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 189 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 190 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 191 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 192 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 194 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 195 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
#endif
# 196 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 198 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 199 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Tp, class _VoidPtr> struct __list_node;
template <class _Tp, class _VoidPtr> struct __list_node_base;

template <class _Tp, class _VoidPtr>
struct __list_node_pointer_traits {
  typedef typename __rebind_pointer<_VoidPtr, __list_node<_Tp, _VoidPtr> >::type
        __node_pointer;
  typedef typename __rebind_pointer<_VoidPtr, __list_node_base<_Tp, _VoidPtr> >::type
        __base_pointer;

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_LIST_REMOVE_NODE_POINTER_UB)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 214 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
  typedef __base_pointer __link_pointer;
#else
# 216 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
  typedef typename conditional<
          is_pointer<_VoidPtr>::value,
          __base_pointer,
          __node_pointer
  >::type __link_pointer;
#endif
# 222 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

  typedef typename conditional<
          is_same<__link_pointer, __node_pointer>::value,
          __base_pointer,
          __node_pointer
  >::type __non_link_pointer;

  static _LIBCPP_INLINE_VISIBILITY
  __link_pointer __unsafe_link_pointer_cast(__link_pointer __p) {
      return __p;
  }

  static _LIBCPP_INLINE_VISIBILITY
  __link_pointer __unsafe_link_pointer_cast(__non_link_pointer __p) {
      return static_cast<__link_pointer>(static_cast<_VoidPtr>(__p));
  }

};

template <class _Tp, class _VoidPtr>
struct __list_node_base
{
    typedef __list_node_pointer_traits<_Tp, _VoidPtr> _NodeTraits;
    typedef typename _NodeTraits::__node_pointer __node_pointer;
    typedef typename _NodeTraits::__base_pointer __base_pointer;
    typedef typename _NodeTraits::__link_pointer __link_pointer;

    __link_pointer __prev_;
    __link_pointer __next_;

    _LIBCPP_INLINE_VISIBILITY
    __list_node_base() : __prev_(_NodeTraits::__unsafe_link_pointer_cast(__self())),
                         __next_(_NodeTraits::__unsafe_link_pointer_cast(__self())) {}

    _LIBCPP_INLINE_VISIBILITY
    __base_pointer __self() {
        return pointer_traits<__base_pointer>::pointer_to(*this);
    }

    _LIBCPP_INLINE_VISIBILITY
    __node_pointer __as_node() {
        return static_cast<__node_pointer>(__self());
    }
};

template <class _Tp, class _VoidPtr>
struct __list_node
    : public __list_node_base<_Tp, _VoidPtr>
{
    _Tp __value_;

    typedef __list_node_base<_Tp, _VoidPtr> __base;
    typedef typename __base::__link_pointer __link_pointer;

    _LIBCPP_INLINE_VISIBILITY
    __link_pointer __as_link() {
        return static_cast<__link_pointer>(__base::__self());
    }
};

template <class _Tp, class _Alloc = allocator<_Tp> > class _LIBCPP_TEMPLATE_VIS list;
template <class _Tp, class _Alloc> class __list_imp;
template <class _Tp, class _VoidPtr> class _LIBCPP_TEMPLATE_VIS __list_const_iterator;

template <class _Tp, class _VoidPtr>
class _LIBCPP_TEMPLATE_VIS __list_iterator
{
    typedef __list_node_pointer_traits<_Tp, _VoidPtr> _NodeTraits;
    typedef typename _NodeTraits::__link_pointer __link_pointer;

    __link_pointer __ptr_;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_INLINE_VISIBILITY
    explicit __list_iterator(__link_pointer __p, const void* __c) _NOEXCEPT
        : __ptr_(__p)
    {
        __get_db()->__insert_ic(this, __c);
    }
#else
# 302 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_INLINE_VISIBILITY
    explicit __list_iterator(__link_pointer __p) _NOEXCEPT : __ptr_(__p) {}
#endif
# 305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3



    template<class, class> friend class list;
    template<class, class> friend class __list_imp;
    template<class, class> friend class __list_const_iterator;
public:
    typedef bidirectional_iterator_tag       iterator_category;
    typedef _Tp                              value_type;
    typedef value_type&                      reference;
    typedef typename __rebind_pointer<_VoidPtr, value_type>::type pointer;
    typedef typename pointer_traits<pointer>::difference_type difference_type;

    _LIBCPP_INLINE_VISIBILITY
    __list_iterator() _NOEXCEPT : __ptr_(nullptr)
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 322 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __get_db()->__insert_i(this);
#endif
# 324 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 327 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    _LIBCPP_INLINE_VISIBILITY
    __list_iterator(const __list_iterator& __p)
        : __ptr_(__p.__ptr_)
    {
        __get_db()->__iterator_copy(this, &__p);
    }

    _LIBCPP_INLINE_VISIBILITY
    ~__list_iterator()
    {
        __get_db()->__erase_i(this);
    }

    _LIBCPP_INLINE_VISIBILITY
    __list_iterator& operator=(const __list_iterator& __p)
    {
        if (this != &__p)
        {
            __get_db()->__iterator_copy(this, &__p);
            __ptr_ = __p.__ptr_;
        }
        return *this;
    }

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 353 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    _LIBCPP_INLINE_VISIBILITY
    reference operator*() const
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 358 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to dereference a non-dereferenceable list::iterator");
#endif
# 361 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return __ptr_->__as_node()->__value_;
    }
    _LIBCPP_INLINE_VISIBILITY
    pointer operator->() const
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 367 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to dereference a non-dereferenceable list::iterator");
#endif
# 370 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return pointer_traits<pointer>::pointer_to(__ptr_->__as_node()->__value_);
    }

    _LIBCPP_INLINE_VISIBILITY
    __list_iterator& operator++()
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 377 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to increment non-incrementable list::iterator");
#endif
# 380 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __ptr_ = __ptr_->__next_;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY
    __list_iterator operator++(int) {__list_iterator __t(*this); ++(*this); return __t;}

    _LIBCPP_INLINE_VISIBILITY
    __list_iterator& operator--()
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 390 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _LIBCPP_ASSERT(__get_const_db()->__decrementable(this),
                       "Attempted to decrement non-decrementable list::iterator");
#endif
# 393 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __ptr_ = __ptr_->__prev_;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY
    __list_iterator operator--(int) {__list_iterator __t(*this); --(*this); return __t;}

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator==(const __list_iterator& __x, const __list_iterator& __y)
    {
        return __x.__ptr_ == __y.__ptr_;
    }
    friend _LIBCPP_INLINE_VISIBILITY
     bool operator!=(const __list_iterator& __x, const __list_iterator& __y)
        {return !(__x == __y);}
};

template <class _Tp, class _VoidPtr>
class _LIBCPP_TEMPLATE_VIS __list_const_iterator
{
    typedef __list_node_pointer_traits<_Tp, _VoidPtr> _NodeTraits;
    typedef typename _NodeTraits::__link_pointer __link_pointer;

    __link_pointer __ptr_;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 418 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_INLINE_VISIBILITY
    explicit __list_const_iterator(__link_pointer __p, const void* __c) _NOEXCEPT
        : __ptr_(__p)
    {
        __get_db()->__insert_ic(this, __c);
    }
#else
# 425 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_INLINE_VISIBILITY
    explicit __list_const_iterator(__link_pointer __p) _NOEXCEPT : __ptr_(__p) {}
#endif
# 428 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    template<class, class> friend class list;
    template<class, class> friend class __list_imp;
public:
    typedef bidirectional_iterator_tag       iterator_category;
    typedef _Tp                              value_type;
    typedef const value_type&                reference;
    typedef typename __rebind_pointer<_VoidPtr, const value_type>::type pointer;
    typedef typename pointer_traits<pointer>::difference_type difference_type;

    _LIBCPP_INLINE_VISIBILITY
    __list_const_iterator() _NOEXCEPT : __ptr_(nullptr)
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 442 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __get_db()->__insert_i(this);
#endif
# 444 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
    _LIBCPP_INLINE_VISIBILITY
    __list_const_iterator(const __list_iterator<_Tp, _VoidPtr>& __p) _NOEXCEPT
        : __ptr_(__p.__ptr_)
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 450 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __get_db()->__iterator_copy(this, &__p);
#endif
# 452 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 455 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    _LIBCPP_INLINE_VISIBILITY
    __list_const_iterator(const __list_const_iterator& __p)
        : __ptr_(__p.__ptr_)
    {
        __get_db()->__iterator_copy(this, &__p);
    }

    _LIBCPP_INLINE_VISIBILITY
    ~__list_const_iterator()
    {
        __get_db()->__erase_i(this);
    }

    _LIBCPP_INLINE_VISIBILITY
    __list_const_iterator& operator=(const __list_const_iterator& __p)
    {
        if (this != &__p)
        {
            __get_db()->__iterator_copy(this, &__p);
            __ptr_ = __p.__ptr_;
        }
        return *this;
    }

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 481 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_INLINE_VISIBILITY
    reference operator*() const
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 485 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to dereference a non-dereferenceable list::const_iterator");
#endif
# 488 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return __ptr_->__as_node()->__value_;
    }
    _LIBCPP_INLINE_VISIBILITY
    pointer operator->() const
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 494 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to dereference a non-dereferenceable list::const_iterator");
#endif
# 497 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return pointer_traits<pointer>::pointer_to(__ptr_->__as_node()->__value_);
    }

    _LIBCPP_INLINE_VISIBILITY
    __list_const_iterator& operator++()
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 504 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to increment non-incrementable list::const_iterator");
#endif
# 507 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __ptr_ = __ptr_->__next_;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY
    __list_const_iterator operator++(int) {__list_const_iterator __t(*this); ++(*this); return __t;}

    _LIBCPP_INLINE_VISIBILITY
    __list_const_iterator& operator--()
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 517 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _LIBCPP_ASSERT(__get_const_db()->__decrementable(this),
                       "Attempted to decrement non-decrementable list::const_iterator");
#endif
# 520 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __ptr_ = __ptr_->__prev_;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY
    __list_const_iterator operator--(int) {__list_const_iterator __t(*this); --(*this); return __t;}

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator==(const __list_const_iterator& __x, const __list_const_iterator& __y)
    {
        return __x.__ptr_ == __y.__ptr_;
    }
    friend _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const __list_const_iterator& __x, const __list_const_iterator& __y)
        {return !(__x == __y);}
};

template <class _Tp, class _Alloc>
class __list_imp
{
    __list_imp(const __list_imp&);
    __list_imp& operator=(const __list_imp&);
public:
    typedef _Alloc                                                  allocator_type;
    typedef allocator_traits<allocator_type>                        __alloc_traits;
    typedef typename __alloc_traits::size_type                      size_type;
protected:
    typedef _Tp                                                     value_type;
    typedef typename __alloc_traits::void_pointer                   __void_pointer;
    typedef __list_iterator<value_type, __void_pointer>             iterator;
    typedef __list_const_iterator<value_type, __void_pointer>       const_iterator;
    typedef __list_node_base<value_type, __void_pointer>            __node_base;
    typedef __list_node<value_type, __void_pointer>                 __node;
    typedef typename __rebind_alloc_helper<__alloc_traits, __node>::type __node_allocator;
    typedef allocator_traits<__node_allocator>                       __node_alloc_traits;
    typedef typename __node_alloc_traits::pointer                    __node_pointer;
    typedef typename __node_alloc_traits::pointer                    __node_const_pointer;
    typedef __list_node_pointer_traits<value_type, __void_pointer> __node_pointer_traits;
    typedef typename __node_pointer_traits::__link_pointer __link_pointer;
    typedef __link_pointer __link_const_pointer;
    typedef typename __alloc_traits::pointer                         pointer;
    typedef typename __alloc_traits::const_pointer                   const_pointer;
    typedef typename __alloc_traits::difference_type                 difference_type;

    typedef typename __rebind_alloc_helper<__alloc_traits, __node_base>::type __node_base_allocator;
    typedef typename allocator_traits<__node_base_allocator>::pointer __node_base_pointer;
    static_assert((!is_same<allocator_type, __node_allocator>::value),
                  "internal allocator type must differ from user-specified "
                  "type; otherwise overload resolution breaks");

    __node_base __end_;
    __compressed_pair<size_type, __node_allocator> __size_alloc_;

    _LIBCPP_INLINE_VISIBILITY
    __link_pointer __end_as_link() const _NOEXCEPT {
        return __node_pointer_traits::__unsafe_link_pointer_cast(
                const_cast<__node_base&>(__end_).__self());
    }

    _LIBCPP_INLINE_VISIBILITY
          size_type& __sz() _NOEXCEPT {return __size_alloc_.first();}
    _LIBCPP_INLINE_VISIBILITY
    const size_type& __sz() const _NOEXCEPT
        {return __size_alloc_.first();}
    _LIBCPP_INLINE_VISIBILITY
          __node_allocator& __node_alloc() _NOEXCEPT
          {return __size_alloc_.second();}
    _LIBCPP_INLINE_VISIBILITY
    const __node_allocator& __node_alloc() const _NOEXCEPT
        {return __size_alloc_.second();}

    _LIBCPP_INLINE_VISIBILITY
    size_type __node_alloc_max_size() const _NOEXCEPT {
        return __node_alloc_traits::max_size(__node_alloc());
    }
    _LIBCPP_INLINE_VISIBILITY
    static void __unlink_nodes(__link_pointer __f, __link_pointer __l) _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    __list_imp()
        _NOEXCEPT_(is_nothrow_default_constructible<__node_allocator>::value);
    _LIBCPP_INLINE_VISIBILITY
    __list_imp(const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    __list_imp(const __node_allocator& __a);
#ifndef _LIBCPP_CXX03_LANG
    __list_imp(__node_allocator&& __a) _NOEXCEPT;
#endif
# 607 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    ~__list_imp();
    void clear() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    bool empty() const _NOEXCEPT {return __sz() == 0;}

    _LIBCPP_INLINE_VISIBILITY
    iterator begin() _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 616 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return iterator(__end_.__next_, this);
#else
# 618 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return iterator(__end_.__next_);
#endif
# 620 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const  _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 625 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return const_iterator(__end_.__next_, this);
#else
# 627 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return const_iterator(__end_.__next_);
#endif
# 629 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
    _LIBCPP_INLINE_VISIBILITY
    iterator end() _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 634 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return iterator(__end_as_link(), this);
#else
# 636 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return iterator(__end_as_link());
#endif
# 638 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 643 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return const_iterator(__end_as_link(), this);
#else
# 645 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        return const_iterator(__end_as_link());
#endif
# 647 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }

    void swap(__list_imp& __c)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 651 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _NOEXCEPT;
#else
# 653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value);
#endif
# 656 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __list_imp& __c)
        {__copy_assign_alloc(__c, integral_constant<bool,
                      __node_alloc_traits::propagate_on_container_copy_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__list_imp& __c)
        _NOEXCEPT_(
            !__node_alloc_traits::propagate_on_container_move_assignment::value ||
            is_nothrow_move_assignable<__node_allocator>::value)
        {__move_assign_alloc(__c, integral_constant<bool,
                      __node_alloc_traits::propagate_on_container_move_assignment::value>());}

private:
    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __list_imp& __c, true_type)
        {
            if (__node_alloc() != __c.__node_alloc())
                clear();
            __node_alloc() = __c.__node_alloc();
        }

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __list_imp&, false_type)
        {}

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__list_imp& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<__node_allocator>::value)
        {
            __node_alloc() = _VSTD::move(__c.__node_alloc());
        }

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__list_imp&, false_type)
        _NOEXCEPT
        {}

    _LIBCPP_INLINE_VISIBILITY
    void __invalidate_all_iterators() {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 698 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
      __get_db()->__invalidate_all(this);
#endif
# 700 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
};

// Unlink nodes [__f, __l]
template <class _Tp, class _Alloc>
inline
void
__list_imp<_Tp, _Alloc>::__unlink_nodes(__link_pointer __f, __link_pointer __l)
    _NOEXCEPT
{
    __f->__prev_->__next_ = __l->__next_;
    __l->__next_->__prev_ = __f->__prev_;
}

template <class _Tp, class _Alloc>
inline
__list_imp<_Tp, _Alloc>::__list_imp()
        _NOEXCEPT_(is_nothrow_default_constructible<__node_allocator>::value)
    : __size_alloc_(0, __default_init_tag())
{
}

template <class _Tp, class _Alloc>
inline
__list_imp<_Tp, _Alloc>::__list_imp(const allocator_type& __a)
    : __size_alloc_(0, __node_allocator(__a))
{
}

template <class _Tp, class _Alloc>
inline __list_imp<_Tp, _Alloc>::__list_imp(const __node_allocator& __a)
    : __size_alloc_(0, __a) {}

#ifndef _LIBCPP_CXX03_LANG
template <class _Tp, class _Alloc>
inline __list_imp<_Tp, _Alloc>::__list_imp(__node_allocator&& __a) _NOEXCEPT
    : __size_alloc_(0, std::move(__a)) {}
#endif
# 738 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

template <class _Tp, class _Alloc>
__list_imp<_Tp, _Alloc>::~__list_imp() {
  clear();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 743 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__erase_c(this);
#endif
# 745 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
void
__list_imp<_Tp, _Alloc>::clear() _NOEXCEPT
{
    if (!empty())
    {
        __node_allocator& __na = __node_alloc();
        __link_pointer __f = __end_.__next_;
        __link_pointer __l = __end_as_link();
        __unlink_nodes(__f, __l->__prev_);
        __sz() = 0;
        while (__f != __l)
        {
            __node_pointer __np = __f->__as_node();
            __f = __f->__next_;
            __node_alloc_traits::destroy(__na, _VSTD::addressof(__np->__value_));
            __node_alloc_traits::deallocate(__na, __np, 1);
        }
        __invalidate_all_iterators();
    }
}

template <class _Tp, class _Alloc>
void
__list_imp<_Tp, _Alloc>::swap(__list_imp& __c)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 773 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _NOEXCEPT
#else
# 775 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value)
#endif
# 778 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
{
    _LIBCPP_ASSERT(__alloc_traits::propagate_on_container_swap::value ||
                   this->__node_alloc() == __c.__node_alloc(),
                   "list::swap: Either propagate_on_container_swap must be true"
                   " or the allocators must compare equal");
    using _VSTD::swap;
    __swap_allocator(__node_alloc(), __c.__node_alloc());
    swap(__sz(), __c.__sz());
    swap(__end_, __c.__end_);
    if (__sz() == 0)
        __end_.__next_ = __end_.__prev_ = __end_as_link();
    else
        __end_.__prev_->__next_ = __end_.__next_->__prev_ = __end_as_link();
    if (__c.__sz() == 0)
        __c.__end_.__next_ = __c.__end_.__prev_ = __c.__end_as_link();
    else
        __c.__end_.__prev_->__next_ = __c.__end_.__next_->__prev_ = __c.__end_as_link();

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 797 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __libcpp_db* __db = __get_db();
    __c_node* __cn1 = __db->__find_c_and_lock(this);
    __c_node* __cn2 = __db->__find_c(&__c);
    std::swap(__cn1->beg_, __cn2->beg_);
    std::swap(__cn1->end_, __cn2->end_);
    std::swap(__cn1->cap_, __cn2->cap_);
    for (__i_node** __p = __cn1->end_; __p != __cn1->beg_;)
    {
        --__p;
        const_iterator* __i = static_cast<const_iterator*>((*__p)->__i_);
        if (__i->__ptr_ == __c.__end_as_link())
        {
            __cn2->__add(*__p);
            if (--__cn1->end_ != __p)
                memmove(__p, __p+1, (__cn1->end_ - __p)*sizeof(__i_node*));
        }
        else
            (*__p)->__c_ = __cn1;
    }
    for (__i_node** __p = __cn2->end_; __p != __cn2->beg_;)
    {
        --__p;
        const_iterator* __i = static_cast<const_iterator*>((*__p)->__i_);
        if (__i->__ptr_ == __end_as_link())
        {
            __cn1->__add(*__p);
            if (--__cn2->end_ != __p)
                memmove(__p, __p+1, (__cn2->end_ - __p)*sizeof(__i_node*));
        }
        else
            (*__p)->__c_ = __cn2;
    }
    __db->unlock();
#endif
# 831 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc /*= allocator<_Tp>*/>
class _LIBCPP_TEMPLATE_VIS list
    : private __list_imp<_Tp, _Alloc>
{
    typedef __list_imp<_Tp, _Alloc> base;
    typedef typename base::__node              __node;
    typedef typename base::__node_allocator    __node_allocator;
    typedef typename base::__node_pointer      __node_pointer;
    typedef typename base::__node_alloc_traits __node_alloc_traits;
    typedef typename base::__node_base         __node_base;
    typedef typename base::__node_base_pointer __node_base_pointer;
    typedef typename base::__link_pointer __link_pointer;

public:
    typedef _Tp                                      value_type;
    typedef _Alloc                                   allocator_type;
    static_assert((is_same<value_type, typename allocator_type::value_type>::value),
                  "Invalid allocator::value_type");
    typedef value_type&                              reference;
    typedef const value_type&                        const_reference;
    typedef typename base::pointer                   pointer;
    typedef typename base::const_pointer             const_pointer;
    typedef typename base::size_type                 size_type;
    typedef typename base::difference_type           difference_type;
    typedef typename base::iterator                  iterator;
    typedef typename base::const_iterator            const_iterator;
    typedef _VSTD::reverse_iterator<iterator>         reverse_iterator;
    typedef _VSTD::reverse_iterator<const_iterator>   const_reverse_iterator;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 862 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    typedef size_type                                __remove_return_type;
#else
# 864 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    typedef void                                     __remove_return_type;
#endif
# 866 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    _LIBCPP_INLINE_VISIBILITY
    list()
        _NOEXCEPT_(is_nothrow_default_constructible<__node_allocator>::value)
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 872 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __get_db()->__insert_c(this);
#endif
# 874 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
    _LIBCPP_INLINE_VISIBILITY
    explicit list(const allocator_type& __a) : base(__a)
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 879 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __get_db()->__insert_c(this);
#endif
# 881 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
    explicit list(size_type __n);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 884 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    explicit list(size_type __n, const allocator_type& __a);
#endif
# 886 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    list(size_type __n, const value_type& __x);
    list(size_type __n, const value_type& __x, const allocator_type& __a);
    template <class _InpIter>
        list(_InpIter __f, _InpIter __l,
             typename enable_if<__is_cpp17_input_iterator<_InpIter>::value>::type* = 0);
    template <class _InpIter>
        list(_InpIter __f, _InpIter __l, const allocator_type& __a,
             typename enable_if<__is_cpp17_input_iterator<_InpIter>::value>::type* = 0);

    list(const list& __c);
    list(const list& __c, const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    list& operator=(const list& __c);
#ifndef _LIBCPP_CXX03_LANG
    list(initializer_list<value_type> __il);
    list(initializer_list<value_type> __il, const allocator_type& __a);

    _LIBCPP_INLINE_VISIBILITY
    list(list&& __c)
        _NOEXCEPT_(is_nothrow_move_constructible<__node_allocator>::value);
    _LIBCPP_INLINE_VISIBILITY
    list(list&& __c, const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    list& operator=(list&& __c)
        _NOEXCEPT_(
            __node_alloc_traits::propagate_on_container_move_assignment::value &&
            is_nothrow_move_assignable<__node_allocator>::value);

    _LIBCPP_INLINE_VISIBILITY
    list& operator=(initializer_list<value_type> __il)
        {assign(__il.begin(), __il.end()); return *this;}

    _LIBCPP_INLINE_VISIBILITY
    void assign(initializer_list<value_type> __il)
        {assign(__il.begin(), __il.end());}
#endif  // _LIBCPP_CXX03_LANG
# 922 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    template <class _InpIter>
        void assign(_InpIter __f, _InpIter __l,
             typename enable_if<__is_cpp17_input_iterator<_InpIter>::value>::type* = 0);
    void assign(size_type __n, const value_type& __x);

    _LIBCPP_INLINE_VISIBILITY
    allocator_type get_allocator() const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type size() const _NOEXCEPT     {return base::__sz();}
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool empty() const _NOEXCEPT         {return base::empty();}
    _LIBCPP_INLINE_VISIBILITY
    size_type max_size() const _NOEXCEPT
        {
            return std::min<size_type>(
                base::__node_alloc_max_size(),
                numeric_limits<difference_type >::max());
        }

    _LIBCPP_INLINE_VISIBILITY
          iterator begin() _NOEXCEPT        {return base::begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin()  const _NOEXCEPT {return base::begin();}
    _LIBCPP_INLINE_VISIBILITY
          iterator end() _NOEXCEPT          {return base::end();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end()    const _NOEXCEPT {return base::end();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator cbegin() const _NOEXCEPT {return base::begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator cend()   const _NOEXCEPT {return base::end();}

    _LIBCPP_INLINE_VISIBILITY
          reverse_iterator rbegin() _NOEXCEPT
            {return       reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin()  const _NOEXCEPT
        {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
          reverse_iterator rend() _NOEXCEPT
            {return       reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend()    const _NOEXCEPT
        {return const_reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT
        {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend()   const _NOEXCEPT
        {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY
    reference front()
    {
        _LIBCPP_ASSERT(!empty(), "list::front called on empty list");
        return base::__end_.__next_->__as_node()->__value_;
    }
    _LIBCPP_INLINE_VISIBILITY
    const_reference front() const
    {
        _LIBCPP_ASSERT(!empty(), "list::front called on empty list");
        return base::__end_.__next_->__as_node()->__value_;
    }
    _LIBCPP_INLINE_VISIBILITY
    reference back()
    {
        _LIBCPP_ASSERT(!empty(), "list::back called on empty list");
        return base::__end_.__prev_->__as_node()->__value_;
    }
    _LIBCPP_INLINE_VISIBILITY
    const_reference back() const
    {
        _LIBCPP_ASSERT(!empty(), "list::back called on empty list");
        return base::__end_.__prev_->__as_node()->__value_;
    }

#ifndef _LIBCPP_CXX03_LANG
    void push_front(value_type&& __x);
    void push_back(value_type&& __x);

    template <class... _Args>
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1006 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
       reference emplace_front(_Args&&... __args);
#else
# 1008 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
       void      emplace_front(_Args&&... __args);
#endif
# 1010 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    template <class... _Args>
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1012 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        reference emplace_back(_Args&&... __args);
#else
# 1014 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
       void       emplace_back(_Args&&... __args);
#endif
# 1016 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    template <class... _Args>
        iterator emplace(const_iterator __p, _Args&&... __args);

    iterator insert(const_iterator __p, value_type&& __x);

    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __p, initializer_list<value_type> __il)
        {return insert(__p, __il.begin(), __il.end());}
#endif  // _LIBCPP_CXX03_LANG
# 1025 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    void push_front(const value_type& __x);
    void push_back(const value_type& __x);

#ifndef _LIBCPP_CXX03_LANG
    template <class _Arg>
    _LIBCPP_INLINE_VISIBILITY
    void __emplace_back(_Arg&& __arg) { emplace_back(_VSTD::forward<_Arg>(__arg)); }
#else
# 1034 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_INLINE_VISIBILITY
    void __emplace_back(value_type const& __arg) { push_back(__arg); }
#endif
# 1037 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    iterator insert(const_iterator __p, const value_type& __x);
    iterator insert(const_iterator __p, size_type __n, const value_type& __x);
    template <class _InpIter>
        iterator insert(const_iterator __p, _InpIter __f, _InpIter __l,
             typename enable_if<__is_cpp17_input_iterator<_InpIter>::value>::type* = 0);

    _LIBCPP_INLINE_VISIBILITY
    void swap(list& __c)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1047 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _NOEXCEPT
#else
# 1049 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        _NOEXCEPT_(!__node_alloc_traits::propagate_on_container_swap::value ||
                   __is_nothrow_swappable<__node_allocator>::value)
#endif
# 1052 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        {base::swap(__c);}
    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT {base::clear();}

    void pop_front();
    void pop_back();

    iterator erase(const_iterator __p);
    iterator erase(const_iterator __f, const_iterator __l);

    void resize(size_type __n);
    void resize(size_type __n, const value_type& __x);

    void splice(const_iterator __p, list& __c);
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    void splice(const_iterator __p, list&& __c) {splice(__p, __c);}
    _LIBCPP_INLINE_VISIBILITY
    void splice(const_iterator __p, list&& __c, const_iterator __i)
        {splice(__p, __c, __i);}
    _LIBCPP_INLINE_VISIBILITY
    void splice(const_iterator __p, list&& __c, const_iterator __f, const_iterator __l)
        {splice(__p, __c, __f, __l);}
#endif
# 1076 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    void splice(const_iterator __p, list& __c, const_iterator __i);
    void splice(const_iterator __p, list& __c, const_iterator __f, const_iterator __l);

    __remove_return_type remove(const value_type& __x);
    template <class _Pred> __remove_return_type remove_if(_Pred __pred);
    _LIBCPP_INLINE_VISIBILITY
    __remove_return_type unique() { return unique(__equal_to<value_type>()); }
    template <class _BinaryPred>
        __remove_return_type unique(_BinaryPred __binary_pred);
    _LIBCPP_INLINE_VISIBILITY
    void merge(list& __c);
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    void merge(list&& __c) {merge(__c);}

    template <class _Comp>
    _LIBCPP_INLINE_VISIBILITY
        void merge(list&& __c, _Comp __comp) {merge(__c, __comp);}
#endif
# 1095 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    template <class _Comp>
        void merge(list& __c, _Comp __comp);

    _LIBCPP_INLINE_VISIBILITY
    void sort();
    template <class _Comp>
        _LIBCPP_INLINE_VISIBILITY
        void sort(_Comp __comp);

    void reverse() _NOEXCEPT;

    bool __invariants() const;

    typedef __allocator_destructor<__node_allocator> __node_destructor;
    typedef unique_ptr<__node, __node_destructor> __hold_pointer;

    _LIBCPP_INLINE_VISIBILITY
    __hold_pointer __allocate_node(__node_allocator& __na) {
      __node_pointer __p = __node_alloc_traits::allocate(__na, 1);
      __p->__prev_ = nullptr;
      return __hold_pointer(__p, __node_destructor(__na, 1));
    }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1119 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

    bool __dereferenceable(const const_iterator* __i) const;
    bool __decrementable(const const_iterator* __i) const;
    bool __addable(const const_iterator* __i, ptrdiff_t __n) const;
    bool __subscriptable(const const_iterator* __i, ptrdiff_t __n) const;

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 1126 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

private:
    _LIBCPP_INLINE_VISIBILITY
    static void __link_nodes  (__link_pointer __p, __link_pointer __f, __link_pointer __l);
    _LIBCPP_INLINE_VISIBILITY
    void __link_nodes_at_front(__link_pointer __f, __link_pointer __l);
    _LIBCPP_INLINE_VISIBILITY
    void __link_nodes_at_back (__link_pointer __f, __link_pointer __l);
    iterator __iterator(size_type __n);
    template <class _Comp>
        static iterator __sort(iterator __f1, iterator __e2, size_type __n, _Comp& __comp);

    void __move_assign(list& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<__node_allocator>::value);
    void __move_assign(list& __c, false_type);
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _InputIterator,
         class _Alloc = typename std::allocator<typename iterator_traits<_InputIterator>::value_type>,
         class = typename enable_if<__is_allocator<_Alloc>::value, void>::type
         >
list(_InputIterator, _InputIterator)
  -> list<typename iterator_traits<_InputIterator>::value_type, _Alloc>;

template<class _InputIterator,
         class _Alloc,
         class = typename enable_if<__is_allocator<_Alloc>::value, void>::type
         >
list(_InputIterator, _InputIterator, _Alloc)
  -> list<typename iterator_traits<_InputIterator>::value_type, _Alloc>;
#endif
# 1158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

// Link in nodes [__f, __l] just prior to __p
template <class _Tp, class _Alloc>
inline
void
list<_Tp, _Alloc>::__link_nodes(__link_pointer __p, __link_pointer __f, __link_pointer __l)
{
    __p->__prev_->__next_ = __f;
    __f->__prev_ = __p->__prev_;
    __p->__prev_ = __l;
    __l->__next_ = __p;
}

// Link in nodes [__f, __l] at the front of the list
template <class _Tp, class _Alloc>
inline
void
list<_Tp, _Alloc>::__link_nodes_at_front(__link_pointer __f, __link_pointer __l)
{
    __f->__prev_ = base::__end_as_link();
    __l->__next_ = base::__end_.__next_;
    __l->__next_->__prev_ = __l;
    base::__end_.__next_ = __f;
}

// Link in nodes [__f, __l] at the back of the list
template <class _Tp, class _Alloc>
inline
void
list<_Tp, _Alloc>::__link_nodes_at_back(__link_pointer __f, __link_pointer __l)
{
    __l->__next_ = base::__end_as_link();
    __f->__prev_ = base::__end_.__prev_;
    __f->__prev_->__next_ = __f;
    base::__end_.__prev_ = __l;
}


template <class _Tp, class _Alloc>
inline
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::__iterator(size_type __n)
{
    return __n <= base::__sz() / 2 ? _VSTD::next(begin(), __n)
                                   : _VSTD::prev(end(), base::__sz() - __n);
}

template <class _Tp, class _Alloc>
list<_Tp, _Alloc>::list(size_type __n)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1209 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1211 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (; __n > 0; --__n)
#ifndef _LIBCPP_CXX03_LANG
        emplace_back();
#else
# 1215 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        push_back(value_type());
#endif
# 1217 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1220 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
template <class _Tp, class _Alloc>
list<_Tp, _Alloc>::list(size_type __n, const allocator_type& __a) : base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1224 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1226 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (; __n > 0; --__n)
        emplace_back();
}
#endif
# 1230 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

template <class _Tp, class _Alloc>
list<_Tp, _Alloc>::list(size_type __n, const value_type& __x)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1235 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1237 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (; __n > 0; --__n)
        push_back(__x);
}

template <class _Tp, class _Alloc>
list<_Tp, _Alloc>::list(size_type __n, const value_type& __x, const allocator_type& __a)
    : base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1246 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1248 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (; __n > 0; --__n)
        push_back(__x);
}

template <class _Tp, class _Alloc>
template <class _InpIter>
list<_Tp, _Alloc>::list(_InpIter __f, _InpIter __l,
                        typename enable_if<__is_cpp17_input_iterator<_InpIter>::value>::type*)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1258 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1260 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (; __f != __l; ++__f)
        __emplace_back(*__f);
}

template <class _Tp, class _Alloc>
template <class _InpIter>
list<_Tp, _Alloc>::list(_InpIter __f, _InpIter __l, const allocator_type& __a,
                        typename enable_if<__is_cpp17_input_iterator<_InpIter>::value>::type*)
    : base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1271 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1273 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (; __f != __l; ++__f)
        __emplace_back(*__f);
}

template <class _Tp, class _Alloc>
list<_Tp, _Alloc>::list(const list& __c)
    : base(__node_alloc_traits::select_on_container_copy_construction(
          __c.__node_alloc())) {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1282 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1284 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (const_iterator __i = __c.begin(), __e = __c.end(); __i != __e; ++__i)
        push_back(*__i);
}

template <class _Tp, class _Alloc>
list<_Tp, _Alloc>::list(const list& __c, const allocator_type& __a)
    : base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1293 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1295 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (const_iterator __i = __c.begin(), __e = __c.end(); __i != __e; ++__i)
        push_back(*__i);
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Alloc>
list<_Tp, _Alloc>::list(initializer_list<value_type> __il, const allocator_type& __a)
    : base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1306 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1308 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (typename initializer_list<value_type>::const_iterator __i = __il.begin(),
            __e = __il.end(); __i != __e; ++__i)
        push_back(*__i);
}

template <class _Tp, class _Alloc>
list<_Tp, _Alloc>::list(initializer_list<value_type> __il)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1317 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1319 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    for (typename initializer_list<value_type>::const_iterator __i = __il.begin(),
            __e = __il.end(); __i != __e; ++__i)
        push_back(*__i);
}

template <class _Tp, class _Alloc>
inline list<_Tp, _Alloc>::list(list&& __c)
    _NOEXCEPT_(is_nothrow_move_constructible<__node_allocator>::value)
    : base(_VSTD::move(__c.__node_alloc())) {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1329 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1331 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    splice(end(), __c);
}

template <class _Tp, class _Alloc>
inline
list<_Tp, _Alloc>::list(list&& __c, const allocator_type& __a)
    : base(__a)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1340 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __get_db()->__insert_c(this);
#endif
# 1342 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    if (__a == __c.get_allocator())
        splice(end(), __c);
    else
    {
        typedef move_iterator<iterator> _Ip;
        assign(_Ip(__c.begin()), _Ip(__c.end()));
    }
}

template <class _Tp, class _Alloc>
inline
list<_Tp, _Alloc>&
list<_Tp, _Alloc>::operator=(list&& __c)
        _NOEXCEPT_(
            __node_alloc_traits::propagate_on_container_move_assignment::value &&
            is_nothrow_move_assignable<__node_allocator>::value)
{
    __move_assign(__c, integral_constant<bool,
          __node_alloc_traits::propagate_on_container_move_assignment::value>());
    return *this;
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::__move_assign(list& __c, false_type)
{
    if (base::__node_alloc() != __c.__node_alloc())
    {
        typedef move_iterator<iterator> _Ip;
        assign(_Ip(__c.begin()), _Ip(__c.end()));
    }
    else
        __move_assign(__c, true_type());
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::__move_assign(list& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<__node_allocator>::value)
{
    clear();
    base::__move_assign_alloc(__c);
    splice(end(), __c);
}

#endif  // _LIBCPP_CXX03_LANG
# 1388 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

template <class _Tp, class _Alloc>
inline
list<_Tp, _Alloc>&
list<_Tp, _Alloc>::operator=(const list& __c)
{
    if (this != &__c)
    {
        base::__copy_assign_alloc(__c);
        assign(__c.begin(), __c.end());
    }
    return *this;
}

template <class _Tp, class _Alloc>
template <class _InpIter>
void
list<_Tp, _Alloc>::assign(_InpIter __f, _InpIter __l,
                          typename enable_if<__is_cpp17_input_iterator<_InpIter>::value>::type*)
{
    iterator __i = begin();
    iterator __e = end();
    for (; __f != __l && __i != __e; ++__f, ++__i)
        *__i = *__f;
    if (__i == __e)
        insert(__e, __f, __l);
    else
        erase(__i, __e);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1417 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
      __get_db()->__invalidate_all(this);
#endif
# 1419 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::assign(size_type __n, const value_type& __x)
{
    iterator __i = begin();
    iterator __e = end();
    for (; __n > 0 && __i != __e; --__n, ++__i)
        *__i = __x;
    if (__i == __e)
        insert(__e, __n, __x);
    else
        erase(__i, __e);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1434 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
      __get_db()->__invalidate_all(this);
#endif
# 1436 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
inline
_Alloc
list<_Tp, _Alloc>::get_allocator() const _NOEXCEPT
{
    return allocator_type(base::__node_alloc());
}

template <class _Tp, class _Alloc>
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::insert(const_iterator __p, const value_type& __x)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1451 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::insert(iterator, x) called with an iterator not"
        " referring to this list");
#endif
# 1455 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), __x);
    __link_nodes(__p.__ptr_, __hold->__as_link(), __hold->__as_link());
    ++base::__sz();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1461 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__hold.release()->__as_link(), this);
#else
# 1463 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__hold.release()->__as_link());
#endif
# 1465 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::insert(const_iterator __p, size_type __n, const value_type& __x)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1472 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::insert(iterator, n, x) called with an iterator not"
        " referring to this list");
    iterator __r(__p.__ptr_, this);
#else
# 1477 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    iterator __r(__p.__ptr_);
#endif
# 1479 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    if (__n > 0)
    {
        size_type __ds = 0;
        __node_allocator& __na = base::__node_alloc();
        __hold_pointer __hold = __allocate_node(__na);
        __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), __x);
        ++__ds;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1487 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __r = iterator(__hold->__as_link(), this);
#else
# 1489 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __r = iterator(__hold->__as_link());
#endif
# 1491 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __hold.release();
        iterator __e = __r;
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1497 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            for (--__n; __n != 0; --__n, ++__e, ++__ds)
            {
                __hold.reset(__node_alloc_traits::allocate(__na, 1));
                __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), __x);
                __e.__ptr_->__next_ = __hold->__as_link();
                __hold->__prev_ = __e.__ptr_;
                __hold.release();
            }
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
            while (true)
            {
                __node_alloc_traits::destroy(__na, _VSTD::addressof(*__e));
                __link_pointer __prev = __e.__ptr_->__prev_;
                __node_alloc_traits::deallocate(__na, __e.__ptr_->__as_node(), 1);
                if (__prev == 0)
                    break;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1517 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
                __e = iterator(__prev, this);
#else
# 1519 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
                __e = iterator(__prev);
#endif
# 1521 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            }
            throw;
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1525 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __link_nodes(__p.__ptr_, __r.__ptr_, __e.__ptr_);
        base::__sz() += __ds;
    }
    return __r;
}

template <class _Tp, class _Alloc>
template <class _InpIter>
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::insert(const_iterator __p, _InpIter __f, _InpIter __l,
             typename enable_if<__is_cpp17_input_iterator<_InpIter>::value>::type*)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1538 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::insert(iterator, range) called with an iterator not"
        " referring to this list");
    iterator __r(__p.__ptr_, this);
#else
# 1543 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    iterator __r(__p.__ptr_);
#endif
# 1545 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    if (__f != __l)
    {
        size_type __ds = 0;
        __node_allocator& __na = base::__node_alloc();
        __hold_pointer __hold = __allocate_node(__na);
        __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), *__f);
        ++__ds;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1553 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __r = iterator(__hold.get()->__as_link(), this);
#else
# 1555 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __r = iterator(__hold.get()->__as_link());
#endif
# 1557 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __hold.release();
        iterator __e = __r;
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1563 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            for (++__f; __f != __l; ++__f, (void) ++__e, (void) ++__ds)
            {
                __hold.reset(__node_alloc_traits::allocate(__na, 1));
                __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), *__f);
                __e.__ptr_->__next_ = __hold.get()->__as_link();
                __hold->__prev_ = __e.__ptr_;
                __hold.release();
            }
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
            while (true)
            {
                __node_alloc_traits::destroy(__na, _VSTD::addressof(*__e));
                __link_pointer __prev = __e.__ptr_->__prev_;
                __node_alloc_traits::deallocate(__na, __e.__ptr_->__as_node(), 1);
                if (__prev == 0)
                    break;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1583 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
                __e = iterator(__prev, this);
#else
# 1585 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
                __e = iterator(__prev);
#endif
# 1587 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            }
            throw;
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1591 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __link_nodes(__p.__ptr_, __r.__ptr_, __e.__ptr_);
        base::__sz() += __ds;
    }
    return __r;
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::push_front(const value_type& __x)
{
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), __x);
    __link_pointer __nl = __hold->__as_link();
    __link_nodes_at_front(__nl, __nl);
    ++base::__sz();
    __hold.release();
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::push_back(const value_type& __x)
{
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), __x);
    __link_nodes_at_back(__hold.get()->__as_link(), __hold.get()->__as_link());
    ++base::__sz();
    __hold.release();
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::push_front(value_type&& __x)
{
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), _VSTD::move(__x));
    __link_nodes_at_front(__hold.get()->__as_link(), __hold.get()->__as_link());
    ++base::__sz();
    __hold.release();
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::push_back(value_type&& __x)
{
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), _VSTD::move(__x));
    __link_nodes_at_back(__hold.get()->__as_link(), __hold.get()->__as_link());
    ++base::__sz();
    __hold.release();
}

template <class _Tp, class _Alloc>
template <class... _Args>
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1651 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
typename list<_Tp, _Alloc>::reference
#else
# 1653 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
void
#endif
# 1655 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
list<_Tp, _Alloc>::emplace_front(_Args&&... __args)
{
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), _VSTD::forward<_Args>(__args)...);
    __link_nodes_at_front(__hold.get()->__as_link(), __hold.get()->__as_link());
    ++base::__sz();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1663 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return __hold.release()->__value_;
#else
# 1665 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __hold.release();
#endif
# 1667 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
template <class... _Args>
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1672 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
typename list<_Tp, _Alloc>::reference
#else
# 1674 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
void
#endif
# 1676 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
list<_Tp, _Alloc>::emplace_back(_Args&&... __args)
{
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), _VSTD::forward<_Args>(__args)...);
    __link_pointer __nl = __hold->__as_link();
    __link_nodes_at_back(__nl, __nl);
    ++base::__sz();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1685 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return __hold.release()->__value_;
#else
# 1687 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __hold.release();
#endif
# 1689 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
template <class... _Args>
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::emplace(const_iterator __p, _Args&&... __args)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1697 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::emplace(iterator, args...) called with an iterator not"
        " referring to this list");
#endif
# 1701 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), _VSTD::forward<_Args>(__args)...);
    __link_pointer __nl = __hold.get()->__as_link();
    __link_nodes(__p.__ptr_, __nl, __nl);
    ++base::__sz();
    __hold.release();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1709 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__nl, this);
#else
# 1711 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__nl);
#endif
# 1713 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::insert(const_iterator __p, value_type&& __x)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1720 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::insert(iterator, x) called with an iterator not"
        " referring to this list");
#endif
# 1724 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __node_allocator& __na = base::__node_alloc();
    __hold_pointer __hold = __allocate_node(__na);
    __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), _VSTD::move(__x));
    __link_pointer __nl = __hold->__as_link();
    __link_nodes(__p.__ptr_, __nl, __nl);
    ++base::__sz();
    __hold.release();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1732 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__nl, this);
#else
# 1734 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__nl);
#endif
# 1736 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

#endif  // _LIBCPP_CXX03_LANG
# 1739 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::pop_front()
{
    _LIBCPP_ASSERT(!empty(), "list::pop_front() called with empty list");
    __node_allocator& __na = base::__node_alloc();
    __link_pointer __n = base::__end_.__next_;
    base::__unlink_nodes(__n, __n);
    --base::__sz();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1750 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __c_node* __c = __get_db()->__find_c_and_lock(this);
    for (__i_node** __p = __c->end_; __p != __c->beg_; )
    {
        --__p;
        iterator* __i = static_cast<iterator*>((*__p)->__i_);
        if (__i->__ptr_ == __n)
        {
            (*__p)->__c_ = nullptr;
            if (--__c->end_ != __p)
                memmove(__p, __p+1, (__c->end_ - __p)*sizeof(__i_node*));
        }
    }
    __get_db()->unlock();
#endif
# 1764 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __node_pointer __np = __n->__as_node();
    __node_alloc_traits::destroy(__na, _VSTD::addressof(__np->__value_));
    __node_alloc_traits::deallocate(__na, __np, 1);
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::pop_back()
{
    _LIBCPP_ASSERT(!empty(), "list::pop_back() called with empty list");
    __node_allocator& __na = base::__node_alloc();
    __link_pointer __n = base::__end_.__prev_;
    base::__unlink_nodes(__n, __n);
    --base::__sz();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1779 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __c_node* __c = __get_db()->__find_c_and_lock(this);
    for (__i_node** __p = __c->end_; __p != __c->beg_; )
    {
        --__p;
        iterator* __i = static_cast<iterator*>((*__p)->__i_);
        if (__i->__ptr_ == __n)
        {
            (*__p)->__c_ = nullptr;
            if (--__c->end_ != __p)
                memmove(__p, __p+1, (__c->end_ - __p)*sizeof(__i_node*));
        }
    }
    __get_db()->unlock();
#endif
# 1793 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __node_pointer __np = __n->__as_node();
    __node_alloc_traits::destroy(__na, _VSTD::addressof(__np->__value_));
    __node_alloc_traits::deallocate(__na, __np, 1);
}

template <class _Tp, class _Alloc>
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::erase(const_iterator __p)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1803 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::erase(iterator) called with an iterator not"
        " referring to this list");
#endif
# 1807 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__p != end(),
        "list::erase(iterator) called with a non-dereferenceable iterator");
    __node_allocator& __na = base::__node_alloc();
    __link_pointer __n = __p.__ptr_;
    __link_pointer __r = __n->__next_;
    base::__unlink_nodes(__n, __n);
    --base::__sz();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1815 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __c_node* __c = __get_db()->__find_c_and_lock(this);
    for (__i_node** __ip = __c->end_; __ip != __c->beg_; )
    {
        --__ip;
        iterator* __i = static_cast<iterator*>((*__ip)->__i_);
        if (__i->__ptr_ == __n)
        {
            (*__ip)->__c_ = nullptr;
            if (--__c->end_ != __ip)
                memmove(__ip, __ip+1, (__c->end_ - __ip)*sizeof(__i_node*));
        }
    }
    __get_db()->unlock();
#endif
# 1829 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    __node_pointer __np = __n->__as_node();
    __node_alloc_traits::destroy(__na, _VSTD::addressof(__np->__value_));
    __node_alloc_traits::deallocate(__na, __np, 1);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1833 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__r, this);
#else
# 1835 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__r);
#endif
# 1837 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::erase(const_iterator __f, const_iterator __l)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1844 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__f) == this,
        "list::erase(iterator, iterator) called with an iterator not"
        " referring to this list");
   _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__l) == this,
        "list::erase(iterator, iterator) called with an iterator not"
        " referring to this list");
#endif
# 1851 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    if (__f != __l)
    {
        __node_allocator& __na = base::__node_alloc();
        base::__unlink_nodes(__f.__ptr_, __l.__ptr_->__prev_);
        while (__f != __l)
        {
            __link_pointer __n = __f.__ptr_;
            ++__f;
            --base::__sz();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1861 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            __c_node* __c = __get_db()->__find_c_and_lock(this);
            for (__i_node** __p = __c->end_; __p != __c->beg_; )
            {
                --__p;
                iterator* __i = static_cast<iterator*>((*__p)->__i_);
                if (__i->__ptr_ == __n)
                {
                    (*__p)->__c_ = nullptr;
                    if (--__c->end_ != __p)
                        memmove(__p, __p+1, (__c->end_ - __p)*sizeof(__i_node*));
                }
            }
            __get_db()->unlock();
#endif
# 1875 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            __node_pointer __np = __n->__as_node();
            __node_alloc_traits::destroy(__na, _VSTD::addressof(__np->__value_));
            __node_alloc_traits::deallocate(__na, __np, 1);
        }
    }
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1881 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__l.__ptr_, this);
#else
# 1883 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    return iterator(__l.__ptr_);
#endif
# 1885 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::resize(size_type __n)
{
    if (__n < base::__sz())
        erase(__iterator(__n), end());
    else if (__n > base::__sz())
    {
        __n -= base::__sz();
        size_type __ds = 0;
        __node_allocator& __na = base::__node_alloc();
        __hold_pointer __hold = __allocate_node(__na);
        __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_));
        ++__ds;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1902 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        iterator __r = iterator(__hold.release()->__as_link(), this);
#else
# 1904 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        iterator __r = iterator(__hold.release()->__as_link());
#endif
# 1906 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        iterator __e = __r;
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1911 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            for (--__n; __n != 0; --__n, ++__e, ++__ds)
            {
                __hold.reset(__node_alloc_traits::allocate(__na, 1));
                __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_));
                __e.__ptr_->__next_ = __hold.get()->__as_link();
                __hold->__prev_ = __e.__ptr_;
                __hold.release();
            }
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
            while (true)
            {
                __node_alloc_traits::destroy(__na, _VSTD::addressof(*__e));
                __link_pointer __prev = __e.__ptr_->__prev_;
                __node_alloc_traits::deallocate(__na, __e.__ptr_->__as_node(), 1);
                if (__prev == 0)
                    break;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1931 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
                __e = iterator(__prev, this);
#else
# 1933 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
                __e = iterator(__prev);
#endif
# 1935 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            }
            throw;
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1939 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __link_nodes_at_back(__r.__ptr_, __e.__ptr_);
        base::__sz() += __ds;
    }
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::resize(size_type __n, const value_type& __x)
{
    if (__n < base::__sz())
        erase(__iterator(__n), end());
    else if (__n > base::__sz())
    {
        __n -= base::__sz();
        size_type __ds = 0;
        __node_allocator& __na = base::__node_alloc();
        __hold_pointer __hold = __allocate_node(__na);
        __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), __x);
        ++__ds;
        __link_pointer __nl = __hold.release()->__as_link();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1960 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        iterator __r = iterator(__nl, this);
#else
# 1962 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        iterator __r = iterator(__nl);
#endif
# 1964 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        iterator __e = __r;
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1969 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            for (--__n; __n != 0; --__n, ++__e, ++__ds)
            {
                __hold.reset(__node_alloc_traits::allocate(__na, 1));
                __node_alloc_traits::construct(__na, _VSTD::addressof(__hold->__value_), __x);
                __e.__ptr_->__next_ = __hold.get()->__as_link();
                __hold->__prev_ = __e.__ptr_;
                __hold.release();
            }
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
            while (true)
            {
                __node_alloc_traits::destroy(__na, _VSTD::addressof(*__e));
                __link_pointer __prev = __e.__ptr_->__prev_;
                __node_alloc_traits::deallocate(__na, __e.__ptr_->__as_node(), 1);
                if (__prev == 0)
                    break;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1989 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
                __e = iterator(__prev, this);
#else
# 1991 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
                __e = iterator(__prev);
#endif
# 1993 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
            }
            throw;
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1997 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __link_nodes(base::__end_as_link(), __r.__ptr_, __e.__ptr_);
        base::__sz() += __ds;
    }
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::splice(const_iterator __p, list& __c)
{
    _LIBCPP_ASSERT(this != &__c,
                   "list::splice(iterator, list) called with this == &list");
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2009 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::splice(iterator, list) called with an iterator not"
        " referring to this list");
#endif
# 2013 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    if (!__c.empty())
    {
        __link_pointer __f = __c.__end_.__next_;
        __link_pointer __l = __c.__end_.__prev_;
        base::__unlink_nodes(__f, __l);
        __link_nodes(__p.__ptr_, __f, __l);
        base::__sz() += __c.__sz();
        __c.__sz() = 0;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2022 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        if (&__c != this) {
            __libcpp_db* __db = __get_db();
            __c_node* __cn1 = __db->__find_c_and_lock(this);
            __c_node* __cn2 = __db->__find_c(&__c);
            for (__i_node** __ip = __cn2->end_; __ip != __cn2->beg_;)
            {
                --__ip;
                iterator* __i = static_cast<iterator*>((*__ip)->__i_);
                if (__i->__ptr_ != __c.__end_as_link())
                {
                    __cn1->__add(*__ip);
                    (*__ip)->__c_ = __cn1;
                    if (--__cn2->end_ != __ip)
                        memmove(__ip, __ip+1, (__cn2->end_ - __ip)*sizeof(__i_node*));
                }
            }
            __db->unlock();
        }
#endif
# 2041 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::splice(const_iterator __p, list& __c, const_iterator __i)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2049 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::splice(iterator, list, iterator) called with first iterator not"
        " referring to this list");
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__i) == &__c,
        "list::splice(iterator, list, iterator) called with second iterator not"
        " referring to list argument");
    _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(&__i),
        "list::splice(iterator, list, iterator) called with second iterator not"
        " derefereceable");
#endif
# 2059 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    if (__p.__ptr_ != __i.__ptr_ && __p.__ptr_ != __i.__ptr_->__next_)
    {
        __link_pointer __f = __i.__ptr_;
        base::__unlink_nodes(__f, __f);
        __link_nodes(__p.__ptr_, __f, __f);
        --__c.__sz();
        ++base::__sz();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2067 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        if (&__c != this) {
            __libcpp_db* __db = __get_db();
            __c_node* __cn1 = __db->__find_c_and_lock(this);
            __c_node* __cn2 = __db->__find_c(&__c);
            for (__i_node** __ip = __cn2->end_; __ip != __cn2->beg_;)
            {
                --__ip;
                iterator* __j = static_cast<iterator*>((*__ip)->__i_);
                if (__j->__ptr_ == __f)
                {
                    __cn1->__add(*__ip);
                    (*__ip)->__c_ = __cn1;
                    if (--__cn2->end_ != __ip)
                        memmove(__ip, __ip+1, (__cn2->end_ - __ip)*sizeof(__i_node*));
                }
            }
            __db->unlock();
        }
#endif
# 2086 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::splice(const_iterator __p, list& __c, const_iterator __f, const_iterator __l)
{
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2094 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__p) == this,
        "list::splice(iterator, list, iterator, iterator) called with first iterator not"
        " referring to this list");
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__f) == &__c,
        "list::splice(iterator, list, iterator, iterator) called with second iterator not"
        " referring to list argument");
    if (this == &__c)
    {
        for (const_iterator __i = __f; __i != __l; ++__i)
            _LIBCPP_ASSERT(__i != __p,
                           "list::splice(iterator, list, iterator, iterator)"
                           " called with the first iterator within the range"
                           " of the second and third iterators");
    }
#endif
# 2109 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    if (__f != __l)
    {
        __link_pointer __first = __f.__ptr_;
        --__l;
        __link_pointer __last = __l.__ptr_;
        if (this != &__c)
        {
            size_type __s = _VSTD::distance(__f, __l) + 1;
            __c.__sz() -= __s;
            base::__sz() += __s;
        }
        base::__unlink_nodes(__first, __last);
        __link_nodes(__p.__ptr_, __first, __last);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2123 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        if (&__c != this) {
            __libcpp_db* __db = __get_db();
            __c_node* __cn1 = __db->__find_c_and_lock(this);
            __c_node* __cn2 = __db->__find_c(&__c);
            for (__i_node** __ip = __cn2->end_; __ip != __cn2->beg_;)
            {
                --__ip;
                iterator* __j = static_cast<iterator*>((*__ip)->__i_);
                for (__link_pointer __k = __f.__ptr_;
                                              __k != __l.__ptr_; __k = __k->__next_)
                {
                    if (__j->__ptr_ == __k)
                    {
                        __cn1->__add(*__ip);
                        (*__ip)->__c_ = __cn1;
                        if (--__cn2->end_ != __ip)
                            memmove(__ip, __ip+1, (__cn2->end_ - __ip)*sizeof(__i_node*));
                    }
                }
            }
            __db->unlock();
        }
#endif
# 2146 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
}

template <class _Tp, class _Alloc>
typename list<_Tp, _Alloc>::__remove_return_type
list<_Tp, _Alloc>::remove(const value_type& __x)
{
    list<_Tp, _Alloc> __deleted_nodes(get_allocator()); // collect the nodes we're removing
    for (const_iterator __i = begin(), __e = end(); __i != __e;)
    {
        if (*__i == __x)
        {
            const_iterator __j = _VSTD::next(__i);
            for (; __j != __e && *__j == __x; ++__j)
                ;
            __deleted_nodes.splice(__deleted_nodes.end(), *this, __i, __j);
            __i = __j;
            if (__i != __e)
                ++__i;
        }
        else
            ++__i;
    }

    return (__remove_return_type) __deleted_nodes.size();
}

template <class _Tp, class _Alloc>
template <class _Pred>
typename list<_Tp, _Alloc>::__remove_return_type
list<_Tp, _Alloc>::remove_if(_Pred __pred)
{
    list<_Tp, _Alloc> __deleted_nodes(get_allocator()); // collect the nodes we're removing
    for (iterator __i = begin(), __e = end(); __i != __e;)
    {
        if (__pred(*__i))
        {
            iterator __j = _VSTD::next(__i);
            for (; __j != __e && __pred(*__j); ++__j)
                ;
            __deleted_nodes.splice(__deleted_nodes.end(), *this, __i, __j);
            __i = __j;
            if (__i != __e)
                ++__i;
        }
        else
            ++__i;
    }

    return (__remove_return_type) __deleted_nodes.size();
}

template <class _Tp, class _Alloc>
template <class _BinaryPred>
typename list<_Tp, _Alloc>::__remove_return_type
list<_Tp, _Alloc>::unique(_BinaryPred __binary_pred)
{
    list<_Tp, _Alloc> __deleted_nodes(get_allocator()); // collect the nodes we're removing
    for (iterator __i = begin(), __e = end(); __i != __e;)
    {
        iterator __j = _VSTD::next(__i);
        for (; __j != __e && __binary_pred(*__i, *__j); ++__j)
            ;
        if (++__i != __j) {
            __deleted_nodes.splice(__deleted_nodes.end(), *this, __i, __j);
            __i = __j;
            }
    }

    return (__remove_return_type) __deleted_nodes.size();
}

template <class _Tp, class _Alloc>
inline
void
list<_Tp, _Alloc>::merge(list& __c)
{
    merge(__c, __less<value_type>());
}

template <class _Tp, class _Alloc>
template <class _Comp>
void
list<_Tp, _Alloc>::merge(list& __c, _Comp __comp)
{
    if (this != _VSTD::addressof(__c))
    {
        iterator __f1 = begin();
        iterator __e1 = end();
        iterator __f2 = __c.begin();
        iterator __e2 = __c.end();
        while (__f1 != __e1 && __f2 != __e2)
        {
            if (__comp(*__f2, *__f1))
            {
                size_type __ds = 1;
                iterator __m2 = _VSTD::next(__f2);
                for (; __m2 != __e2 && __comp(*__m2, *__f1); ++__m2, ++__ds)
                    ;
                base::__sz() += __ds;
                __c.__sz() -= __ds;
                __link_pointer __f = __f2.__ptr_;
                __link_pointer __l = __m2.__ptr_->__prev_;
                __f2 = __m2;
                base::__unlink_nodes(__f, __l);
                __m2 = _VSTD::next(__f1);
                __link_nodes(__f1.__ptr_, __f, __l);
                __f1 = __m2;
            }
            else
                ++__f1;
        }
        splice(__e1, __c);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2260 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
        __libcpp_db* __db = __get_db();
        __c_node* __cn1 = __db->__find_c_and_lock(this);
        __c_node* __cn2 = __db->__find_c(&__c);
        for (__i_node** __p = __cn2->end_; __p != __cn2->beg_;)
        {
            --__p;
            iterator* __i = static_cast<iterator*>((*__p)->__i_);
            if (__i->__ptr_ != __c.__end_as_link())
            {
                __cn1->__add(*__p);
                (*__p)->__c_ = __cn1;
                if (--__cn2->end_ != __p)
                    memmove(__p, __p+1, (__cn2->end_ - __p)*sizeof(__i_node*));
            }
        }
        __db->unlock();
#endif
# 2277 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
    }
}

template <class _Tp, class _Alloc>
inline
void
list<_Tp, _Alloc>::sort()
{
    sort(__less<value_type>());
}

template <class _Tp, class _Alloc>
template <class _Comp>
inline
void
list<_Tp, _Alloc>::sort(_Comp __comp)
{
    __sort(begin(), end(), base::__sz(), __comp);
}

template <class _Tp, class _Alloc>
template <class _Comp>
typename list<_Tp, _Alloc>::iterator
list<_Tp, _Alloc>::__sort(iterator __f1, iterator __e2, size_type __n, _Comp& __comp)
{
    switch (__n)
    {
    case 0:
    case 1:
        return __f1;
    case 2:
        if (__comp(*--__e2, *__f1))
        {
            __link_pointer __f = __e2.__ptr_;
            base::__unlink_nodes(__f, __f);
            __link_nodes(__f1.__ptr_, __f, __f);
            return __e2;
        }
        return __f1;
    }
    size_type __n2 = __n / 2;
    iterator __e1 = _VSTD::next(__f1, __n2);
    iterator  __r = __f1 = __sort(__f1, __e1, __n2, __comp);
    iterator __f2 = __e1 = __sort(__e1, __e2, __n - __n2, __comp);
    if (__comp(*__f2, *__f1))
    {
        iterator __m2 = _VSTD::next(__f2);
        for (; __m2 != __e2 && __comp(*__m2, *__f1); ++__m2)
            ;
        __link_pointer __f = __f2.__ptr_;
        __link_pointer __l = __m2.__ptr_->__prev_;
        __r = __f2;
        __e1 = __f2 = __m2;
        base::__unlink_nodes(__f, __l);
        __m2 = _VSTD::next(__f1);
        __link_nodes(__f1.__ptr_, __f, __l);
        __f1 = __m2;
    }
    else
        ++__f1;
    while (__f1 != __e1 && __f2 != __e2)
    {
        if (__comp(*__f2, *__f1))
        {
            iterator __m2 = _VSTD::next(__f2);
            for (; __m2 != __e2 && __comp(*__m2, *__f1); ++__m2)
                ;
            __link_pointer __f = __f2.__ptr_;
            __link_pointer __l = __m2.__ptr_->__prev_;
            if (__e1 == __f2)
                __e1 = __m2;
            __f2 = __m2;
            base::__unlink_nodes(__f, __l);
            __m2 = _VSTD::next(__f1);
            __link_nodes(__f1.__ptr_, __f, __l);
            __f1 = __m2;
        }
        else
            ++__f1;
    }
    return __r;
}

template <class _Tp, class _Alloc>
void
list<_Tp, _Alloc>::reverse() _NOEXCEPT
{
    if (base::__sz() > 1)
    {
        iterator __e = end();
        for (iterator __i = begin(); __i.__ptr_ != __e.__ptr_;)
        {
            _VSTD::swap(__i.__ptr_->__prev_, __i.__ptr_->__next_);
            __i.__ptr_ = __i.__ptr_->__prev_;
        }
        _VSTD::swap(__e.__ptr_->__prev_, __e.__ptr_->__next_);
    }
}

template <class _Tp, class _Alloc>
bool
list<_Tp, _Alloc>::__invariants() const
{
    return size() == _VSTD::distance(begin(), end());
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_DEBUG_LEVEL >= 2
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2384 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

template <class _Tp, class _Alloc>
bool
list<_Tp, _Alloc>::__dereferenceable(const const_iterator* __i) const
{
    return __i->__ptr_ != this->__end_as_link();
}

template <class _Tp, class _Alloc>
bool
list<_Tp, _Alloc>::__decrementable(const const_iterator* __i) const
{
    return !empty() &&  __i->__ptr_ != base::__end_.__next_;
}

template <class _Tp, class _Alloc>
bool
list<_Tp, _Alloc>::__addable(const const_iterator*, ptrdiff_t) const
{
    return false;
}

template <class _Tp, class _Alloc>
bool
list<_Tp, _Alloc>::__subscriptable(const const_iterator*, ptrdiff_t) const
{
    return false;
}

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 2414 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

template <class _Tp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const list<_Tp, _Alloc>& __x, const list<_Tp, _Alloc>& __y)
{
    return __x.size() == __y.size() && _VSTD::equal(__x.begin(), __x.end(), __y.begin());
}

template <class _Tp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const list<_Tp, _Alloc>& __x, const list<_Tp, _Alloc>& __y)
{
    return _VSTD::lexicographical_compare(__x.begin(), __x.end(), __y.begin(), __y.end());
}

template <class _Tp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const list<_Tp, _Alloc>& __x, const list<_Tp, _Alloc>& __y)
{
    return !(__x == __y);
}

template <class _Tp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const list<_Tp, _Alloc>& __x, const list<_Tp, _Alloc>& __y)
{
    return __y < __x;
}

template <class _Tp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const list<_Tp, _Alloc>& __x, const list<_Tp, _Alloc>& __y)
{
    return !(__x < __y);
}

template <class _Tp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const list<_Tp, _Alloc>& __x, const list<_Tp, _Alloc>& __y)
{
    return !(__y < __x);
}

template <class _Tp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(list<_Tp, _Alloc>& __x, list<_Tp, _Alloc>& __y)
    _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2473 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
template <class _Tp, class _Allocator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
void erase_if(list<_Tp, _Allocator>& __c, _Predicate __pred)
{ __c.remove_if(__pred); }

template <class _Tp, class _Allocator, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
void erase(list<_Tp, _Allocator>& __c, const _Up& __v)
{ _VSTD::erase_if(__c, [&](auto& __elem) { return __elem == __v; }); }
#endif
# 2483 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_LIST
# 2489 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/list" 3
# 33 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <map>
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 1 3
// -*- C++ -*-
//===----------------------------- map ------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_MAP
#define _LIBCPP_MAP

/*

    map synopsis

namespace std
{

template <class Key, class T, class Compare = less<Key>,
          class Allocator = allocator<pair<const Key, T>>>
class map
{
public:
    // types:
    typedef Key                                      key_type;
    typedef T                                        mapped_type;
    typedef pair<const key_type, mapped_type>        value_type;
    typedef Compare                                  key_compare;
    typedef Allocator                                allocator_type;
    typedef typename allocator_type::reference       reference;
    typedef typename allocator_type::const_reference const_reference;
    typedef typename allocator_type::pointer         pointer;
    typedef typename allocator_type::const_pointer   const_pointer;
    typedef typename allocator_type::size_type       size_type;
    typedef typename allocator_type::difference_type difference_type;

    typedef implementation-defined                   iterator;
    typedef implementation-defined                   const_iterator;
    typedef std::reverse_iterator<iterator>          reverse_iterator;
    typedef std::reverse_iterator<const_iterator>    const_reverse_iterator;
    typedef unspecified                              node_type;              // C++17
    typedef INSERT_RETURN_TYPE<iterator, node_type>  insert_return_type;     // C++17

    class value_compare
        : public binary_function<value_type, value_type, bool>
    {
        friend class map;
    protected:
        key_compare comp;

        value_compare(key_compare c);
    public:
        bool operator()(const value_type& x, const value_type& y) const;
    };

    // construct/copy/destroy:
    map()
        noexcept(
            is_nothrow_default_constructible<allocator_type>::value &&
            is_nothrow_default_constructible<key_compare>::value &&
            is_nothrow_copy_constructible<key_compare>::value);
    explicit map(const key_compare& comp);
    map(const key_compare& comp, const allocator_type& a);
    template <class InputIterator>
        map(InputIterator first, InputIterator last,
            const key_compare& comp = key_compare());
    template <class InputIterator>
        map(InputIterator first, InputIterator last,
            const key_compare& comp, const allocator_type& a);
    map(const map& m);
    map(map&& m)
        noexcept(
            is_nothrow_move_constructible<allocator_type>::value &&
            is_nothrow_move_constructible<key_compare>::value);
    explicit map(const allocator_type& a);
    map(const map& m, const allocator_type& a);
    map(map&& m, const allocator_type& a);
    map(initializer_list<value_type> il, const key_compare& comp = key_compare());
    map(initializer_list<value_type> il, const key_compare& comp, const allocator_type& a);
    template <class InputIterator>
        map(InputIterator first, InputIterator last, const allocator_type& a)
            : map(first, last, Compare(), a) {}  // C++14
    map(initializer_list<value_type> il, const allocator_type& a)
        : map(il, Compare(), a) {}  // C++14
   ~map();

    map& operator=(const map& m);
    map& operator=(map&& m)
        noexcept(
            allocator_type::propagate_on_container_move_assignment::value &&
            is_nothrow_move_assignable<allocator_type>::value &&
            is_nothrow_move_assignable<key_compare>::value);
    map& operator=(initializer_list<value_type> il);

    // iterators:
          iterator begin() noexcept;
    const_iterator begin() const noexcept;
          iterator end() noexcept;
    const_iterator end()   const noexcept;

          reverse_iterator rbegin() noexcept;
    const_reverse_iterator rbegin() const noexcept;
          reverse_iterator rend() noexcept;
    const_reverse_iterator rend()   const noexcept;

    const_iterator         cbegin()  const noexcept;
    const_iterator         cend()    const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend()   const noexcept;

    // capacity:
    bool      empty()    const noexcept;
    size_type size()     const noexcept;
    size_type max_size() const noexcept;

    // element access:
    mapped_type& operator[](const key_type& k);
    mapped_type& operator[](key_type&& k);

          mapped_type& at(const key_type& k);
    const mapped_type& at(const key_type& k) const;

    // modifiers:
    template <class... Args>
        pair<iterator, bool> emplace(Args&&... args);
    template <class... Args>
        iterator emplace_hint(const_iterator position, Args&&... args);
    pair<iterator, bool> insert(const value_type& v);
    pair<iterator, bool> insert(      value_type&& v);                                // C++17
    template <class P>
        pair<iterator, bool> insert(P&& p);
    iterator insert(const_iterator position, const value_type& v);
    iterator insert(const_iterator position,       value_type&& v);                   // C++17
    template <class P>
        iterator insert(const_iterator position, P&& p);
    template <class InputIterator>
        void insert(InputIterator first, InputIterator last);
    void insert(initializer_list<value_type> il);

    node_type extract(const_iterator position);                                       // C++17
    node_type extract(const key_type& x);                                             // C++17
    insert_return_type insert(node_type&& nh);                                        // C++17
    iterator insert(const_iterator hint, node_type&& nh);                             // C++17

    template <class... Args>
        pair<iterator, bool> try_emplace(const key_type& k, Args&&... args);          // C++17
    template <class... Args>
        pair<iterator, bool> try_emplace(key_type&& k, Args&&... args);               // C++17
    template <class... Args>
        iterator try_emplace(const_iterator hint, const key_type& k, Args&&... args); // C++17
    template <class... Args>
        iterator try_emplace(const_iterator hint, key_type&& k, Args&&... args);      // C++17
    template <class M>
        pair<iterator, bool> insert_or_assign(const key_type& k, M&& obj);            // C++17
    template <class M>
        pair<iterator, bool> insert_or_assign(key_type&& k, M&& obj);                 // C++17
    template <class M>
        iterator insert_or_assign(const_iterator hint, const key_type& k, M&& obj);   // C++17
    template <class M>
        iterator insert_or_assign(const_iterator hint, key_type&& k, M&& obj);        // C++17

    iterator  erase(const_iterator position);
    iterator  erase(iterator position); // C++14
    size_type erase(const key_type& k);
    iterator  erase(const_iterator first, const_iterator last);
    void clear() noexcept;

    template<class C2>
      void merge(map<Key, T, C2, Allocator>& source);         // C++17
    template<class C2>
      void merge(map<Key, T, C2, Allocator>&& source);        // C++17
    template<class C2>
      void merge(multimap<Key, T, C2, Allocator>& source);    // C++17
    template<class C2>
      void merge(multimap<Key, T, C2, Allocator>&& source);   // C++17

    void swap(map& m)
        noexcept(allocator_traits<allocator_type>::is_always_equal::value &&
            is_nothrow_swappable<key_compare>::value); // C++17

    // observers:
    allocator_type get_allocator() const noexcept;
    key_compare    key_comp()      const;
    value_compare  value_comp()    const;

    // map operations:
          iterator find(const key_type& k);
    const_iterator find(const key_type& k) const;
    template<typename K>
        iterator find(const K& x);              // C++14
    template<typename K>
        const_iterator find(const K& x) const;  // C++14
    template<typename K>
      size_type count(const K& x) const;        // C++14
    size_type      count(const key_type& k) const;
        bool contains(const key_type& x) const; // C++20
          iterator lower_bound(const key_type& k);
    const_iterator lower_bound(const key_type& k) const;
    template<typename K>
        iterator lower_bound(const K& x);              // C++14
    template<typename K>
        const_iterator lower_bound(const K& x) const;  // C++14

          iterator upper_bound(const key_type& k);
    const_iterator upper_bound(const key_type& k) const;
    template<typename K>
        iterator upper_bound(const K& x);              // C++14
    template<typename K>
        const_iterator upper_bound(const K& x) const;  // C++14

    pair<iterator,iterator>             equal_range(const key_type& k);
    pair<const_iterator,const_iterator> equal_range(const key_type& k) const;
    template<typename K>
        pair<iterator,iterator>             equal_range(const K& x);        // C++14
    template<typename K>
        pair<const_iterator,const_iterator> equal_range(const K& x) const;  // C++14
};

template <class Key, class T, class Compare, class Allocator>
bool
operator==(const map<Key, T, Compare, Allocator>& x,
           const map<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator< (const map<Key, T, Compare, Allocator>& x,
           const map<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator!=(const map<Key, T, Compare, Allocator>& x,
           const map<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator> (const map<Key, T, Compare, Allocator>& x,
           const map<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator>=(const map<Key, T, Compare, Allocator>& x,
           const map<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator<=(const map<Key, T, Compare, Allocator>& x,
           const map<Key, T, Compare, Allocator>& y);

// specialized algorithms:
template <class Key, class T, class Compare, class Allocator>
void
swap(map<Key, T, Compare, Allocator>& x, map<Key, T, Compare, Allocator>& y)
    noexcept(noexcept(x.swap(y)));

template <class Key, class T, class Compare, class Allocator, class Predicate>
  void erase_if(map<Key, T, Compare, Allocator>& c, Predicate pred);  // C++20


template <class Key, class T, class Compare = less<Key>,
          class Allocator = allocator<pair<const Key, T>>>
class multimap
{
public:
    // types:
    typedef Key                                      key_type;
    typedef T                                        mapped_type;
    typedef pair<const key_type,mapped_type>         value_type;
    typedef Compare                                  key_compare;
    typedef Allocator                                allocator_type;
    typedef typename allocator_type::reference       reference;
    typedef typename allocator_type::const_reference const_reference;
    typedef typename allocator_type::size_type       size_type;
    typedef typename allocator_type::difference_type difference_type;
    typedef typename allocator_type::pointer         pointer;
    typedef typename allocator_type::const_pointer   const_pointer;

    typedef implementation-defined                   iterator;
    typedef implementation-defined                   const_iterator;
    typedef std::reverse_iterator<iterator>          reverse_iterator;
    typedef std::reverse_iterator<const_iterator>    const_reverse_iterator;
    typedef unspecified                              node_type;              // C++17

    class value_compare
        : public binary_function<value_type,value_type,bool>
    {
        friend class multimap;
    protected:
        key_compare comp;
        value_compare(key_compare c);
    public:
        bool operator()(const value_type& x, const value_type& y) const;
    };

    // construct/copy/destroy:
    multimap()
        noexcept(
            is_nothrow_default_constructible<allocator_type>::value &&
            is_nothrow_default_constructible<key_compare>::value &&
            is_nothrow_copy_constructible<key_compare>::value);
    explicit multimap(const key_compare& comp);
    multimap(const key_compare& comp, const allocator_type& a);
    template <class InputIterator>
        multimap(InputIterator first, InputIterator last, const key_compare& comp);
    template <class InputIterator>
        multimap(InputIterator first, InputIterator last, const key_compare& comp,
                 const allocator_type& a);
    multimap(const multimap& m);
    multimap(multimap&& m)
        noexcept(
            is_nothrow_move_constructible<allocator_type>::value &&
            is_nothrow_move_constructible<key_compare>::value);
    explicit multimap(const allocator_type& a);
    multimap(const multimap& m, const allocator_type& a);
    multimap(multimap&& m, const allocator_type& a);
    multimap(initializer_list<value_type> il, const key_compare& comp = key_compare());
    multimap(initializer_list<value_type> il, const key_compare& comp,
             const allocator_type& a);
    template <class InputIterator>
        multimap(InputIterator first, InputIterator last, const allocator_type& a)
            : multimap(first, last, Compare(), a) {} // C++14
    multimap(initializer_list<value_type> il, const allocator_type& a)
        : multimap(il, Compare(), a) {} // C++14
    ~multimap();

    multimap& operator=(const multimap& m);
    multimap& operator=(multimap&& m)
        noexcept(
            allocator_type::propagate_on_container_move_assignment::value &&
            is_nothrow_move_assignable<allocator_type>::value &&
            is_nothrow_move_assignable<key_compare>::value);
    multimap& operator=(initializer_list<value_type> il);

    // iterators:
          iterator begin() noexcept;
    const_iterator begin() const noexcept;
          iterator end() noexcept;
    const_iterator end()   const noexcept;

          reverse_iterator rbegin() noexcept;
    const_reverse_iterator rbegin() const noexcept;
          reverse_iterator rend() noexcept;
    const_reverse_iterator rend()   const noexcept;

    const_iterator         cbegin()  const noexcept;
    const_iterator         cend()    const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend()   const noexcept;

    // capacity:
    bool      empty()    const noexcept;
    size_type size()     const noexcept;
    size_type max_size() const noexcept;

    // modifiers:
    template <class... Args>
        iterator emplace(Args&&... args);
    template <class... Args>
        iterator emplace_hint(const_iterator position, Args&&... args);
    iterator insert(const value_type& v);
    iterator insert(      value_type&& v);                                            // C++17
    template <class P>
        iterator insert(P&& p);
    iterator insert(const_iterator position, const value_type& v);
    iterator insert(const_iterator position,       value_type&& v);                   // C++17
    template <class P>
        iterator insert(const_iterator position, P&& p);
    template <class InputIterator>
        void insert(InputIterator first, InputIterator last);
    void insert(initializer_list<value_type> il);

    node_type extract(const_iterator position);                                       // C++17
    node_type extract(const key_type& x);                                             // C++17
    iterator insert(node_type&& nh);                                                  // C++17
    iterator insert(const_iterator hint, node_type&& nh);                             // C++17

    iterator  erase(const_iterator position);
    iterator  erase(iterator position); // C++14
    size_type erase(const key_type& k);
    iterator  erase(const_iterator first, const_iterator last);
    void clear() noexcept;

    template<class C2>
      void merge(multimap<Key, T, C2, Allocator>& source);    // C++17
    template<class C2>
      void merge(multimap<Key, T, C2, Allocator>&& source);   // C++17
    template<class C2>
      void merge(map<Key, T, C2, Allocator>& source);         // C++17
    template<class C2>
      void merge(map<Key, T, C2, Allocator>&& source);        // C++17

    void swap(multimap& m)
        noexcept(allocator_traits<allocator_type>::is_always_equal::value &&
            is_nothrow_swappable<key_compare>::value); // C++17

    // observers:
    allocator_type get_allocator() const noexcept;
    key_compare    key_comp()      const;
    value_compare  value_comp()    const;

    // map operations:
          iterator find(const key_type& k);
    const_iterator find(const key_type& k) const;
    template<typename K>
        iterator find(const K& x);              // C++14
    template<typename K>
        const_iterator find(const K& x) const;  // C++14
    template<typename K>
      size_type count(const K& x) const;        // C++14
    size_type      count(const key_type& k) const;
        bool contains(const key_type& x) const; // C++20
          iterator lower_bound(const key_type& k);
    const_iterator lower_bound(const key_type& k) const;
    template<typename K>
        iterator lower_bound(const K& x);              // C++14
    template<typename K>
        const_iterator lower_bound(const K& x) const;  // C++14

          iterator upper_bound(const key_type& k);
    const_iterator upper_bound(const key_type& k) const;
    template<typename K>
        iterator upper_bound(const K& x);              // C++14
    template<typename K>
        const_iterator upper_bound(const K& x) const;  // C++14

    pair<iterator,iterator>             equal_range(const key_type& k);
    pair<const_iterator,const_iterator> equal_range(const key_type& k) const;
    template<typename K>
        pair<iterator,iterator>             equal_range(const K& x);        // C++14
    template<typename K>
        pair<const_iterator,const_iterator> equal_range(const K& x) const;  // C++14
};

template <class Key, class T, class Compare, class Allocator>
bool
operator==(const multimap<Key, T, Compare, Allocator>& x,
           const multimap<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator< (const multimap<Key, T, Compare, Allocator>& x,
           const multimap<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator!=(const multimap<Key, T, Compare, Allocator>& x,
           const multimap<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator> (const multimap<Key, T, Compare, Allocator>& x,
           const multimap<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator>=(const multimap<Key, T, Compare, Allocator>& x,
           const multimap<Key, T, Compare, Allocator>& y);

template <class Key, class T, class Compare, class Allocator>
bool
operator<=(const multimap<Key, T, Compare, Allocator>& x,
           const multimap<Key, T, Compare, Allocator>& y);

// specialized algorithms:
template <class Key, class T, class Compare, class Allocator>
void
swap(multimap<Key, T, Compare, Allocator>& x,
     multimap<Key, T, Compare, Allocator>& y)
    noexcept(noexcept(x.swap(y)));

template <class Key, class T, class Compare, class Allocator, class Predicate>
  void erase_if(multimap<Key, T, Compare, Allocator>& c, Predicate pred);  // C++20

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 478 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 479 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#if 0 /* expanded by -frewrite-includes */
#include <__tree>
#endif /* expanded by -frewrite-includes */
# 479 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___TREE
#define _LIBCPP___TREE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

#if 0 /* disabled by -frewrite-includes */
#if defined(__GNUC__) && !defined(__clang__) // gcc.gnu.org/PR37804
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 30 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
template <class, class, class, class> class _LIBCPP_TEMPLATE_VIS map;
template <class, class, class, class> class _LIBCPP_TEMPLATE_VIS multimap;
template <class, class, class> class _LIBCPP_TEMPLATE_VIS set;
template <class, class, class> class _LIBCPP_TEMPLATE_VIS multiset;
#endif
# 35 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

template <class _Tp, class _Compare, class _Allocator> class __tree;
template <class _Tp, class _NodePtr, class _DiffType>
    class _LIBCPP_TEMPLATE_VIS __tree_iterator;
template <class _Tp, class _ConstNodePtr, class _DiffType>
    class _LIBCPP_TEMPLATE_VIS __tree_const_iterator;

template <class _Pointer> class __tree_end_node;
template <class _VoidPtr> class __tree_node_base;
template <class _Tp, class _VoidPtr> class __tree_node;

template <class _Key, class _Value>
struct __value_type;

template <class _Allocator> class __map_node_destructor;
template <class _TreeIterator> class _LIBCPP_TEMPLATE_VIS __map_iterator;
template <class _TreeIterator> class _LIBCPP_TEMPLATE_VIS __map_const_iterator;

/*

_NodePtr algorithms

The algorithms taking _NodePtr are red black tree algorithms.  Those
algorithms taking a parameter named __root should assume that __root
points to a proper red black tree (unless otherwise specified).

Each algorithm herein assumes that __root->__parent_ points to a non-null
structure which has a member __left_ which points back to __root.  No other
member is read or written to at __root->__parent_.

__root->__parent_ will be referred to below (in comments only) as end_node.
end_node->__left_ is an externably accessible lvalue for __root, and can be
changed by node insertion and removal (without explicit reference to end_node).

All nodes (with the exception of end_node), even the node referred to as
__root, have a non-null __parent_ field.

*/

// Returns:  true if __x is a left child of its parent, else false
// Precondition:  __x != nullptr.
template <class _NodePtr>
inline _LIBCPP_INLINE_VISIBILITY
bool
__tree_is_left_child(_NodePtr __x) _NOEXCEPT
{
    return __x == __x->__parent_->__left_;
}

// Determines if the subtree rooted at __x is a proper red black subtree.  If
//    __x is a proper subtree, returns the black height (null counts as 1).  If
//    __x is an improper subtree, returns 0.
template <class _NodePtr>
unsigned
__tree_sub_invariant(_NodePtr __x)
{
    if (__x == nullptr)
        return 1;
    // parent consistency checked by caller
    // check __x->__left_ consistency
    if (__x->__left_ != nullptr && __x->__left_->__parent_ != __x)
        return 0;
    // check __x->__right_ consistency
    if (__x->__right_ != nullptr && __x->__right_->__parent_ != __x)
        return 0;
    // check __x->__left_ != __x->__right_ unless both are nullptr
    if (__x->__left_ == __x->__right_ && __x->__left_ != nullptr)
        return 0;
    // If this is red, neither child can be red
    if (!__x->__is_black_)
    {
        if (__x->__left_ && !__x->__left_->__is_black_)
            return 0;
        if (__x->__right_ && !__x->__right_->__is_black_)
            return 0;
    }
    unsigned __h = __tree_sub_invariant(__x->__left_);
    if (__h == 0)
        return 0;  // invalid left subtree
    if (__h != __tree_sub_invariant(__x->__right_))
        return 0;  // invalid or different height right subtree
    return __h + __x->__is_black_;  // return black height of this node
}

// Determines if the red black tree rooted at __root is a proper red black tree.
//    __root == nullptr is a proper tree.  Returns true is __root is a proper
//    red black tree, else returns false.
template <class _NodePtr>
bool
__tree_invariant(_NodePtr __root)
{
    if (__root == nullptr)
        return true;
    // check __x->__parent_ consistency
    if (__root->__parent_ == nullptr)
        return false;
    if (!__tree_is_left_child(__root))
        return false;
    // root must be black
    if (!__root->__is_black_)
        return false;
    // do normal node checks
    return __tree_sub_invariant(__root) != 0;
}

// Returns:  pointer to the left-most node under __x.
// Precondition:  __x != nullptr.
template <class _NodePtr>
inline _LIBCPP_INLINE_VISIBILITY
_NodePtr
__tree_min(_NodePtr __x) _NOEXCEPT
{
    while (__x->__left_ != nullptr)
        __x = __x->__left_;
    return __x;
}

// Returns:  pointer to the right-most node under __x.
// Precondition:  __x != nullptr.
template <class _NodePtr>
inline _LIBCPP_INLINE_VISIBILITY
_NodePtr
__tree_max(_NodePtr __x) _NOEXCEPT
{
    while (__x->__right_ != nullptr)
        __x = __x->__right_;
    return __x;
}

// Returns:  pointer to the next in-order node after __x.
// Precondition:  __x != nullptr.
template <class _NodePtr>
_NodePtr
__tree_next(_NodePtr __x) _NOEXCEPT
{
    if (__x->__right_ != nullptr)
        return __tree_min(__x->__right_);
    while (!__tree_is_left_child(__x))
        __x = __x->__parent_unsafe();
    return __x->__parent_unsafe();
}

template <class _EndNodePtr, class _NodePtr>
inline _LIBCPP_INLINE_VISIBILITY
_EndNodePtr
__tree_next_iter(_NodePtr __x) _NOEXCEPT
{
    if (__x->__right_ != nullptr)
        return static_cast<_EndNodePtr>(__tree_min(__x->__right_));
    while (!__tree_is_left_child(__x))
        __x = __x->__parent_unsafe();
    return static_cast<_EndNodePtr>(__x->__parent_);
}

// Returns:  pointer to the previous in-order node before __x.
// Precondition:  __x != nullptr.
// Note: __x may be the end node.
template <class _NodePtr, class _EndNodePtr>
inline _LIBCPP_INLINE_VISIBILITY
_NodePtr
__tree_prev_iter(_EndNodePtr __x) _NOEXCEPT
{
    if (__x->__left_ != nullptr)
        return __tree_max(__x->__left_);
    _NodePtr __xx = static_cast<_NodePtr>(__x);
    while (__tree_is_left_child(__xx))
        __xx = __xx->__parent_unsafe();
    return __xx->__parent_unsafe();
}

// Returns:  pointer to a node which has no children
// Precondition:  __x != nullptr.
template <class _NodePtr>
_NodePtr
__tree_leaf(_NodePtr __x) _NOEXCEPT
{
    while (true)
    {
        if (__x->__left_ != nullptr)
        {
            __x = __x->__left_;
            continue;
        }
        if (__x->__right_ != nullptr)
        {
            __x = __x->__right_;
            continue;
        }
        break;
    }
    return __x;
}

// Effects:  Makes __x->__right_ the subtree root with __x as its left child
//           while preserving in-order order.
// Precondition:  __x->__right_ != nullptr
template <class _NodePtr>
void
__tree_left_rotate(_NodePtr __x) _NOEXCEPT
{
    _NodePtr __y = __x->__right_;
    __x->__right_ = __y->__left_;
    if (__x->__right_ != nullptr)
        __x->__right_->__set_parent(__x);
    __y->__parent_ = __x->__parent_;
    if (__tree_is_left_child(__x))
        __x->__parent_->__left_ = __y;
    else
        __x->__parent_unsafe()->__right_ = __y;
    __y->__left_ = __x;
    __x->__set_parent(__y);
}

// Effects:  Makes __x->__left_ the subtree root with __x as its right child
//           while preserving in-order order.
// Precondition:  __x->__left_ != nullptr
template <class _NodePtr>
void
__tree_right_rotate(_NodePtr __x) _NOEXCEPT
{
    _NodePtr __y = __x->__left_;
    __x->__left_ = __y->__right_;
    if (__x->__left_ != nullptr)
        __x->__left_->__set_parent(__x);
    __y->__parent_ = __x->__parent_;
    if (__tree_is_left_child(__x))
        __x->__parent_->__left_ = __y;
    else
        __x->__parent_unsafe()->__right_ = __y;
    __y->__right_ = __x;
    __x->__set_parent(__y);
}

// Effects:  Rebalances __root after attaching __x to a leaf.
// Precondition:  __root != nulptr && __x != nullptr.
//                __x has no children.
//                __x == __root or == a direct or indirect child of __root.
//                If __x were to be unlinked from __root (setting __root to
//                  nullptr if __root == __x), __tree_invariant(__root) == true.
// Postcondition: __tree_invariant(end_node->__left_) == true.  end_node->__left_
//                may be different than the value passed in as __root.
template <class _NodePtr>
void
__tree_balance_after_insert(_NodePtr __root, _NodePtr __x) _NOEXCEPT
{
    __x->__is_black_ = __x == __root;
    while (__x != __root && !__x->__parent_unsafe()->__is_black_)
    {
        // __x->__parent_ != __root because __x->__parent_->__is_black == false
        if (__tree_is_left_child(__x->__parent_unsafe()))
        {
            _NodePtr __y = __x->__parent_unsafe()->__parent_unsafe()->__right_;
            if (__y != nullptr && !__y->__is_black_)
            {
                __x = __x->__parent_unsafe();
                __x->__is_black_ = true;
                __x = __x->__parent_unsafe();
                __x->__is_black_ = __x == __root;
                __y->__is_black_ = true;
            }
            else
            {
                if (!__tree_is_left_child(__x))
                {
                    __x = __x->__parent_unsafe();
                    __tree_left_rotate(__x);
                }
                __x = __x->__parent_unsafe();
                __x->__is_black_ = true;
                __x = __x->__parent_unsafe();
                __x->__is_black_ = false;
                __tree_right_rotate(__x);
                break;
            }
        }
        else
        {
            _NodePtr __y = __x->__parent_unsafe()->__parent_->__left_;
            if (__y != nullptr && !__y->__is_black_)
            {
                __x = __x->__parent_unsafe();
                __x->__is_black_ = true;
                __x = __x->__parent_unsafe();
                __x->__is_black_ = __x == __root;
                __y->__is_black_ = true;
            }
            else
            {
                if (__tree_is_left_child(__x))
                {
                    __x = __x->__parent_unsafe();
                    __tree_right_rotate(__x);
                }
                __x = __x->__parent_unsafe();
                __x->__is_black_ = true;
                __x = __x->__parent_unsafe();
                __x->__is_black_ = false;
                __tree_left_rotate(__x);
                break;
            }
        }
    }
}

// Precondition:  __root != nullptr && __z != nullptr.
//                __tree_invariant(__root) == true.
//                __z == __root or == a direct or indirect child of __root.
// Effects:  unlinks __z from the tree rooted at __root, rebalancing as needed.
// Postcondition: __tree_invariant(end_node->__left_) == true && end_node->__left_
//                nor any of its children refer to __z.  end_node->__left_
//                may be different than the value passed in as __root.
template <class _NodePtr>
void
__tree_remove(_NodePtr __root, _NodePtr __z) _NOEXCEPT
{
    // __z will be removed from the tree.  Client still needs to destruct/deallocate it
    // __y is either __z, or if __z has two children, __tree_next(__z).
    // __y will have at most one child.
    // __y will be the initial hole in the tree (make the hole at a leaf)
    _NodePtr __y = (__z->__left_ == nullptr || __z->__right_ == nullptr) ?
                    __z : __tree_next(__z);
    // __x is __y's possibly null single child
    _NodePtr __x = __y->__left_ != nullptr ? __y->__left_ : __y->__right_;
    // __w is __x's possibly null uncle (will become __x's sibling)
    _NodePtr __w = nullptr;
    // link __x to __y's parent, and find __w
    if (__x != nullptr)
        __x->__parent_ = __y->__parent_;
    if (__tree_is_left_child(__y))
    {
        __y->__parent_->__left_ = __x;
        if (__y != __root)
            __w = __y->__parent_unsafe()->__right_;
        else
            __root = __x;  // __w == nullptr
    }
    else
    {
        __y->__parent_unsafe()->__right_ = __x;
        // __y can't be root if it is a right child
        __w = __y->__parent_->__left_;
    }
    bool __removed_black = __y->__is_black_;
    // If we didn't remove __z, do so now by splicing in __y for __z,
    //    but copy __z's color.  This does not impact __x or __w.
    if (__y != __z)
    {
        // __z->__left_ != nulptr but __z->__right_ might == __x == nullptr
        __y->__parent_ = __z->__parent_;
        if (__tree_is_left_child(__z))
            __y->__parent_->__left_ = __y;
        else
            __y->__parent_unsafe()->__right_ = __y;
        __y->__left_ = __z->__left_;
        __y->__left_->__set_parent(__y);
        __y->__right_ = __z->__right_;
        if (__y->__right_ != nullptr)
            __y->__right_->__set_parent(__y);
        __y->__is_black_ = __z->__is_black_;
        if (__root == __z)
            __root = __y;
    }
    // There is no need to rebalance if we removed a red, or if we removed
    //     the last node.
    if (__removed_black && __root != nullptr)
    {
        // Rebalance:
        // __x has an implicit black color (transferred from the removed __y)
        //    associated with it, no matter what its color is.
        // If __x is __root (in which case it can't be null), it is supposed
        //    to be black anyway, and if it is doubly black, then the double
        //    can just be ignored.
        // If __x is red (in which case it can't be null), then it can absorb
        //    the implicit black just by setting its color to black.
        // Since __y was black and only had one child (which __x points to), __x
        //   is either red with no children, else null, otherwise __y would have
        //   different black heights under left and right pointers.
        // if (__x == __root || __x != nullptr && !__x->__is_black_)
        if (__x != nullptr)
            __x->__is_black_ = true;
        else
        {
            //  Else __x isn't root, and is "doubly black", even though it may
            //     be null.  __w can not be null here, else the parent would
            //     see a black height >= 2 on the __x side and a black height
            //     of 1 on the __w side (__w must be a non-null black or a red
            //     with a non-null black child).
            while (true)
            {
                if (!__tree_is_left_child(__w))  // if x is left child
                {
                    if (!__w->__is_black_)
                    {
                        __w->__is_black_ = true;
                        __w->__parent_unsafe()->__is_black_ = false;
                        __tree_left_rotate(__w->__parent_unsafe());
                        // __x is still valid
                        // reset __root only if necessary
                        if (__root == __w->__left_)
                            __root = __w;
                        // reset sibling, and it still can't be null
                        __w = __w->__left_->__right_;
                    }
                    // __w->__is_black_ is now true, __w may have null children
                    if ((__w->__left_  == nullptr || __w->__left_->__is_black_) &&
                        (__w->__right_ == nullptr || __w->__right_->__is_black_))
                    {
                        __w->__is_black_ = false;
                        __x = __w->__parent_unsafe();
                        // __x can no longer be null
                        if (__x == __root || !__x->__is_black_)
                        {
                            __x->__is_black_ = true;
                            break;
                        }
                        // reset sibling, and it still can't be null
                        __w = __tree_is_left_child(__x) ?
                                    __x->__parent_unsafe()->__right_ :
                                    __x->__parent_->__left_;
                        // continue;
                    }
                    else  // __w has a red child
                    {
                        if (__w->__right_ == nullptr || __w->__right_->__is_black_)
                        {
                            // __w left child is non-null and red
                            __w->__left_->__is_black_ = true;
                            __w->__is_black_ = false;
                            __tree_right_rotate(__w);
                            // __w is known not to be root, so root hasn't changed
                            // reset sibling, and it still can't be null
                            __w = __w->__parent_unsafe();
                        }
                        // __w has a right red child, left child may be null
                        __w->__is_black_ = __w->__parent_unsafe()->__is_black_;
                        __w->__parent_unsafe()->__is_black_ = true;
                        __w->__right_->__is_black_ = true;
                        __tree_left_rotate(__w->__parent_unsafe());
                        break;
                    }
                }
                else
                {
                    if (!__w->__is_black_)
                    {
                        __w->__is_black_ = true;
                        __w->__parent_unsafe()->__is_black_ = false;
                        __tree_right_rotate(__w->__parent_unsafe());
                        // __x is still valid
                        // reset __root only if necessary
                        if (__root == __w->__right_)
                            __root = __w;
                        // reset sibling, and it still can't be null
                        __w = __w->__right_->__left_;
                    }
                    // __w->__is_black_ is now true, __w may have null children
                    if ((__w->__left_  == nullptr || __w->__left_->__is_black_) &&
                        (__w->__right_ == nullptr || __w->__right_->__is_black_))
                    {
                        __w->__is_black_ = false;
                        __x = __w->__parent_unsafe();
                        // __x can no longer be null
                        if (!__x->__is_black_ || __x == __root)
                        {
                            __x->__is_black_ = true;
                            break;
                        }
                        // reset sibling, and it still can't be null
                        __w = __tree_is_left_child(__x) ?
                                    __x->__parent_unsafe()->__right_ :
                                    __x->__parent_->__left_;
                        // continue;
                    }
                    else  // __w has a red child
                    {
                        if (__w->__left_ == nullptr || __w->__left_->__is_black_)
                        {
                            // __w right child is non-null and red
                            __w->__right_->__is_black_ = true;
                            __w->__is_black_ = false;
                            __tree_left_rotate(__w);
                            // __w is known not to be root, so root hasn't changed
                            // reset sibling, and it still can't be null
                            __w = __w->__parent_unsafe();
                        }
                        // __w has a left red child, right child may be null
                        __w->__is_black_ = __w->__parent_unsafe()->__is_black_;
                        __w->__parent_unsafe()->__is_black_ = true;
                        __w->__left_->__is_black_ = true;
                        __tree_right_rotate(__w->__parent_unsafe());
                        break;
                    }
                }
            }
        }
    }
}

// node traits


#ifndef _LIBCPP_CXX03_LANG
template <class _Tp>
struct __is_tree_value_type_imp : false_type {};

template <class _Key, class _Value>
struct __is_tree_value_type_imp<__value_type<_Key, _Value>> : true_type {};

template <class ..._Args>
struct __is_tree_value_type : false_type {};

template <class _One>
struct __is_tree_value_type<_One> : __is_tree_value_type_imp<typename __uncvref<_One>::type> {};
#endif
# 549 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

template <class _Tp>
struct __tree_key_value_types {
  typedef _Tp key_type;
  typedef _Tp __node_value_type;
  typedef _Tp __container_value_type;
  static const bool __is_map = false;

  _LIBCPP_INLINE_VISIBILITY
  static key_type const& __get_key(_Tp const& __v) {
    return __v;
  }
  _LIBCPP_INLINE_VISIBILITY
  static __container_value_type const& __get_value(__node_value_type const& __v) {
    return __v;
  }
  _LIBCPP_INLINE_VISIBILITY
  static __container_value_type* __get_ptr(__node_value_type& __n) {
    return _VSTD::addressof(__n);
  }
#ifndef _LIBCPP_CXX03_LANG
  _LIBCPP_INLINE_VISIBILITY
  static __container_value_type&& __move(__node_value_type& __v) {
    return _VSTD::move(__v);
  }
#endif
# 575 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
};

template <class _Key, class _Tp>
struct __tree_key_value_types<__value_type<_Key, _Tp> > {
  typedef _Key                                         key_type;
  typedef _Tp                                          mapped_type;
  typedef __value_type<_Key, _Tp>                      __node_value_type;
  typedef pair<const _Key, _Tp>                        __container_value_type;
  typedef __container_value_type                       __map_value_type;
  static const bool __is_map = true;

  _LIBCPP_INLINE_VISIBILITY
  static key_type const&
  __get_key(__node_value_type const& __t) {
    return __t.__get_value().first;
  }

  template <class _Up>
  _LIBCPP_INLINE_VISIBILITY
  static typename enable_if<__is_same_uncvref<_Up, __container_value_type>::value,
      key_type const&>::type
  __get_key(_Up& __t) {
    return __t.first;
  }

  _LIBCPP_INLINE_VISIBILITY
  static __container_value_type const&
  __get_value(__node_value_type const& __t) {
    return __t.__get_value();
  }

  template <class _Up>
  _LIBCPP_INLINE_VISIBILITY
  static typename enable_if<__is_same_uncvref<_Up, __container_value_type>::value,
      __container_value_type const&>::type
  __get_value(_Up& __t) {
    return __t;
  }

  _LIBCPP_INLINE_VISIBILITY
  static __container_value_type* __get_ptr(__node_value_type& __n) {
    return _VSTD::addressof(__n.__get_value());
  }

#ifndef _LIBCPP_CXX03_LANG
  _LIBCPP_INLINE_VISIBILITY
  static pair<key_type&&, mapped_type&&> __move(__node_value_type& __v) {
    return __v.__move();
  }
#endif
# 625 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
};

template <class _VoidPtr>
struct __tree_node_base_types {
  typedef _VoidPtr                                               __void_pointer;

  typedef __tree_node_base<__void_pointer>                      __node_base_type;
  typedef typename __rebind_pointer<_VoidPtr, __node_base_type>::type
                                                             __node_base_pointer;

  typedef __tree_end_node<__node_base_pointer>                  __end_node_type;
  typedef typename __rebind_pointer<_VoidPtr, __end_node_type>::type
                                                             __end_node_pointer;
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_TREE_REMOVE_NODE_POINTER_UB)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 639 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
  typedef __end_node_pointer __parent_pointer;
#else
# 641 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
  typedef typename conditional<
      is_pointer<__end_node_pointer>::value,
        __end_node_pointer,
        __node_base_pointer>::type __parent_pointer;
#endif
# 646 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

private:
  static_assert((is_same<typename pointer_traits<_VoidPtr>::element_type, void>::value),
                  "_VoidPtr does not point to unqualified void type");
};

template <class _Tp, class _AllocPtr, class _KVTypes = __tree_key_value_types<_Tp>,
         bool = _KVTypes::__is_map>
struct __tree_map_pointer_types {};

template <class _Tp, class _AllocPtr, class _KVTypes>
struct __tree_map_pointer_types<_Tp, _AllocPtr, _KVTypes, true> {
  typedef typename _KVTypes::__map_value_type   _Mv;
  typedef typename __rebind_pointer<_AllocPtr, _Mv>::type
                                                       __map_value_type_pointer;
  typedef typename __rebind_pointer<_AllocPtr, const _Mv>::type
                                                 __const_map_value_type_pointer;
};

template <class _NodePtr, class _NodeT = typename pointer_traits<_NodePtr>::element_type>
struct __tree_node_types;

template <class _NodePtr, class _Tp, class _VoidPtr>
struct __tree_node_types<_NodePtr, __tree_node<_Tp, _VoidPtr> >
    : public __tree_node_base_types<_VoidPtr>,
             __tree_key_value_types<_Tp>,
             __tree_map_pointer_types<_Tp, _VoidPtr>
{
  typedef __tree_node_base_types<_VoidPtr> __base;
  typedef __tree_key_value_types<_Tp>      __key_base;
  typedef __tree_map_pointer_types<_Tp, _VoidPtr> __map_pointer_base;
public:

  typedef typename pointer_traits<_NodePtr>::element_type       __node_type;
  typedef _NodePtr                                              __node_pointer;

  typedef _Tp                                                 __node_value_type;
  typedef typename __rebind_pointer<_VoidPtr, __node_value_type>::type
                                                      __node_value_type_pointer;
  typedef typename __rebind_pointer<_VoidPtr, const __node_value_type>::type
                                                __const_node_value_type_pointer;
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_ABI_TREE_REMOVE_NODE_POINTER_UB)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 688 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
  typedef typename __base::__end_node_pointer __iter_pointer;
#else
# 690 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
  typedef typename conditional<
      is_pointer<__node_pointer>::value,
        typename __base::__end_node_pointer,
        __node_pointer>::type __iter_pointer;
#endif
# 695 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
private:
    static_assert(!is_const<__node_type>::value,
                "_NodePtr should never be a pointer to const");
    static_assert((is_same<typename __rebind_pointer<_VoidPtr, __node_type>::type,
                          _NodePtr>::value), "_VoidPtr does not rebind to _NodePtr.");
};

template <class _ValueTp, class _VoidPtr>
struct __make_tree_node_types {
  typedef typename __rebind_pointer<_VoidPtr, __tree_node<_ValueTp, _VoidPtr> >::type
                                                                        _NodePtr;
  typedef __tree_node_types<_NodePtr> type;
};

// node

template <class _Pointer>
class __tree_end_node
{
public:
    typedef _Pointer pointer;
    pointer __left_;

    _LIBCPP_INLINE_VISIBILITY
    __tree_end_node() _NOEXCEPT : __left_() {}
};

template <class _VoidPtr>
class __tree_node_base
    : public __tree_node_base_types<_VoidPtr>::__end_node_type
{
    typedef __tree_node_base_types<_VoidPtr> _NodeBaseTypes;

public:
    typedef typename _NodeBaseTypes::__node_base_pointer pointer;
    typedef typename _NodeBaseTypes::__parent_pointer __parent_pointer;

    pointer          __right_;
    __parent_pointer __parent_;
    bool __is_black_;

    _LIBCPP_INLINE_VISIBILITY
    pointer __parent_unsafe() const { return static_cast<pointer>(__parent_);}

    _LIBCPP_INLINE_VISIBILITY
    void __set_parent(pointer __p) {
        __parent_ = static_cast<__parent_pointer>(__p);
    }

private:
  ~__tree_node_base() _LIBCPP_EQUAL_DELETE;
  __tree_node_base(__tree_node_base const&) _LIBCPP_EQUAL_DELETE;
  __tree_node_base& operator=(__tree_node_base const&) _LIBCPP_EQUAL_DELETE;
};

template <class _Tp, class _VoidPtr>
class __tree_node
    : public __tree_node_base<_VoidPtr>
{
public:
    typedef _Tp __node_value_type;

    __node_value_type __value_;

private:
  ~__tree_node() _LIBCPP_EQUAL_DELETE;
  __tree_node(__tree_node const&) _LIBCPP_EQUAL_DELETE;
  __tree_node& operator=(__tree_node const&) _LIBCPP_EQUAL_DELETE;
};


template <class _Allocator>
class __tree_node_destructor
{
    typedef _Allocator                                      allocator_type;
    typedef allocator_traits<allocator_type>                __alloc_traits;

public:
    typedef typename __alloc_traits::pointer                pointer;
private:
    typedef __tree_node_types<pointer> _NodeTypes;
    allocator_type& __na_;


public:
    bool __value_constructed;


    __tree_node_destructor(const __tree_node_destructor &) = default;
    __tree_node_destructor& operator=(const __tree_node_destructor&) = delete;

    _LIBCPP_INLINE_VISIBILITY
    explicit __tree_node_destructor(allocator_type& __na, bool __val = false) _NOEXCEPT
        : __na_(__na),
          __value_constructed(__val)
        {}

    _LIBCPP_INLINE_VISIBILITY
    void operator()(pointer __p) _NOEXCEPT
    {
        if (__value_constructed)
            __alloc_traits::destroy(__na_, _NodeTypes::__get_ptr(__p->__value_));
        if (__p)
            __alloc_traits::deallocate(__na_, __p, 1);
    }

    template <class> friend class __map_node_destructor;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 805 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
template <class _NodeType, class _Alloc>
struct __generic_container_node_destructor;
template <class _Tp, class _VoidPtr, class _Alloc>
struct __generic_container_node_destructor<__tree_node<_Tp, _VoidPtr>, _Alloc>
    : __tree_node_destructor<_Alloc>
{
    using __tree_node_destructor<_Alloc>::__tree_node_destructor;
};
#endif
# 814 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

template <class _Tp, class _NodePtr, class _DiffType>
class _LIBCPP_TEMPLATE_VIS __tree_iterator
{
    typedef __tree_node_types<_NodePtr>                     _NodeTypes;
    typedef _NodePtr                                        __node_pointer;
    typedef typename _NodeTypes::__node_base_pointer        __node_base_pointer;
    typedef typename _NodeTypes::__end_node_pointer         __end_node_pointer;
    typedef typename _NodeTypes::__iter_pointer             __iter_pointer;
    typedef pointer_traits<__node_pointer> __pointer_traits;

    __iter_pointer __ptr_;

public:
    typedef bidirectional_iterator_tag                     iterator_category;
    typedef _Tp                                            value_type;
    typedef _DiffType                                      difference_type;
    typedef value_type&                                    reference;
    typedef typename _NodeTypes::__node_value_type_pointer pointer;

    _LIBCPP_INLINE_VISIBILITY __tree_iterator() _NOEXCEPT
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 836 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
    : __ptr_(nullptr)
#endif
# 838 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
    {}

    _LIBCPP_INLINE_VISIBILITY reference operator*() const
        {return __get_np()->__value_;}
    _LIBCPP_INLINE_VISIBILITY pointer operator->() const
        {return pointer_traits<pointer>::pointer_to(__get_np()->__value_);}

    _LIBCPP_INLINE_VISIBILITY
    __tree_iterator& operator++() {
      __ptr_ = static_cast<__iter_pointer>(
          __tree_next_iter<__end_node_pointer>(static_cast<__node_base_pointer>(__ptr_)));
      return *this;
    }
    _LIBCPP_INLINE_VISIBILITY
    __tree_iterator operator++(int)
        {__tree_iterator __t(*this); ++(*this); return __t;}

    _LIBCPP_INLINE_VISIBILITY
    __tree_iterator& operator--() {
      __ptr_ = static_cast<__iter_pointer>(__tree_prev_iter<__node_base_pointer>(
          static_cast<__end_node_pointer>(__ptr_)));
      return *this;
    }
    _LIBCPP_INLINE_VISIBILITY
    __tree_iterator operator--(int)
        {__tree_iterator __t(*this); --(*this); return __t;}

    friend _LIBCPP_INLINE_VISIBILITY
        bool operator==(const __tree_iterator& __x, const __tree_iterator& __y)
        {return __x.__ptr_ == __y.__ptr_;}
    friend _LIBCPP_INLINE_VISIBILITY
        bool operator!=(const __tree_iterator& __x, const __tree_iterator& __y)
        {return !(__x == __y);}

private:
    _LIBCPP_INLINE_VISIBILITY
    explicit __tree_iterator(__node_pointer __p) _NOEXCEPT : __ptr_(__p) {}
    _LIBCPP_INLINE_VISIBILITY
    explicit __tree_iterator(__end_node_pointer __p) _NOEXCEPT : __ptr_(__p) {}
    _LIBCPP_INLINE_VISIBILITY
    __node_pointer __get_np() const { return static_cast<__node_pointer>(__ptr_); }
    template <class, class, class> friend class __tree;
    template <class, class, class> friend class _LIBCPP_TEMPLATE_VIS __tree_const_iterator;
    template <class> friend class _LIBCPP_TEMPLATE_VIS __map_iterator;
    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS map;
    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS multimap;
    template <class, class, class> friend class _LIBCPP_TEMPLATE_VIS set;
    template <class, class, class> friend class _LIBCPP_TEMPLATE_VIS multiset;
};

template <class _Tp, class _NodePtr, class _DiffType>
class _LIBCPP_TEMPLATE_VIS __tree_const_iterator
{
    typedef __tree_node_types<_NodePtr>                     _NodeTypes;
    typedef typename _NodeTypes::__node_pointer             __node_pointer;
    typedef typename _NodeTypes::__node_base_pointer        __node_base_pointer;
    typedef typename _NodeTypes::__end_node_pointer         __end_node_pointer;
    typedef typename _NodeTypes::__iter_pointer             __iter_pointer;
    typedef pointer_traits<__node_pointer> __pointer_traits;

    __iter_pointer __ptr_;

public:
    typedef bidirectional_iterator_tag                           iterator_category;
    typedef _Tp                                                  value_type;
    typedef _DiffType                                            difference_type;
    typedef const value_type&                                    reference;
    typedef typename _NodeTypes::__const_node_value_type_pointer pointer;

    _LIBCPP_INLINE_VISIBILITY __tree_const_iterator() _NOEXCEPT
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 909 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
    : __ptr_(nullptr)
#endif
# 911 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
    {}

private:
    typedef __tree_iterator<value_type, __node_pointer, difference_type>
                                                           __non_const_iterator;
public:
    _LIBCPP_INLINE_VISIBILITY
    __tree_const_iterator(__non_const_iterator __p) _NOEXCEPT
        : __ptr_(__p.__ptr_) {}

    _LIBCPP_INLINE_VISIBILITY reference operator*() const
        {return __get_np()->__value_;}
    _LIBCPP_INLINE_VISIBILITY pointer operator->() const
        {return pointer_traits<pointer>::pointer_to(__get_np()->__value_);}

    _LIBCPP_INLINE_VISIBILITY
    __tree_const_iterator& operator++() {
      __ptr_ = static_cast<__iter_pointer>(
          __tree_next_iter<__end_node_pointer>(static_cast<__node_base_pointer>(__ptr_)));
      return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __tree_const_iterator operator++(int)
        {__tree_const_iterator __t(*this); ++(*this); return __t;}

    _LIBCPP_INLINE_VISIBILITY
    __tree_const_iterator& operator--() {
      __ptr_ = static_cast<__iter_pointer>(__tree_prev_iter<__node_base_pointer>(
          static_cast<__end_node_pointer>(__ptr_)));
      return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __tree_const_iterator operator--(int)
        {__tree_const_iterator __t(*this); --(*this); return __t;}

    friend _LIBCPP_INLINE_VISIBILITY
        bool operator==(const __tree_const_iterator& __x, const __tree_const_iterator& __y)
        {return __x.__ptr_ == __y.__ptr_;}
    friend _LIBCPP_INLINE_VISIBILITY
        bool operator!=(const __tree_const_iterator& __x, const __tree_const_iterator& __y)
        {return !(__x == __y);}

private:
    _LIBCPP_INLINE_VISIBILITY
    explicit __tree_const_iterator(__node_pointer __p) _NOEXCEPT
        : __ptr_(__p) {}
    _LIBCPP_INLINE_VISIBILITY
    explicit __tree_const_iterator(__end_node_pointer __p) _NOEXCEPT
        : __ptr_(__p) {}
    _LIBCPP_INLINE_VISIBILITY
    __node_pointer __get_np() const { return static_cast<__node_pointer>(__ptr_); }

    template <class, class, class> friend class __tree;
    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS map;
    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS multimap;
    template <class, class, class> friend class _LIBCPP_TEMPLATE_VIS set;
    template <class, class, class> friend class _LIBCPP_TEMPLATE_VIS multiset;
    template <class> friend class _LIBCPP_TEMPLATE_VIS __map_const_iterator;

};

template<class _Tp, class _Compare>
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_DIAGNOSE_WARNING(!std::__invokable<_Compare const&, _Tp const&, _Tp const&>::value,
        "the specified comparator type does not provide a viable const call operator")
#endif
# 979 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
int __diagnose_non_const_comparator();

template <class _Tp, class _Compare, class _Allocator>
class __tree
{
public:
    typedef _Tp                                      value_type;
    typedef _Compare                                 value_compare;
    typedef _Allocator                               allocator_type;

private:
    typedef allocator_traits<allocator_type>         __alloc_traits;
    typedef typename __make_tree_node_types<value_type,
        typename __alloc_traits::void_pointer>::type
                                                    _NodeTypes;
    typedef typename _NodeTypes::key_type           key_type;
public:
    typedef typename _NodeTypes::__node_value_type      __node_value_type;
    typedef typename _NodeTypes::__container_value_type __container_value_type;

    typedef typename __alloc_traits::pointer         pointer;
    typedef typename __alloc_traits::const_pointer   const_pointer;
    typedef typename __alloc_traits::size_type       size_type;
    typedef typename __alloc_traits::difference_type difference_type;

public:
    typedef typename _NodeTypes::__void_pointer        __void_pointer;

    typedef typename _NodeTypes::__node_type           __node;
    typedef typename _NodeTypes::__node_pointer        __node_pointer;

    typedef typename _NodeTypes::__node_base_type      __node_base;
    typedef typename _NodeTypes::__node_base_pointer   __node_base_pointer;

    typedef typename _NodeTypes::__end_node_type       __end_node_t;
    typedef typename _NodeTypes::__end_node_pointer    __end_node_ptr;

    typedef typename _NodeTypes::__parent_pointer      __parent_pointer;
    typedef typename _NodeTypes::__iter_pointer        __iter_pointer;

    typedef typename __rebind_alloc_helper<__alloc_traits, __node>::type __node_allocator;
    typedef allocator_traits<__node_allocator>         __node_traits;

private:
    // check for sane allocator pointer rebinding semantics. Rebinding the
    // allocator for a new pointer type should be exactly the same as rebinding
    // the pointer using 'pointer_traits'.
    static_assert((is_same<__node_pointer, typename __node_traits::pointer>::value),
                  "Allocator does not rebind pointers in a sane manner.");
    typedef typename __rebind_alloc_helper<__node_traits, __node_base>::type
        __node_base_allocator;
    typedef allocator_traits<__node_base_allocator> __node_base_traits;
    static_assert((is_same<__node_base_pointer, typename __node_base_traits::pointer>::value),
                 "Allocator does not rebind pointers in a sane manner.");

private:
    __iter_pointer                                     __begin_node_;
    __compressed_pair<__end_node_t, __node_allocator>  __pair1_;
    __compressed_pair<size_type, value_compare>        __pair3_;

public:
    _LIBCPP_INLINE_VISIBILITY
    __iter_pointer __end_node() _NOEXCEPT
    {
        return static_cast<__iter_pointer>(
                pointer_traits<__end_node_ptr>::pointer_to(__pair1_.first())
        );
    }
    _LIBCPP_INLINE_VISIBILITY
    __iter_pointer __end_node() const _NOEXCEPT
    {
        return static_cast<__iter_pointer>(
            pointer_traits<__end_node_ptr>::pointer_to(
                const_cast<__end_node_t&>(__pair1_.first())
            )
        );
    }
    _LIBCPP_INLINE_VISIBILITY
          __node_allocator& __node_alloc() _NOEXCEPT {return __pair1_.second();}
private:
    _LIBCPP_INLINE_VISIBILITY
    const __node_allocator& __node_alloc() const _NOEXCEPT
        {return __pair1_.second();}
    _LIBCPP_INLINE_VISIBILITY
          __iter_pointer& __begin_node() _NOEXCEPT {return __begin_node_;}
    _LIBCPP_INLINE_VISIBILITY
    const __iter_pointer& __begin_node() const _NOEXCEPT {return __begin_node_;}
public:
    _LIBCPP_INLINE_VISIBILITY
    allocator_type __alloc() const _NOEXCEPT
        {return allocator_type(__node_alloc());}
private:
    _LIBCPP_INLINE_VISIBILITY
          size_type& size() _NOEXCEPT {return __pair3_.first();}
public:
    _LIBCPP_INLINE_VISIBILITY
    const size_type& size() const _NOEXCEPT {return __pair3_.first();}
    _LIBCPP_INLINE_VISIBILITY
          value_compare& value_comp() _NOEXCEPT {return __pair3_.second();}
    _LIBCPP_INLINE_VISIBILITY
    const value_compare& value_comp() const _NOEXCEPT
        {return __pair3_.second();}
public:

    _LIBCPP_INLINE_VISIBILITY
    __node_pointer __root() const _NOEXCEPT
        {return static_cast<__node_pointer>(__end_node()->__left_);}

    __node_base_pointer* __root_ptr() const _NOEXCEPT {
        return _VSTD::addressof(__end_node()->__left_);
    }

    typedef __tree_iterator<value_type, __node_pointer, difference_type>             iterator;
    typedef __tree_const_iterator<value_type, __node_pointer, difference_type> const_iterator;

    explicit __tree(const value_compare& __comp)
        _NOEXCEPT_(
            is_nothrow_default_constructible<__node_allocator>::value &&
            is_nothrow_copy_constructible<value_compare>::value);
    explicit __tree(const allocator_type& __a);
    __tree(const value_compare& __comp, const allocator_type& __a);
    __tree(const __tree& __t);
    __tree& operator=(const __tree& __t);
    template <class _ForwardIterator>
        void __assign_unique(_ForwardIterator __first, _ForwardIterator __last);
    template <class _InputIterator>
        void __assign_multi(_InputIterator __first, _InputIterator __last);
#ifndef _LIBCPP_CXX03_LANG
    __tree(__tree&& __t)
        _NOEXCEPT_(
            is_nothrow_move_constructible<__node_allocator>::value &&
            is_nothrow_move_constructible<value_compare>::value);
    __tree(__tree&& __t, const allocator_type& __a);
    __tree& operator=(__tree&& __t)
        _NOEXCEPT_(
            __node_traits::propagate_on_container_move_assignment::value &&
            is_nothrow_move_assignable<value_compare>::value &&
            is_nothrow_move_assignable<__node_allocator>::value);
#endif // _LIBCPP_CXX03_LANG
# 1118 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

    ~__tree();

    _LIBCPP_INLINE_VISIBILITY
          iterator begin()  _NOEXCEPT {return       iterator(__begin_node());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT {return const_iterator(__begin_node());}
    _LIBCPP_INLINE_VISIBILITY
          iterator end() _NOEXCEPT {return       iterator(__end_node());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT {return const_iterator(__end_node());}

    _LIBCPP_INLINE_VISIBILITY
    size_type max_size() const _NOEXCEPT
        {return std::min<size_type>(
                __node_traits::max_size(__node_alloc()),
                numeric_limits<difference_type >::max());}

    void clear() _NOEXCEPT;

    void swap(__tree& __t)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 11
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1140 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
        _NOEXCEPT_(
            __is_nothrow_swappable<value_compare>::value
            && (!__node_traits::propagate_on_container_swap::value ||
                 __is_nothrow_swappable<__node_allocator>::value)
            );
#else
# 1146 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
        _NOEXCEPT_(__is_nothrow_swappable<value_compare>::value);
#endif
# 1148 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

#ifndef _LIBCPP_CXX03_LANG
    template <class _Key, class ..._Args>
    pair<iterator, bool>
    __emplace_unique_key_args(_Key const&, _Args&&... __args);
    template <class _Key, class ..._Args>
    iterator
    __emplace_hint_unique_key_args(const_iterator, _Key const&, _Args&&...);

    template <class... _Args>
    pair<iterator, bool> __emplace_unique_impl(_Args&&... __args);

    template <class... _Args>
    iterator __emplace_hint_unique_impl(const_iterator __p, _Args&&... __args);

    template <class... _Args>
    iterator __emplace_multi(_Args&&... __args);

    template <class... _Args>
    iterator __emplace_hint_multi(const_iterator __p, _Args&&... __args);

    template <class _Pp>
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool> __emplace_unique(_Pp&& __x) {
        return __emplace_unique_extract_key(_VSTD::forward<_Pp>(__x),
                                            __can_extract_key<_Pp, key_type>());
    }

    template <class _First, class _Second>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<
        __can_extract_map_key<_First, key_type, __container_value_type>::value,
        pair<iterator, bool>
    >::type __emplace_unique(_First&& __f, _Second&& __s) {
        return __emplace_unique_key_args(__f, _VSTD::forward<_First>(__f),
                                              _VSTD::forward<_Second>(__s));
    }

    template <class... _Args>
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool> __emplace_unique(_Args&&... __args) {
        return __emplace_unique_impl(_VSTD::forward<_Args>(__args)...);
    }

    template <class _Pp>
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool>
    __emplace_unique_extract_key(_Pp&& __x, __extract_key_fail_tag) {
      return __emplace_unique_impl(_VSTD::forward<_Pp>(__x));
    }

    template <class _Pp>
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool>
    __emplace_unique_extract_key(_Pp&& __x, __extract_key_self_tag) {
      return __emplace_unique_key_args(__x, _VSTD::forward<_Pp>(__x));
    }

    template <class _Pp>
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool>
    __emplace_unique_extract_key(_Pp&& __x, __extract_key_first_tag) {
      return __emplace_unique_key_args(__x.first, _VSTD::forward<_Pp>(__x));
    }

    template <class _Pp>
    _LIBCPP_INLINE_VISIBILITY
    iterator __emplace_hint_unique(const_iterator __p, _Pp&& __x) {
        return __emplace_hint_unique_extract_key(__p, _VSTD::forward<_Pp>(__x),
                                            __can_extract_key<_Pp, key_type>());
    }

    template <class _First, class _Second>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<
        __can_extract_map_key<_First, key_type, __container_value_type>::value,
        iterator
    >::type __emplace_hint_unique(const_iterator __p, _First&& __f, _Second&& __s) {
        return __emplace_hint_unique_key_args(__p, __f,
                                              _VSTD::forward<_First>(__f),
                                              _VSTD::forward<_Second>(__s));
    }

    template <class... _Args>
    _LIBCPP_INLINE_VISIBILITY
    iterator __emplace_hint_unique(const_iterator __p, _Args&&... __args) {
        return __emplace_hint_unique_impl(__p, _VSTD::forward<_Args>(__args)...);
    }

    template <class _Pp>
    _LIBCPP_INLINE_VISIBILITY
    iterator
    __emplace_hint_unique_extract_key(const_iterator __p, _Pp&& __x, __extract_key_fail_tag) {
      return __emplace_hint_unique_impl(__p, _VSTD::forward<_Pp>(__x));
    }

    template <class _Pp>
    _LIBCPP_INLINE_VISIBILITY
    iterator
    __emplace_hint_unique_extract_key(const_iterator __p, _Pp&& __x, __extract_key_self_tag) {
      return __emplace_hint_unique_key_args(__p, __x, _VSTD::forward<_Pp>(__x));
    }

    template <class _Pp>
    _LIBCPP_INLINE_VISIBILITY
    iterator
    __emplace_hint_unique_extract_key(const_iterator __p, _Pp&& __x, __extract_key_first_tag) {
      return __emplace_hint_unique_key_args(__p, __x.first, _VSTD::forward<_Pp>(__x));
    }

#else
# 1259 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
    template <class _Key, class _Args>
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool> __emplace_unique_key_args(_Key const&, _Args& __args);
    template <class _Key, class _Args>
    _LIBCPP_INLINE_VISIBILITY
    iterator __emplace_hint_unique_key_args(const_iterator, _Key const&, _Args&);
#endif
# 1266 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool> __insert_unique(const __container_value_type& __v) {
        return __emplace_unique_key_args(_NodeTypes::__get_key(__v), __v);
    }

    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_unique(const_iterator __p, const __container_value_type& __v) {
        return __emplace_hint_unique_key_args(__p, _NodeTypes::__get_key(__v), __v);
    }

#ifdef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_multi(const __container_value_type& __v);
    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_multi(const_iterator __p, const __container_value_type& __v);
#else
# 1283 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool> __insert_unique(__container_value_type&& __v) {
        return __emplace_unique_key_args(_NodeTypes::__get_key(__v), _VSTD::move(__v));
    }

    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_unique(const_iterator __p, __container_value_type&& __v) {
        return __emplace_hint_unique_key_args(__p, _NodeTypes::__get_key(__v), _VSTD::move(__v));
    }

    template <class _Vp, class = typename enable_if<
            !is_same<typename __unconstref<_Vp>::type,
                     __container_value_type
            >::value
        >::type>
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool> __insert_unique(_Vp&& __v) {
        return __emplace_unique(_VSTD::forward<_Vp>(__v));
    }

    template <class _Vp, class = typename enable_if<
            !is_same<typename __unconstref<_Vp>::type,
                     __container_value_type
            >::value
        >::type>
    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_unique(const_iterator __p, _Vp&& __v) {
        return __emplace_hint_unique(__p, _VSTD::forward<_Vp>(__v));
    }

    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_multi(__container_value_type&& __v) {
        return __emplace_multi(_VSTD::move(__v));
    }

    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_multi(const_iterator __p, __container_value_type&& __v) {
        return __emplace_hint_multi(__p, _VSTD::move(__v));
    }

    template <class _Vp>
    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_multi(_Vp&& __v) {
        return __emplace_multi(_VSTD::forward<_Vp>(__v));
    }

    template <class _Vp>
    _LIBCPP_INLINE_VISIBILITY
    iterator __insert_multi(const_iterator __p, _Vp&& __v) {
        return __emplace_hint_multi(__p, _VSTD::forward<_Vp>(__v));
    }

#endif // !_LIBCPP_CXX03_LANG
# 1336 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool> __node_assign_unique(const __container_value_type& __v, __node_pointer __dest);

    _LIBCPP_INLINE_VISIBILITY
    iterator __node_insert_multi(__node_pointer __nd);
    _LIBCPP_INLINE_VISIBILITY
    iterator __node_insert_multi(const_iterator __p, __node_pointer __nd);


    _LIBCPP_INLINE_VISIBILITY iterator
    __remove_node_pointer(__node_pointer) _NOEXCEPT;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1350 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
    template <class _NodeHandle, class _InsertReturnType>
    _LIBCPP_INLINE_VISIBILITY
    _InsertReturnType __node_handle_insert_unique(_NodeHandle&&);
    template <class _NodeHandle>
    _LIBCPP_INLINE_VISIBILITY
    iterator __node_handle_insert_unique(const_iterator, _NodeHandle&&);
    template <class _Tree>
    _LIBCPP_INLINE_VISIBILITY
    void __node_handle_merge_unique(_Tree& __source);

    template <class _NodeHandle>
    _LIBCPP_INLINE_VISIBILITY
    iterator __node_handle_insert_multi(_NodeHandle&&);
    template <class _NodeHandle>
    _LIBCPP_INLINE_VISIBILITY
    iterator __node_handle_insert_multi(const_iterator, _NodeHandle&&);
    template <class _Tree>
    _LIBCPP_INLINE_VISIBILITY
    void __node_handle_merge_multi(_Tree& __source);


    template <class _NodeHandle>
    _LIBCPP_INLINE_VISIBILITY
    _NodeHandle __node_handle_extract(key_type const&);
    template <class _NodeHandle>
    _LIBCPP_INLINE_VISIBILITY
    _NodeHandle __node_handle_extract(const_iterator);
#endif
# 1378 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

    iterator erase(const_iterator __p);
    iterator erase(const_iterator __f, const_iterator __l);
    template <class _Key>
        size_type __erase_unique(const _Key& __k);
    template <class _Key>
        size_type __erase_multi(const _Key& __k);

    void __insert_node_at(__parent_pointer     __parent,
                          __node_base_pointer& __child,
                          __node_base_pointer __new_node) _NOEXCEPT;

    template <class _Key>
        iterator find(const _Key& __v);
    template <class _Key>
        const_iterator find(const _Key& __v) const;

    template <class _Key>
        size_type __count_unique(const _Key& __k) const;
    template <class _Key>
        size_type __count_multi(const _Key& __k) const;

    template <class _Key>
        _LIBCPP_INLINE_VISIBILITY
        iterator lower_bound(const _Key& __v)
            {return __lower_bound(__v, __root(), __end_node());}
    template <class _Key>
        iterator __lower_bound(const _Key& __v,
                               __node_pointer __root,
                               __iter_pointer __result);
    template <class _Key>
        _LIBCPP_INLINE_VISIBILITY
        const_iterator lower_bound(const _Key& __v) const
            {return __lower_bound(__v, __root(), __end_node());}
    template <class _Key>
        const_iterator __lower_bound(const _Key& __v,
                                     __node_pointer __root,
                                     __iter_pointer __result) const;
    template <class _Key>
        _LIBCPP_INLINE_VISIBILITY
        iterator upper_bound(const _Key& __v)
            {return __upper_bound(__v, __root(), __end_node());}
    template <class _Key>
        iterator __upper_bound(const _Key& __v,
                               __node_pointer __root,
                               __iter_pointer __result);
    template <class _Key>
        _LIBCPP_INLINE_VISIBILITY
        const_iterator upper_bound(const _Key& __v) const
            {return __upper_bound(__v, __root(), __end_node());}
    template <class _Key>
        const_iterator __upper_bound(const _Key& __v,
                                     __node_pointer __root,
                                     __iter_pointer __result) const;
    template <class _Key>
        pair<iterator, iterator>
        __equal_range_unique(const _Key& __k);
    template <class _Key>
        pair<const_iterator, const_iterator>
        __equal_range_unique(const _Key& __k) const;

    template <class _Key>
        pair<iterator, iterator>
        __equal_range_multi(const _Key& __k);
    template <class _Key>
        pair<const_iterator, const_iterator>
        __equal_range_multi(const _Key& __k) const;

    typedef __tree_node_destructor<__node_allocator> _Dp;
    typedef unique_ptr<__node, _Dp> __node_holder;

    __node_holder remove(const_iterator __p) _NOEXCEPT;
private:
    __node_base_pointer&
        __find_leaf_low(__parent_pointer& __parent, const key_type& __v);
    __node_base_pointer&
        __find_leaf_high(__parent_pointer& __parent, const key_type& __v);
    __node_base_pointer&
        __find_leaf(const_iterator __hint,
                    __parent_pointer& __parent, const key_type& __v);
    // FIXME: Make this function const qualified. Unfortunetly doing so
    // breaks existing code which uses non-const callable comparators.
    template <class _Key>
    __node_base_pointer&
        __find_equal(__parent_pointer& __parent, const _Key& __v);
    template <class _Key>
    _LIBCPP_INLINE_VISIBILITY __node_base_pointer&
    __find_equal(__parent_pointer& __parent, const _Key& __v) const {
      return const_cast<__tree*>(this)->__find_equal(__parent, __v);
    }
    template <class _Key>
    __node_base_pointer&
        __find_equal(const_iterator __hint, __parent_pointer& __parent,
                     __node_base_pointer& __dummy,
                     const _Key& __v);

#ifndef _LIBCPP_CXX03_LANG
    template <class ..._Args>
    __node_holder __construct_node(_Args&& ...__args);
#else
# 1478 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
    __node_holder __construct_node(const __container_value_type& __v);
#endif
# 1480 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

    void destroy(__node_pointer __nd) _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __tree& __t)
        {__copy_assign_alloc(__t, integral_constant<bool,
             __node_traits::propagate_on_container_copy_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __tree& __t, true_type)
        {
        if (__node_alloc() != __t.__node_alloc())
            clear();
        __node_alloc() = __t.__node_alloc();
        }
    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const __tree&, false_type) {}

    void __move_assign(__tree& __t, false_type);
    void __move_assign(__tree& __t, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<value_compare>::value &&
                   is_nothrow_move_assignable<__node_allocator>::value);

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__tree& __t)
        _NOEXCEPT_(
            !__node_traits::propagate_on_container_move_assignment::value ||
            is_nothrow_move_assignable<__node_allocator>::value)
        {__move_assign_alloc(__t, integral_constant<bool,
             __node_traits::propagate_on_container_move_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__tree& __t, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<__node_allocator>::value)
        {__node_alloc() = _VSTD::move(__t.__node_alloc());}
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__tree&, false_type) _NOEXCEPT {}

    struct _DetachedTreeCache {
      _LIBCPP_INLINE_VISIBILITY
      explicit _DetachedTreeCache(__tree *__t) _NOEXCEPT : __t_(__t),
        __cache_root_(__detach_from_tree(__t)) {
          __advance();
        }

      _LIBCPP_INLINE_VISIBILITY
      __node_pointer __get() const _NOEXCEPT {
        return __cache_elem_;
      }

      _LIBCPP_INLINE_VISIBILITY
      void __advance() _NOEXCEPT {
        __cache_elem_ = __cache_root_;
        if (__cache_root_) {
          __cache_root_ = __detach_next(__cache_root_);
        }
      }

      _LIBCPP_INLINE_VISIBILITY
      ~_DetachedTreeCache() {
        __t_->destroy(__cache_elem_);
        if (__cache_root_) {
          while (__cache_root_->__parent_ != nullptr)
            __cache_root_ = static_cast<__node_pointer>(__cache_root_->__parent_);
          __t_->destroy(__cache_root_);
        }
      }

       _DetachedTreeCache(_DetachedTreeCache const&) = delete;
       _DetachedTreeCache& operator=(_DetachedTreeCache const&) = delete;

    private:
      _LIBCPP_INLINE_VISIBILITY
      static __node_pointer __detach_from_tree(__tree *__t) _NOEXCEPT;
      _LIBCPP_INLINE_VISIBILITY
      static __node_pointer __detach_next(__node_pointer) _NOEXCEPT;

      __tree *__t_;
      __node_pointer __cache_root_;
      __node_pointer __cache_elem_;
    };


    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS map;
    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS multimap;
};

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>::__tree(const value_compare& __comp)
        _NOEXCEPT_(
            is_nothrow_default_constructible<__node_allocator>::value &&
            is_nothrow_copy_constructible<value_compare>::value)
    : __pair3_(0, __comp)
{
    __begin_node() = __end_node();
}

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>::__tree(const allocator_type& __a)
    : __begin_node_(__iter_pointer()),
      __pair1_(__default_init_tag(), __node_allocator(__a)),
      __pair3_(0, __default_init_tag())
{
    __begin_node() = __end_node();
}

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>::__tree(const value_compare& __comp,
                                           const allocator_type& __a)
    : __begin_node_(__iter_pointer()),
      __pair1_(__default_init_tag(), __node_allocator(__a)),
      __pair3_(0, __comp)
{
    __begin_node() = __end_node();
}

// Precondition:  size() != 0
template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::__node_pointer
__tree<_Tp, _Compare, _Allocator>::_DetachedTreeCache::__detach_from_tree(__tree *__t) _NOEXCEPT
{
    __node_pointer __cache = static_cast<__node_pointer>(__t->__begin_node());
    __t->__begin_node() = __t->__end_node();
    __t->__end_node()->__left_->__parent_ = nullptr;
    __t->__end_node()->__left_ = nullptr;
    __t->size() = 0;
    // __cache->__left_ == nullptr
    if (__cache->__right_ != nullptr)
        __cache = static_cast<__node_pointer>(__cache->__right_);
    // __cache->__left_ == nullptr
    // __cache->__right_ == nullptr
    return __cache;
}

// Precondition:  __cache != nullptr
//    __cache->left_ == nullptr
//    __cache->right_ == nullptr
//    This is no longer a red-black tree
template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::__node_pointer
__tree<_Tp, _Compare, _Allocator>::_DetachedTreeCache::__detach_next(__node_pointer __cache) _NOEXCEPT
{
    if (__cache->__parent_ == nullptr)
        return nullptr;
    if (__tree_is_left_child(static_cast<__node_base_pointer>(__cache)))
    {
        __cache->__parent_->__left_ = nullptr;
        __cache = static_cast<__node_pointer>(__cache->__parent_);
        if (__cache->__right_ == nullptr)
            return __cache;
        return static_cast<__node_pointer>(__tree_leaf(__cache->__right_));
    }
    // __cache is right child
    __cache->__parent_unsafe()->__right_ = nullptr;
    __cache = static_cast<__node_pointer>(__cache->__parent_);
    if (__cache->__left_ == nullptr)
        return __cache;
    return static_cast<__node_pointer>(__tree_leaf(__cache->__left_));
}

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>&
__tree<_Tp, _Compare, _Allocator>::operator=(const __tree& __t)
{
    if (this != &__t)
    {
        value_comp() = __t.value_comp();
        __copy_assign_alloc(__t);
        __assign_multi(__t.begin(), __t.end());
    }
    return *this;
}

template <class _Tp, class _Compare, class _Allocator>
template <class _ForwardIterator>
void
__tree<_Tp, _Compare, _Allocator>::__assign_unique(_ForwardIterator __first, _ForwardIterator __last)
{
    typedef iterator_traits<_ForwardIterator> _ITraits;
    typedef typename _ITraits::value_type _ItValueType;
    static_assert((is_same<_ItValueType, __container_value_type>::value),
                  "__assign_unique may only be called with the containers value type");
    static_assert(__is_cpp17_forward_iterator<_ForwardIterator>::value,
                  "__assign_unique requires a forward iterator");
    if (size() != 0)
    {
        _DetachedTreeCache __cache(this);
          for (; __cache.__get() != nullptr && __first != __last; ++__first) {
              if (__node_assign_unique(*__first, __cache.__get()).second)
                  __cache.__advance();
            }
    }
    for (; __first != __last; ++__first)
        __insert_unique(*__first);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _InputIterator>
void
__tree<_Tp, _Compare, _Allocator>::__assign_multi(_InputIterator __first, _InputIterator __last)
{
    typedef iterator_traits<_InputIterator> _ITraits;
    typedef typename _ITraits::value_type _ItValueType;
    static_assert((is_same<_ItValueType, __container_value_type>::value ||
                  is_same<_ItValueType, __node_value_type>::value),
                  "__assign_multi may only be called with the containers value type"
                  " or the nodes value type");
    if (size() != 0)
    {
        _DetachedTreeCache __cache(this);
        for (; __cache.__get() && __first != __last; ++__first) {
            __cache.__get()->__value_ = *__first;
            __node_insert_multi(__cache.__get());
            __cache.__advance();
        }
    }
    for (; __first != __last; ++__first)
        __insert_multi(_NodeTypes::__get_value(*__first));
}

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>::__tree(const __tree& __t)
    : __begin_node_(__iter_pointer()),
      __pair1_(__default_init_tag(), __node_traits::select_on_container_copy_construction(__t.__node_alloc())),
      __pair3_(0, __t.value_comp())
{
    __begin_node() = __end_node();
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>::__tree(__tree&& __t)
    _NOEXCEPT_(
        is_nothrow_move_constructible<__node_allocator>::value &&
        is_nothrow_move_constructible<value_compare>::value)
    : __begin_node_(_VSTD::move(__t.__begin_node_)),
      __pair1_(_VSTD::move(__t.__pair1_)),
      __pair3_(_VSTD::move(__t.__pair3_))
{
    if (size() == 0)
        __begin_node() = __end_node();
    else
    {
        __end_node()->__left_->__parent_ = static_cast<__parent_pointer>(__end_node());
        __t.__begin_node() = __t.__end_node();
        __t.__end_node()->__left_ = nullptr;
        __t.size() = 0;
    }
}

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>::__tree(__tree&& __t, const allocator_type& __a)
    : __pair1_(__default_init_tag(), __node_allocator(__a)),
      __pair3_(0, _VSTD::move(__t.value_comp()))
{
    if (__a == __t.__alloc())
    {
        if (__t.size() == 0)
            __begin_node() = __end_node();
        else
        {
            __begin_node() = __t.__begin_node();
            __end_node()->__left_ = __t.__end_node()->__left_;
            __end_node()->__left_->__parent_ = static_cast<__parent_pointer>(__end_node());
            size() = __t.size();
            __t.__begin_node() = __t.__end_node();
            __t.__end_node()->__left_ = nullptr;
            __t.size() = 0;
        }
    }
    else
    {
        __begin_node() = __end_node();
    }
}

template <class _Tp, class _Compare, class _Allocator>
void
__tree<_Tp, _Compare, _Allocator>::__move_assign(__tree& __t, true_type)
    _NOEXCEPT_(is_nothrow_move_assignable<value_compare>::value &&
               is_nothrow_move_assignable<__node_allocator>::value)
{
    destroy(static_cast<__node_pointer>(__end_node()->__left_));
    __begin_node_ = __t.__begin_node_;
    __pair1_.first() = __t.__pair1_.first();
    __move_assign_alloc(__t);
    __pair3_ = _VSTD::move(__t.__pair3_);
    if (size() == 0)
        __begin_node() = __end_node();
    else
    {
        __end_node()->__left_->__parent_ = static_cast<__parent_pointer>(__end_node());
        __t.__begin_node() = __t.__end_node();
        __t.__end_node()->__left_ = nullptr;
        __t.size() = 0;
    }
}

template <class _Tp, class _Compare, class _Allocator>
void
__tree<_Tp, _Compare, _Allocator>::__move_assign(__tree& __t, false_type)
{
    if (__node_alloc() == __t.__node_alloc())
        __move_assign(__t, true_type());
    else
    {
        value_comp() = _VSTD::move(__t.value_comp());
        const_iterator __e = end();
        if (size() != 0)
        {
            _DetachedTreeCache __cache(this);
            while (__cache.__get() != nullptr && __t.size() != 0) {
              __cache.__get()->__value_ = _VSTD::move(__t.remove(__t.begin())->__value_);
              __node_insert_multi(__cache.__get());
              __cache.__advance();
            }
        }
        while (__t.size() != 0)
            __insert_multi(__e, _NodeTypes::__move(__t.remove(__t.begin())->__value_));
    }
}

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>&
__tree<_Tp, _Compare, _Allocator>::operator=(__tree&& __t)
    _NOEXCEPT_(
        __node_traits::propagate_on_container_move_assignment::value &&
        is_nothrow_move_assignable<value_compare>::value &&
        is_nothrow_move_assignable<__node_allocator>::value)

{
    __move_assign(__t, integral_constant<bool,
                  __node_traits::propagate_on_container_move_assignment::value>());
    return *this;
}

#endif  // _LIBCPP_CXX03_LANG
# 1818 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

template <class _Tp, class _Compare, class _Allocator>
__tree<_Tp, _Compare, _Allocator>::~__tree()
{
    static_assert((is_copy_constructible<value_compare>::value),
                 "Comparator must be copy-constructible.");
  destroy(__root());
}

template <class _Tp, class _Compare, class _Allocator>
void
__tree<_Tp, _Compare, _Allocator>::destroy(__node_pointer __nd) _NOEXCEPT
{
    if (__nd != nullptr)
    {
        destroy(static_cast<__node_pointer>(__nd->__left_));
        destroy(static_cast<__node_pointer>(__nd->__right_));
        __node_allocator& __na = __node_alloc();
        __node_traits::destroy(__na, _NodeTypes::__get_ptr(__nd->__value_));
        __node_traits::deallocate(__na, __nd, 1);
    }
}

template <class _Tp, class _Compare, class _Allocator>
void
__tree<_Tp, _Compare, _Allocator>::swap(__tree& __t)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER <= 11
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1845 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
        _NOEXCEPT_(
            __is_nothrow_swappable<value_compare>::value
            && (!__node_traits::propagate_on_container_swap::value ||
                 __is_nothrow_swappable<__node_allocator>::value)
            )
#else
# 1851 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
        _NOEXCEPT_(__is_nothrow_swappable<value_compare>::value)
#endif
# 1853 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
{
    using _VSTD::swap;
    swap(__begin_node_, __t.__begin_node_);
    swap(__pair1_.first(), __t.__pair1_.first());
    __swap_allocator(__node_alloc(), __t.__node_alloc());
    __pair3_.swap(__t.__pair3_);
    if (size() == 0)
        __begin_node() = __end_node();
    else
        __end_node()->__left_->__parent_ = static_cast<__parent_pointer>(__end_node());
    if (__t.size() == 0)
        __t.__begin_node() = __t.__end_node();
    else
        __t.__end_node()->__left_->__parent_ = static_cast<__parent_pointer>(__t.__end_node());
}

template <class _Tp, class _Compare, class _Allocator>
void
__tree<_Tp, _Compare, _Allocator>::clear() _NOEXCEPT
{
    destroy(__root());
    size() = 0;
    __begin_node() = __end_node();
    __end_node()->__left_ = nullptr;
}

// Find lower_bound place to insert
// Set __parent to parent of null leaf
// Return reference to null leaf
template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::__node_base_pointer&
__tree<_Tp, _Compare, _Allocator>::__find_leaf_low(__parent_pointer& __parent,
                                                   const key_type& __v)
{
    __node_pointer __nd = __root();
    if (__nd != nullptr)
    {
        while (true)
        {
            if (value_comp()(__nd->__value_, __v))
            {
                if (__nd->__right_ != nullptr)
                    __nd = static_cast<__node_pointer>(__nd->__right_);
                else
                {
                    __parent = static_cast<__parent_pointer>(__nd);
                    return __nd->__right_;
                }
            }
            else
            {
                if (__nd->__left_ != nullptr)
                    __nd = static_cast<__node_pointer>(__nd->__left_);
                else
                {
                    __parent = static_cast<__parent_pointer>(__nd);
                    return __parent->__left_;
                }
            }
        }
    }
    __parent = static_cast<__parent_pointer>(__end_node());
    return __parent->__left_;
}

// Find upper_bound place to insert
// Set __parent to parent of null leaf
// Return reference to null leaf
template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::__node_base_pointer&
__tree<_Tp, _Compare, _Allocator>::__find_leaf_high(__parent_pointer& __parent,
                                                    const key_type& __v)
{
    __node_pointer __nd = __root();
    if (__nd != nullptr)
    {
        while (true)
        {
            if (value_comp()(__v, __nd->__value_))
            {
                if (__nd->__left_ != nullptr)
                    __nd = static_cast<__node_pointer>(__nd->__left_);
                else
                {
                    __parent = static_cast<__parent_pointer>(__nd);
                    return __parent->__left_;
                }
            }
            else
            {
                if (__nd->__right_ != nullptr)
                    __nd = static_cast<__node_pointer>(__nd->__right_);
                else
                {
                    __parent = static_cast<__parent_pointer>(__nd);
                    return __nd->__right_;
                }
            }
        }
    }
    __parent = static_cast<__parent_pointer>(__end_node());
    return __parent->__left_;
}

// Find leaf place to insert closest to __hint
// First check prior to __hint.
// Next check after __hint.
// Next do O(log N) search.
// Set __parent to parent of null leaf
// Return reference to null leaf
template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::__node_base_pointer&
__tree<_Tp, _Compare, _Allocator>::__find_leaf(const_iterator __hint,
                                               __parent_pointer& __parent,
                                               const key_type& __v)
{
    if (__hint == end() || !value_comp()(*__hint, __v))  // check before
    {
        // __v <= *__hint
        const_iterator __prior = __hint;
        if (__prior == begin() || !value_comp()(__v, *--__prior))
        {
            // *prev(__hint) <= __v <= *__hint
            if (__hint.__ptr_->__left_ == nullptr)
            {
                __parent = static_cast<__parent_pointer>(__hint.__ptr_);
                return __parent->__left_;
            }
            else
            {
                __parent = static_cast<__parent_pointer>(__prior.__ptr_);
                return static_cast<__node_base_pointer>(__prior.__ptr_)->__right_;
            }
        }
        // __v < *prev(__hint)
        return __find_leaf_high(__parent, __v);
    }
    // else __v > *__hint
    return __find_leaf_low(__parent, __v);
}

// Find place to insert if __v doesn't exist
// Set __parent to parent of null leaf
// Return reference to null leaf
// If __v exists, set parent to node of __v and return reference to node of __v
template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::__node_base_pointer&
__tree<_Tp, _Compare, _Allocator>::__find_equal(__parent_pointer& __parent,
                                                const _Key& __v)
{
    __node_pointer __nd = __root();
    __node_base_pointer* __nd_ptr = __root_ptr();
    if (__nd != nullptr)
    {
        while (true)
        {
            if (value_comp()(__v, __nd->__value_))
            {
                if (__nd->__left_ != nullptr) {
                    __nd_ptr = _VSTD::addressof(__nd->__left_);
                    __nd = static_cast<__node_pointer>(__nd->__left_);
                } else {
                    __parent = static_cast<__parent_pointer>(__nd);
                    return __parent->__left_;
                }
            }
            else if (value_comp()(__nd->__value_, __v))
            {
                if (__nd->__right_ != nullptr) {
                    __nd_ptr = _VSTD::addressof(__nd->__right_);
                    __nd = static_cast<__node_pointer>(__nd->__right_);
                } else {
                    __parent = static_cast<__parent_pointer>(__nd);
                    return __nd->__right_;
                }
            }
            else
            {
                __parent = static_cast<__parent_pointer>(__nd);
                return *__nd_ptr;
            }
        }
    }
    __parent = static_cast<__parent_pointer>(__end_node());
    return __parent->__left_;
}

// Find place to insert if __v doesn't exist
// First check prior to __hint.
// Next check after __hint.
// Next do O(log N) search.
// Set __parent to parent of null leaf
// Return reference to null leaf
// If __v exists, set parent to node of __v and return reference to node of __v
template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::__node_base_pointer&
__tree<_Tp, _Compare, _Allocator>::__find_equal(const_iterator __hint,
                                                __parent_pointer& __parent,
                                                __node_base_pointer& __dummy,
                                                const _Key& __v)
{
    if (__hint == end() || value_comp()(__v, *__hint))  // check before
    {
        // __v < *__hint
        const_iterator __prior = __hint;
        if (__prior == begin() || value_comp()(*--__prior, __v))
        {
            // *prev(__hint) < __v < *__hint
            if (__hint.__ptr_->__left_ == nullptr)
            {
                __parent = static_cast<__parent_pointer>(__hint.__ptr_);
                return __parent->__left_;
            }
            else
            {
                __parent = static_cast<__parent_pointer>(__prior.__ptr_);
                return static_cast<__node_base_pointer>(__prior.__ptr_)->__right_;
            }
        }
        // __v <= *prev(__hint)
        return __find_equal(__parent, __v);
    }
    else if (value_comp()(*__hint, __v))  // check after
    {
        // *__hint < __v
        const_iterator __next = _VSTD::next(__hint);
        if (__next == end() || value_comp()(__v, *__next))
        {
            // *__hint < __v < *_VSTD::next(__hint)
            if (__hint.__get_np()->__right_ == nullptr)
            {
                __parent = static_cast<__parent_pointer>(__hint.__ptr_);
                return static_cast<__node_base_pointer>(__hint.__ptr_)->__right_;
            }
            else
            {
                __parent = static_cast<__parent_pointer>(__next.__ptr_);
                return __parent->__left_;
            }
        }
        // *next(__hint) <= __v
        return __find_equal(__parent, __v);
    }
    // else __v == *__hint
    __parent = static_cast<__parent_pointer>(__hint.__ptr_);
    __dummy = static_cast<__node_base_pointer>(__hint.__ptr_);
    return __dummy;
}

template <class _Tp, class _Compare, class _Allocator>
void __tree<_Tp, _Compare, _Allocator>::__insert_node_at(
    __parent_pointer __parent, __node_base_pointer& __child,
    __node_base_pointer __new_node) _NOEXCEPT
{
    __new_node->__left_   = nullptr;
    __new_node->__right_  = nullptr;
    __new_node->__parent_ = __parent;
    // __new_node->__is_black_ is initialized in __tree_balance_after_insert
    __child = __new_node;
    if (__begin_node()->__left_ != nullptr)
        __begin_node() = static_cast<__iter_pointer>(__begin_node()->__left_);
    __tree_balance_after_insert(__end_node()->__left_, __child);
    ++size();
}

#ifndef _LIBCPP_CXX03_LANG
template <class _Tp, class _Compare, class _Allocator>
template <class _Key, class... _Args>
pair<typename __tree<_Tp, _Compare, _Allocator>::iterator, bool>
__tree<_Tp, _Compare, _Allocator>::__emplace_unique_key_args(_Key const& __k, _Args&&... __args)
#else
# 2126 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
template <class _Tp, class _Compare, class _Allocator>
template <class _Key, class _Args>
pair<typename __tree<_Tp, _Compare, _Allocator>::iterator, bool>
__tree<_Tp, _Compare, _Allocator>::__emplace_unique_key_args(_Key const& __k, _Args& __args)
#endif
# 2131 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
{
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_equal(__parent, __k);
    __node_pointer __r = static_cast<__node_pointer>(__child);
    bool __inserted = false;
    if (__child == nullptr)
    {
#ifndef _LIBCPP_CXX03_LANG
        __node_holder __h = __construct_node(_VSTD::forward<_Args>(__args)...);
#else
# 2141 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
        __node_holder __h = __construct_node(__args);
#endif
# 2143 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
        __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
        __r = __h.release();
        __inserted = true;
    }
    return pair<iterator, bool>(iterator(__r), __inserted);
}


#ifndef _LIBCPP_CXX03_LANG
template <class _Tp, class _Compare, class _Allocator>
template <class _Key, class... _Args>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__emplace_hint_unique_key_args(
    const_iterator __p, _Key const& __k, _Args&&... __args)
#else
# 2158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
template <class _Tp, class _Compare, class _Allocator>
template <class _Key, class _Args>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__emplace_hint_unique_key_args(
    const_iterator __p, _Key const& __k, _Args& __args)
#endif
# 2164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
{
    __parent_pointer __parent;
    __node_base_pointer __dummy;
    __node_base_pointer& __child = __find_equal(__p, __parent, __dummy, __k);
    __node_pointer __r = static_cast<__node_pointer>(__child);
    if (__child == nullptr)
    {
#ifndef _LIBCPP_CXX03_LANG
        __node_holder __h = __construct_node(_VSTD::forward<_Args>(__args)...);
#else
# 2174 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
        __node_holder __h = __construct_node(__args);
#endif
# 2176 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
        __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
        __r = __h.release();
    }
    return iterator(__r);
}


#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Compare, class _Allocator>
template <class ..._Args>
typename __tree<_Tp, _Compare, _Allocator>::__node_holder
__tree<_Tp, _Compare, _Allocator>::__construct_node(_Args&& ...__args)
{
    static_assert(!__is_tree_value_type<_Args...>::value,
                  "Cannot construct from __value_type");
    __node_allocator& __na = __node_alloc();
    __node_holder __h(__node_traits::allocate(__na, 1), _Dp(__na));
    __node_traits::construct(__na, _NodeTypes::__get_ptr(__h->__value_), _VSTD::forward<_Args>(__args)...);
    __h.get_deleter().__value_constructed = true;
    return __h;
}


template <class _Tp, class _Compare, class _Allocator>
template <class... _Args>
pair<typename __tree<_Tp, _Compare, _Allocator>::iterator, bool>
__tree<_Tp, _Compare, _Allocator>::__emplace_unique_impl(_Args&&... __args)
{
    __node_holder __h = __construct_node(_VSTD::forward<_Args>(__args)...);
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_equal(__parent, __h->__value_);
    __node_pointer __r = static_cast<__node_pointer>(__child);
    bool __inserted = false;
    if (__child == nullptr)
    {
        __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
        __r = __h.release();
        __inserted = true;
    }
    return pair<iterator, bool>(iterator(__r), __inserted);
}

template <class _Tp, class _Compare, class _Allocator>
template <class... _Args>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__emplace_hint_unique_impl(const_iterator __p, _Args&&... __args)
{
    __node_holder __h = __construct_node(_VSTD::forward<_Args>(__args)...);
    __parent_pointer __parent;
    __node_base_pointer __dummy;
    __node_base_pointer& __child = __find_equal(__p, __parent, __dummy, __h->__value_);
    __node_pointer __r = static_cast<__node_pointer>(__child);
    if (__child == nullptr)
    {
        __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
        __r = __h.release();
    }
    return iterator(__r);
}

template <class _Tp, class _Compare, class _Allocator>
template <class... _Args>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__emplace_multi(_Args&&... __args)
{
    __node_holder __h = __construct_node(_VSTD::forward<_Args>(__args)...);
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_leaf_high(__parent, _NodeTypes::__get_key(__h->__value_));
    __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
    return iterator(static_cast<__node_pointer>(__h.release()));
}

template <class _Tp, class _Compare, class _Allocator>
template <class... _Args>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__emplace_hint_multi(const_iterator __p,
                                                        _Args&&... __args)
{
    __node_holder __h = __construct_node(_VSTD::forward<_Args>(__args)...);
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_leaf(__p, __parent, _NodeTypes::__get_key(__h->__value_));
    __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
    return iterator(static_cast<__node_pointer>(__h.release()));
}


#else  // _LIBCPP_CXX03_LANG
# 2264 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::__node_holder
__tree<_Tp, _Compare, _Allocator>::__construct_node(const __container_value_type& __v)
{
    __node_allocator& __na = __node_alloc();
    __node_holder __h(__node_traits::allocate(__na, 1), _Dp(__na));
    __node_traits::construct(__na, _NodeTypes::__get_ptr(__h->__value_), __v);
    __h.get_deleter().__value_constructed = true;
    return _LIBCPP_EXPLICIT_MOVE(__h);  // explicitly moved for C++03
}

#endif  // _LIBCPP_CXX03_LANG
# 2277 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

#ifdef _LIBCPP_CXX03_LANG
template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__insert_multi(const __container_value_type& __v)
{
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_leaf_high(__parent, _NodeTypes::__get_key(__v));
    __node_holder __h = __construct_node(__v);
    __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
    return iterator(__h.release());
}

template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__insert_multi(const_iterator __p, const __container_value_type& __v)
{
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_leaf(__p, __parent, _NodeTypes::__get_key(__v));
    __node_holder __h = __construct_node(__v);
    __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
    return iterator(__h.release());
}
#endif
# 2301 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

template <class _Tp, class _Compare, class _Allocator>
pair<typename __tree<_Tp, _Compare, _Allocator>::iterator, bool>
__tree<_Tp, _Compare, _Allocator>::__node_assign_unique(const __container_value_type& __v, __node_pointer __nd)
{
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_equal(__parent, _NodeTypes::__get_key(__v));
    __node_pointer __r = static_cast<__node_pointer>(__child);
    bool __inserted = false;
    if (__child == nullptr)
    {
        __nd->__value_ = __v;
        __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__nd));
        __r = __nd;
        __inserted = true;
    }
    return pair<iterator, bool>(iterator(__r), __inserted);
}


template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__node_insert_multi(__node_pointer __nd)
{
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_leaf_high(__parent, _NodeTypes::__get_key(__nd->__value_));
    __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__nd));
    return iterator(__nd);
}

template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__node_insert_multi(const_iterator __p,
                                                       __node_pointer __nd)
{
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_leaf(__p, __parent, _NodeTypes::__get_key(__nd->__value_));
    __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__nd));
    return iterator(__nd);
}

template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__remove_node_pointer(__node_pointer __ptr) _NOEXCEPT
{
    iterator __r(__ptr);
    ++__r;
    if (__begin_node() == __ptr)
        __begin_node() = __r.__ptr_;
    --size();
    __tree_remove(__end_node()->__left_,
                  static_cast<__node_base_pointer>(__ptr));
    return __r;
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2357 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
template <class _Tp, class _Compare, class _Allocator>
template <class _NodeHandle, class _InsertReturnType>
_LIBCPP_INLINE_VISIBILITY
_InsertReturnType
__tree<_Tp, _Compare, _Allocator>::__node_handle_insert_unique(
    _NodeHandle&& __nh)
{
    if (__nh.empty())
        return _InsertReturnType{end(), false, _NodeHandle()};

    __node_pointer __ptr = __nh.__ptr_;
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_equal(__parent,
                                                __ptr->__value_);
    if (__child != nullptr)
        return _InsertReturnType{
            iterator(static_cast<__node_pointer>(__child)),
            false, _VSTD::move(__nh)};

    __insert_node_at(__parent, __child,
                     static_cast<__node_base_pointer>(__ptr));
    __nh.__release_ptr();
    return _InsertReturnType{iterator(__ptr), true, _NodeHandle()};
}

template <class _Tp, class _Compare, class _Allocator>
template <class _NodeHandle>
_LIBCPP_INLINE_VISIBILITY
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__node_handle_insert_unique(
    const_iterator __hint, _NodeHandle&& __nh)
{
    if (__nh.empty())
        return end();

    __node_pointer __ptr = __nh.__ptr_;
    __parent_pointer __parent;
    __node_base_pointer __dummy;
    __node_base_pointer& __child = __find_equal(__hint, __parent, __dummy,
                                                __ptr->__value_);
    __node_pointer __r = static_cast<__node_pointer>(__child);
    if (__child == nullptr)
    {
        __insert_node_at(__parent, __child,
                         static_cast<__node_base_pointer>(__ptr));
        __r = __ptr;
        __nh.__release_ptr();
    }
    return iterator(__r);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _NodeHandle>
_LIBCPP_INLINE_VISIBILITY
_NodeHandle
__tree<_Tp, _Compare, _Allocator>::__node_handle_extract(key_type const& __key)
{
    iterator __it = find(__key);
    if (__it == end())
        return _NodeHandle();
    return __node_handle_extract<_NodeHandle>(__it);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _NodeHandle>
_LIBCPP_INLINE_VISIBILITY
_NodeHandle
__tree<_Tp, _Compare, _Allocator>::__node_handle_extract(const_iterator __p)
{
    __node_pointer __np = __p.__get_np();
    __remove_node_pointer(__np);
    return _NodeHandle(__np, __alloc());
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Tree>
_LIBCPP_INLINE_VISIBILITY
void
__tree<_Tp, _Compare, _Allocator>::__node_handle_merge_unique(_Tree& __source)
{
    static_assert(is_same<typename _Tree::__node_pointer, __node_pointer>::value, "");

    for (typename _Tree::iterator __i = __source.begin();
         __i != __source.end();)
    {
        __node_pointer __src_ptr = __i.__get_np();
        __parent_pointer __parent;
        __node_base_pointer& __child =
            __find_equal(__parent, _NodeTypes::__get_key(__src_ptr->__value_));
        ++__i;
        if (__child != nullptr)
            continue;
        __source.__remove_node_pointer(__src_ptr);
        __insert_node_at(__parent, __child,
                         static_cast<__node_base_pointer>(__src_ptr));
    }
}

template <class _Tp, class _Compare, class _Allocator>
template <class _NodeHandle>
_LIBCPP_INLINE_VISIBILITY
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__node_handle_insert_multi(_NodeHandle&& __nh)
{
    if (__nh.empty())
        return end();
    __node_pointer __ptr = __nh.__ptr_;
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_leaf_high(
        __parent, _NodeTypes::__get_key(__ptr->__value_));
    __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__ptr));
    __nh.__release_ptr();
    return iterator(__ptr);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _NodeHandle>
_LIBCPP_INLINE_VISIBILITY
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__node_handle_insert_multi(
    const_iterator __hint, _NodeHandle&& __nh)
{
    if (__nh.empty())
        return end();

    __node_pointer __ptr = __nh.__ptr_;
    __parent_pointer __parent;
    __node_base_pointer& __child = __find_leaf(__hint, __parent,
                                               _NodeTypes::__get_key(__ptr->__value_));
    __insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__ptr));
    __nh.__release_ptr();
    return iterator(__ptr);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Tree>
_LIBCPP_INLINE_VISIBILITY
void
__tree<_Tp, _Compare, _Allocator>::__node_handle_merge_multi(_Tree& __source)
{
    static_assert(is_same<typename _Tree::__node_pointer, __node_pointer>::value, "");

    for (typename _Tree::iterator __i = __source.begin();
         __i != __source.end();)
    {
        __node_pointer __src_ptr = __i.__get_np();
        __parent_pointer __parent;
        __node_base_pointer& __child = __find_leaf_high(
            __parent, _NodeTypes::__get_key(__src_ptr->__value_));
        ++__i;
        __source.__remove_node_pointer(__src_ptr);
        __insert_node_at(__parent, __child,
                         static_cast<__node_base_pointer>(__src_ptr));
    }
}

#endif  // _LIBCPP_STD_VER > 14
# 2514 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3

template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::erase(const_iterator __p)
{
    __node_pointer __np = __p.__get_np();
    iterator __r = __remove_node_pointer(__np);
    __node_allocator& __na = __node_alloc();
    __node_traits::destroy(__na, _NodeTypes::__get_ptr(
        const_cast<__node_value_type&>(*__p)));
    __node_traits::deallocate(__na, __np, 1);
    return __r;
}

template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::erase(const_iterator __f, const_iterator __l)
{
    while (__f != __l)
        __f = erase(__f);
    return iterator(__l.__ptr_);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::size_type
__tree<_Tp, _Compare, _Allocator>::__erase_unique(const _Key& __k)
{
    iterator __i = find(__k);
    if (__i == end())
        return 0;
    erase(__i);
    return 1;
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::size_type
__tree<_Tp, _Compare, _Allocator>::__erase_multi(const _Key& __k)
{
    pair<iterator, iterator> __p = __equal_range_multi(__k);
    size_type __r = 0;
    for (; __p.first != __p.second; ++__r)
        __p.first = erase(__p.first);
    return __r;
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::find(const _Key& __v)
{
    iterator __p = __lower_bound(__v, __root(), __end_node());
    if (__p != end() && !value_comp()(__v, *__p))
        return __p;
    return end();
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::const_iterator
__tree<_Tp, _Compare, _Allocator>::find(const _Key& __v) const
{
    const_iterator __p = __lower_bound(__v, __root(), __end_node());
    if (__p != end() && !value_comp()(__v, *__p))
        return __p;
    return end();
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::size_type
__tree<_Tp, _Compare, _Allocator>::__count_unique(const _Key& __k) const
{
    __node_pointer __rt = __root();
    while (__rt != nullptr)
    {
        if (value_comp()(__k, __rt->__value_))
        {
            __rt = static_cast<__node_pointer>(__rt->__left_);
        }
        else if (value_comp()(__rt->__value_, __k))
            __rt = static_cast<__node_pointer>(__rt->__right_);
        else
            return 1;
    }
    return 0;
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::size_type
__tree<_Tp, _Compare, _Allocator>::__count_multi(const _Key& __k) const
{
    __iter_pointer __result = __end_node();
    __node_pointer __rt = __root();
    while (__rt != nullptr)
    {
        if (value_comp()(__k, __rt->__value_))
        {
            __result = static_cast<__iter_pointer>(__rt);
            __rt = static_cast<__node_pointer>(__rt->__left_);
        }
        else if (value_comp()(__rt->__value_, __k))
            __rt = static_cast<__node_pointer>(__rt->__right_);
        else
            return _VSTD::distance(
                __lower_bound(__k, static_cast<__node_pointer>(__rt->__left_), static_cast<__iter_pointer>(__rt)),
                __upper_bound(__k, static_cast<__node_pointer>(__rt->__right_), __result)
            );
    }
    return 0;
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__lower_bound(const _Key& __v,
                                                 __node_pointer __root,
                                                 __iter_pointer __result)
{
    while (__root != nullptr)
    {
        if (!value_comp()(__root->__value_, __v))
        {
            __result = static_cast<__iter_pointer>(__root);
            __root = static_cast<__node_pointer>(__root->__left_);
        }
        else
            __root = static_cast<__node_pointer>(__root->__right_);
    }
    return iterator(__result);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::const_iterator
__tree<_Tp, _Compare, _Allocator>::__lower_bound(const _Key& __v,
                                                 __node_pointer __root,
                                                 __iter_pointer __result) const
{
    while (__root != nullptr)
    {
        if (!value_comp()(__root->__value_, __v))
        {
            __result = static_cast<__iter_pointer>(__root);
            __root = static_cast<__node_pointer>(__root->__left_);
        }
        else
            __root = static_cast<__node_pointer>(__root->__right_);
    }
    return const_iterator(__result);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::iterator
__tree<_Tp, _Compare, _Allocator>::__upper_bound(const _Key& __v,
                                                 __node_pointer __root,
                                                 __iter_pointer __result)
{
    while (__root != nullptr)
    {
        if (value_comp()(__v, __root->__value_))
        {
            __result = static_cast<__iter_pointer>(__root);
            __root = static_cast<__node_pointer>(__root->__left_);
        }
        else
            __root = static_cast<__node_pointer>(__root->__right_);
    }
    return iterator(__result);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
typename __tree<_Tp, _Compare, _Allocator>::const_iterator
__tree<_Tp, _Compare, _Allocator>::__upper_bound(const _Key& __v,
                                                 __node_pointer __root,
                                                 __iter_pointer __result) const
{
    while (__root != nullptr)
    {
        if (value_comp()(__v, __root->__value_))
        {
            __result = static_cast<__iter_pointer>(__root);
            __root = static_cast<__node_pointer>(__root->__left_);
        }
        else
            __root = static_cast<__node_pointer>(__root->__right_);
    }
    return const_iterator(__result);
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
pair<typename __tree<_Tp, _Compare, _Allocator>::iterator,
     typename __tree<_Tp, _Compare, _Allocator>::iterator>
__tree<_Tp, _Compare, _Allocator>::__equal_range_unique(const _Key& __k)
{
    typedef pair<iterator, iterator> _Pp;
    __iter_pointer __result = __end_node();
    __node_pointer __rt = __root();
    while (__rt != nullptr)
    {
        if (value_comp()(__k, __rt->__value_))
        {
            __result = static_cast<__iter_pointer>(__rt);
            __rt = static_cast<__node_pointer>(__rt->__left_);
        }
        else if (value_comp()(__rt->__value_, __k))
            __rt = static_cast<__node_pointer>(__rt->__right_);
        else
            return _Pp(iterator(__rt),
                      iterator(
                          __rt->__right_ != nullptr ?
                              static_cast<__iter_pointer>(__tree_min(__rt->__right_))
                            : __result));
    }
    return _Pp(iterator(__result), iterator(__result));
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
pair<typename __tree<_Tp, _Compare, _Allocator>::const_iterator,
     typename __tree<_Tp, _Compare, _Allocator>::const_iterator>
__tree<_Tp, _Compare, _Allocator>::__equal_range_unique(const _Key& __k) const
{
    typedef pair<const_iterator, const_iterator> _Pp;
    __iter_pointer __result = __end_node();
    __node_pointer __rt = __root();
    while (__rt != nullptr)
    {
        if (value_comp()(__k, __rt->__value_))
        {
            __result = static_cast<__iter_pointer>(__rt);
            __rt = static_cast<__node_pointer>(__rt->__left_);
        }
        else if (value_comp()(__rt->__value_, __k))
            __rt = static_cast<__node_pointer>(__rt->__right_);
        else
            return _Pp(const_iterator(__rt),
                      const_iterator(
                          __rt->__right_ != nullptr ?
                              static_cast<__iter_pointer>(__tree_min(__rt->__right_))
                            : __result));
    }
    return _Pp(const_iterator(__result), const_iterator(__result));
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
pair<typename __tree<_Tp, _Compare, _Allocator>::iterator,
     typename __tree<_Tp, _Compare, _Allocator>::iterator>
__tree<_Tp, _Compare, _Allocator>::__equal_range_multi(const _Key& __k)
{
    typedef pair<iterator, iterator> _Pp;
    __iter_pointer __result = __end_node();
    __node_pointer __rt = __root();
    while (__rt != nullptr)
    {
        if (value_comp()(__k, __rt->__value_))
        {
            __result = static_cast<__iter_pointer>(__rt);
            __rt = static_cast<__node_pointer>(__rt->__left_);
        }
        else if (value_comp()(__rt->__value_, __k))
            __rt = static_cast<__node_pointer>(__rt->__right_);
        else
            return _Pp(__lower_bound(__k, static_cast<__node_pointer>(__rt->__left_), static_cast<__iter_pointer>(__rt)),
                      __upper_bound(__k, static_cast<__node_pointer>(__rt->__right_), __result));
    }
    return _Pp(iterator(__result), iterator(__result));
}

template <class _Tp, class _Compare, class _Allocator>
template <class _Key>
pair<typename __tree<_Tp, _Compare, _Allocator>::const_iterator,
     typename __tree<_Tp, _Compare, _Allocator>::const_iterator>
__tree<_Tp, _Compare, _Allocator>::__equal_range_multi(const _Key& __k) const
{
    typedef pair<const_iterator, const_iterator> _Pp;
    __iter_pointer __result = __end_node();
    __node_pointer __rt = __root();
    while (__rt != nullptr)
    {
        if (value_comp()(__k, __rt->__value_))
        {
            __result = static_cast<__iter_pointer>(__rt);
            __rt = static_cast<__node_pointer>(__rt->__left_);
        }
        else if (value_comp()(__rt->__value_, __k))
            __rt = static_cast<__node_pointer>(__rt->__right_);
        else
            return _Pp(__lower_bound(__k, static_cast<__node_pointer>(__rt->__left_), static_cast<__iter_pointer>(__rt)),
                      __upper_bound(__k, static_cast<__node_pointer>(__rt->__right_), __result));
    }
    return _Pp(const_iterator(__result), const_iterator(__result));
}

template <class _Tp, class _Compare, class _Allocator>
typename __tree<_Tp, _Compare, _Allocator>::__node_holder
__tree<_Tp, _Compare, _Allocator>::remove(const_iterator __p) _NOEXCEPT
{
    __node_pointer __np = __p.__get_np();
    if (__begin_node() == __p.__ptr_)
    {
        if (__np->__right_ != nullptr)
            __begin_node() = static_cast<__iter_pointer>(__np->__right_);
        else
            __begin_node() = static_cast<__iter_pointer>(__np->__parent_);
    }
    --size();
    __tree_remove(__end_node()->__left_,
                  static_cast<__node_base_pointer>(__np));
    return __node_holder(__np, _Dp(__node_alloc(), true));
}

template <class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(__tree<_Tp, _Compare, _Allocator>& __x,
     __tree<_Tp, _Compare, _Allocator>& __y)
    _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP___TREE
# 2847 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__tree" 3
# 480 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <__node_handle>
#endif /* expanded by -frewrite-includes */
# 480 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___NODE_HANDLE
#define _LIBCPP___NODE_HANDLE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
#if 0 /* expanded by -frewrite-includes */
#include <optional>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 1 3
// -*- C++ -*-
//===-------------------------- optional ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_OPTIONAL
#define _LIBCPP_OPTIONAL

/*
    optional synopsis

// C++1z

namespace std {
  // 23.6.3, optional for object types
  template <class T> class optional;

  // 23.6.4, no-value state indicator
  struct nullopt_t{see below };
  inline constexpr nullopt_t nullopt(unspecified );

  // 23.6.5, class bad_optional_access
  class bad_optional_access;

  // 23.6.6, relational operators
  template <class T, class U>
  constexpr bool operator==(const optional<T>&, const optional<U>&);
  template <class T, class U>
  constexpr bool operator!=(const optional<T>&, const optional<U>&);
  template <class T, class U>
  constexpr bool operator<(const optional<T>&, const optional<U>&);
  template <class T, class U>
  constexpr bool operator>(const optional<T>&, const optional<U>&);
  template <class T, class U>
  constexpr bool operator<=(const optional<T>&, const optional<U>&);
  template <class T, class U>
  constexpr bool operator>=(const optional<T>&, const optional<U>&);

  // 23.6.7 comparison with nullopt
  template <class T> constexpr bool operator==(const optional<T>&, nullopt_t) noexcept;
  template <class T> constexpr bool operator==(nullopt_t, const optional<T>&) noexcept;
  template <class T> constexpr bool operator!=(const optional<T>&, nullopt_t) noexcept;
  template <class T> constexpr bool operator!=(nullopt_t, const optional<T>&) noexcept;
  template <class T> constexpr bool operator<(const optional<T>&, nullopt_t) noexcept;
  template <class T> constexpr bool operator<(nullopt_t, const optional<T>&) noexcept;
  template <class T> constexpr bool operator<=(const optional<T>&, nullopt_t) noexcept;
  template <class T> constexpr bool operator<=(nullopt_t, const optional<T>&) noexcept;
  template <class T> constexpr bool operator>(const optional<T>&, nullopt_t) noexcept;
  template <class T> constexpr bool operator>(nullopt_t, const optional<T>&) noexcept;
  template <class T> constexpr bool operator>=(const optional<T>&, nullopt_t) noexcept;
  template <class T> constexpr bool operator>=(nullopt_t, const optional<T>&) noexcept;

  // 23.6.8, comparison with T
  template <class T, class U> constexpr bool operator==(const optional<T>&, const U&);
  template <class T, class U> constexpr bool operator==(const T&, const optional<U>&);
  template <class T, class U> constexpr bool operator!=(const optional<T>&, const U&);
  template <class T, class U> constexpr bool operator!=(const T&, const optional<U>&);
  template <class T, class U> constexpr bool operator<(const optional<T>&, const U&);
  template <class T, class U> constexpr bool operator<(const T&, const optional<U>&);
  template <class T, class U> constexpr bool operator<=(const optional<T>&, const U&);
  template <class T, class U> constexpr bool operator<=(const T&, const optional<U>&);
  template <class T, class U> constexpr bool operator>(const optional<T>&, const U&);
  template <class T, class U> constexpr bool operator>(const T&, const optional<U>&);
  template <class T, class U> constexpr bool operator>=(const optional<T>&, const U&);
  template <class T, class U> constexpr bool operator>=(const T&, const optional<U>&);

  // 23.6.9, specialized algorithms
  template <class T> void swap(optional<T>&, optional<T>&) noexcept(see below );
  template <class T> constexpr optional<see below > make_optional(T&&);
  template <class T, class... Args>
    constexpr optional<T> make_optional(Args&&... args);
  template <class T, class U, class... Args>
    constexpr optional<T> make_optional(initializer_list<U> il, Args&&... args);

  // 23.6.10, hash support
  template <class T> struct hash;
  template <class T> struct hash<optional<T>>;

  template <class T> class optional {
  public:
    using value_type = T;

    // 23.6.3.1, constructors
    constexpr optional() noexcept;
    constexpr optional(nullopt_t) noexcept;
    optional(const optional &);
    optional(optional &&) noexcept(see below);
    template <class... Args> constexpr explicit optional(in_place_t, Args &&...);
    template <class U, class... Args>
      constexpr explicit optional(in_place_t, initializer_list<U>, Args &&...);
    template <class U = T>
      constexpr EXPLICIT optional(U &&);
    template <class U>
      constexpr EXPLICIT optional(const optional<U> &);
    template <class U>
      constexpr EXPLICIT optional(optional<U> &&);

    // 23.6.3.2, destructor
    ~optional();

    // 23.6.3.3, assignment
    optional &operator=(nullopt_t) noexcept;
    optional &operator=(const optional &);                // constexpr in C++20
    optional &operator=(optional &&) noexcept(see below); // constexpr in C++20
    template <class U = T> optional &operator=(U &&);
    template <class U> optional &operator=(const optional<U> &);
    template <class U> optional &operator=(optional<U> &&);
    template <class... Args> T& emplace(Args &&...);
    template <class U, class... Args>
      T& emplace(initializer_list<U>, Args &&...);

    // 23.6.3.4, swap
    void swap(optional &) noexcept(see below );

    // 23.6.3.5, observers
    constexpr T const *operator->() const;
    constexpr T *operator->();
    constexpr T const &operator*() const &;
    constexpr T &operator*() &;
    constexpr T &&operator*() &&;
    constexpr const T &&operator*() const &&;
    constexpr explicit operator bool() const noexcept;
    constexpr bool has_value() const noexcept;
    constexpr T const &value() const &;
    constexpr T &value() &;
    constexpr T &&value() &&;
    constexpr const T &&value() const &&;
    template <class U> constexpr T value_or(U &&) const &;
    template <class U> constexpr T value_or(U &&) &&;

    // 23.6.3.6, modifiers
    void reset() noexcept;

  private:
    T *val; // exposition only
  };

template<class T>
  optional(T) -> optional<T>;

} // namespace std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 149 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 150 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <__debug>
#endif /* expanded by -frewrite-includes */
# 150 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 151 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 151 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <functional>
#endif /* expanded by -frewrite-includes */
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 153 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 153 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 154 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 155 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 155 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 156 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 157 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 157 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 158 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 159 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 161 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 162 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
#endif
# 163 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 165 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 2 3


namespace std  // purposefully not using versioning namespace
{

class _LIBCPP_EXCEPTION_ABI _LIBCPP_AVAILABILITY_BAD_OPTIONAL_ACCESS bad_optional_access
    : public exception
{
public:
    // Get the key function ~bad_optional_access() into the dylib
    virtual ~bad_optional_access() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

}  // std

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 183 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3

_LIBCPP_BEGIN_NAMESPACE_STD

_LIBCPP_NORETURN
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_AVAILABILITY_THROW_BAD_OPTIONAL_ACCESS
void __throw_bad_optional_access() {
#ifndef _LIBCPP_NO_EXCEPTIONS
        throw bad_optional_access();
#else
# 193 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
        _VSTD::abort();
#endif
# 195 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
}

struct nullopt_t
{
    struct __secret_tag { _LIBCPP_INLINE_VISIBILITY explicit __secret_tag() = default; };
    _LIBCPP_INLINE_VISIBILITY constexpr explicit nullopt_t(__secret_tag, __secret_tag) noexcept {}
};

_LIBCPP_INLINE_VAR constexpr nullopt_t nullopt{nullopt_t::__secret_tag{}, nullopt_t::__secret_tag{}};

template <class _Tp, bool = is_trivially_destructible<_Tp>::value>
struct __optional_destruct_base;

template <class _Tp>
struct __optional_destruct_base<_Tp, false>
{
    typedef _Tp value_type;
    static_assert(is_object_v<value_type>,
        "instantiation of optional with a non-object type is undefined behavior");
    union
    {
        char __null_state_;
        value_type __val_;
    };
    bool __engaged_;

    _LIBCPP_INLINE_VISIBILITY
    ~__optional_destruct_base()
    {
        if (__engaged_)
            __val_.~value_type();
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr __optional_destruct_base() noexcept
        :  __null_state_(),
           __engaged_(false) {}

    template <class... _Args>
    _LIBCPP_INLINE_VISIBILITY
    constexpr explicit __optional_destruct_base(in_place_t, _Args&&... __args)
        :  __val_(_VSTD::forward<_Args>(__args)...),
           __engaged_(true) {}

    _LIBCPP_INLINE_VISIBILITY
    void reset() noexcept
    {
        if (__engaged_)
        {
            __val_.~value_type();
            __engaged_ = false;
        }
    }
};

template <class _Tp>
struct __optional_destruct_base<_Tp, true>
{
    typedef _Tp value_type;
    static_assert(is_object_v<value_type>,
        "instantiation of optional with a non-object type is undefined behavior");
    union
    {
        char __null_state_;
        value_type __val_;
    };
    bool __engaged_;

    _LIBCPP_INLINE_VISIBILITY
    constexpr __optional_destruct_base() noexcept
        :  __null_state_(),
           __engaged_(false) {}

    template <class... _Args>
    _LIBCPP_INLINE_VISIBILITY
    constexpr explicit __optional_destruct_base(in_place_t, _Args&&... __args)
        :  __val_(_VSTD::forward<_Args>(__args)...),
           __engaged_(true) {}

    _LIBCPP_INLINE_VISIBILITY
    void reset() noexcept
    {
        if (__engaged_)
        {
            __engaged_ = false;
        }
    }
};

template <class _Tp, bool = is_reference<_Tp>::value>
struct __optional_storage_base : __optional_destruct_base<_Tp>
{
    using __base = __optional_destruct_base<_Tp>;
    using value_type = _Tp;
    using __base::__base;

    _LIBCPP_INLINE_VISIBILITY
    constexpr bool has_value() const noexcept
    {
        return this->__engaged_;
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr value_type& __get() & noexcept
    {
        return this->__val_;
    }
    _LIBCPP_INLINE_VISIBILITY
    constexpr const value_type& __get() const& noexcept
    {
        return this->__val_;
    }
    _LIBCPP_INLINE_VISIBILITY
    constexpr value_type&& __get() && noexcept
    {
        return _VSTD::move(this->__val_);
    }
    _LIBCPP_INLINE_VISIBILITY
    constexpr const value_type&& __get() const&& noexcept
    {
        return _VSTD::move(this->__val_);
    }

    template <class... _Args>
    _LIBCPP_INLINE_VISIBILITY
    void __construct(_Args&&... __args)
    {
        _LIBCPP_ASSERT(!has_value(), "__construct called for engaged __optional_storage");
        ::new((void*)_VSTD::addressof(this->__val_)) value_type(_VSTD::forward<_Args>(__args)...);
        this->__engaged_ = true;
    }

    template <class _That>
    _LIBCPP_INLINE_VISIBILITY
    void __construct_from(_That&& __opt)
    {
        if (__opt.has_value())
            __construct(_VSTD::forward<_That>(__opt).__get());
    }

    template <class _That>
    _LIBCPP_INLINE_VISIBILITY
    void __assign_from(_That&& __opt)
    {
        if (this->__engaged_ == __opt.has_value())
        {
            if (this->__engaged_)
                this->__val_ = _VSTD::forward<_That>(__opt).__get();
        }
        else
        {
            if (this->__engaged_)
                this->reset();
            else
                __construct(_VSTD::forward<_That>(__opt).__get());
        }
    }
};

// optional<T&> is currently required ill-formed, however it may to be in the
// future. For this reason it has already been implemented to ensure we can
// make the change in an ABI compatible manner.
template <class _Tp>
struct __optional_storage_base<_Tp, true>
{
    using value_type = _Tp;
    using __raw_type = remove_reference_t<_Tp>;
    __raw_type* __value_;

    template <class _Up>
    static constexpr bool __can_bind_reference() {
        using _RawUp = typename remove_reference<_Up>::type;
        using _UpPtr = _RawUp*;
        using _RawTp = typename remove_reference<_Tp>::type;
        using _TpPtr = _RawTp*;
        using _CheckLValueArg = integral_constant<bool,
            (is_lvalue_reference<_Up>::value && is_convertible<_UpPtr, _TpPtr>::value)
        ||  is_same<_RawUp, reference_wrapper<_RawTp>>::value
        ||  is_same<_RawUp, reference_wrapper<typename remove_const<_RawTp>::type>>::value
        >;
        return (is_lvalue_reference<_Tp>::value && _CheckLValueArg::value)
            || (is_rvalue_reference<_Tp>::value && !is_lvalue_reference<_Up>::value &&
                is_convertible<_UpPtr, _TpPtr>::value);
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr __optional_storage_base() noexcept
        :  __value_(nullptr) {}

    template <class _UArg>
    _LIBCPP_INLINE_VISIBILITY
    constexpr explicit __optional_storage_base(in_place_t, _UArg&& __uarg)
        :  __value_(_VSTD::addressof(__uarg))
    {
      static_assert(__can_bind_reference<_UArg>(),
        "Attempted to construct a reference element in tuple from a "
        "possible temporary");
    }

    _LIBCPP_INLINE_VISIBILITY
    void reset() noexcept { __value_ = nullptr; }

    _LIBCPP_INLINE_VISIBILITY
    constexpr bool has_value() const noexcept
      { return __value_ != nullptr; }

    _LIBCPP_INLINE_VISIBILITY
    constexpr value_type& __get() const& noexcept
      { return *__value_; }

    _LIBCPP_INLINE_VISIBILITY
    constexpr value_type&& __get() const&& noexcept
      { return _VSTD::forward<value_type>(*__value_); }

    template <class _UArg>
    _LIBCPP_INLINE_VISIBILITY
    void __construct(_UArg&& __val)
    {
        _LIBCPP_ASSERT(!has_value(), "__construct called for engaged __optional_storage");
        static_assert(__can_bind_reference<_UArg>(),
            "Attempted to construct a reference element in tuple from a "
            "possible temporary");
        __value_ = _VSTD::addressof(__val);
    }

    template <class _That>
    _LIBCPP_INLINE_VISIBILITY
    void __construct_from(_That&& __opt)
    {
        if (__opt.has_value())
            __construct(_VSTD::forward<_That>(__opt).__get());
    }

    template <class _That>
    _LIBCPP_INLINE_VISIBILITY
    void __assign_from(_That&& __opt)
    {
        if (has_value() == __opt.has_value())
        {
            if (has_value())
                *__value_ = _VSTD::forward<_That>(__opt).__get();
        }
        else
        {
            if (has_value())
                reset();
            else
                __construct(_VSTD::forward<_That>(__opt).__get());
        }
    }
};

template <class _Tp, bool = is_trivially_copy_constructible<_Tp>::value>
struct __optional_copy_base : __optional_storage_base<_Tp>
{
    using __optional_storage_base<_Tp>::__optional_storage_base;
};

template <class _Tp>
struct __optional_copy_base<_Tp, false> : __optional_storage_base<_Tp>
{
    using __optional_storage_base<_Tp>::__optional_storage_base;

    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_base() = default;

    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_base(const __optional_copy_base& __opt)
    {
        this->__construct_from(__opt);
    }

    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_base(__optional_copy_base&&) = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_base& operator=(const __optional_copy_base&) = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_base& operator=(__optional_copy_base&&) = default;
};

template <class _Tp, bool = is_trivially_move_constructible<_Tp>::value>
struct __optional_move_base : __optional_copy_base<_Tp>
{
    using __optional_copy_base<_Tp>::__optional_copy_base;
};

template <class _Tp>
struct __optional_move_base<_Tp, false> : __optional_copy_base<_Tp>
{
    using value_type = _Tp;
    using __optional_copy_base<_Tp>::__optional_copy_base;

    _LIBCPP_INLINE_VISIBILITY
    __optional_move_base() = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_move_base(const __optional_move_base&) = default;

    _LIBCPP_INLINE_VISIBILITY
    __optional_move_base(__optional_move_base&& __opt)
        noexcept(is_nothrow_move_constructible_v<value_type>)
    {
        this->__construct_from(_VSTD::move(__opt));
    }

    _LIBCPP_INLINE_VISIBILITY
    __optional_move_base& operator=(const __optional_move_base&) = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_move_base& operator=(__optional_move_base&&) = default;
};

template <class _Tp, bool =
    is_trivially_destructible<_Tp>::value &&
    is_trivially_copy_constructible<_Tp>::value &&
    is_trivially_copy_assignable<_Tp>::value>
struct __optional_copy_assign_base : __optional_move_base<_Tp>
{
    using __optional_move_base<_Tp>::__optional_move_base;
};

template <class _Tp>
struct __optional_copy_assign_base<_Tp, false> : __optional_move_base<_Tp>
{
    using __optional_move_base<_Tp>::__optional_move_base;

    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_assign_base() = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_assign_base(const __optional_copy_assign_base&) = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_assign_base(__optional_copy_assign_base&&) = default;

    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_assign_base& operator=(const __optional_copy_assign_base& __opt)
    {
        this->__assign_from(__opt);
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __optional_copy_assign_base& operator=(__optional_copy_assign_base&&) = default;
};

template <class _Tp, bool =
    is_trivially_destructible<_Tp>::value &&
    is_trivially_move_constructible<_Tp>::value &&
    is_trivially_move_assignable<_Tp>::value>
struct __optional_move_assign_base : __optional_copy_assign_base<_Tp>
{
    using __optional_copy_assign_base<_Tp>::__optional_copy_assign_base;
};

template <class _Tp>
struct __optional_move_assign_base<_Tp, false> : __optional_copy_assign_base<_Tp>
{
    using value_type = _Tp;
    using __optional_copy_assign_base<_Tp>::__optional_copy_assign_base;

    _LIBCPP_INLINE_VISIBILITY
    __optional_move_assign_base() = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_move_assign_base(const __optional_move_assign_base& __opt) = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_move_assign_base(__optional_move_assign_base&&) = default;
    _LIBCPP_INLINE_VISIBILITY
    __optional_move_assign_base& operator=(const __optional_move_assign_base&) = default;

    _LIBCPP_INLINE_VISIBILITY
    __optional_move_assign_base& operator=(__optional_move_assign_base&& __opt)
        noexcept(is_nothrow_move_assignable_v<value_type> &&
                 is_nothrow_move_constructible_v<value_type>)
    {
        this->__assign_from(_VSTD::move(__opt));
        return *this;
    }
};

template <class _Tp>
using __optional_sfinae_ctor_base_t = __sfinae_ctor_base<
    is_copy_constructible<_Tp>::value,
    is_move_constructible<_Tp>::value
>;

template <class _Tp>
using __optional_sfinae_assign_base_t = __sfinae_assign_base<
    (is_copy_constructible<_Tp>::value && is_copy_assignable<_Tp>::value),
    (is_move_constructible<_Tp>::value && is_move_assignable<_Tp>::value)
>;

template <class _Tp>
class optional
    : private __optional_move_assign_base<_Tp>
    , private __optional_sfinae_ctor_base_t<_Tp>
    , private __optional_sfinae_assign_base_t<_Tp>
{
    using __base = __optional_move_assign_base<_Tp>;
public:
    using value_type = _Tp;

private:
     // Disable the reference extension using this static assert.
    static_assert(!is_same_v<__uncvref_t<value_type>, in_place_t>,
        "instantiation of optional with in_place_t is ill-formed");
    static_assert(!is_same_v<__uncvref_t<value_type>, nullopt_t>,
        "instantiation of optional with nullopt_t is ill-formed");
    static_assert(!is_reference_v<value_type>,
        "instantiation of optional with a reference type is ill-formed");
    static_assert(is_destructible_v<value_type>,
        "instantiation of optional with a non-destructible type is ill-formed");
    static_assert(!is_array_v<value_type>,
        "instantiation of optional with an array type is ill-formed");

    // LWG2756: conditionally explicit conversion from _Up
    struct _CheckOptionalArgsConstructor {
      template <class _Up>
      static constexpr bool __enable_implicit() {
          return is_constructible_v<_Tp, _Up&&> &&
                 is_convertible_v<_Up&&, _Tp>;
      }

      template <class _Up>
      static constexpr bool __enable_explicit() {
          return is_constructible_v<_Tp, _Up&&> &&
                 !is_convertible_v<_Up&&, _Tp>;
      }
    };
    template <class _Up>
    using _CheckOptionalArgsCtor = _If<
        _IsNotSame<__uncvref_t<_Up>, in_place_t>::value &&
        _IsNotSame<__uncvref_t<_Up>, optional>::value,
        _CheckOptionalArgsConstructor,
        __check_tuple_constructor_fail
    >;
    template <class _QualUp>
    struct _CheckOptionalLikeConstructor {
      template <class _Up, class _Opt = optional<_Up>>
      using __check_constructible_from_opt = _Or<
          is_constructible<_Tp, _Opt&>,
          is_constructible<_Tp, _Opt const&>,
          is_constructible<_Tp, _Opt&&>,
          is_constructible<_Tp, _Opt const&&>,
          is_convertible<_Opt&, _Tp>,
          is_convertible<_Opt const&, _Tp>,
          is_convertible<_Opt&&, _Tp>,
          is_convertible<_Opt const&&, _Tp>
      >;
      template <class _Up, class _Opt = optional<_Up>>
      using __check_assignable_from_opt = _Or<
          is_assignable<_Tp&, _Opt&>,
          is_assignable<_Tp&, _Opt const&>,
          is_assignable<_Tp&, _Opt&&>,
          is_assignable<_Tp&, _Opt const&&>
      >;
      template <class _Up, class _QUp = _QualUp>
      static constexpr bool __enable_implicit() {
          return is_convertible<_QUp, _Tp>::value &&
              !__check_constructible_from_opt<_Up>::value;
      }
      template <class _Up, class _QUp = _QualUp>
      static constexpr bool __enable_explicit() {
          return !is_convertible<_QUp, _Tp>::value &&
              !__check_constructible_from_opt<_Up>::value;
      }
      template <class _Up, class _QUp = _QualUp>
      static constexpr bool __enable_assign() {
          // Construction and assignability of _Qup to _Tp has already been
          // checked.
          return !__check_constructible_from_opt<_Up>::value &&
              !__check_assignable_from_opt<_Up>::value;
      }
    };

    template <class _Up, class _QualUp>
    using _CheckOptionalLikeCtor = _If<
      _And<
         _IsNotSame<_Up, _Tp>,
          is_constructible<_Tp, _QualUp>
      >::value,
      _CheckOptionalLikeConstructor<_QualUp>,
      __check_tuple_constructor_fail
    >;
    template <class _Up, class _QualUp>
    using _CheckOptionalLikeAssign = _If<
      _And<
          _IsNotSame<_Up, _Tp>,
          is_constructible<_Tp, _QualUp>,
          is_assignable<_Tp&, _QualUp>
      >::value,
      _CheckOptionalLikeConstructor<_QualUp>,
      __check_tuple_constructor_fail
    >;
public:

    _LIBCPP_INLINE_VISIBILITY constexpr optional() noexcept {}
    _LIBCPP_INLINE_VISIBILITY constexpr optional(const optional&) = default;
    _LIBCPP_INLINE_VISIBILITY constexpr optional(optional&&) = default;
    _LIBCPP_INLINE_VISIBILITY constexpr optional(nullopt_t) noexcept {}

    template <class _InPlaceT, class... _Args, class = _EnableIf<
          _And<
              _IsSame<_InPlaceT, in_place_t>,
              is_constructible<value_type, _Args...>
            >::value
        >
    >
    _LIBCPP_INLINE_VISIBILITY
    constexpr explicit optional(_InPlaceT, _Args&&... __args)
        : __base(in_place, _VSTD::forward<_Args>(__args)...) {}

    template <class _Up, class... _Args, class = _EnableIf<
        is_constructible_v<value_type, initializer_list<_Up>&, _Args...>>
    >
    _LIBCPP_INLINE_VISIBILITY
    constexpr explicit optional(in_place_t, initializer_list<_Up> __il, _Args&&... __args)
        : __base(in_place, __il, _VSTD::forward<_Args>(__args)...) {}

    template <class _Up = value_type, _EnableIf<
        _CheckOptionalArgsCtor<_Up>::template __enable_implicit<_Up>()
    , int> = 0>
    _LIBCPP_INLINE_VISIBILITY
    constexpr optional(_Up&& __v)
        : __base(in_place, _VSTD::forward<_Up>(__v)) {}

    template <class _Up, _EnableIf<
        _CheckOptionalArgsCtor<_Up>::template __enable_explicit<_Up>()
    , int> = 0>
    _LIBCPP_INLINE_VISIBILITY
    constexpr explicit optional(_Up&& __v)
        : __base(in_place, _VSTD::forward<_Up>(__v)) {}

    // LWG2756: conditionally explicit conversion from const optional<_Up>&
    template <class _Up, _EnableIf<
        _CheckOptionalLikeCtor<_Up, _Up const&>::template __enable_implicit<_Up>()
    , int> = 0>
    _LIBCPP_INLINE_VISIBILITY
    optional(const optional<_Up>& __v)
    {
        this->__construct_from(__v);
    }
    template <class _Up, _EnableIf<
        _CheckOptionalLikeCtor<_Up, _Up const&>::template __enable_explicit<_Up>()
    , int> = 0>
    _LIBCPP_INLINE_VISIBILITY
    explicit optional(const optional<_Up>& __v)
    {
        this->__construct_from(__v);
    }

    // LWG2756: conditionally explicit conversion from optional<_Up>&&
    template <class _Up, _EnableIf<
        _CheckOptionalLikeCtor<_Up, _Up &&>::template __enable_implicit<_Up>()
    , int> = 0>
    _LIBCPP_INLINE_VISIBILITY
    optional(optional<_Up>&& __v)
    {
        this->__construct_from(_VSTD::move(__v));
    }
    template <class _Up, _EnableIf<
        _CheckOptionalLikeCtor<_Up, _Up &&>::template __enable_explicit<_Up>()
    , int> = 0>
    _LIBCPP_INLINE_VISIBILITY
    explicit optional(optional<_Up>&& __v)
    {
        this->__construct_from(_VSTD::move(__v));
    }

    _LIBCPP_INLINE_VISIBILITY
    optional& operator=(nullopt_t) noexcept
    {
        reset();
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY optional& operator=(const optional&) = default;
    _LIBCPP_INLINE_VISIBILITY optional& operator=(optional&&) = default;

    // LWG2756
    template <class _Up = value_type,
              class = _EnableIf<
                      _And<
                          _IsNotSame<__uncvref_t<_Up>, optional>,
                          _Or<
                              _IsNotSame<__uncvref_t<_Up>, value_type>,
                              _Not<is_scalar<value_type>>
                          >,
                          is_constructible<value_type, _Up>,
                          is_assignable<value_type&, _Up>
                      >::value>
             >
    _LIBCPP_INLINE_VISIBILITY
    optional&
    operator=(_Up&& __v)
    {
        if (this->has_value())
            this->__get() = _VSTD::forward<_Up>(__v);
        else
            this->__construct(_VSTD::forward<_Up>(__v));
        return *this;
    }

    // LWG2756
    template <class _Up, _EnableIf<
        _CheckOptionalLikeAssign<_Up, _Up const&>::template __enable_assign<_Up>()
    , int> = 0>
    _LIBCPP_INLINE_VISIBILITY
    optional&
    operator=(const optional<_Up>& __v)
    {
        this->__assign_from(__v);
        return *this;
    }

    // LWG2756
    template <class _Up, _EnableIf<
        _CheckOptionalLikeCtor<_Up, _Up &&>::template __enable_assign<_Up>()
    , int> = 0>
    _LIBCPP_INLINE_VISIBILITY
    optional&
    operator=(optional<_Up>&& __v)
    {
        this->__assign_from(_VSTD::move(__v));
        return *this;
    }

    template <class... _Args,
              class = _EnableIf
                      <
                          is_constructible_v<value_type, _Args...>
                      >
             >
    _LIBCPP_INLINE_VISIBILITY
    _Tp &
    emplace(_Args&&... __args)
    {
        reset();
        this->__construct(_VSTD::forward<_Args>(__args)...);
        return this->__get();
    }

    template <class _Up, class... _Args,
              class = _EnableIf
                      <
                          is_constructible_v<value_type, initializer_list<_Up>&, _Args...>
                      >
             >
    _LIBCPP_INLINE_VISIBILITY
    _Tp &
    emplace(initializer_list<_Up> __il, _Args&&... __args)
    {
        reset();
        this->__construct(__il, _VSTD::forward<_Args>(__args)...);
        return this->__get();
    }

    _LIBCPP_INLINE_VISIBILITY
    void swap(optional& __opt)
        noexcept(is_nothrow_move_constructible_v<value_type> &&
                 is_nothrow_swappable_v<value_type>)
    {
        if (this->has_value() == __opt.has_value())
        {
            using _VSTD::swap;
            if (this->has_value())
                swap(this->__get(), __opt.__get());
        }
        else
        {
            if (this->has_value())
            {
                __opt.__construct(_VSTD::move(this->__get()));
                reset();
            }
            else
            {
                this->__construct(_VSTD::move(__opt.__get()));
                __opt.reset();
            }
        }
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr
    add_pointer_t<value_type const>
    operator->() const
    {
        _LIBCPP_ASSERT(this->has_value(), "optional operator-> called for disengaged value");
#ifndef _LIBCPP_HAS_NO_BUILTIN_ADDRESSOF
        return _VSTD::addressof(this->__get());
#else
# 883 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
        return __operator_arrow(__has_operator_addressof<value_type>{}, this->__get());
#endif
# 885 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr
    add_pointer_t<value_type>
    operator->()
    {
        _LIBCPP_ASSERT(this->has_value(), "optional operator-> called for disengaged value");
#ifndef _LIBCPP_HAS_NO_BUILTIN_ADDRESSOF
        return _VSTD::addressof(this->__get());
#else
# 896 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
        return __operator_arrow(__has_operator_addressof<value_type>{}, this->__get());
#endif
# 898 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr
    const value_type&
    operator*() const&
    {
        _LIBCPP_ASSERT(this->has_value(), "optional operator* called for disengaged value");
        return this->__get();
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr
    value_type&
    operator*() &
    {
        _LIBCPP_ASSERT(this->has_value(), "optional operator* called for disengaged value");
        return this->__get();
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr
    value_type&&
    operator*() &&
    {
        _LIBCPP_ASSERT(this->has_value(), "optional operator* called for disengaged value");
        return _VSTD::move(this->__get());
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr
    const value_type&&
    operator*() const&&
    {
        _LIBCPP_ASSERT(this->has_value(), "optional operator* called for disengaged value");
        return _VSTD::move(this->__get());
    }

    _LIBCPP_INLINE_VISIBILITY
    constexpr explicit operator bool() const noexcept { return has_value(); }

    using __base::has_value;
    using __base::__get;

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_AVAILABILITY_THROW_BAD_OPTIONAL_ACCESS
    constexpr value_type const& value() const&
    {
        if (!this->has_value())
            __throw_bad_optional_access();
        return this->__get();
    }

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_AVAILABILITY_THROW_BAD_OPTIONAL_ACCESS
    constexpr value_type& value() &
    {
        if (!this->has_value())
            __throw_bad_optional_access();
        return this->__get();
    }

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_AVAILABILITY_THROW_BAD_OPTIONAL_ACCESS
    constexpr value_type&& value() &&
    {
        if (!this->has_value())
            __throw_bad_optional_access();
        return _VSTD::move(this->__get());
    }

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_AVAILABILITY_THROW_BAD_OPTIONAL_ACCESS
    constexpr value_type const&& value() const&&
    {
        if (!this->has_value())
            __throw_bad_optional_access();
        return _VSTD::move(this->__get());
    }

    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY
    constexpr value_type value_or(_Up&& __v) const&
    {
        static_assert(is_copy_constructible_v<value_type>,
                      "optional<T>::value_or: T must be copy constructible");
        static_assert(is_convertible_v<_Up, value_type>,
                      "optional<T>::value_or: U must be convertible to T");
        return this->has_value() ? this->__get() :
                                  static_cast<value_type>(_VSTD::forward<_Up>(__v));
    }

    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY
    constexpr value_type value_or(_Up&& __v) &&
    {
        static_assert(is_move_constructible_v<value_type>,
                      "optional<T>::value_or: T must be move constructible");
        static_assert(is_convertible_v<_Up, value_type>,
                      "optional<T>::value_or: U must be convertible to T");
        return this->has_value() ? _VSTD::move(this->__get()) :
                                  static_cast<value_type>(_VSTD::forward<_Up>(__v));
    }

    using __base::reset;

private:
    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY
    static _Up*
    __operator_arrow(true_type, _Up& __x)
    {
        return _VSTD::addressof(__x);
    }

    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY
    static constexpr _Up*
    __operator_arrow(false_type, _Up& __x)
    {
        return &__x;
    }
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class T>
    optional(T) -> optional<T>;
#endif
# 1026 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3

// Comparisons between optionals
template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() ==
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator==(const optional<_Tp>& __x, const optional<_Up>& __y)
{
    if (static_cast<bool>(__x) != static_cast<bool>(__y))
        return false;
    if (!static_cast<bool>(__x))
        return true;
    return *__x == *__y;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() !=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator!=(const optional<_Tp>& __x, const optional<_Up>& __y)
{
    if (static_cast<bool>(__x) != static_cast<bool>(__y))
        return true;
    if (!static_cast<bool>(__x))
        return false;
    return *__x != *__y;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() <
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator<(const optional<_Tp>& __x, const optional<_Up>& __y)
{
    if (!static_cast<bool>(__y))
        return false;
    if (!static_cast<bool>(__x))
        return true;
    return *__x < *__y;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() >
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator>(const optional<_Tp>& __x, const optional<_Up>& __y)
{
    if (!static_cast<bool>(__x))
        return false;
    if (!static_cast<bool>(__y))
        return true;
    return *__x > *__y;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() <=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator<=(const optional<_Tp>& __x, const optional<_Up>& __y)
{
    if (!static_cast<bool>(__x))
        return true;
    if (!static_cast<bool>(__y))
        return false;
    return *__x <= *__y;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() >=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator>=(const optional<_Tp>& __x, const optional<_Up>& __y)
{
    if (!static_cast<bool>(__y))
        return true;
    if (!static_cast<bool>(__x))
        return false;
    return *__x >= *__y;
}

// Comparisons with nullopt
template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator==(const optional<_Tp>& __x, nullopt_t) noexcept
{
    return !static_cast<bool>(__x);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator==(nullopt_t, const optional<_Tp>& __x) noexcept
{
    return !static_cast<bool>(__x);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator!=(const optional<_Tp>& __x, nullopt_t) noexcept
{
    return static_cast<bool>(__x);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator!=(nullopt_t, const optional<_Tp>& __x) noexcept
{
    return static_cast<bool>(__x);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator<(const optional<_Tp>&, nullopt_t) noexcept
{
    return false;
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator<(nullopt_t, const optional<_Tp>& __x) noexcept
{
    return static_cast<bool>(__x);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator<=(const optional<_Tp>& __x, nullopt_t) noexcept
{
    return !static_cast<bool>(__x);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator<=(nullopt_t, const optional<_Tp>&) noexcept
{
    return true;
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator>(const optional<_Tp>& __x, nullopt_t) noexcept
{
    return static_cast<bool>(__x);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator>(nullopt_t, const optional<_Tp>&) noexcept
{
    return false;
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator>=(const optional<_Tp>&, nullopt_t) noexcept
{
    return true;
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
bool
operator>=(nullopt_t, const optional<_Tp>& __x) noexcept
{
    return !static_cast<bool>(__x);
}

// Comparisons with T
template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() ==
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator==(const optional<_Tp>& __x, const _Up& __v)
{
    return static_cast<bool>(__x) ? *__x == __v : false;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() ==
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator==(const _Tp& __v, const optional<_Up>& __x)
{
    return static_cast<bool>(__x) ? __v == *__x : false;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() !=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator!=(const optional<_Tp>& __x, const _Up& __v)
{
    return static_cast<bool>(__x) ? *__x != __v : true;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() !=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator!=(const _Tp& __v, const optional<_Up>& __x)
{
    return static_cast<bool>(__x) ? __v != *__x : true;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() <
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator<(const optional<_Tp>& __x, const _Up& __v)
{
    return static_cast<bool>(__x) ? *__x < __v : true;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() <
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator<(const _Tp& __v, const optional<_Up>& __x)
{
    return static_cast<bool>(__x) ? __v < *__x : false;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() <=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator<=(const optional<_Tp>& __x, const _Up& __v)
{
    return static_cast<bool>(__x) ? *__x <= __v : true;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() <=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator<=(const _Tp& __v, const optional<_Up>& __x)
{
    return static_cast<bool>(__x) ? __v <= *__x : false;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() >
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator>(const optional<_Tp>& __x, const _Up& __v)
{
    return static_cast<bool>(__x) ? *__x > __v : false;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() >
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator>(const _Tp& __v, const optional<_Up>& __x)
{
    return static_cast<bool>(__x) ? __v > *__x : true;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() >=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator>=(const optional<_Tp>& __x, const _Up& __v)
{
    return static_cast<bool>(__x) ? *__x >= __v : false;
}

template <class _Tp, class _Up>
_LIBCPP_INLINE_VISIBILITY constexpr
_EnableIf<
    is_convertible_v<decltype(_VSTD::declval<const _Tp&>() >=
        _VSTD::declval<const _Up&>()), bool>,
    bool
>
operator>=(const _Tp& __v, const optional<_Up>& __x)
{
    return static_cast<bool>(__x) ? __v >= *__x : true;
}


template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_EnableIf<
    is_move_constructible_v<_Tp> && is_swappable_v<_Tp>,
    void
>
swap(optional<_Tp>& __x, optional<_Tp>& __y) noexcept(noexcept(__x.swap(__y)))
{
    __x.swap(__y);
}

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY constexpr
optional<decay_t<_Tp>> make_optional(_Tp&& __v)
{
    return optional<decay_t<_Tp>>(_VSTD::forward<_Tp>(__v));
}

template <class _Tp, class... _Args>
_LIBCPP_INLINE_VISIBILITY constexpr
optional<_Tp> make_optional(_Args&&... __args)
{
    return optional<_Tp>(in_place, _VSTD::forward<_Args>(__args)...);
}

template <class _Tp, class _Up, class... _Args>
_LIBCPP_INLINE_VISIBILITY constexpr
optional<_Tp> make_optional(initializer_list<_Up> __il,  _Args&&... __args)
{
    return optional<_Tp>(in_place, __il, _VSTD::forward<_Args>(__args)...);
}

template <class _Tp>
struct _LIBCPP_TEMPLATE_VIS hash<
    __enable_hash_helper<optional<_Tp>, remove_const_t<_Tp>>
>
{
    typedef optional<_Tp> argument_type;
    typedef size_t        result_type;

    _LIBCPP_INLINE_VISIBILITY
    result_type operator()(const argument_type& __opt) const
    {
        return static_cast<bool>(__opt) ? hash<remove_const_t<_Tp>>()(*__opt) : 0;
    }
};

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_STD_VER > 14
# 1417 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_OPTIONAL
# 1421 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/optional" 3
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 2 3

_LIBCPP_BEGIN_NAMESPACE_STD

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3

// Specialized in __tree & __hash_table for their _NodeType.
template <class _NodeType, class _Alloc>
struct __generic_container_node_destructor;

template <class _NodeType, class _Alloc,
          template <class, class> class _MapOrSetSpecifics>
class _LIBCPP_TEMPLATE_VIS __basic_node_handle
    : public _MapOrSetSpecifics<
          _NodeType,
          __basic_node_handle<_NodeType, _Alloc, _MapOrSetSpecifics>>
{
    template <class _Tp, class _Compare, class _Allocator>
        friend class __tree;
    template <class _Tp, class _Hash, class _Equal, class _Allocator>
        friend class __hash_table;
    friend struct _MapOrSetSpecifics<
        _NodeType, __basic_node_handle<_NodeType, _Alloc, _MapOrSetSpecifics>>;

    typedef allocator_traits<_Alloc> __alloc_traits;
    typedef typename __rebind_pointer<typename __alloc_traits::void_pointer,
                                      _NodeType>::type
        __node_pointer_type;

public:
    typedef _Alloc allocator_type;

private:
    __node_pointer_type __ptr_ = nullptr;
    optional<allocator_type> __alloc_;

    _LIBCPP_INLINE_VISIBILITY
    void __release_ptr()
    {
        __ptr_ = nullptr;
        __alloc_ = _VSTD::nullopt;
    }

    _LIBCPP_INLINE_VISIBILITY
    void __destroy_node_pointer()
    {
        if (__ptr_ != nullptr)
        {
            typedef typename __allocator_traits_rebind<
                allocator_type, _NodeType>::type __node_alloc_type;
            __node_alloc_type __alloc(*__alloc_);
            __generic_container_node_destructor<_NodeType, __node_alloc_type>(
                __alloc, true)(__ptr_);
            __ptr_ = nullptr;
        }
    }

    _LIBCPP_INLINE_VISIBILITY
    __basic_node_handle(__node_pointer_type __ptr,
                        allocator_type const& __alloc)
            : __ptr_(__ptr), __alloc_(__alloc)
    {
    }

public:
    _LIBCPP_INLINE_VISIBILITY
    __basic_node_handle() = default;

    _LIBCPP_INLINE_VISIBILITY
    __basic_node_handle(__basic_node_handle&& __other) noexcept
            : __ptr_(__other.__ptr_),
              __alloc_(_VSTD::move(__other.__alloc_))
    {
        __other.__ptr_ = nullptr;
        __other.__alloc_ = _VSTD::nullopt;
    }

    _LIBCPP_INLINE_VISIBILITY
    __basic_node_handle& operator=(__basic_node_handle&& __other)
    {
        _LIBCPP_ASSERT(
            __alloc_ == _VSTD::nullopt ||
            __alloc_traits::propagate_on_container_move_assignment::value ||
            __alloc_ == __other.__alloc_,
            "node_type with incompatible allocator passed to "
            "node_type::operator=(node_type&&)");

        __destroy_node_pointer();
        __ptr_ = __other.__ptr_;

        if (__alloc_traits::propagate_on_container_move_assignment::value ||
            __alloc_ == _VSTD::nullopt)
            __alloc_ = _VSTD::move(__other.__alloc_);

        __other.__ptr_ = nullptr;
        __other.__alloc_ = _VSTD::nullopt;

        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    allocator_type get_allocator() const { return *__alloc_; }

    _LIBCPP_INLINE_VISIBILITY
    explicit operator bool() const { return __ptr_ != nullptr; }

    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool empty() const { return __ptr_ == nullptr; }

    _LIBCPP_INLINE_VISIBILITY
    void swap(__basic_node_handle& __other) noexcept(
        __alloc_traits::propagate_on_container_swap::value ||
        __alloc_traits::is_always_equal::value)
    {
        using _VSTD::swap;
        swap(__ptr_, __other.__ptr_);
        if (__alloc_traits::propagate_on_container_swap::value ||
            __alloc_ == _VSTD::nullopt || __other.__alloc_ == _VSTD::nullopt)
            swap(__alloc_, __other.__alloc_);
    }

    _LIBCPP_INLINE_VISIBILITY
    friend void swap(__basic_node_handle& __a, __basic_node_handle& __b)
        noexcept(noexcept(__a.swap(__b))) { __a.swap(__b); }

    _LIBCPP_INLINE_VISIBILITY
    ~__basic_node_handle()
    {
        __destroy_node_pointer();
    }
};

template <class _NodeType, class _Derived>
struct __set_node_handle_specifics
{
    typedef typename _NodeType::__node_value_type value_type;

    _LIBCPP_INLINE_VISIBILITY
    value_type& value() const
    {
        return static_cast<_Derived const*>(this)->__ptr_->__value_;
    }
};

template <class _NodeType, class _Derived>
struct __map_node_handle_specifics
{
    typedef typename _NodeType::__node_value_type::key_type key_type;
    typedef typename _NodeType::__node_value_type::mapped_type mapped_type;

    _LIBCPP_INLINE_VISIBILITY
    key_type& key() const
    {
        return static_cast<_Derived const*>(this)->
            __ptr_->__value_.__ref().first;
    }

    _LIBCPP_INLINE_VISIBILITY
    mapped_type& mapped() const
    {
        return static_cast<_Derived const*>(this)->
            __ptr_->__value_.__ref().second;
    }
};

template <class _NodeType, class _Alloc>
using __set_node_handle =
    __basic_node_handle< _NodeType, _Alloc, __set_node_handle_specifics>;

template <class _NodeType, class _Alloc>
using __map_node_handle =
    __basic_node_handle< _NodeType, _Alloc, __map_node_handle_specifics>;

template <class _Iterator, class _NodeType>
struct _LIBCPP_TEMPLATE_VIS __insert_return_type
{
    _Iterator position;
    bool inserted;
    _NodeType node;
};

#endif // _LIBCPP_STD_VER > 14
# 204 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3

_LIBCPP_END_NAMESPACE_STD
_LIBCPP_POP_MACROS

#endif
# 209 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__node_handle" 3
# 481 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 481 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 482 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 482 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 483 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 483 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 484 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#if 0 /* expanded by -frewrite-includes */
#include <functional>
#endif /* expanded by -frewrite-includes */
# 484 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 485 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 485 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 486 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 486 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 487 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 487 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 488 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 490 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 491 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
#endif
# 492 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Key, class _CP, class _Compare,
          bool = is_empty<_Compare>::value && !__libcpp_is_final<_Compare>::value>
class __map_value_compare
    : private _Compare
{
public:
    _LIBCPP_INLINE_VISIBILITY
    __map_value_compare()
        _NOEXCEPT_(is_nothrow_default_constructible<_Compare>::value)
        : _Compare() {}
    _LIBCPP_INLINE_VISIBILITY
    __map_value_compare(_Compare c)
        _NOEXCEPT_(is_nothrow_copy_constructible<_Compare>::value)
        : _Compare(c) {}
    _LIBCPP_INLINE_VISIBILITY
    const _Compare& key_comp() const _NOEXCEPT {return *this;}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _CP& __x, const _CP& __y) const
        {return static_cast<const _Compare&>(*this)(__x.__get_value().first, __y.__get_value().first);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _CP& __x, const _Key& __y) const
        {return static_cast<const _Compare&>(*this)(__x.__get_value().first, __y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Key& __x, const _CP& __y) const
        {return static_cast<const _Compare&>(*this)(__x, __y.__get_value().first);}
    void swap(__map_value_compare&__y)
        _NOEXCEPT_(__is_nothrow_swappable<_Compare>::value)
    {
      using _VSTD::swap;
      swap(static_cast<_Compare&>(*this), static_cast<_Compare&>(__y));
    }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 528 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value, bool>::type
    operator () ( const _K2& __x, const _CP& __y ) const
        {return static_cast<const _Compare&>(*this) (__x, __y.__get_value().first);}

    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value, bool>::type
    operator () (const _CP& __x, const _K2& __y) const
        {return static_cast<const _Compare&>(*this) (__x.__get_value().first, __y);}
#endif
# 540 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
};

template <class _Key, class _CP, class _Compare>
class __map_value_compare<_Key, _CP, _Compare, false>
{
    _Compare comp;

public:
    _LIBCPP_INLINE_VISIBILITY
    __map_value_compare()
        _NOEXCEPT_(is_nothrow_default_constructible<_Compare>::value)
        : comp() {}
    _LIBCPP_INLINE_VISIBILITY
    __map_value_compare(_Compare c)
        _NOEXCEPT_(is_nothrow_copy_constructible<_Compare>::value)
        : comp(c) {}
    _LIBCPP_INLINE_VISIBILITY
    const _Compare& key_comp() const _NOEXCEPT {return comp;}

    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _CP& __x, const _CP& __y) const
        {return comp(__x.__get_value().first, __y.__get_value().first);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _CP& __x, const _Key& __y) const
        {return comp(__x.__get_value().first, __y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Key& __x, const _CP& __y) const
        {return comp(__x, __y.__get_value().first);}
    void swap(__map_value_compare&__y)
        _NOEXCEPT_(__is_nothrow_swappable<_Compare>::value)
    {
        using _VSTD::swap;
        swap(comp, __y.comp);
    }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 576 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value, bool>::type
    operator () ( const _K2& __x, const _CP& __y ) const
        {return comp (__x, __y.__get_value().first);}

    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value, bool>::type
    operator () (const _CP& __x, const _K2& __y) const
        {return comp (__x.__get_value().first, __y);}
#endif
# 588 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
};

template <class _Key, class _CP, class _Compare, bool __b>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(__map_value_compare<_Key, _CP, _Compare, __b>& __x,
     __map_value_compare<_Key, _CP, _Compare, __b>& __y)
    _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

template <class _Allocator>
class __map_node_destructor
{
    typedef _Allocator                          allocator_type;
    typedef allocator_traits<allocator_type>    __alloc_traits;

public:
    typedef typename __alloc_traits::pointer    pointer;

private:
    allocator_type& __na_;

    __map_node_destructor& operator=(const __map_node_destructor&);

public:
    bool __first_constructed;
    bool __second_constructed;

    _LIBCPP_INLINE_VISIBILITY
    explicit __map_node_destructor(allocator_type& __na) _NOEXCEPT
        : __na_(__na),
          __first_constructed(false),
          __second_constructed(false)
        {}

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    __map_node_destructor(__tree_node_destructor<allocator_type>&& __x) _NOEXCEPT
        : __na_(__x.__na_),
          __first_constructed(__x.__value_constructed),
          __second_constructed(__x.__value_constructed)
        {
            __x.__value_constructed = false;
        }
#endif  // _LIBCPP_CXX03_LANG
# 635 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    void operator()(pointer __p) _NOEXCEPT
    {
        if (__second_constructed)
            __alloc_traits::destroy(__na_, _VSTD::addressof(__p->__value_.__get_value().second));
        if (__first_constructed)
            __alloc_traits::destroy(__na_, _VSTD::addressof(__p->__value_.__get_value().first));
        if (__p)
            __alloc_traits::deallocate(__na_, __p, 1);
    }
};

template <class _Key, class _Tp, class _Compare, class _Allocator>
    class map;
template <class _Key, class _Tp, class _Compare, class _Allocator>
    class multimap;
template <class _TreeIterator> class __map_const_iterator;

#ifndef _LIBCPP_CXX03_LANG

template <class _Key, class _Tp>
struct __value_type
{
    typedef _Key                                     key_type;
    typedef _Tp                                      mapped_type;
    typedef pair<const key_type, mapped_type>        value_type;
    typedef pair<key_type&, mapped_type&>            __nc_ref_pair_type;
    typedef pair<key_type&&, mapped_type&&>          __nc_rref_pair_type;

private:
    value_type __cc;

public:
    _LIBCPP_INLINE_VISIBILITY
    value_type& __get_value()
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 673 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
        return *_VSTD::launder(_VSTD::addressof(__cc));
#else
# 675 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
        return __cc;
#endif
# 677 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    }

    _LIBCPP_INLINE_VISIBILITY
    const value_type& __get_value() const
    {
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 683 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
        return *_VSTD::launder(_VSTD::addressof(__cc));
#else
# 685 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
        return __cc;
#endif
# 687 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    }

    _LIBCPP_INLINE_VISIBILITY
    __nc_ref_pair_type __ref()
    {
        value_type& __v = __get_value();
        return __nc_ref_pair_type(const_cast<key_type&>(__v.first), __v.second);
    }

    _LIBCPP_INLINE_VISIBILITY
    __nc_rref_pair_type __move()
    {
        value_type& __v = __get_value();
        return __nc_rref_pair_type(
            _VSTD::move(const_cast<key_type&>(__v.first)),
            _VSTD::move(__v.second));
    }

    _LIBCPP_INLINE_VISIBILITY
    __value_type& operator=(const __value_type& __v)
    {
        __ref() = __v.__get_value();
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __value_type& operator=(__value_type&& __v)
    {
        __ref() = __v.__move();
        return *this;
    }

    template <class _ValueTp,
              class = typename enable_if<
                    __is_same_uncvref<_ValueTp, value_type>::value
                 >::type
             >
    _LIBCPP_INLINE_VISIBILITY
    __value_type& operator=(_ValueTp&& __v)
    {
        __ref() = _VSTD::forward<_ValueTp>(__v);
        return *this;
    }

private:
    __value_type() _LIBCPP_EQUAL_DELETE;
    ~__value_type() _LIBCPP_EQUAL_DELETE;
    __value_type(const __value_type& __v) _LIBCPP_EQUAL_DELETE;
    __value_type(__value_type&& __v) _LIBCPP_EQUAL_DELETE;
};

#else
# 739 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

template <class _Key, class _Tp>
struct __value_type
{
    typedef _Key                                     key_type;
    typedef _Tp                                      mapped_type;
    typedef pair<const key_type, mapped_type>        value_type;

private:
    value_type __cc;

public:
    _LIBCPP_INLINE_VISIBILITY
    value_type& __get_value() { return __cc; }
    _LIBCPP_INLINE_VISIBILITY
    const value_type& __get_value() const { return __cc; }

private:
   __value_type();
   __value_type(__value_type const&);
   __value_type& operator=(__value_type const&);
   ~__value_type();
};

#endif // _LIBCPP_CXX03_LANG
# 764 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

template <class _Tp>
struct __extract_key_value_types;

template <class _Key, class _Tp>
struct __extract_key_value_types<__value_type<_Key, _Tp> >
{
  typedef _Key const __key_type;
  typedef _Tp        __mapped_type;
};

template <class _TreeIterator>
class _LIBCPP_TEMPLATE_VIS __map_iterator
{
    typedef typename _TreeIterator::_NodeTypes                   _NodeTypes;
    typedef typename _TreeIterator::__pointer_traits             __pointer_traits;

    _TreeIterator __i_;

public:
    typedef bidirectional_iterator_tag                           iterator_category;
    typedef typename _NodeTypes::__map_value_type                value_type;
    typedef typename _TreeIterator::difference_type              difference_type;
    typedef value_type&                                          reference;
    typedef typename _NodeTypes::__map_value_type_pointer        pointer;

    _LIBCPP_INLINE_VISIBILITY
    __map_iterator() _NOEXCEPT {}

    _LIBCPP_INLINE_VISIBILITY
    __map_iterator(_TreeIterator __i) _NOEXCEPT : __i_(__i) {}

    _LIBCPP_INLINE_VISIBILITY
    reference operator*() const {return __i_->__get_value();}
    _LIBCPP_INLINE_VISIBILITY
    pointer operator->() const {return pointer_traits<pointer>::pointer_to(__i_->__get_value());}

    _LIBCPP_INLINE_VISIBILITY
    __map_iterator& operator++() {++__i_; return *this;}
    _LIBCPP_INLINE_VISIBILITY
    __map_iterator operator++(int)
    {
        __map_iterator __t(*this);
        ++(*this);
        return __t;
    }

    _LIBCPP_INLINE_VISIBILITY
    __map_iterator& operator--() {--__i_; return *this;}
    _LIBCPP_INLINE_VISIBILITY
    __map_iterator operator--(int)
    {
        __map_iterator __t(*this);
        --(*this);
        return __t;
    }

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator==(const __map_iterator& __x, const __map_iterator& __y)
        {return __x.__i_ == __y.__i_;}
    friend
    _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const __map_iterator& __x, const __map_iterator& __y)
        {return __x.__i_ != __y.__i_;}

    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS map;
    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS multimap;
    template <class> friend class _LIBCPP_TEMPLATE_VIS __map_const_iterator;
};

template <class _TreeIterator>
class _LIBCPP_TEMPLATE_VIS __map_const_iterator
{
    typedef typename _TreeIterator::_NodeTypes                   _NodeTypes;
    typedef typename _TreeIterator::__pointer_traits             __pointer_traits;

    _TreeIterator __i_;

public:
    typedef bidirectional_iterator_tag                           iterator_category;
    typedef typename _NodeTypes::__map_value_type                value_type;
    typedef typename _TreeIterator::difference_type              difference_type;
    typedef const value_type&                                    reference;
    typedef typename _NodeTypes::__const_map_value_type_pointer  pointer;

    _LIBCPP_INLINE_VISIBILITY
    __map_const_iterator() _NOEXCEPT {}

    _LIBCPP_INLINE_VISIBILITY
    __map_const_iterator(_TreeIterator __i) _NOEXCEPT : __i_(__i) {}
    _LIBCPP_INLINE_VISIBILITY
    __map_const_iterator(__map_iterator<
        typename _TreeIterator::__non_const_iterator> __i) _NOEXCEPT
        : __i_(__i.__i_) {}

    _LIBCPP_INLINE_VISIBILITY
    reference operator*() const {return __i_->__get_value();}
    _LIBCPP_INLINE_VISIBILITY
    pointer operator->() const {return pointer_traits<pointer>::pointer_to(__i_->__get_value());}

    _LIBCPP_INLINE_VISIBILITY
    __map_const_iterator& operator++() {++__i_; return *this;}
    _LIBCPP_INLINE_VISIBILITY
    __map_const_iterator operator++(int)
    {
        __map_const_iterator __t(*this);
        ++(*this);
        return __t;
    }

    _LIBCPP_INLINE_VISIBILITY
    __map_const_iterator& operator--() {--__i_; return *this;}
    _LIBCPP_INLINE_VISIBILITY
    __map_const_iterator operator--(int)
    {
        __map_const_iterator __t(*this);
        --(*this);
        return __t;
    }

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator==(const __map_const_iterator& __x, const __map_const_iterator& __y)
        {return __x.__i_ == __y.__i_;}
    friend _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const __map_const_iterator& __x, const __map_const_iterator& __y)
        {return __x.__i_ != __y.__i_;}

    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS map;
    template <class, class, class, class> friend class _LIBCPP_TEMPLATE_VIS multimap;
    template <class, class, class> friend class _LIBCPP_TEMPLATE_VIS __tree_const_iterator;
};

template <class _Key, class _Tp, class _Compare = less<_Key>,
          class _Allocator = allocator<pair<const _Key, _Tp> > >
class _LIBCPP_TEMPLATE_VIS map
{
public:
    // types:
    typedef _Key                                     key_type;
    typedef _Tp                                      mapped_type;
    typedef pair<const key_type, mapped_type>        value_type;
    typedef typename __identity<_Compare>::type      key_compare;
    typedef typename __identity<_Allocator>::type    allocator_type;
    typedef value_type&                              reference;
    typedef const value_type&                        const_reference;

    static_assert((is_same<typename allocator_type::value_type, value_type>::value),
                  "Allocator::value_type must be same type as value_type");

    class _LIBCPP_TEMPLATE_VIS value_compare
        : public binary_function<value_type, value_type, bool>
    {
        friend class map;
    protected:
        key_compare comp;

        _LIBCPP_INLINE_VISIBILITY value_compare(key_compare c) : comp(c) {}
    public:
        _LIBCPP_INLINE_VISIBILITY
        bool operator()(const value_type& __x, const value_type& __y) const
            {return comp(__x.first, __y.first);}
    };

private:

    typedef _VSTD::__value_type<key_type, mapped_type>             __value_type;
    typedef __map_value_compare<key_type, __value_type, key_compare> __vc;
    typedef typename __rebind_alloc_helper<allocator_traits<allocator_type>,
                                                 __value_type>::type __allocator_type;
    typedef __tree<__value_type, __vc, __allocator_type>   __base;
    typedef typename __base::__node_traits                 __node_traits;
    typedef allocator_traits<allocator_type>               __alloc_traits;

    __base __tree_;

public:
    typedef typename __alloc_traits::pointer               pointer;
    typedef typename __alloc_traits::const_pointer         const_pointer;
    typedef typename __alloc_traits::size_type             size_type;
    typedef typename __alloc_traits::difference_type       difference_type;
    typedef __map_iterator<typename __base::iterator>             iterator;
    typedef __map_const_iterator<typename __base::const_iterator> const_iterator;
    typedef _VSTD::reverse_iterator<iterator>               reverse_iterator;
    typedef _VSTD::reverse_iterator<const_iterator>         const_reverse_iterator;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 950 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    typedef __map_node_handle<typename __base::__node, allocator_type> node_type;
    typedef __insert_return_type<iterator, node_type> insert_return_type;
#endif
# 953 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    template <class _Key2, class _Value2, class _Comp2, class _Alloc2>
        friend class _LIBCPP_TEMPLATE_VIS map;
    template <class _Key2, class _Value2, class _Comp2, class _Alloc2>
        friend class _LIBCPP_TEMPLATE_VIS multimap;

    _LIBCPP_INLINE_VISIBILITY
    map()
        _NOEXCEPT_(
            is_nothrow_default_constructible<allocator_type>::value &&
            is_nothrow_default_constructible<key_compare>::value &&
            is_nothrow_copy_constructible<key_compare>::value)
        : __tree_(__vc(key_compare())) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit map(const key_compare& __comp)
        _NOEXCEPT_(
            is_nothrow_default_constructible<allocator_type>::value &&
            is_nothrow_copy_constructible<key_compare>::value)
        : __tree_(__vc(__comp)) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit map(const key_compare& __comp, const allocator_type& __a)
        : __tree_(__vc(__comp), typename __base::allocator_type(__a)) {}

    template <class _InputIterator>
    _LIBCPP_INLINE_VISIBILITY
        map(_InputIterator __f, _InputIterator __l,
            const key_compare& __comp = key_compare())
        : __tree_(__vc(__comp))
        {
            insert(__f, __l);
        }

    template <class _InputIterator>
    _LIBCPP_INLINE_VISIBILITY
        map(_InputIterator __f, _InputIterator __l,
            const key_compare& __comp, const allocator_type& __a)
        : __tree_(__vc(__comp), typename __base::allocator_type(__a))
        {
            insert(__f, __l);
        }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 997 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <class _InputIterator>
    _LIBCPP_INLINE_VISIBILITY
    map(_InputIterator __f, _InputIterator __l, const allocator_type& __a)
        : map(__f, __l, key_compare(), __a) {}
#endif
# 1002 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    map(const map& __m)
        : __tree_(__m.__tree_)
        {
            insert(__m.begin(), __m.end());
        }

    _LIBCPP_INLINE_VISIBILITY
    map& operator=(const map& __m)
        {
#ifndef _LIBCPP_CXX03_LANG
            __tree_ = __m.__tree_;
#else
# 1016 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
            if (this != &__m) {
                __tree_.clear();
                __tree_.value_comp() = __m.__tree_.value_comp();
                __tree_.__copy_assign_alloc(__m.__tree_);
                insert(__m.begin(), __m.end());
            }
#endif
# 1023 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
            return *this;
        }

#ifndef _LIBCPP_CXX03_LANG

    _LIBCPP_INLINE_VISIBILITY
    map(map&& __m)
        _NOEXCEPT_(is_nothrow_move_constructible<__base>::value)
        : __tree_(_VSTD::move(__m.__tree_))
        {
        }

    map(map&& __m, const allocator_type& __a);

    _LIBCPP_INLINE_VISIBILITY
    map& operator=(map&& __m)
        _NOEXCEPT_(is_nothrow_move_assignable<__base>::value)
        {
            __tree_ = _VSTD::move(__m.__tree_);
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    map(initializer_list<value_type> __il, const key_compare& __comp = key_compare())
        : __tree_(__vc(__comp))
        {
            insert(__il.begin(), __il.end());
        }

    _LIBCPP_INLINE_VISIBILITY
    map(initializer_list<value_type> __il, const key_compare& __comp, const allocator_type& __a)
        : __tree_(__vc(__comp), typename __base::allocator_type(__a))
        {
            insert(__il.begin(), __il.end());
        }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1060 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    _LIBCPP_INLINE_VISIBILITY
    map(initializer_list<value_type> __il, const allocator_type& __a)
        : map(__il, key_compare(), __a) {}
#endif
# 1064 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    map& operator=(initializer_list<value_type> __il)
        {
            __tree_.__assign_unique(__il.begin(), __il.end());
            return *this;
        }

#endif  // _LIBCPP_CXX03_LANG
# 1073 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    explicit map(const allocator_type& __a)
        : __tree_(typename __base::allocator_type(__a))
        {
        }

    _LIBCPP_INLINE_VISIBILITY
    map(const map& __m, const allocator_type& __a)
        : __tree_(__m.__tree_.value_comp(), typename __base::allocator_type(__a))
        {
            insert(__m.begin(), __m.end());
        }

    _LIBCPP_INLINE_VISIBILITY
    ~map() {
        static_assert(sizeof(__diagnose_non_const_comparator<_Key, _Compare>()), "");
    }

    _LIBCPP_INLINE_VISIBILITY
          iterator begin() _NOEXCEPT {return __tree_.begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT {return __tree_.begin();}
    _LIBCPP_INLINE_VISIBILITY
          iterator end() _NOEXCEPT {return __tree_.end();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT {return __tree_.end();}

    _LIBCPP_INLINE_VISIBILITY
          reverse_iterator rbegin() _NOEXCEPT {return reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin() const _NOEXCEPT
        {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
          reverse_iterator rend() _NOEXCEPT
            {return       reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend() const _NOEXCEPT
        {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY
    const_iterator cbegin() const _NOEXCEPT {return begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator cend() const _NOEXCEPT {return end();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT {return rbegin();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend() const _NOEXCEPT {return rend();}

    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool      empty() const _NOEXCEPT {return __tree_.size() == 0;}
    _LIBCPP_INLINE_VISIBILITY
    size_type size() const _NOEXCEPT {return __tree_.size();}
    _LIBCPP_INLINE_VISIBILITY
    size_type max_size() const _NOEXCEPT {return __tree_.max_size();}

    mapped_type& operator[](const key_type& __k);
#ifndef _LIBCPP_CXX03_LANG
    mapped_type& operator[](key_type&& __k);
#endif
# 1133 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

          mapped_type& at(const key_type& __k);
    const mapped_type& at(const key_type& __k) const;

    _LIBCPP_INLINE_VISIBILITY
    allocator_type get_allocator() const _NOEXCEPT {return allocator_type(__tree_.__alloc());}
    _LIBCPP_INLINE_VISIBILITY
    key_compare    key_comp()      const {return __tree_.value_comp().key_comp();}
    _LIBCPP_INLINE_VISIBILITY
    value_compare  value_comp()    const {return value_compare(__tree_.value_comp().key_comp());}

#ifndef _LIBCPP_CXX03_LANG
    template <class ..._Args>
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool> emplace(_Args&& ...__args) {
        return __tree_.__emplace_unique(_VSTD::forward<_Args>(__args)...);
    }

    template <class ..._Args>
    _LIBCPP_INLINE_VISIBILITY
    iterator emplace_hint(const_iterator __p, _Args&& ...__args) {
        return __tree_.__emplace_hint_unique(__p.__i_, _VSTD::forward<_Args>(__args)...);
    }

    template <class _Pp,
              class = typename enable_if<is_constructible<value_type, _Pp>::value>::type>
        _LIBCPP_INLINE_VISIBILITY
        pair<iterator, bool> insert(_Pp&& __p)
            {return __tree_.__insert_unique(_VSTD::forward<_Pp>(__p));}

    template <class _Pp,
              class = typename enable_if<is_constructible<value_type, _Pp>::value>::type>
        _LIBCPP_INLINE_VISIBILITY
        iterator insert(const_iterator __pos, _Pp&& __p)
            {return __tree_.__insert_unique(__pos.__i_, _VSTD::forward<_Pp>(__p));}

#endif  // _LIBCPP_CXX03_LANG
# 1170 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool>
        insert(const value_type& __v) {return __tree_.__insert_unique(__v);}

    _LIBCPP_INLINE_VISIBILITY
    iterator
        insert(const_iterator __p, const value_type& __v)
            {return __tree_.__insert_unique(__p.__i_, __v);}

#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    pair<iterator, bool>
    insert(value_type&& __v) {return __tree_.__insert_unique(_VSTD::move(__v));}

    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __p,  value_type&& __v)
    {return __tree_.__insert_unique(__p.__i_, _VSTD::move(__v));}

    _LIBCPP_INLINE_VISIBILITY
    void insert(initializer_list<value_type> __il)
        {insert(__il.begin(), __il.end());}
#endif
# 1193 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    template <class _InputIterator>
        _LIBCPP_INLINE_VISIBILITY
        void insert(_InputIterator __f, _InputIterator __l)
        {
            for (const_iterator __e = cend(); __f != __l; ++__f)
                insert(__e.__i_, *__f);
        }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1203 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    template <class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        pair<iterator, bool> try_emplace(const key_type& __k, _Args&&... __args)
    {
        return __tree_.__emplace_unique_key_args(__k,
            _VSTD::piecewise_construct,
            _VSTD::forward_as_tuple(__k),
            _VSTD::forward_as_tuple(_VSTD::forward<_Args>(__args)...));
    }

    template <class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        pair<iterator, bool> try_emplace(key_type&& __k, _Args&&... __args)
    {
        return __tree_.__emplace_unique_key_args(__k,
            _VSTD::piecewise_construct,
            _VSTD::forward_as_tuple(_VSTD::move(__k)),
            _VSTD::forward_as_tuple(_VSTD::forward<_Args>(__args)...));
    }

    template <class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        iterator try_emplace(const_iterator __h, const key_type& __k, _Args&&... __args)
    {
        return __tree_.__emplace_hint_unique_key_args(__h.__i_, __k,
            _VSTD::piecewise_construct,
            _VSTD::forward_as_tuple(__k),
            _VSTD::forward_as_tuple(_VSTD::forward<_Args>(__args)...));
    }

    template <class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        iterator try_emplace(const_iterator __h, key_type&& __k, _Args&&... __args)
    {
        return __tree_.__emplace_hint_unique_key_args(__h.__i_, __k,
            _VSTD::piecewise_construct,
            _VSTD::forward_as_tuple(_VSTD::move(__k)),
            _VSTD::forward_as_tuple(_VSTD::forward<_Args>(__args)...));
    }

    template <class _Vp>
        _LIBCPP_INLINE_VISIBILITY
        pair<iterator, bool> insert_or_assign(const key_type& __k, _Vp&& __v)
    {
        iterator __p = lower_bound(__k);
        if ( __p != end() && !key_comp()(__k, __p->first))
        {
            __p->second = _VSTD::forward<_Vp>(__v);
            return _VSTD::make_pair(__p, false);
        }
        return _VSTD::make_pair(emplace_hint(__p, __k, _VSTD::forward<_Vp>(__v)), true);
    }

    template <class _Vp>
        _LIBCPP_INLINE_VISIBILITY
        pair<iterator, bool> insert_or_assign(key_type&& __k, _Vp&& __v)
    {
        iterator __p = lower_bound(__k);
        if ( __p != end() && !key_comp()(__k, __p->first))
        {
            __p->second = _VSTD::forward<_Vp>(__v);
            return _VSTD::make_pair(__p, false);
        }
        return _VSTD::make_pair(emplace_hint(__p, _VSTD::move(__k), _VSTD::forward<_Vp>(__v)), true);
    }

    template <class _Vp>
        _LIBCPP_INLINE_VISIBILITY
        iterator insert_or_assign(const_iterator __h, const key_type& __k, _Vp&& __v)
     {
        iterator __p = lower_bound(__k);
        if ( __p != end() && !key_comp()(__k, __p->first))
        {
            __p->second = _VSTD::forward<_Vp>(__v);
            return __p;
        }
        return emplace_hint(__h, __k, _VSTD::forward<_Vp>(__v));
     }

    template <class _Vp>
        _LIBCPP_INLINE_VISIBILITY
        iterator insert_or_assign(const_iterator __h, key_type&& __k, _Vp&& __v)
     {
        iterator __p = lower_bound(__k);
        if ( __p != end() && !key_comp()(__k, __p->first))
        {
            __p->second = _VSTD::forward<_Vp>(__v);
            return __p;
        }
        return emplace_hint(__h, _VSTD::move(__k), _VSTD::forward<_Vp>(__v));
     }

#endif // _LIBCPP_STD_VER > 14
# 1297 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    iterator erase(const_iterator __p) {return __tree_.erase(__p.__i_);}
    _LIBCPP_INLINE_VISIBILITY
    iterator erase(iterator __p)       {return __tree_.erase(__p.__i_);}
    _LIBCPP_INLINE_VISIBILITY
    size_type erase(const key_type& __k)
        {return __tree_.__erase_unique(__k);}
    _LIBCPP_INLINE_VISIBILITY
    iterator  erase(const_iterator __f, const_iterator __l)
        {return __tree_.erase(__f.__i_, __l.__i_);}
    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT {__tree_.clear();}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1312 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    _LIBCPP_INLINE_VISIBILITY
    insert_return_type insert(node_type&& __nh)
    {
        _LIBCPP_ASSERT(__nh.empty() || __nh.get_allocator() == get_allocator(),
            "node_type with incompatible allocator passed to map::insert()");
        return __tree_.template __node_handle_insert_unique<
            node_type, insert_return_type>(_VSTD::move(__nh));
    }
    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __hint, node_type&& __nh)
    {
        _LIBCPP_ASSERT(__nh.empty() || __nh.get_allocator() == get_allocator(),
            "node_type with incompatible allocator passed to map::insert()");
        return __tree_.template __node_handle_insert_unique<node_type>(
            __hint.__i_, _VSTD::move(__nh));
    }
    _LIBCPP_INLINE_VISIBILITY
    node_type extract(key_type const& __key)
    {
        return __tree_.template __node_handle_extract<node_type>(__key);
    }
    _LIBCPP_INLINE_VISIBILITY
    node_type extract(const_iterator __it)
    {
        return __tree_.template __node_handle_extract<node_type>(__it.__i_);
    }
    template <class _Compare2>
    _LIBCPP_INLINE_VISIBILITY
    void merge(map<key_type, mapped_type, _Compare2, allocator_type>& __source)
    {
        _LIBCPP_ASSERT(__source.get_allocator() == get_allocator(),
                       "merging container with incompatible allocator");
        __tree_.__node_handle_merge_unique(__source.__tree_);
    }
    template <class _Compare2>
    _LIBCPP_INLINE_VISIBILITY
    void merge(map<key_type, mapped_type, _Compare2, allocator_type>&& __source)
    {
        _LIBCPP_ASSERT(__source.get_allocator() == get_allocator(),
                       "merging container with incompatible allocator");
        __tree_.__node_handle_merge_unique(__source.__tree_);
    }
    template <class _Compare2>
    _LIBCPP_INLINE_VISIBILITY
    void merge(multimap<key_type, mapped_type, _Compare2, allocator_type>& __source)
    {
        _LIBCPP_ASSERT(__source.get_allocator() == get_allocator(),
                       "merging container with incompatible allocator");
        __tree_.__node_handle_merge_unique(__source.__tree_);
    }
    template <class _Compare2>
    _LIBCPP_INLINE_VISIBILITY
    void merge(multimap<key_type, mapped_type, _Compare2, allocator_type>&& __source)
    {
        _LIBCPP_ASSERT(__source.get_allocator() == get_allocator(),
                       "merging container with incompatible allocator");
        __tree_.__node_handle_merge_unique(__source.__tree_);
    }
#endif
# 1371 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    void swap(map& __m)
        _NOEXCEPT_(__is_nothrow_swappable<__base>::value)
        {__tree_.swap(__m.__tree_);}

    _LIBCPP_INLINE_VISIBILITY
    iterator find(const key_type& __k)             {return __tree_.find(__k);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator find(const key_type& __k) const {return __tree_.find(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1382 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,iterator>::type
    find(const _K2& __k)                           {return __tree_.find(__k);}
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,const_iterator>::type
    find(const _K2& __k) const                     {return __tree_.find(__k);}
#endif
# 1391 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    size_type      count(const key_type& __k) const
        {return __tree_.__count_unique(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1396 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,size_type>::type
    count(const _K2& __k) const {return __tree_.__count_multi(__k);}
#endif
# 1401 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1403 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    _LIBCPP_INLINE_VISIBILITY
    bool contains(const key_type& __k) const {return find(__k) != end();}
#endif // _LIBCPP_STD_VER > 17
# 1406 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    iterator lower_bound(const key_type& __k)
        {return __tree_.lower_bound(__k);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator lower_bound(const key_type& __k) const
        {return __tree_.lower_bound(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1414 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,iterator>::type
    lower_bound(const _K2& __k)       {return __tree_.lower_bound(__k);}

    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,const_iterator>::type
    lower_bound(const _K2& __k) const {return __tree_.lower_bound(__k);}
#endif
# 1424 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    iterator upper_bound(const key_type& __k)
        {return __tree_.upper_bound(__k);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator upper_bound(const key_type& __k) const
        {return __tree_.upper_bound(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1432 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,iterator>::type
    upper_bound(const _K2& __k)       {return __tree_.upper_bound(__k);}
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,const_iterator>::type
    upper_bound(const _K2& __k) const {return __tree_.upper_bound(__k);}
#endif
# 1441 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    pair<iterator,iterator> equal_range(const key_type& __k)
        {return __tree_.__equal_range_unique(__k);}
    _LIBCPP_INLINE_VISIBILITY
    pair<const_iterator,const_iterator> equal_range(const key_type& __k) const
        {return __tree_.__equal_range_unique(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1449 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,pair<iterator,iterator>>::type
    equal_range(const _K2& __k)       {return __tree_.__equal_range_multi(__k);}
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,pair<const_iterator,const_iterator>>::type
    equal_range(const _K2& __k) const {return __tree_.__equal_range_multi(__k);}
#endif
# 1458 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

private:
    typedef typename __base::__node                    __node;
    typedef typename __base::__node_allocator          __node_allocator;
    typedef typename __base::__node_pointer            __node_pointer;
    typedef typename __base::__node_base_pointer       __node_base_pointer;
    typedef typename __base::__parent_pointer          __parent_pointer;

    typedef __map_node_destructor<__node_allocator> _Dp;
    typedef unique_ptr<__node, _Dp> __node_holder;

#ifdef _LIBCPP_CXX03_LANG
    __node_holder __construct_node_with_key(const key_type& __k);
#endif
# 1472 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _InputIterator, class _Compare = less<__iter_key_type<_InputIterator>>,
         class _Allocator = allocator<__iter_to_alloc_type<_InputIterator>>,
         class = _EnableIf<!__is_allocator<_Compare>::value, void>,
         class = _EnableIf<__is_allocator<_Allocator>::value, void>>
map(_InputIterator, _InputIterator, _Compare = _Compare(), _Allocator = _Allocator())
  -> map<__iter_key_type<_InputIterator>, __iter_mapped_type<_InputIterator>, _Compare, _Allocator>;

template<class _Key, class _Tp, class _Compare = less<remove_const_t<_Key>>,
         class _Allocator = allocator<pair<const _Key, _Tp>>,
         class = _EnableIf<!__is_allocator<_Compare>::value, void>,
         class = _EnableIf<__is_allocator<_Allocator>::value, void>>
map(initializer_list<pair<_Key, _Tp>>, _Compare = _Compare(), _Allocator = _Allocator())
  -> map<remove_const_t<_Key>, _Tp, _Compare, _Allocator>;

template<class _InputIterator, class _Allocator,
         class = _EnableIf<__is_allocator<_Allocator>::value, void>>
map(_InputIterator, _InputIterator, _Allocator)
  -> map<__iter_key_type<_InputIterator>, __iter_mapped_type<_InputIterator>,
         less<__iter_key_type<_InputIterator>>, _Allocator>;

template<class _Key, class _Tp, class _Allocator,
         class = _EnableIf<__is_allocator<_Allocator>::value, void>>
map(initializer_list<pair<_Key, _Tp>>, _Allocator)
  -> map<remove_const_t<_Key>, _Tp, less<remove_const_t<_Key>>, _Allocator>;
#endif
# 1500 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

#ifndef _LIBCPP_CXX03_LANG
template <class _Key, class _Tp, class _Compare, class _Allocator>
map<_Key, _Tp, _Compare, _Allocator>::map(map&& __m, const allocator_type& __a)
    : __tree_(_VSTD::move(__m.__tree_), typename __base::allocator_type(__a))
{
    if (__a != __m.get_allocator())
    {
        const_iterator __e = cend();
        while (!__m.empty())
            __tree_.__insert_unique(__e.__i_,
                    __m.__tree_.remove(__m.begin().__i_)->__value_.__move());
    }
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
_Tp&
map<_Key, _Tp, _Compare, _Allocator>::operator[](const key_type& __k)
{
    return __tree_.__emplace_unique_key_args(__k,
        _VSTD::piecewise_construct,
        _VSTD::forward_as_tuple(__k),
        _VSTD::forward_as_tuple()).first->__get_value().second;
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
_Tp&
map<_Key, _Tp, _Compare, _Allocator>::operator[](key_type&& __k)
{
    return __tree_.__emplace_unique_key_args(__k,
        _VSTD::piecewise_construct,
        _VSTD::forward_as_tuple(_VSTD::move(__k)),
        _VSTD::forward_as_tuple()).first->__get_value().second;
}

#else // _LIBCPP_CXX03_LANG
# 1536 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

template <class _Key, class _Tp, class _Compare, class _Allocator>
typename map<_Key, _Tp, _Compare, _Allocator>::__node_holder
map<_Key, _Tp, _Compare, _Allocator>::__construct_node_with_key(const key_type& __k)
{
    __node_allocator& __na = __tree_.__node_alloc();
    __node_holder __h(__node_traits::allocate(__na, 1), _Dp(__na));
    __node_traits::construct(__na, _VSTD::addressof(__h->__value_.__get_value().first), __k);
    __h.get_deleter().__first_constructed = true;
    __node_traits::construct(__na, _VSTD::addressof(__h->__value_.__get_value().second));
    __h.get_deleter().__second_constructed = true;
    return _LIBCPP_EXPLICIT_MOVE(__h);  // explicitly moved for C++03
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
_Tp&
map<_Key, _Tp, _Compare, _Allocator>::operator[](const key_type& __k)
{
    __parent_pointer __parent;
    __node_base_pointer& __child = __tree_.__find_equal(__parent, __k);
    __node_pointer __r = static_cast<__node_pointer>(__child);
    if (__child == nullptr)
    {
        __node_holder __h = __construct_node_with_key(__k);
        __tree_.__insert_node_at(__parent, __child, static_cast<__node_base_pointer>(__h.get()));
        __r = __h.release();
    }
    return __r->__value_.__get_value().second;
}

#endif  // _LIBCPP_CXX03_LANG
# 1567 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

template <class _Key, class _Tp, class _Compare, class _Allocator>
_Tp&
map<_Key, _Tp, _Compare, _Allocator>::at(const key_type& __k)
{
    __parent_pointer __parent;
    __node_base_pointer& __child = __tree_.__find_equal(__parent, __k);
    if (__child == nullptr)
        __throw_out_of_range("map::at:  key not found");
    return static_cast<__node_pointer>(__child)->__value_.__get_value().second;
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
const _Tp&
map<_Key, _Tp, _Compare, _Allocator>::at(const key_type& __k) const
{
    __parent_pointer __parent;
    __node_base_pointer __child = __tree_.__find_equal(__parent, __k);
    if (__child == nullptr)
        __throw_out_of_range("map::at:  key not found");
    return static_cast<__node_pointer>(__child)->__value_.__get_value().second;
}


template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const map<_Key, _Tp, _Compare, _Allocator>& __x,
           const map<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return __x.size() == __y.size() && _VSTD::equal(__x.begin(), __x.end(), __y.begin());
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const map<_Key, _Tp, _Compare, _Allocator>& __x,
           const map<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return _VSTD::lexicographical_compare(__x.begin(), __x.end(), __y.begin(), __y.end());
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const map<_Key, _Tp, _Compare, _Allocator>& __x,
           const map<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return !(__x == __y);
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const map<_Key, _Tp, _Compare, _Allocator>& __x,
           const map<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return __y < __x;
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const map<_Key, _Tp, _Compare, _Allocator>& __x,
           const map<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return !(__x < __y);
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const map<_Key, _Tp, _Compare, _Allocator>& __x,
           const map<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return !(__y < __x);
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(map<_Key, _Tp, _Compare, _Allocator>& __x,
     map<_Key, _Tp, _Compare, _Allocator>& __y)
    _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1656 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
template <class _Key, class _Tp, class _Compare, class _Allocator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
void erase_if(map<_Key, _Tp, _Compare, _Allocator>& __c, _Predicate __pred)
{ __libcpp_erase_if_container(__c, __pred); }
#endif
# 1661 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3


template <class _Key, class _Tp, class _Compare = less<_Key>,
          class _Allocator = allocator<pair<const _Key, _Tp> > >
class _LIBCPP_TEMPLATE_VIS multimap
{
public:
    // types:
    typedef _Key                                     key_type;
    typedef _Tp                                      mapped_type;
    typedef pair<const key_type, mapped_type>        value_type;
    typedef typename __identity<_Compare>::type      key_compare;
    typedef typename __identity<_Allocator>::type    allocator_type;
    typedef value_type&                              reference;
    typedef const value_type&                        const_reference;

    static_assert((is_same<typename allocator_type::value_type, value_type>::value),
                  "Allocator::value_type must be same type as value_type");

    class _LIBCPP_TEMPLATE_VIS value_compare
        : public binary_function<value_type, value_type, bool>
    {
        friend class multimap;
    protected:
        key_compare comp;

        _LIBCPP_INLINE_VISIBILITY
        value_compare(key_compare c) : comp(c) {}
    public:
        _LIBCPP_INLINE_VISIBILITY
        bool operator()(const value_type& __x, const value_type& __y) const
            {return comp(__x.first, __y.first);}
    };

private:

    typedef _VSTD::__value_type<key_type, mapped_type>             __value_type;
    typedef __map_value_compare<key_type, __value_type, key_compare> __vc;
    typedef typename __rebind_alloc_helper<allocator_traits<allocator_type>,
                                                 __value_type>::type __allocator_type;
    typedef __tree<__value_type, __vc, __allocator_type>            __base;
    typedef typename __base::__node_traits                          __node_traits;
    typedef allocator_traits<allocator_type>                        __alloc_traits;

    __base __tree_;

public:
    typedef typename __alloc_traits::pointer               pointer;
    typedef typename __alloc_traits::const_pointer         const_pointer;
    typedef typename __alloc_traits::size_type             size_type;
    typedef typename __alloc_traits::difference_type       difference_type;
    typedef __map_iterator<typename __base::iterator>      iterator;
    typedef __map_const_iterator<typename __base::const_iterator> const_iterator;
    typedef _VSTD::reverse_iterator<iterator>               reverse_iterator;
    typedef _VSTD::reverse_iterator<const_iterator>         const_reverse_iterator;

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1718 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    typedef __map_node_handle<typename __base::__node, allocator_type> node_type;
#endif
# 1720 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    template <class _Key2, class _Value2, class _Comp2, class _Alloc2>
        friend class _LIBCPP_TEMPLATE_VIS map;
    template <class _Key2, class _Value2, class _Comp2, class _Alloc2>
        friend class _LIBCPP_TEMPLATE_VIS multimap;

    _LIBCPP_INLINE_VISIBILITY
    multimap()
        _NOEXCEPT_(
            is_nothrow_default_constructible<allocator_type>::value &&
            is_nothrow_default_constructible<key_compare>::value &&
            is_nothrow_copy_constructible<key_compare>::value)
        : __tree_(__vc(key_compare())) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit multimap(const key_compare& __comp)
        _NOEXCEPT_(
            is_nothrow_default_constructible<allocator_type>::value &&
            is_nothrow_copy_constructible<key_compare>::value)
        : __tree_(__vc(__comp)) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit multimap(const key_compare& __comp, const allocator_type& __a)
        : __tree_(__vc(__comp), typename __base::allocator_type(__a)) {}

    template <class _InputIterator>
        _LIBCPP_INLINE_VISIBILITY
        multimap(_InputIterator __f, _InputIterator __l,
            const key_compare& __comp = key_compare())
        : __tree_(__vc(__comp))
        {
            insert(__f, __l);
        }

    template <class _InputIterator>
        _LIBCPP_INLINE_VISIBILITY
        multimap(_InputIterator __f, _InputIterator __l,
            const key_compare& __comp, const allocator_type& __a)
        : __tree_(__vc(__comp), typename __base::allocator_type(__a))
        {
            insert(__f, __l);
        }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1764 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <class _InputIterator>
    _LIBCPP_INLINE_VISIBILITY
    multimap(_InputIterator __f, _InputIterator __l, const allocator_type& __a)
        : multimap(__f, __l, key_compare(), __a) {}
#endif
# 1769 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    multimap(const multimap& __m)
        : __tree_(__m.__tree_.value_comp(),
          __alloc_traits::select_on_container_copy_construction(__m.__tree_.__alloc()))
        {
            insert(__m.begin(), __m.end());
        }

    _LIBCPP_INLINE_VISIBILITY
    multimap& operator=(const multimap& __m)
        {
#ifndef _LIBCPP_CXX03_LANG
            __tree_ = __m.__tree_;
#else
# 1784 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
            if (this != &__m) {
                __tree_.clear();
                __tree_.value_comp() = __m.__tree_.value_comp();
                __tree_.__copy_assign_alloc(__m.__tree_);
                insert(__m.begin(), __m.end());
            }
#endif
# 1791 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
            return *this;
        }

#ifndef _LIBCPP_CXX03_LANG

    _LIBCPP_INLINE_VISIBILITY
    multimap(multimap&& __m)
        _NOEXCEPT_(is_nothrow_move_constructible<__base>::value)
        : __tree_(_VSTD::move(__m.__tree_))
        {
        }

    multimap(multimap&& __m, const allocator_type& __a);

    _LIBCPP_INLINE_VISIBILITY
    multimap& operator=(multimap&& __m)
        _NOEXCEPT_(is_nothrow_move_assignable<__base>::value)
        {
            __tree_ = _VSTD::move(__m.__tree_);
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    multimap(initializer_list<value_type> __il, const key_compare& __comp = key_compare())
        : __tree_(__vc(__comp))
        {
            insert(__il.begin(), __il.end());
        }

    _LIBCPP_INLINE_VISIBILITY
    multimap(initializer_list<value_type> __il, const key_compare& __comp, const allocator_type& __a)
        : __tree_(__vc(__comp), typename __base::allocator_type(__a))
        {
            insert(__il.begin(), __il.end());
        }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1828 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    _LIBCPP_INLINE_VISIBILITY
    multimap(initializer_list<value_type> __il, const allocator_type& __a)
        : multimap(__il, key_compare(), __a) {}
#endif
# 1832 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    multimap& operator=(initializer_list<value_type> __il)
        {
            __tree_.__assign_multi(__il.begin(), __il.end());
            return *this;
        }

#endif  // _LIBCPP_CXX03_LANG
# 1841 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    explicit multimap(const allocator_type& __a)
        : __tree_(typename __base::allocator_type(__a))
        {
        }

    _LIBCPP_INLINE_VISIBILITY
    multimap(const multimap& __m, const allocator_type& __a)
        : __tree_(__m.__tree_.value_comp(), typename __base::allocator_type(__a))
        {
            insert(__m.begin(), __m.end());
        }

    _LIBCPP_INLINE_VISIBILITY
    ~multimap() {
        static_assert(sizeof(__diagnose_non_const_comparator<_Key, _Compare>()), "");
    }

    _LIBCPP_INLINE_VISIBILITY
          iterator begin() _NOEXCEPT {return __tree_.begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT {return __tree_.begin();}
    _LIBCPP_INLINE_VISIBILITY
          iterator end() _NOEXCEPT {return __tree_.end();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT {return __tree_.end();}

    _LIBCPP_INLINE_VISIBILITY
          reverse_iterator rbegin() _NOEXCEPT {return reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin() const _NOEXCEPT
        {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
          reverse_iterator rend() _NOEXCEPT {return reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend() const _NOEXCEPT
        {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY
    const_iterator cbegin()  const _NOEXCEPT {return begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator cend() const _NOEXCEPT {return end();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT {return rbegin();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend() const _NOEXCEPT {return rend();}

    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool empty() const _NOEXCEPT {return __tree_.size() == 0;}
    _LIBCPP_INLINE_VISIBILITY
    size_type size() const _NOEXCEPT {return __tree_.size();}
    _LIBCPP_INLINE_VISIBILITY
    size_type max_size() const _NOEXCEPT {return __tree_.max_size();}

    _LIBCPP_INLINE_VISIBILITY
    allocator_type get_allocator() const _NOEXCEPT {return allocator_type(__tree_.__alloc());}
    _LIBCPP_INLINE_VISIBILITY
    key_compare    key_comp() const {return __tree_.value_comp().key_comp();}
    _LIBCPP_INLINE_VISIBILITY
    value_compare  value_comp() const
        {return value_compare(__tree_.value_comp().key_comp());}

#ifndef _LIBCPP_CXX03_LANG

    template <class ..._Args>
    _LIBCPP_INLINE_VISIBILITY
    iterator emplace(_Args&& ...__args) {
        return __tree_.__emplace_multi(_VSTD::forward<_Args>(__args)...);
    }

    template <class ..._Args>
    _LIBCPP_INLINE_VISIBILITY
    iterator emplace_hint(const_iterator __p, _Args&& ...__args) {
        return __tree_.__emplace_hint_multi(__p.__i_, _VSTD::forward<_Args>(__args)...);
    }

    template <class _Pp,
              class = typename enable_if<is_constructible<value_type, _Pp>::value>::type>
        _LIBCPP_INLINE_VISIBILITY
        iterator insert(_Pp&& __p)
            {return __tree_.__insert_multi(_VSTD::forward<_Pp>(__p));}

    template <class _Pp,
              class = typename enable_if<is_constructible<value_type, _Pp>::value>::type>
        _LIBCPP_INLINE_VISIBILITY
        iterator insert(const_iterator __pos, _Pp&& __p)
            {return __tree_.__insert_multi(__pos.__i_, _VSTD::forward<_Pp>(__p));}

    _LIBCPP_INLINE_VISIBILITY
    iterator insert(value_type&& __v)
        {return __tree_.__insert_multi(_VSTD::move(__v));}

    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __p, value_type&& __v)
        {return __tree_.__insert_multi(__p.__i_, _VSTD::move(__v));}


    _LIBCPP_INLINE_VISIBILITY
    void insert(initializer_list<value_type> __il)
        {insert(__il.begin(), __il.end());}

#endif  // _LIBCPP_CXX03_LANG
# 1944 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const value_type& __v) {return __tree_.__insert_multi(__v);}

    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __p, const value_type& __v)
            {return __tree_.__insert_multi(__p.__i_, __v);}

    template <class _InputIterator>
        _LIBCPP_INLINE_VISIBILITY
        void insert(_InputIterator __f, _InputIterator __l)
        {
            for (const_iterator __e = cend(); __f != __l; ++__f)
                __tree_.__insert_multi(__e.__i_, *__f);
        }

    _LIBCPP_INLINE_VISIBILITY
    iterator erase(const_iterator __p) {return __tree_.erase(__p.__i_);}
    _LIBCPP_INLINE_VISIBILITY
    iterator erase(iterator __p)       {return __tree_.erase(__p.__i_);}
    _LIBCPP_INLINE_VISIBILITY
    size_type erase(const key_type& __k) {return __tree_.__erase_multi(__k);}
    _LIBCPP_INLINE_VISIBILITY
    iterator  erase(const_iterator __f, const_iterator __l)
        {return __tree_.erase(__f.__i_, __l.__i_);}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1971 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    _LIBCPP_INLINE_VISIBILITY
    iterator insert(node_type&& __nh)
    {
        _LIBCPP_ASSERT(__nh.empty() || __nh.get_allocator() == get_allocator(),
            "node_type with incompatible allocator passed to multimap::insert()");
        return __tree_.template __node_handle_insert_multi<node_type>(
            _VSTD::move(__nh));
    }
    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __hint, node_type&& __nh)
    {
        _LIBCPP_ASSERT(__nh.empty() || __nh.get_allocator() == get_allocator(),
            "node_type with incompatible allocator passed to multimap::insert()");
        return __tree_.template __node_handle_insert_multi<node_type>(
            __hint.__i_, _VSTD::move(__nh));
    }
    _LIBCPP_INLINE_VISIBILITY
    node_type extract(key_type const& __key)
    {
        return __tree_.template __node_handle_extract<node_type>(__key);
    }
    _LIBCPP_INLINE_VISIBILITY
    node_type extract(const_iterator __it)
    {
        return __tree_.template __node_handle_extract<node_type>(
            __it.__i_);
    }
    template <class _Compare2>
    _LIBCPP_INLINE_VISIBILITY
    void merge(multimap<key_type, mapped_type, _Compare2, allocator_type>& __source)
    {
        _LIBCPP_ASSERT(__source.get_allocator() == get_allocator(),
                       "merging container with incompatible allocator");
        return __tree_.__node_handle_merge_multi(__source.__tree_);
    }
    template <class _Compare2>
    _LIBCPP_INLINE_VISIBILITY
    void merge(multimap<key_type, mapped_type, _Compare2, allocator_type>&& __source)
    {
        _LIBCPP_ASSERT(__source.get_allocator() == get_allocator(),
                       "merging container with incompatible allocator");
        return __tree_.__node_handle_merge_multi(__source.__tree_);
    }
    template <class _Compare2>
    _LIBCPP_INLINE_VISIBILITY
    void merge(map<key_type, mapped_type, _Compare2, allocator_type>& __source)
    {
        _LIBCPP_ASSERT(__source.get_allocator() == get_allocator(),
                       "merging container with incompatible allocator");
        return __tree_.__node_handle_merge_multi(__source.__tree_);
    }
    template <class _Compare2>
    _LIBCPP_INLINE_VISIBILITY
    void merge(map<key_type, mapped_type, _Compare2, allocator_type>&& __source)
    {
        _LIBCPP_ASSERT(__source.get_allocator() == get_allocator(),
                       "merging container with incompatible allocator");
        return __tree_.__node_handle_merge_multi(__source.__tree_);
    }
#endif
# 2031 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT {__tree_.clear();}

    _LIBCPP_INLINE_VISIBILITY
    void swap(multimap& __m)
        _NOEXCEPT_(__is_nothrow_swappable<__base>::value)
        {__tree_.swap(__m.__tree_);}

    _LIBCPP_INLINE_VISIBILITY
    iterator find(const key_type& __k)             {return __tree_.find(__k);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator find(const key_type& __k) const {return __tree_.find(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2045 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,iterator>::type
    find(const _K2& __k)                           {return __tree_.find(__k);}
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,const_iterator>::type
    find(const _K2& __k) const                     {return __tree_.find(__k);}
#endif
# 2054 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    size_type      count(const key_type& __k) const
        {return __tree_.__count_multi(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2059 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,size_type>::type
    count(const _K2& __k) const {return __tree_.__count_multi(__k);}
#endif
# 2064 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2066 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    _LIBCPP_INLINE_VISIBILITY
    bool contains(const key_type& __k) const {return find(__k) != end();}
#endif // _LIBCPP_STD_VER > 17
# 2069 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    iterator lower_bound(const key_type& __k)
        {return __tree_.lower_bound(__k);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator lower_bound(const key_type& __k) const
            {return __tree_.lower_bound(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2077 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,iterator>::type
    lower_bound(const _K2& __k)       {return __tree_.lower_bound(__k);}

    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,const_iterator>::type
    lower_bound(const _K2& __k) const {return __tree_.lower_bound(__k);}
#endif
# 2087 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    iterator upper_bound(const key_type& __k)
            {return __tree_.upper_bound(__k);}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator upper_bound(const key_type& __k) const
            {return __tree_.upper_bound(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2095 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,iterator>::type
    upper_bound(const _K2& __k)       {return __tree_.upper_bound(__k);}
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,const_iterator>::type
    upper_bound(const _K2& __k) const {return __tree_.upper_bound(__k);}
#endif
# 2104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

    _LIBCPP_INLINE_VISIBILITY
    pair<iterator,iterator>             equal_range(const key_type& __k)
            {return __tree_.__equal_range_multi(__k);}
    _LIBCPP_INLINE_VISIBILITY
    pair<const_iterator,const_iterator> equal_range(const key_type& __k) const
            {return __tree_.__equal_range_multi(__k);}
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2112 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,pair<iterator,iterator>>::type
    equal_range(const _K2& __k)       {return __tree_.__equal_range_multi(__k);}
    template <typename _K2>
    _LIBCPP_INLINE_VISIBILITY
    typename enable_if<__is_transparent<_Compare, _K2>::value,pair<const_iterator,const_iterator>>::type
    equal_range(const _K2& __k) const {return __tree_.__equal_range_multi(__k);}
#endif
# 2121 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

private:
    typedef typename __base::__node                    __node;
    typedef typename __base::__node_allocator          __node_allocator;
    typedef typename __base::__node_pointer            __node_pointer;

    typedef __map_node_destructor<__node_allocator> _Dp;
    typedef unique_ptr<__node, _Dp> __node_holder;
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _InputIterator, class _Compare = less<__iter_key_type<_InputIterator>>,
         class _Allocator = allocator<__iter_to_alloc_type<_InputIterator>>,
         class = _EnableIf<!__is_allocator<_Compare>::value, void>,
         class = _EnableIf<__is_allocator<_Allocator>::value, void>>
multimap(_InputIterator, _InputIterator, _Compare = _Compare(), _Allocator = _Allocator())
  -> multimap<__iter_key_type<_InputIterator>, __iter_mapped_type<_InputIterator>, _Compare, _Allocator>;

template<class _Key, class _Tp, class _Compare = less<remove_const_t<_Key>>,
         class _Allocator = allocator<pair<const _Key, _Tp>>,
         class = _EnableIf<!__is_allocator<_Compare>::value, void>,
         class = _EnableIf<__is_allocator<_Allocator>::value, void>>
multimap(initializer_list<pair<_Key, _Tp>>, _Compare = _Compare(), _Allocator = _Allocator())
  -> multimap<remove_const_t<_Key>, _Tp, _Compare, _Allocator>;

template<class _InputIterator, class _Allocator,
         class = _EnableIf<__is_allocator<_Allocator>::value, void>>
multimap(_InputIterator, _InputIterator, _Allocator)
  -> multimap<__iter_key_type<_InputIterator>, __iter_mapped_type<_InputIterator>,
         less<__iter_key_type<_InputIterator>>, _Allocator>;

template<class _Key, class _Tp, class _Allocator,
         class = _EnableIf<__is_allocator<_Allocator>::value, void>>
multimap(initializer_list<pair<_Key, _Tp>>, _Allocator)
  -> multimap<remove_const_t<_Key>, _Tp, less<remove_const_t<_Key>>, _Allocator>;
#endif
# 2157 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

#ifndef _LIBCPP_CXX03_LANG
template <class _Key, class _Tp, class _Compare, class _Allocator>
multimap<_Key, _Tp, _Compare, _Allocator>::multimap(multimap&& __m, const allocator_type& __a)
    : __tree_(_VSTD::move(__m.__tree_), typename __base::allocator_type(__a))
{
    if (__a != __m.get_allocator())
    {
        const_iterator __e = cend();
        while (!__m.empty())
            __tree_.__insert_multi(__e.__i_,
                    _VSTD::move(__m.__tree_.remove(__m.begin().__i_)->__value_.__move()));
    }
}
#endif
# 2172 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const multimap<_Key, _Tp, _Compare, _Allocator>& __x,
           const multimap<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return __x.size() == __y.size() && _VSTD::equal(__x.begin(), __x.end(), __y.begin());
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const multimap<_Key, _Tp, _Compare, _Allocator>& __x,
           const multimap<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return _VSTD::lexicographical_compare(__x.begin(), __x.end(), __y.begin(), __y.end());
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const multimap<_Key, _Tp, _Compare, _Allocator>& __x,
           const multimap<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return !(__x == __y);
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const multimap<_Key, _Tp, _Compare, _Allocator>& __x,
           const multimap<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return __y < __x;
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const multimap<_Key, _Tp, _Compare, _Allocator>& __x,
           const multimap<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return !(__x < __y);
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const multimap<_Key, _Tp, _Compare, _Allocator>& __x,
           const multimap<_Key, _Tp, _Compare, _Allocator>& __y)
{
    return !(__y < __x);
}

template <class _Key, class _Tp, class _Compare, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(multimap<_Key, _Tp, _Compare, _Allocator>& __x,
     multimap<_Key, _Tp, _Compare, _Allocator>& __y)
    _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2238 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
template <class _Key, class _Tp, class _Compare, class _Allocator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
void erase_if(multimap<_Key, _Tp, _Compare, _Allocator>& __c, _Predicate __pred)
{ __libcpp_erase_if_container(__c, __pred); }
#endif
# 2243 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_MAP
# 2247 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/map" 3
# 34 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 35 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 36 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 36 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 37 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 37 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 38 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 38 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 39 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"

namespace clang {

class DeclContext;
class DiagnosticBuilder;
class DiagnosticConsumer;
class IdentifierInfo;
class LangOptions;
class Preprocessor;
class SourceManager;
class StoredDiagnostic;

namespace tok {

enum TokenKind : unsigned short;

} // namespace tok

/// Annotates a diagnostic with some code that should be
/// inserted, removed, or replaced to fix the problem.
///
/// This kind of hint should be used when we are certain that the
/// introduction, removal, or modification of a particular (small!)
/// amount of code will correct a compilation error. The compiler
/// should also provide full recovery from such errors, such that
/// suppressing the diagnostic output can still result in successful
/// compilation.
class FixItHint {
public:
  /// Code that should be replaced to correct the error. Empty for an
  /// insertion hint.
  CharSourceRange RemoveRange;

  /// Code in the specific range that should be inserted in the insertion
  /// location.
  CharSourceRange InsertFromRange;

  /// The actual code to insert at the insertion location, as a
  /// string.
  std::string CodeToInsert;

  bool BeforePreviousInsertions = false;

  /// Empty code modification hint, indicating that no code
  /// modification is known.
  FixItHint() = default;

  bool isNull() const {
    return !RemoveRange.isValid();
  }

  /// Create a code modification hint that inserts the given
  /// code string at a specific location.
  static FixItHint CreateInsertion(SourceLocation InsertionLoc,
                                   StringRef Code,
                                   bool BeforePreviousInsertions = false) {
    FixItHint Hint;
    Hint.RemoveRange =
      CharSourceRange::getCharRange(InsertionLoc, InsertionLoc);
    Hint.CodeToInsert = std::string(Code);
    Hint.BeforePreviousInsertions = BeforePreviousInsertions;
    return Hint;
  }

  /// Create a code modification hint that inserts the given
  /// code from \p FromRange at a specific location.
  static FixItHint CreateInsertionFromRange(SourceLocation InsertionLoc,
                                            CharSourceRange FromRange,
                                        bool BeforePreviousInsertions = false) {
    FixItHint Hint;
    Hint.RemoveRange =
      CharSourceRange::getCharRange(InsertionLoc, InsertionLoc);
    Hint.InsertFromRange = FromRange;
    Hint.BeforePreviousInsertions = BeforePreviousInsertions;
    return Hint;
  }

  /// Create a code modification hint that removes the given
  /// source range.
  static FixItHint CreateRemoval(CharSourceRange RemoveRange) {
    FixItHint Hint;
    Hint.RemoveRange = RemoveRange;
    return Hint;
  }
  static FixItHint CreateRemoval(SourceRange RemoveRange) {
    return CreateRemoval(CharSourceRange::getTokenRange(RemoveRange));
  }

  /// Create a code modification hint that replaces the given
  /// source range with the given code string.
  static FixItHint CreateReplacement(CharSourceRange RemoveRange,
                                     StringRef Code) {
    FixItHint Hint;
    Hint.RemoveRange = RemoveRange;
    Hint.CodeToInsert = std::string(Code);
    return Hint;
  }

  static FixItHint CreateReplacement(SourceRange RemoveRange,
                                     StringRef Code) {
    return CreateReplacement(CharSourceRange::getTokenRange(RemoveRange), Code);
  }
};

/// Concrete class used by the front-end to report problems and issues.
///
/// This massages the diagnostics (e.g. handling things like "report warnings
/// as errors" and passes them off to the DiagnosticConsumer for reporting to
/// the user. DiagnosticsEngine is tied to one translation unit and one
/// SourceManager.
class DiagnosticsEngine : public RefCountedBase<DiagnosticsEngine> {
public:
  /// The level of the diagnostic, after it has been through mapping.
  enum Level {
    Ignored = DiagnosticIDs::Ignored,
    Note = DiagnosticIDs::Note,
    Remark = DiagnosticIDs::Remark,
    Warning = DiagnosticIDs::Warning,
    Error = DiagnosticIDs::Error,
    Fatal = DiagnosticIDs::Fatal
  };

  enum ArgumentKind {
    /// std::string
    ak_std_string,

    /// const char *
    ak_c_string,

    /// int
    ak_sint,

    /// unsigned
    ak_uint,

    /// enum TokenKind : unsigned
    ak_tokenkind,

    /// IdentifierInfo
    ak_identifierinfo,

    /// address space
    ak_addrspace,

    /// Qualifiers
    ak_qual,

    /// QualType
    ak_qualtype,

    /// DeclarationName
    ak_declarationname,

    /// NamedDecl *
    ak_nameddecl,

    /// NestedNameSpecifier *
    ak_nestednamespec,

    /// DeclContext *
    ak_declcontext,

    /// pair<QualType, QualType>
    ak_qualtype_pair,

    /// Attr *
    ak_attr
  };

  /// Represents on argument value, which is a union discriminated
  /// by ArgumentKind, with a value.
  using ArgumentValue = std::pair<ArgumentKind, intptr_t>;

private:
  // Used by __extension__
  unsigned char AllExtensionsSilenced = 0;

  // Treat fatal errors like errors.
  bool FatalsAsError = false;

  // Suppress all diagnostics.
  bool SuppressAllDiagnostics = false;

  // Elide common types of templates.
  bool ElideType = true;

  // Print a tree when comparing templates.
  bool PrintTemplateTree = false;

  // Color printing is enabled.
  bool ShowColors = false;

  // Which overload candidates to show.
  OverloadsShown ShowOverloads = Ovl_All;

  // Cap of # errors emitted, 0 -> no limit.
  unsigned ErrorLimit = 0;

  // Cap on depth of template backtrace stack, 0 -> no limit.
  unsigned TemplateBacktraceLimit = 0;

  // Cap on depth of constexpr evaluation backtrace stack, 0 -> no limit.
  unsigned ConstexprBacktraceLimit = 0;

  IntrusiveRefCntPtr<DiagnosticIDs> Diags;
  IntrusiveRefCntPtr<DiagnosticOptions> DiagOpts;
  DiagnosticConsumer *Client = nullptr;
  std::unique_ptr<DiagnosticConsumer> Owner;
  SourceManager *SourceMgr = nullptr;

  /// Mapping information for diagnostics.
  ///
  /// Mapping info is packed into four bits per diagnostic.  The low three
  /// bits are the mapping (an instance of diag::Severity), or zero if unset.
  /// The high bit is set when the mapping was established as a user mapping.
  /// If the high bit is clear, then the low bits are set to the default
  /// value, and should be mapped with -pedantic, -Werror, etc.
  ///
  /// A new DiagState is created and kept around when diagnostic pragmas modify
  /// the state so that we know what is the diagnostic state at any given
  /// source location.
  class DiagState {
    llvm::DenseMap<unsigned, DiagnosticMapping> DiagMap;

  public:
    // "Global" configuration state that can actually vary between modules.

    // Ignore all warnings: -w
    unsigned IgnoreAllWarnings : 1;

    // Enable all warnings.
    unsigned EnableAllWarnings : 1;

    // Treat warnings like errors.
    unsigned WarningsAsErrors : 1;

    // Treat errors like fatal errors.
    unsigned ErrorsAsFatal : 1;

    // Suppress warnings in system headers.
    unsigned SuppressSystemWarnings : 1;

    // Map extensions to warnings or errors?
    diag::Severity ExtBehavior = diag::Severity::Ignored;

    DiagState()
        : IgnoreAllWarnings(false), EnableAllWarnings(false),
          WarningsAsErrors(false), ErrorsAsFatal(false),
          SuppressSystemWarnings(false) {}

    using iterator = llvm::DenseMap<unsigned, DiagnosticMapping>::iterator;
    using const_iterator =
        llvm::DenseMap<unsigned, DiagnosticMapping>::const_iterator;

    void setMapping(diag::kind Diag, DiagnosticMapping Info) {
      DiagMap[Diag] = Info;
    }

    DiagnosticMapping lookupMapping(diag::kind Diag) const {
      return DiagMap.lookup(Diag);
    }

    DiagnosticMapping &getOrAddMapping(diag::kind Diag);

    const_iterator begin() const { return DiagMap.begin(); }
    const_iterator end() const { return DiagMap.end(); }
  };

  /// Keeps and automatically disposes all DiagStates that we create.
  std::list<DiagState> DiagStates;

  /// A mapping from files to the diagnostic states for those files. Lazily
  /// built on demand for files in which the diagnostic state has not changed.
  class DiagStateMap {
  public:
    /// Add an initial diagnostic state.
    void appendFirst(DiagState *State);

    /// Add a new latest state point.
    void append(SourceManager &SrcMgr, SourceLocation Loc, DiagState *State);

    /// Look up the diagnostic state at a given source location.
    DiagState *lookup(SourceManager &SrcMgr, SourceLocation Loc) const;

    /// Determine whether this map is empty.
    bool empty() const { return Files.empty(); }

    /// Clear out this map.
    void clear() {
      Files.clear();
      FirstDiagState = CurDiagState = nullptr;
      CurDiagStateLoc = SourceLocation();
    }

    /// Produce a debugging dump of the diagnostic state.
    LLVM_DUMP_METHOD void dump(SourceManager &SrcMgr,
                               StringRef DiagName = StringRef()) const;

    /// Grab the most-recently-added state point.
    DiagState *getCurDiagState() const { return CurDiagState; }

    /// Get the location at which a diagnostic state was last added.
    SourceLocation getCurDiagStateLoc() const { return CurDiagStateLoc; }

  private:
    friend class ASTReader;
    friend class ASTWriter;

    /// Represents a point in source where the diagnostic state was
    /// modified because of a pragma.
    ///
    /// 'Loc' can be null if the point represents the diagnostic state
    /// modifications done through the command-line.
    struct DiagStatePoint {
      DiagState *State;
      unsigned Offset;

      DiagStatePoint(DiagState *State, unsigned Offset)
          : State(State), Offset(Offset) {}
    };

    /// Description of the diagnostic states and state transitions for a
    /// particular FileID.
    struct File {
      /// The diagnostic state for the parent file. This is strictly redundant,
      /// as looking up the DecomposedIncludedLoc for the FileID in the Files
      /// map would give us this, but we cache it here for performance.
      File *Parent = nullptr;

      /// The offset of this file within its parent.
      unsigned ParentOffset = 0;

      /// Whether this file has any local (not imported from an AST file)
      /// diagnostic state transitions.
      bool HasLocalTransitions = false;

      /// The points within the file where the state changes. There will always
      /// be at least one of these (the state on entry to the file).
      llvm::SmallVector<DiagStatePoint, 4> StateTransitions;

      DiagState *lookup(unsigned Offset) const;
    };

    /// The diagnostic states for each file.
    mutable std::map<FileID, File> Files;

    /// The initial diagnostic state.
    DiagState *FirstDiagState;

    /// The current diagnostic state.
    DiagState *CurDiagState;

    /// The location at which the current diagnostic state was established.
    SourceLocation CurDiagStateLoc;

    /// Get the diagnostic state information for a file.
    File *getFile(SourceManager &SrcMgr, FileID ID) const;
  };

  DiagStateMap DiagStatesByLoc;

  /// Keeps the DiagState that was active during each diagnostic 'push'
  /// so we can get back at it when we 'pop'.
  std::vector<DiagState *> DiagStateOnPushStack;

  DiagState *GetCurDiagState() const {
    return DiagStatesByLoc.getCurDiagState();
  }

  void PushDiagStatePoint(DiagState *State, SourceLocation L);

  /// Finds the DiagStatePoint that contains the diagnostic state of
  /// the given source location.
  DiagState *GetDiagStateForLoc(SourceLocation Loc) const {
    return SourceMgr ? DiagStatesByLoc.lookup(*SourceMgr, Loc)
                     : DiagStatesByLoc.getCurDiagState();
  }

  /// Sticky flag set to \c true when an error is emitted.
  bool ErrorOccurred;

  /// Sticky flag set to \c true when an "uncompilable error" occurs.
  /// I.e. an error that was not upgraded from a warning by -Werror.
  bool UncompilableErrorOccurred;

  /// Sticky flag set to \c true when a fatal error is emitted.
  bool FatalErrorOccurred;

  /// Indicates that an unrecoverable error has occurred.
  bool UnrecoverableErrorOccurred;

  /// Counts for DiagnosticErrorTrap to check whether an error occurred
  /// during a parsing section, e.g. during parsing a function.
  unsigned TrapNumErrorsOccurred;
  unsigned TrapNumUnrecoverableErrorsOccurred;

  /// The level of the last diagnostic emitted.
  ///
  /// This is used to emit continuation diagnostics with the same level as the
  /// diagnostic that they follow.
  DiagnosticIDs::Level LastDiagLevel;

  /// Number of warnings reported
  unsigned NumWarnings;

  /// Number of errors reported
  unsigned NumErrors;

  /// A function pointer that converts an opaque diagnostic
  /// argument to a strings.
  ///
  /// This takes the modifiers and argument that was present in the diagnostic.
  ///
  /// The PrevArgs array indicates the previous arguments formatted for this
  /// diagnostic.  Implementations of this function can use this information to
  /// avoid redundancy across arguments.
  ///
  /// This is a hack to avoid a layering violation between libbasic and libsema.
  using ArgToStringFnTy = void (*)(
      ArgumentKind Kind, intptr_t Val,
      StringRef Modifier, StringRef Argument,
      ArrayRef<ArgumentValue> PrevArgs,
      SmallVectorImpl<char> &Output,
      void *Cookie,
      ArrayRef<intptr_t> QualTypeVals);

  void *ArgToStringCookie = nullptr;
  ArgToStringFnTy ArgToStringFn;

  /// ID of the "delayed" diagnostic, which is a (typically
  /// fatal) diagnostic that had to be delayed because it was found
  /// while emitting another diagnostic.
  unsigned DelayedDiagID;

  /// First string argument for the delayed diagnostic.
  std::string DelayedDiagArg1;

  /// Second string argument for the delayed diagnostic.
  std::string DelayedDiagArg2;

  /// Third string argument for the delayed diagnostic.
  std::string DelayedDiagArg3;

  /// Optional flag value.
  ///
  /// Some flags accept values, for instance: -Wframe-larger-than=<value> and
  /// -Rpass=<value>. The content of this string is emitted after the flag name
  /// and '='.
  std::string FlagValue;

public:
  explicit DiagnosticsEngine(IntrusiveRefCntPtr<DiagnosticIDs> Diags,
                             IntrusiveRefCntPtr<DiagnosticOptions> DiagOpts,
                             DiagnosticConsumer *client = nullptr,
                             bool ShouldOwnClient = true);
  DiagnosticsEngine(const DiagnosticsEngine &) = delete;
  DiagnosticsEngine &operator=(const DiagnosticsEngine &) = delete;
  ~DiagnosticsEngine();

  LLVM_DUMP_METHOD void dump() const;
  LLVM_DUMP_METHOD void dump(StringRef DiagName) const;

  const IntrusiveRefCntPtr<DiagnosticIDs> &getDiagnosticIDs() const {
    return Diags;
  }

  /// Retrieve the diagnostic options.
  DiagnosticOptions &getDiagnosticOptions() const { return *DiagOpts; }

  using diag_mapping_range = llvm::iterator_range<DiagState::const_iterator>;

  /// Get the current set of diagnostic mappings.
  diag_mapping_range getDiagnosticMappings() const {
    const DiagState &DS = *GetCurDiagState();
    return diag_mapping_range(DS.begin(), DS.end());
  }

  DiagnosticConsumer *getClient() { return Client; }
  const DiagnosticConsumer *getClient() const { return Client; }

  /// Determine whether this \c DiagnosticsEngine object own its client.
  bool ownsClient() const { return Owner != nullptr; }

  /// Return the current diagnostic client along with ownership of that
  /// client.
  std::unique_ptr<DiagnosticConsumer> takeClient() { return std::move(Owner); }

  bool hasSourceManager() const { return SourceMgr != nullptr; }

  SourceManager &getSourceManager() const {
    assert(SourceMgr && "SourceManager not set!");
    return *SourceMgr;
  }

  void setSourceManager(SourceManager *SrcMgr) {
    assert(DiagStatesByLoc.empty() &&
           "Leftover diag state from a different SourceManager.");
    SourceMgr = SrcMgr;
  }

  //===--------------------------------------------------------------------===//
  //  DiagnosticsEngine characterization methods, used by a client to customize
  //  how diagnostics are emitted.
  //

  /// Copies the current DiagMappings and pushes the new copy
  /// onto the top of the stack.
  void pushMappings(SourceLocation Loc);

  /// Pops the current DiagMappings off the top of the stack,
  /// causing the new top of the stack to be the active mappings.
  ///
  /// \returns \c true if the pop happens, \c false if there is only one
  /// DiagMapping on the stack.
  bool popMappings(SourceLocation Loc);

  /// Set the diagnostic client associated with this diagnostic object.
  ///
  /// \param ShouldOwnClient true if the diagnostic object should take
  /// ownership of \c client.
  void setClient(DiagnosticConsumer *client, bool ShouldOwnClient = true);

  /// Specify a limit for the number of errors we should
  /// emit before giving up.
  ///
  /// Zero disables the limit.
  void setErrorLimit(unsigned Limit) { ErrorLimit = Limit; }

  /// Specify the maximum number of template instantiation
  /// notes to emit along with a given diagnostic.
  void setTemplateBacktraceLimit(unsigned Limit) {
    TemplateBacktraceLimit = Limit;
  }

  /// Retrieve the maximum number of template instantiation
  /// notes to emit along with a given diagnostic.
  unsigned getTemplateBacktraceLimit() const {
    return TemplateBacktraceLimit;
  }

  /// Specify the maximum number of constexpr evaluation
  /// notes to emit along with a given diagnostic.
  void setConstexprBacktraceLimit(unsigned Limit) {
    ConstexprBacktraceLimit = Limit;
  }

  /// Retrieve the maximum number of constexpr evaluation
  /// notes to emit along with a given diagnostic.
  unsigned getConstexprBacktraceLimit() const {
    return ConstexprBacktraceLimit;
  }

  /// When set to true, any unmapped warnings are ignored.
  ///
  /// If this and WarningsAsErrors are both set, then this one wins.
  void setIgnoreAllWarnings(bool Val) {
    GetCurDiagState()->IgnoreAllWarnings = Val;
  }
  bool getIgnoreAllWarnings() const {
    return GetCurDiagState()->IgnoreAllWarnings;
  }

  /// When set to true, any unmapped ignored warnings are no longer
  /// ignored.
  ///
  /// If this and IgnoreAllWarnings are both set, then that one wins.
  void setEnableAllWarnings(bool Val) {
    GetCurDiagState()->EnableAllWarnings = Val;
  }
  bool getEnableAllWarnings() const {
    return GetCurDiagState()->EnableAllWarnings;
  }

  /// When set to true, any warnings reported are issued as errors.
  void setWarningsAsErrors(bool Val) {
    GetCurDiagState()->WarningsAsErrors = Val;
  }
  bool getWarningsAsErrors() const {
    return GetCurDiagState()->WarningsAsErrors;
  }

  /// When set to true, any error reported is made a fatal error.
  void setErrorsAsFatal(bool Val) { GetCurDiagState()->ErrorsAsFatal = Val; }
  bool getErrorsAsFatal() const { return GetCurDiagState()->ErrorsAsFatal; }

  /// \brief When set to true, any fatal error reported is made an error.
  ///
  /// This setting takes precedence over the setErrorsAsFatal setting above.
  void setFatalsAsError(bool Val) { FatalsAsError = Val; }
  bool getFatalsAsError() const { return FatalsAsError; }

  /// When set to true mask warnings that come from system headers.
  void setSuppressSystemWarnings(bool Val) {
    GetCurDiagState()->SuppressSystemWarnings = Val;
  }
  bool getSuppressSystemWarnings() const {
    return GetCurDiagState()->SuppressSystemWarnings;
  }

  /// Suppress all diagnostics, to silence the front end when we
  /// know that we don't want any more diagnostics to be passed along to the
  /// client
  void setSuppressAllDiagnostics(bool Val) { SuppressAllDiagnostics = Val; }
  bool getSuppressAllDiagnostics() const { return SuppressAllDiagnostics; }

  /// Set type eliding, to skip outputting same types occurring in
  /// template types.
  void setElideType(bool Val) { ElideType = Val; }
  bool getElideType() { return ElideType; }

  /// Set tree printing, to outputting the template difference in a
  /// tree format.
  void setPrintTemplateTree(bool Val) { PrintTemplateTree = Val; }
  bool getPrintTemplateTree() { return PrintTemplateTree; }

  /// Set color printing, so the type diffing will inject color markers
  /// into the output.
  void setShowColors(bool Val) { ShowColors = Val; }
  bool getShowColors() { return ShowColors; }

  /// Specify which overload candidates to show when overload resolution
  /// fails.
  ///
  /// By default, we show all candidates.
  void setShowOverloads(OverloadsShown Val) {
    ShowOverloads = Val;
  }
  OverloadsShown getShowOverloads() const { return ShowOverloads; }

  /// Pretend that the last diagnostic issued was ignored, so any
  /// subsequent notes will be suppressed, or restore a prior ignoring
  /// state after ignoring some diagnostics and their notes, possibly in
  /// the middle of another diagnostic.
  ///
  /// This can be used by clients who suppress diagnostics themselves.
  void setLastDiagnosticIgnored(bool Ignored) {
    if (LastDiagLevel == DiagnosticIDs::Fatal)
      FatalErrorOccurred = true;
    LastDiagLevel = Ignored ? DiagnosticIDs::Ignored : DiagnosticIDs::Warning;
  }

  /// Determine whether the previous diagnostic was ignored. This can
  /// be used by clients that want to determine whether notes attached to a
  /// diagnostic will be suppressed.
  bool isLastDiagnosticIgnored() const {
    return LastDiagLevel == DiagnosticIDs::Ignored;
  }

  /// Controls whether otherwise-unmapped extension diagnostics are
  /// mapped onto ignore/warning/error.
  ///
  /// This corresponds to the GCC -pedantic and -pedantic-errors option.
  void setExtensionHandlingBehavior(diag::Severity H) {
    GetCurDiagState()->ExtBehavior = H;
  }
  diag::Severity getExtensionHandlingBehavior() const {
    return GetCurDiagState()->ExtBehavior;
  }

  /// Counter bumped when an __extension__  block is/ encountered.
  ///
  /// When non-zero, all extension diagnostics are entirely silenced, no
  /// matter how they are mapped.
  void IncrementAllExtensionsSilenced() { ++AllExtensionsSilenced; }
  void DecrementAllExtensionsSilenced() { --AllExtensionsSilenced; }
  bool hasAllExtensionsSilenced() { return AllExtensionsSilenced != 0; }

  /// This allows the client to specify that certain warnings are
  /// ignored.
  ///
  /// Notes can never be mapped, errors can only be mapped to fatal, and
  /// WARNINGs and EXTENSIONs can be mapped arbitrarily.
  ///
  /// \param Loc The source location that this change of diagnostic state should
  /// take affect. It can be null if we are setting the latest state.
  void setSeverity(diag::kind Diag, diag::Severity Map, SourceLocation Loc);

  /// Change an entire diagnostic group (e.g. "unknown-pragmas") to
  /// have the specified mapping.
  ///
  /// \returns true (and ignores the request) if "Group" was unknown, false
  /// otherwise.
  ///
  /// \param Flavor The flavor of group to affect. -Rfoo does not affect the
  /// state of the -Wfoo group and vice versa.
  ///
  /// \param Loc The source location that this change of diagnostic state should
  /// take affect. It can be null if we are setting the state from command-line.
  bool setSeverityForGroup(diag::Flavor Flavor, StringRef Group,
                           diag::Severity Map,
                           SourceLocation Loc = SourceLocation());

  /// Set the warning-as-error flag for the given diagnostic group.
  ///
  /// This function always only operates on the current diagnostic state.
  ///
  /// \returns True if the given group is unknown, false otherwise.
  bool setDiagnosticGroupWarningAsError(StringRef Group, bool Enabled);

  /// Set the error-as-fatal flag for the given diagnostic group.
  ///
  /// This function always only operates on the current diagnostic state.
  ///
  /// \returns True if the given group is unknown, false otherwise.
  bool setDiagnosticGroupErrorAsFatal(StringRef Group, bool Enabled);

  /// Add the specified mapping to all diagnostics of the specified
  /// flavor.
  ///
  /// Mainly to be used by -Wno-everything to disable all warnings but allow
  /// subsequent -W options to enable specific warnings.
  void setSeverityForAll(diag::Flavor Flavor, diag::Severity Map,
                         SourceLocation Loc = SourceLocation());

  bool hasErrorOccurred() const { return ErrorOccurred; }

  /// Errors that actually prevent compilation, not those that are
  /// upgraded from a warning by -Werror.
  bool hasUncompilableErrorOccurred() const {
    return UncompilableErrorOccurred;
  }
  bool hasFatalErrorOccurred() const { return FatalErrorOccurred; }

  /// Determine whether any kind of unrecoverable error has occurred.
  bool hasUnrecoverableErrorOccurred() const {
    return FatalErrorOccurred || UnrecoverableErrorOccurred;
  }

  unsigned getNumWarnings() const { return NumWarnings; }

  void setNumWarnings(unsigned NumWarnings) {
    this->NumWarnings = NumWarnings;
  }

  /// Return an ID for a diagnostic with the specified format string and
  /// level.
  ///
  /// If this is the first request for this diagnostic, it is registered and
  /// created, otherwise the existing ID is returned.
  ///
  /// \param FormatString A fixed diagnostic format string that will be hashed
  /// and mapped to a unique DiagID.
  template <unsigned N>
  unsigned getCustomDiagID(Level L, const char (&FormatString)[N]) {
    return Diags->getCustomDiagID((DiagnosticIDs::Level)L,
                                  StringRef(FormatString, N - 1));
  }

  /// Converts a diagnostic argument (as an intptr_t) into the string
  /// that represents it.
  void ConvertArgToString(ArgumentKind Kind, intptr_t Val,
                          StringRef Modifier, StringRef Argument,
                          ArrayRef<ArgumentValue> PrevArgs,
                          SmallVectorImpl<char> &Output,
                          ArrayRef<intptr_t> QualTypeVals) const {
    ArgToStringFn(Kind, Val, Modifier, Argument, PrevArgs, Output,
                  ArgToStringCookie, QualTypeVals);
  }

  void SetArgToStringFn(ArgToStringFnTy Fn, void *Cookie) {
    ArgToStringFn = Fn;
    ArgToStringCookie = Cookie;
  }

  /// Note that the prior diagnostic was emitted by some other
  /// \c DiagnosticsEngine, and we may be attaching a note to that diagnostic.
  void notePriorDiagnosticFrom(const DiagnosticsEngine &Other) {
    LastDiagLevel = Other.LastDiagLevel;
  }

  /// Reset the state of the diagnostic object to its initial
  /// configuration.
  void Reset();

  //===--------------------------------------------------------------------===//
  // DiagnosticsEngine classification and reporting interfaces.
  //

  /// Determine whether the diagnostic is known to be ignored.
  ///
  /// This can be used to opportunistically avoid expensive checks when it's
  /// known for certain that the diagnostic has been suppressed at the
  /// specified location \p Loc.
  ///
  /// \param Loc The source location we are interested in finding out the
  /// diagnostic state. Can be null in order to query the latest state.
  bool isIgnored(unsigned DiagID, SourceLocation Loc) const {
    return Diags->getDiagnosticSeverity(DiagID, Loc, *this) ==
           diag::Severity::Ignored;
  }

  /// Based on the way the client configured the DiagnosticsEngine
  /// object, classify the specified diagnostic ID into a Level, consumable by
  /// the DiagnosticConsumer.
  ///
  /// To preserve invariant assumptions, this function should not be used to
  /// influence parse or semantic analysis actions. Instead consider using
  /// \c isIgnored().
  ///
  /// \param Loc The source location we are interested in finding out the
  /// diagnostic state. Can be null in order to query the latest state.
  Level getDiagnosticLevel(unsigned DiagID, SourceLocation Loc) const {
    return (Level)Diags->getDiagnosticLevel(DiagID, Loc, *this);
  }

  /// Issue the message to the client.
  ///
  /// This actually returns an instance of DiagnosticBuilder which emits the
  /// diagnostics (through @c ProcessDiag) when it is destroyed.
  ///
  /// \param DiagID A member of the @c diag::kind enum.
  /// \param Loc Represents the source location associated with the diagnostic,
  /// which can be an invalid location if no position information is available.
  inline DiagnosticBuilder Report(SourceLocation Loc, unsigned DiagID);
  inline DiagnosticBuilder Report(unsigned DiagID);

  void Report(const StoredDiagnostic &storedDiag);

  /// Determine whethere there is already a diagnostic in flight.
  bool isDiagnosticInFlight() const {
    return CurDiagID != std::numeric_limits<unsigned>::max();
  }

  /// Set the "delayed" diagnostic that will be emitted once
  /// the current diagnostic completes.
  ///
  ///  If a diagnostic is already in-flight but the front end must
  ///  report a problem (e.g., with an inconsistent file system
  ///  state), this routine sets a "delayed" diagnostic that will be
  ///  emitted after the current diagnostic completes. This should
  ///  only be used for fatal errors detected at inconvenient
  ///  times. If emitting a delayed diagnostic causes a second delayed
  ///  diagnostic to be introduced, that second delayed diagnostic
  ///  will be ignored.
  ///
  /// \param DiagID The ID of the diagnostic being delayed.
  ///
  /// \param Arg1 A string argument that will be provided to the
  /// diagnostic. A copy of this string will be stored in the
  /// DiagnosticsEngine object itself.
  ///
  /// \param Arg2 A string argument that will be provided to the
  /// diagnostic. A copy of this string will be stored in the
  /// DiagnosticsEngine object itself.
  ///
  /// \param Arg3 A string argument that will be provided to the
  /// diagnostic. A copy of this string will be stored in the
  /// DiagnosticsEngine object itself.
  void SetDelayedDiagnostic(unsigned DiagID, StringRef Arg1 = "",
                            StringRef Arg2 = "", StringRef Arg3 = "");

  /// Clear out the current diagnostic.
  void Clear() { CurDiagID = std::numeric_limits<unsigned>::max(); }

  /// Return the value associated with this diagnostic flag.
  StringRef getFlagValue() const { return FlagValue; }

private:
  // This is private state used by DiagnosticBuilder.  We put it here instead of
  // in DiagnosticBuilder in order to keep DiagnosticBuilder a small lightweight
  // object.  This implementation choice means that we can only have one
  // diagnostic "in flight" at a time, but this seems to be a reasonable
  // tradeoff to keep these objects small.  Assertions verify that only one
  // diagnostic is in flight at a time.
  friend class Diagnostic;
  friend class DiagnosticBuilder;
  friend class DiagnosticErrorTrap;
  friend class DiagnosticIDs;
  friend class PartialDiagnostic;

  /// Report the delayed diagnostic.
  void ReportDelayed();

  /// The location of the current diagnostic that is in flight.
  SourceLocation CurDiagLoc;

  /// The ID of the current diagnostic that is in flight.
  ///
  /// This is set to std::numeric_limits<unsigned>::max() when there is no
  /// diagnostic in flight.
  unsigned CurDiagID;

  enum {
    /// The maximum number of arguments we can hold.
    ///
    /// We currently only support up to 10 arguments (%0-%9).  A single
    /// diagnostic with more than that almost certainly has to be simplified
    /// anyway.
    MaxArguments = 10,
  };

  /// The number of entries in Arguments.
  signed char NumDiagArgs;

  /// Specifies whether an argument is in DiagArgumentsStr or
  /// in DiagArguments.
  ///
  /// This is an array of ArgumentKind::ArgumentKind enum values, one for each
  /// argument.
  unsigned char DiagArgumentsKind[MaxArguments];

  /// Holds the values of each string argument for the current
  /// diagnostic.
  ///
  /// This is only used when the corresponding ArgumentKind is ak_std_string.
  std::string DiagArgumentsStr[MaxArguments];

  /// The values for the various substitution positions.
  ///
  /// This is used when the argument is not an std::string.  The specific
  /// value is mangled into an intptr_t and the interpretation depends on
  /// exactly what sort of argument kind it is.
  intptr_t DiagArgumentsVal[MaxArguments];

  /// The list of ranges added to this diagnostic.
  SmallVector<CharSourceRange, 8> DiagRanges;

  /// If valid, provides a hint with some code to insert, remove,
  /// or modify at a particular position.
  SmallVector<FixItHint, 8> DiagFixItHints;

  DiagnosticMapping makeUserMapping(diag::Severity Map, SourceLocation L) {
    bool isPragma = L.isValid();
    DiagnosticMapping Mapping =
        DiagnosticMapping::Make(Map, /*IsUser=*/true, isPragma);

    // If this is a pragma mapping, then set the diagnostic mapping flags so
    // that we override command line options.
    if (isPragma) {
      Mapping.setNoWarningAsError(true);
      Mapping.setNoErrorAsFatal(true);
    }

    return Mapping;
  }

  /// Used to report a diagnostic that is finally fully formed.
  ///
  /// \returns true if the diagnostic was emitted, false if it was suppressed.
  bool ProcessDiag() {
    return Diags->ProcessDiag(*this);
  }

  /// @name Diagnostic Emission
  /// @{
protected:
  friend class ASTReader;
  friend class ASTWriter;

  // Sema requires access to the following functions because the current design
  // of SFINAE requires it to use its own SemaDiagnosticBuilder, which needs to
  // access us directly to ensure we minimize the emitted code for the common
  // Sema::Diag() patterns.
  friend class Sema;

  /// Emit the current diagnostic and clear the diagnostic state.
  ///
  /// \param Force Emit the diagnostic regardless of suppression settings.
  bool EmitCurrentDiagnostic(bool Force = false);

  unsigned getCurrentDiagID() const { return CurDiagID; }

  SourceLocation getCurrentDiagLoc() const { return CurDiagLoc; }

  /// @}
};

/// RAII class that determines when any errors have occurred
/// between the time the instance was created and the time it was
/// queried.
class DiagnosticErrorTrap {
  DiagnosticsEngine &Diag;
  unsigned NumErrors;
  unsigned NumUnrecoverableErrors;

public:
  explicit DiagnosticErrorTrap(DiagnosticsEngine &Diag)
      : Diag(Diag) { reset(); }

  /// Determine whether any errors have occurred since this
  /// object instance was created.
  bool hasErrorOccurred() const {
    return Diag.TrapNumErrorsOccurred > NumErrors;
  }

  /// Determine whether any unrecoverable errors have occurred since this
  /// object instance was created.
  bool hasUnrecoverableErrorOccurred() const {
    return Diag.TrapNumUnrecoverableErrorsOccurred > NumUnrecoverableErrors;
  }

  /// Set to initial state of "no errors occurred".
  void reset() {
    NumErrors = Diag.TrapNumErrorsOccurred;
    NumUnrecoverableErrors = Diag.TrapNumUnrecoverableErrorsOccurred;
  }
};

//===----------------------------------------------------------------------===//
// DiagnosticBuilder
//===----------------------------------------------------------------------===//

/// A little helper class used to produce diagnostics.
///
/// This is constructed by the DiagnosticsEngine::Report method, and
/// allows insertion of extra information (arguments and source ranges) into
/// the currently "in flight" diagnostic.  When the temporary for the builder
/// is destroyed, the diagnostic is issued.
///
/// Note that many of these will be created as temporary objects (many call
/// sites), so we want them to be small and we never want their address taken.
/// This ensures that compilers with somewhat reasonable optimizers will promote
/// the common fields to registers, eliminating increments of the NumArgs field,
/// for example.
class DiagnosticBuilder {
  friend class DiagnosticsEngine;
  friend class PartialDiagnostic;

  mutable DiagnosticsEngine *DiagObj = nullptr;
  mutable unsigned NumArgs = 0;

  /// Status variable indicating if this diagnostic is still active.
  ///
  // NOTE: This field is redundant with DiagObj (IsActive iff (DiagObj == 0)),
  // but LLVM is not currently smart enough to eliminate the null check that
  // Emit() would end up with if we used that as our status variable.
  mutable bool IsActive = false;

  /// Flag indicating that this diagnostic is being emitted via a
  /// call to ForceEmit.
  mutable bool IsForceEmit = false;

  DiagnosticBuilder() = default;

  explicit DiagnosticBuilder(DiagnosticsEngine *diagObj)
      : DiagObj(diagObj), IsActive(true) {
    assert(diagObj && "DiagnosticBuilder requires a valid DiagnosticsEngine!");
    diagObj->DiagRanges.clear();
    diagObj->DiagFixItHints.clear();
  }

protected:
  void FlushCounts() {
    DiagObj->NumDiagArgs = NumArgs;
  }

  /// Clear out the current diagnostic.
  void Clear() const {
    DiagObj = nullptr;
    IsActive = false;
    IsForceEmit = false;
  }

  /// Determine whether this diagnostic is still active.
  bool isActive() const { return IsActive; }

  /// Force the diagnostic builder to emit the diagnostic now.
  ///
  /// Once this function has been called, the DiagnosticBuilder object
  /// should not be used again before it is destroyed.
  ///
  /// \returns true if a diagnostic was emitted, false if the
  /// diagnostic was suppressed.
  bool Emit() {
    // If this diagnostic is inactive, then its soul was stolen by the copy ctor
    // (or by a subclass, as in SemaDiagnosticBuilder).
    if (!isActive()) return false;

    // When emitting diagnostics, we set the final argument count into
    // the DiagnosticsEngine object.
    FlushCounts();

    // Process the diagnostic.
    bool Result = DiagObj->EmitCurrentDiagnostic(IsForceEmit);

    // This diagnostic is dead.
    Clear();

    return Result;
  }

public:
  /// Copy constructor.  When copied, this "takes" the diagnostic info from the
  /// input and neuters it.
  DiagnosticBuilder(const DiagnosticBuilder &D) {
    DiagObj = D.DiagObj;
    IsActive = D.IsActive;
    IsForceEmit = D.IsForceEmit;
    D.Clear();
    NumArgs = D.NumArgs;
  }

  DiagnosticBuilder &operator=(const DiagnosticBuilder &) = delete;

  /// Emits the diagnostic.
  ~DiagnosticBuilder() {
    Emit();
  }

  /// Forces the diagnostic to be emitted.
  const DiagnosticBuilder &setForceEmit() const {
    IsForceEmit = true;
    return *this;
  }

  /// Conversion of DiagnosticBuilder to bool always returns \c true.
  ///
  /// This allows is to be used in boolean error contexts (where \c true is
  /// used to indicate that an error has occurred), like:
  /// \code
  /// return Diag(...);
  /// \endcode
  operator bool() const { return true; }

  void AddString(StringRef S) const {
    assert(isActive() && "Clients must not add to cleared diagnostic!");
    assert(NumArgs < DiagnosticsEngine::MaxArguments &&
           "Too many arguments to diagnostic!");
    DiagObj->DiagArgumentsKind[NumArgs] = DiagnosticsEngine::ak_std_string;
    DiagObj->DiagArgumentsStr[NumArgs++] = std::string(S);
  }

  void AddTaggedVal(intptr_t V, DiagnosticsEngine::ArgumentKind Kind) const {
    assert(isActive() && "Clients must not add to cleared diagnostic!");
    assert(NumArgs < DiagnosticsEngine::MaxArguments &&
           "Too many arguments to diagnostic!");
    DiagObj->DiagArgumentsKind[NumArgs] = Kind;
    DiagObj->DiagArgumentsVal[NumArgs++] = V;
  }

  void AddSourceRange(const CharSourceRange &R) const {
    assert(isActive() && "Clients must not add to cleared diagnostic!");
    DiagObj->DiagRanges.push_back(R);
  }

  void AddFixItHint(const FixItHint &Hint) const {
    assert(isActive() && "Clients must not add to cleared diagnostic!");
    if (!Hint.isNull())
      DiagObj->DiagFixItHints.push_back(Hint);
  }

  void addFlagValue(StringRef V) const { DiagObj->FlagValue = std::string(V); }
};

struct AddFlagValue {
  StringRef Val;

  explicit AddFlagValue(StringRef V) : Val(V) {}
};

/// Register a value for the flag in the current diagnostic. This
/// value will be shown as the suffix "=value" after the flag name. It is
/// useful in cases where the diagnostic flag accepts values (e.g.,
/// -Rpass or -Wframe-larger-than).
inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           const AddFlagValue V) {
  DB.addFlagValue(V.Val);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           StringRef S) {
  DB.AddString(S);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           const char *Str) {
  DB.AddTaggedVal(reinterpret_cast<intptr_t>(Str),
                  DiagnosticsEngine::ak_c_string);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB, int I) {
  DB.AddTaggedVal(I, DiagnosticsEngine::ak_sint);
  return DB;
}

// We use enable_if here to prevent that this overload is selected for
// pointers or other arguments that are implicitly convertible to bool.
template <typename T>
inline std::enable_if_t<std::is_same<T, bool>::value, const DiagnosticBuilder &>
operator<<(const DiagnosticBuilder &DB, T I) {
  DB.AddTaggedVal(I, DiagnosticsEngine::ak_sint);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           unsigned I) {
  DB.AddTaggedVal(I, DiagnosticsEngine::ak_uint);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           tok::TokenKind I) {
  DB.AddTaggedVal(static_cast<unsigned>(I), DiagnosticsEngine::ak_tokenkind);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           const IdentifierInfo *II) {
  DB.AddTaggedVal(reinterpret_cast<intptr_t>(II),
                  DiagnosticsEngine::ak_identifierinfo);
  return DB;
}

// Adds a DeclContext to the diagnostic. The enable_if template magic is here
// so that we only match those arguments that are (statically) DeclContexts;
// other arguments that derive from DeclContext (e.g., RecordDecls) will not
// match.
template <typename T>
inline std::enable_if_t<
    std::is_same<std::remove_const_t<T>, DeclContext>::value,
    const DiagnosticBuilder &>
operator<<(const DiagnosticBuilder &DB, T *DC) {
  DB.AddTaggedVal(reinterpret_cast<intptr_t>(DC),
                  DiagnosticsEngine::ak_declcontext);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           SourceRange R) {
  DB.AddSourceRange(CharSourceRange::getTokenRange(R));
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           ArrayRef<SourceRange> Ranges) {
  for (SourceRange R : Ranges)
    DB.AddSourceRange(CharSourceRange::getTokenRange(R));
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           const CharSourceRange &R) {
  DB.AddSourceRange(R);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           const FixItHint &Hint) {
  DB.AddFixItHint(Hint);
  return DB;
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           ArrayRef<FixItHint> Hints) {
  for (const FixItHint &Hint : Hints)
    DB.AddFixItHint(Hint);
  return DB;
}

/// A nullability kind paired with a bit indicating whether it used a
/// context-sensitive keyword.
using DiagNullabilityKind = std::pair<NullabilityKind, bool>;

const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                    DiagNullabilityKind nullability);

inline DiagnosticBuilder DiagnosticsEngine::Report(SourceLocation Loc,
                                                   unsigned DiagID) {
  assert(CurDiagID == std::numeric_limits<unsigned>::max() &&
         "Multiple diagnostics in flight at once!");
  CurDiagLoc = Loc;
  CurDiagID = DiagID;
  FlagValue.clear();
  return DiagnosticBuilder(this);
}

inline const DiagnosticBuilder &operator<<(const DiagnosticBuilder &DB,
                                           llvm::Error &&E) {
  DB.AddString(toString(std::move(E)));
  return DB;
}

inline DiagnosticBuilder DiagnosticsEngine::Report(unsigned DiagID) {
  return Report(SourceLocation(), DiagID);
}

//===----------------------------------------------------------------------===//
// Diagnostic
//===----------------------------------------------------------------------===//

/// A little helper class (which is basically a smart pointer that forwards
/// info from DiagnosticsEngine) that allows clients to enquire about the
/// currently in-flight diagnostic.
class Diagnostic {
  const DiagnosticsEngine *DiagObj;
  StringRef StoredDiagMessage;

public:
  explicit Diagnostic(const DiagnosticsEngine *DO) : DiagObj(DO) {}
  Diagnostic(const DiagnosticsEngine *DO, StringRef storedDiagMessage)
      : DiagObj(DO), StoredDiagMessage(storedDiagMessage) {}

  const DiagnosticsEngine *getDiags() const { return DiagObj; }
  unsigned getID() const { return DiagObj->CurDiagID; }
  const SourceLocation &getLocation() const { return DiagObj->CurDiagLoc; }
  bool hasSourceManager() const { return DiagObj->hasSourceManager(); }
  SourceManager &getSourceManager() const { return DiagObj->getSourceManager();}

  unsigned getNumArgs() const { return DiagObj->NumDiagArgs; }

  /// Return the kind of the specified index.
  ///
  /// Based on the kind of argument, the accessors below can be used to get
  /// the value.
  ///
  /// \pre Idx < getNumArgs()
  DiagnosticsEngine::ArgumentKind getArgKind(unsigned Idx) const {
    assert(Idx < getNumArgs() && "Argument index out of range!");
    return (DiagnosticsEngine::ArgumentKind)DiagObj->DiagArgumentsKind[Idx];
  }

  /// Return the provided argument string specified by \p Idx.
  /// \pre getArgKind(Idx) == DiagnosticsEngine::ak_std_string
  const std::string &getArgStdStr(unsigned Idx) const {
    assert(getArgKind(Idx) == DiagnosticsEngine::ak_std_string &&
           "invalid argument accessor!");
    return DiagObj->DiagArgumentsStr[Idx];
  }

  /// Return the specified C string argument.
  /// \pre getArgKind(Idx) == DiagnosticsEngine::ak_c_string
  const char *getArgCStr(unsigned Idx) const {
    assert(getArgKind(Idx) == DiagnosticsEngine::ak_c_string &&
           "invalid argument accessor!");
    return reinterpret_cast<const char*>(DiagObj->DiagArgumentsVal[Idx]);
  }

  /// Return the specified signed integer argument.
  /// \pre getArgKind(Idx) == DiagnosticsEngine::ak_sint
  int getArgSInt(unsigned Idx) const {
    assert(getArgKind(Idx) == DiagnosticsEngine::ak_sint &&
           "invalid argument accessor!");
    return (int)DiagObj->DiagArgumentsVal[Idx];
  }

  /// Return the specified unsigned integer argument.
  /// \pre getArgKind(Idx) == DiagnosticsEngine::ak_uint
  unsigned getArgUInt(unsigned Idx) const {
    assert(getArgKind(Idx) == DiagnosticsEngine::ak_uint &&
           "invalid argument accessor!");
    return (unsigned)DiagObj->DiagArgumentsVal[Idx];
  }

  /// Return the specified IdentifierInfo argument.
  /// \pre getArgKind(Idx) == DiagnosticsEngine::ak_identifierinfo
  const IdentifierInfo *getArgIdentifier(unsigned Idx) const {
    assert(getArgKind(Idx) == DiagnosticsEngine::ak_identifierinfo &&
           "invalid argument accessor!");
    return reinterpret_cast<IdentifierInfo*>(DiagObj->DiagArgumentsVal[Idx]);
  }

  /// Return the specified non-string argument in an opaque form.
  /// \pre getArgKind(Idx) != DiagnosticsEngine::ak_std_string
  intptr_t getRawArg(unsigned Idx) const {
    assert(getArgKind(Idx) != DiagnosticsEngine::ak_std_string &&
           "invalid argument accessor!");
    return DiagObj->DiagArgumentsVal[Idx];
  }

  /// Return the number of source ranges associated with this diagnostic.
  unsigned getNumRanges() const {
    return DiagObj->DiagRanges.size();
  }

  /// \pre Idx < getNumRanges()
  const CharSourceRange &getRange(unsigned Idx) const {
    assert(Idx < getNumRanges() && "Invalid diagnostic range index!");
    return DiagObj->DiagRanges[Idx];
  }

  /// Return an array reference for this diagnostic's ranges.
  ArrayRef<CharSourceRange> getRanges() const {
    return DiagObj->DiagRanges;
  }

  unsigned getNumFixItHints() const {
    return DiagObj->DiagFixItHints.size();
  }

  const FixItHint &getFixItHint(unsigned Idx) const {
    assert(Idx < getNumFixItHints() && "Invalid index!");
    return DiagObj->DiagFixItHints[Idx];
  }

  ArrayRef<FixItHint> getFixItHints() const {
    return DiagObj->DiagFixItHints;
  }

  /// Format this diagnostic into a string, substituting the
  /// formal arguments into the %0 slots.
  ///
  /// The result is appended onto the \p OutStr array.
  void FormatDiagnostic(SmallVectorImpl<char> &OutStr) const;

  /// Format the given format-string into the output buffer using the
  /// arguments stored in this diagnostic.
  void FormatDiagnostic(const char *DiagStr, const char *DiagEnd,
                        SmallVectorImpl<char> &OutStr) const;
};

/**
 * Represents a diagnostic in a form that can be retained until its
 * corresponding source manager is destroyed.
 */
class StoredDiagnostic {
  unsigned ID;
  DiagnosticsEngine::Level Level;
  FullSourceLoc Loc;
  std::string Message;
  std::vector<CharSourceRange> Ranges;
  std::vector<FixItHint> FixIts;

public:
  StoredDiagnostic() = default;
  StoredDiagnostic(DiagnosticsEngine::Level Level, const Diagnostic &Info);
  StoredDiagnostic(DiagnosticsEngine::Level Level, unsigned ID,
                   StringRef Message);
  StoredDiagnostic(DiagnosticsEngine::Level Level, unsigned ID,
                   StringRef Message, FullSourceLoc Loc,
                   ArrayRef<CharSourceRange> Ranges,
                   ArrayRef<FixItHint> Fixits);

  /// Evaluates true when this object stores a diagnostic.
  explicit operator bool() const { return !Message.empty(); }

  unsigned getID() const { return ID; }
  DiagnosticsEngine::Level getLevel() const { return Level; }
  const FullSourceLoc &getLocation() const { return Loc; }
  StringRef getMessage() const { return Message; }

  void setLocation(FullSourceLoc Loc) { this->Loc = Loc; }

  using range_iterator = std::vector<CharSourceRange>::const_iterator;

  range_iterator range_begin() const { return Ranges.begin(); }
  range_iterator range_end() const { return Ranges.end(); }
  unsigned range_size() const { return Ranges.size(); }

  ArrayRef<CharSourceRange> getRanges() const {
    return llvm::makeArrayRef(Ranges);
  }

  using fixit_iterator = std::vector<FixItHint>::const_iterator;

  fixit_iterator fixit_begin() const { return FixIts.begin(); }
  fixit_iterator fixit_end() const { return FixIts.end(); }
  unsigned fixit_size() const { return FixIts.size(); }

  ArrayRef<FixItHint> getFixIts() const {
    return llvm::makeArrayRef(FixIts);
  }
};

/// Abstract interface, implemented by clients of the front-end, which
/// formats and prints fully processed diagnostics.
class DiagnosticConsumer {
protected:
  unsigned NumWarnings = 0;       ///< Number of warnings reported
  unsigned NumErrors = 0;         ///< Number of errors reported

public:
  DiagnosticConsumer() = default;
  virtual ~DiagnosticConsumer();

  unsigned getNumErrors() const { return NumErrors; }
  unsigned getNumWarnings() const { return NumWarnings; }
  virtual void clear() { NumWarnings = NumErrors = 0; }

  /// Callback to inform the diagnostic client that processing
  /// of a source file is beginning.
  ///
  /// Note that diagnostics may be emitted outside the processing of a source
  /// file, for example during the parsing of command line options. However,
  /// diagnostics with source range information are required to only be emitted
  /// in between BeginSourceFile() and EndSourceFile().
  ///
  /// \param LangOpts The language options for the source file being processed.
  /// \param PP The preprocessor object being used for the source; this is
  /// optional, e.g., it may not be present when processing AST source files.
  virtual void BeginSourceFile(const LangOptions &LangOpts,
                               const Preprocessor *PP = nullptr) {}

  /// Callback to inform the diagnostic client that processing
  /// of a source file has ended.
  ///
  /// The diagnostic client should assume that any objects made available via
  /// BeginSourceFile() are inaccessible.
  virtual void EndSourceFile() {}

  /// Callback to inform the diagnostic client that processing of all
  /// source files has ended.
  virtual void finish() {}

  /// Indicates whether the diagnostics handled by this
  /// DiagnosticConsumer should be included in the number of diagnostics
  /// reported by DiagnosticsEngine.
  ///
  /// The default implementation returns true.
  virtual bool IncludeInDiagnosticCounts() const;

  /// Handle this diagnostic, reporting it to the user or
  /// capturing it to a log as needed.
  ///
  /// The default implementation just keeps track of the total number of
  /// warnings and errors.
  virtual void HandleDiagnostic(DiagnosticsEngine::Level DiagLevel,
                                const Diagnostic &Info);
};

/// A diagnostic client that ignores all diagnostics.
class IgnoringDiagConsumer : public DiagnosticConsumer {
  virtual void anchor();

  void HandleDiagnostic(DiagnosticsEngine::Level DiagLevel,
                        const Diagnostic &Info) override {
    // Just ignore it.
  }
};

/// Diagnostic consumer that forwards diagnostics along to an
/// existing, already-initialized diagnostic consumer.
///
class ForwardingDiagnosticConsumer : public DiagnosticConsumer {
  DiagnosticConsumer &Target;

public:
  ForwardingDiagnosticConsumer(DiagnosticConsumer &Target) : Target(Target) {}
  ~ForwardingDiagnosticConsumer() override;

  void HandleDiagnostic(DiagnosticsEngine::Level DiagLevel,
                        const Diagnostic &Info) override;
  void clear() override;

  bool IncludeInDiagnosticCounts() const override;
};

// Struct used for sending info about how a type should be printed.
struct TemplateDiffTypes {
  intptr_t FromType;
  intptr_t ToType;
  unsigned PrintTree : 1;
  unsigned PrintFromType : 1;
  unsigned ElideType : 1;
  unsigned ShowColors : 1;

  // The printer sets this variable to true if the template diff was used.
  unsigned TemplateDiffUsed : 1;
};

/// Special character that the diagnostic printer will use to toggle the bold
/// attribute.  The character itself will be not be printed.
const char ToggleHighlight = 127;

/// ProcessWarningOptions - Initialize the diagnostic client and process the
/// warning options specified on the command line.
void ProcessWarningOptions(DiagnosticsEngine &Diags,
                           const DiagnosticOptions &Opts,
                           bool ReportDiags = true);

} // namespace clang

#endif // LLVM_CLANG_BASIC_DIAGNOSTIC_H
# 1604 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/Diagnostic.h"
# 38 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/FileManager.h"
#endif /* expanded by -frewrite-includes */
# 38 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h" 1
//===--- FileManager.h - File System Probing and Caching --------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
///
/// \file
/// Defines the clang::FileManager interface and associated types.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_FILEMANAGER_H
#define LLVM_CLANG_BASIC_FILEMANAGER_H

#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/FileSystemOptions.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileSystemOptions.h" 1
//===--- FileSystemOptions.h - File System Options --------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
///
/// \file
/// Defines the clang::FileSystemOptions interface.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_FILESYSTEMOPTIONS_H
#define LLVM_CLANG_BASIC_FILESYSTEMOPTIONS_H

#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileSystemOptions.h"
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileSystemOptions.h"

namespace clang {

/// Keeps track of options that affect how file operations are performed.
class FileSystemOptions {
public:
  /// If set, paths are resolved as if the working directory was
  /// set to the value of WorkingDir.
  std::string WorkingDir;
};

} // end namespace clang

#endif
# 32 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileSystemOptions.h"
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/LLVM.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMap.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/IntrusiveRefCntPtr.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringMap.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h" 1
//===- StringMap.h - String Hash table map interface ------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the StringMap class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_STRINGMAP_H
#define LLVM_ADT_STRINGMAP_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator_range.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/AllocatorBase.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AllocatorBase.h" 1
//===- AllocatorBase.h - Simple memory allocation abstraction ---*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
/// \file
///
/// This file defines MallocAllocator. MallocAllocator conforms to the LLVM
/// "Allocator" concept which consists of an Allocate method accepting a size
/// and alignment, and a Deallocate accepting a pointer and size. Further, the
/// LLVM "Allocator" concept has overloads of Allocate and Deallocate for
/// setting size and alignment based on the final type. These overloads are
/// typically provided by a base class template \c AllocatorBase.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_ALLOCATORBASE_H
#define LLVM_SUPPORT_ALLOCATORBASE_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AllocatorBase.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AllocatorBase.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MemAlloc.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AllocatorBase.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AllocatorBase.h"

namespace llvm {

/// CRTP base class providing obvious overloads for the core \c
/// Allocate() methods of LLVM-style allocators.
///
/// This base class both documents the full public interface exposed by all
/// LLVM-style allocators, and redirects all of the overloads to a single core
/// set of methods which the derived class must define.
template <typename DerivedT> class AllocatorBase {
public:
  /// Allocate \a Size bytes of \a Alignment aligned memory. This method
  /// must be implemented by \c DerivedT.
  void *Allocate(size_t Size, size_t Alignment) {
#ifdef __clang__
    static_assert(static_cast<void *(AllocatorBase::*)(size_t, size_t)>(
                      &AllocatorBase::Allocate) !=
                      static_cast<void *(DerivedT::*)(size_t, size_t)>(
                          &DerivedT::Allocate),
                  "Class derives from AllocatorBase without implementing the "
                  "core Allocate(size_t, size_t) overload!");
#endif
# 46 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AllocatorBase.h"
    return static_cast<DerivedT *>(this)->Allocate(Size, Alignment);
  }

  /// Deallocate \a Ptr to \a Size bytes of memory allocated by this
  /// allocator.
  void Deallocate(const void *Ptr, size_t Size) {
#ifdef __clang__
    static_assert(static_cast<void (AllocatorBase::*)(const void *, size_t)>(
                      &AllocatorBase::Deallocate) !=
                      static_cast<void (DerivedT::*)(const void *, size_t)>(
                          &DerivedT::Deallocate),
                  "Class derives from AllocatorBase without implementing the "
                  "core Deallocate(void *) overload!");
#endif
# 60 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AllocatorBase.h"
    return static_cast<DerivedT *>(this)->Deallocate(Ptr, Size);
  }

  // The rest of these methods are helpers that redirect to one of the above
  // core methods.

  /// Allocate space for a sequence of objects without constructing them.
  template <typename T> T *Allocate(size_t Num = 1) {
    return static_cast<T *>(Allocate(Num * sizeof(T), alignof(T)));
  }

  /// Deallocate space for a sequence of objects without constructing them.
  template <typename T>
  std::enable_if_t<!std::is_same<std::remove_cv_t<T>, void>::value, void>
  Deallocate(T *Ptr, size_t Num = 1) {
    Deallocate(static_cast<const void *>(Ptr), Num * sizeof(T));
  }
};

class MallocAllocator : public AllocatorBase<MallocAllocator> {
public:
  void Reset() {}

  LLVM_ATTRIBUTE_RETURNS_NONNULL void *Allocate(size_t Size,
                                                size_t /*Alignment*/) {
    return safe_malloc(Size);
  }

  // Pull in base class overloads.
  using AllocatorBase<MallocAllocator>::Allocate;

  void Deallocate(const void *Ptr, size_t /*Size*/) {
    free(const_cast<void *>(Ptr));
  }

  // Pull in base class overloads.
  using AllocatorBase<MallocAllocator>::Deallocate;

  void PrintStats() const {}
};

} // namespace llvm

#endif // LLVM_SUPPORT_ALLOCATORBASE_H
# 104 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/AllocatorBase.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/PointerLikeTypeTraits.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"

namespace llvm {

template<typename ValueTy> class StringMapConstIterator;
template<typename ValueTy> class StringMapIterator;
template<typename ValueTy> class StringMapKeyIterator;

/// StringMapEntryBase - Shared base class of StringMapEntry instances.
class StringMapEntryBase {
  size_t StrLen;

public:
  explicit StringMapEntryBase(size_t Len) : StrLen(Len) {}

  size_t getKeyLength() const { return StrLen; }
};

/// StringMapImpl - This is the base class of StringMap that is shared among
/// all of its instantiations.
class StringMapImpl {
protected:
  // Array of NumBuckets pointers to entries, null pointers are holes.
  // TheTable[NumBuckets] contains a sentinel value for easy iteration. Followed
  // by an array of the actual hash values as unsigned integers.
  StringMapEntryBase **TheTable = nullptr;
  unsigned NumBuckets = 0;
  unsigned NumItems = 0;
  unsigned NumTombstones = 0;
  unsigned ItemSize;

protected:
  explicit StringMapImpl(unsigned itemSize)
      : ItemSize(itemSize) {}
  StringMapImpl(StringMapImpl &&RHS)
      : TheTable(RHS.TheTable), NumBuckets(RHS.NumBuckets),
        NumItems(RHS.NumItems), NumTombstones(RHS.NumTombstones),
        ItemSize(RHS.ItemSize) {
    RHS.TheTable = nullptr;
    RHS.NumBuckets = 0;
    RHS.NumItems = 0;
    RHS.NumTombstones = 0;
  }

  StringMapImpl(unsigned InitSize, unsigned ItemSize);
  unsigned RehashTable(unsigned BucketNo = 0);

  /// LookupBucketFor - Look up the bucket that the specified string should end
  /// up in.  If it already exists as a key in the map, the Item pointer for the
  /// specified bucket will be non-null.  Otherwise, it will be null.  In either
  /// case, the FullHashValue field of the bucket will be set to the hash value
  /// of the string.
  unsigned LookupBucketFor(StringRef Key);

  /// FindKey - Look up the bucket that contains the specified key. If it exists
  /// in the map, return the bucket number of the key.  Otherwise return -1.
  /// This does not modify the map.
  int FindKey(StringRef Key) const;

  /// RemoveKey - Remove the specified StringMapEntry from the table, but do not
  /// delete it.  This aborts if the value isn't in the table.
  void RemoveKey(StringMapEntryBase *V);

  /// RemoveKey - Remove the StringMapEntry for the specified key from the
  /// table, returning it.  If the key is not in the table, this returns null.
  StringMapEntryBase *RemoveKey(StringRef Key);

  /// Allocate the table with the specified number of buckets and otherwise
  /// setup the map as empty.
  void init(unsigned Size);

public:
  static StringMapEntryBase *getTombstoneVal() {
    uintptr_t Val = static_cast<uintptr_t>(-1);
    Val <<= PointerLikeTypeTraits<StringMapEntryBase *>::NumLowBitsAvailable;
    return reinterpret_cast<StringMapEntryBase *>(Val);
  }

  unsigned getNumBuckets() const { return NumBuckets; }
  unsigned getNumItems() const { return NumItems; }

  bool empty() const { return NumItems == 0; }
  unsigned size() const { return NumItems; }

  void swap(StringMapImpl &Other) {
    std::swap(TheTable, Other.TheTable);
    std::swap(NumBuckets, Other.NumBuckets);
    std::swap(NumItems, Other.NumItems);
    std::swap(NumTombstones, Other.NumTombstones);
  }
};

/// StringMapEntryStorage - Holds the value in a StringMapEntry.
///
/// Factored out into a separate base class to make it easier to specialize.
/// This is primarily intended to support StringSet, which doesn't need a value
/// stored at all.
template<typename ValueTy>
class StringMapEntryStorage : public StringMapEntryBase {
public:
  ValueTy second;

  explicit StringMapEntryStorage(size_t strLen)
    : StringMapEntryBase(strLen), second() {}
  template <typename... InitTy>
  StringMapEntryStorage(size_t strLen, InitTy &&... InitVals)
      : StringMapEntryBase(strLen), second(std::forward<InitTy>(InitVals)...) {}
  StringMapEntryStorage(StringMapEntryStorage &E) = delete;

  const ValueTy &getValue() const { return second; }
  ValueTy &getValue() { return second; }

  void setValue(const ValueTy &V) { second = V; }
};

template<>
class StringMapEntryStorage<NoneType> : public StringMapEntryBase {
public:
  explicit StringMapEntryStorage(size_t strLen, NoneType none = None)
    : StringMapEntryBase(strLen) {}
  StringMapEntryStorage(StringMapEntryStorage &E) = delete;

  NoneType getValue() const { return None; }
};

/// StringMapEntry - This is used to represent one value that is inserted into
/// a StringMap.  It contains the Value itself and the key: the string length
/// and data.
template<typename ValueTy>
class StringMapEntry final : public StringMapEntryStorage<ValueTy> {
public:
  using StringMapEntryStorage<ValueTy>::StringMapEntryStorage;

  StringRef getKey() const {
    return StringRef(getKeyData(), this->getKeyLength());
  }

  /// getKeyData - Return the start of the string data that is the key for this
  /// value.  The string data is always stored immediately after the
  /// StringMapEntry object.
  const char *getKeyData() const {return reinterpret_cast<const char*>(this+1);}

  StringRef first() const {
    return StringRef(getKeyData(), this->getKeyLength());
  }

  /// Create a StringMapEntry for the specified key construct the value using
  /// \p InitiVals.
  template <typename AllocatorTy, typename... InitTy>
  static StringMapEntry *Create(StringRef Key, AllocatorTy &Allocator,
                                InitTy &&... InitVals) {
    size_t KeyLength = Key.size();

    // Allocate a new item with space for the string at the end and a null
    // terminator.
    size_t AllocSize = sizeof(StringMapEntry) + KeyLength + 1;
    size_t Alignment = alignof(StringMapEntry);

    StringMapEntry *NewItem =
      static_cast<StringMapEntry*>(Allocator.Allocate(AllocSize,Alignment));
    assert(NewItem && "Unhandled out-of-memory");

    // Construct the value.
    new (NewItem) StringMapEntry(KeyLength, std::forward<InitTy>(InitVals)...);

    // Copy the string information.
    char *StrBuffer = const_cast<char*>(NewItem->getKeyData());
    if (KeyLength > 0)
      memcpy(StrBuffer, Key.data(), KeyLength);
    StrBuffer[KeyLength] = 0;  // Null terminate for convenience of clients.
    return NewItem;
  }

  /// Create - Create a StringMapEntry with normal malloc/free.
  template <typename... InitType>
  static StringMapEntry *Create(StringRef Key, InitType &&... InitVal) {
    MallocAllocator A;
    return Create(Key, A, std::forward<InitType>(InitVal)...);
  }

  static StringMapEntry *Create(StringRef Key) {
    return Create(Key, ValueTy());
  }

  /// GetStringMapEntryFromKeyData - Given key data that is known to be embedded
  /// into a StringMapEntry, return the StringMapEntry itself.
  static StringMapEntry &GetStringMapEntryFromKeyData(const char *KeyData) {
    char *Ptr = const_cast<char*>(KeyData) - sizeof(StringMapEntry<ValueTy>);
    return *reinterpret_cast<StringMapEntry*>(Ptr);
  }

  /// Destroy - Destroy this StringMapEntry, releasing memory back to the
  /// specified allocator.
  template<typename AllocatorTy>
  void Destroy(AllocatorTy &Allocator) {
    // Free memory referenced by the item.
    size_t AllocSize = sizeof(StringMapEntry) + this->getKeyLength() + 1;
    this->~StringMapEntry();
    Allocator.Deallocate(static_cast<void *>(this), AllocSize);
  }

  /// Destroy this object, releasing memory back to the malloc allocator.
  void Destroy() {
    MallocAllocator A;
    Destroy(A);
  }
};

/// StringMap - This is an unconventional map that is specialized for handling
/// keys that are "strings", which are basically ranges of bytes. This does some
/// funky memory allocation and hashing things to make it extremely efficient,
/// storing the string data *after* the value in the map.
template<typename ValueTy, typename AllocatorTy = MallocAllocator>
class StringMap : public StringMapImpl {
  AllocatorTy Allocator;

public:
  using MapEntryTy = StringMapEntry<ValueTy>;

  StringMap() : StringMapImpl(static_cast<unsigned>(sizeof(MapEntryTy))) {}

  explicit StringMap(unsigned InitialSize)
    : StringMapImpl(InitialSize, static_cast<unsigned>(sizeof(MapEntryTy))) {}

  explicit StringMap(AllocatorTy A)
    : StringMapImpl(static_cast<unsigned>(sizeof(MapEntryTy))), Allocator(A) {}

  StringMap(unsigned InitialSize, AllocatorTy A)
    : StringMapImpl(InitialSize, static_cast<unsigned>(sizeof(MapEntryTy))),
      Allocator(A) {}

  StringMap(std::initializer_list<std::pair<StringRef, ValueTy>> List)
      : StringMapImpl(List.size(), static_cast<unsigned>(sizeof(MapEntryTy))) {
    for (const auto &P : List) {
      insert(P);
    }
  }

  StringMap(StringMap &&RHS)
      : StringMapImpl(std::move(RHS)), Allocator(std::move(RHS.Allocator)) {}

  StringMap(const StringMap &RHS) :
    StringMapImpl(static_cast<unsigned>(sizeof(MapEntryTy))),
    Allocator(RHS.Allocator) {
    if (RHS.empty())
      return;

    // Allocate TheTable of the same size as RHS's TheTable, and set the
    // sentinel appropriately (and NumBuckets).
    init(RHS.NumBuckets);
    unsigned *HashTable = (unsigned *)(TheTable + NumBuckets + 1),
             *RHSHashTable = (unsigned *)(RHS.TheTable + NumBuckets + 1);

    NumItems = RHS.NumItems;
    NumTombstones = RHS.NumTombstones;
    for (unsigned I = 0, E = NumBuckets; I != E; ++I) {
      StringMapEntryBase *Bucket = RHS.TheTable[I];
      if (!Bucket || Bucket == getTombstoneVal()) {
        TheTable[I] = Bucket;
        continue;
      }

      TheTable[I] = MapEntryTy::Create(
          static_cast<MapEntryTy *>(Bucket)->getKey(), Allocator,
          static_cast<MapEntryTy *>(Bucket)->getValue());
      HashTable[I] = RHSHashTable[I];
    }

    // Note that here we've copied everything from the RHS into this object,
    // tombstones included. We could, instead, have re-probed for each key to
    // instantiate this new object without any tombstone buckets. The
    // assumption here is that items are rarely deleted from most StringMaps,
    // and so tombstones are rare, so the cost of re-probing for all inputs is
    // not worthwhile.
  }

  StringMap &operator=(StringMap RHS) {
    StringMapImpl::swap(RHS);
    std::swap(Allocator, RHS.Allocator);
    return *this;
  }

  ~StringMap() {
    // Delete all the elements in the map, but don't reset the elements
    // to default values.  This is a copy of clear(), but avoids unnecessary
    // work not required in the destructor.
    if (!empty()) {
      for (unsigned I = 0, E = NumBuckets; I != E; ++I) {
        StringMapEntryBase *Bucket = TheTable[I];
        if (Bucket && Bucket != getTombstoneVal()) {
          static_cast<MapEntryTy*>(Bucket)->Destroy(Allocator);
        }
      }
    }
    free(TheTable);
  }

  AllocatorTy &getAllocator() { return Allocator; }
  const AllocatorTy &getAllocator() const { return Allocator; }

  using key_type = const char*;
  using mapped_type = ValueTy;
  using value_type = StringMapEntry<ValueTy>;
  using size_type = size_t;

  using const_iterator = StringMapConstIterator<ValueTy>;
  using iterator = StringMapIterator<ValueTy>;

  iterator begin() {
    return iterator(TheTable, NumBuckets == 0);
  }
  iterator end() {
    return iterator(TheTable+NumBuckets, true);
  }
  const_iterator begin() const {
    return const_iterator(TheTable, NumBuckets == 0);
  }
  const_iterator end() const {
    return const_iterator(TheTable+NumBuckets, true);
  }

  iterator_range<StringMapKeyIterator<ValueTy>> keys() const {
    return make_range(StringMapKeyIterator<ValueTy>(begin()),
                      StringMapKeyIterator<ValueTy>(end()));
  }

  iterator find(StringRef Key) {
    int Bucket = FindKey(Key);
    if (Bucket == -1) return end();
    return iterator(TheTable+Bucket, true);
  }

  const_iterator find(StringRef Key) const {
    int Bucket = FindKey(Key);
    if (Bucket == -1) return end();
    return const_iterator(TheTable+Bucket, true);
  }

  /// lookup - Return the entry for the specified key, or a default
  /// constructed value if no such entry exists.
  ValueTy lookup(StringRef Key) const {
    const_iterator it = find(Key);
    if (it != end())
      return it->second;
    return ValueTy();
  }

  /// Lookup the ValueTy for the \p Key, or create a default constructed value
  /// if the key is not in the map.
  ValueTy &operator[](StringRef Key) { return try_emplace(Key).first->second; }

  /// count - Return 1 if the element is in the map, 0 otherwise.
  size_type count(StringRef Key) const {
    return find(Key) == end() ? 0 : 1;
  }

  template <typename InputTy>
  size_type count(const StringMapEntry<InputTy> &MapEntry) const {
    return count(MapEntry.getKey());
  }

  /// insert - Insert the specified key/value pair into the map.  If the key
  /// already exists in the map, return false and ignore the request, otherwise
  /// insert it and return true.
  bool insert(MapEntryTy *KeyValue) {
    unsigned BucketNo = LookupBucketFor(KeyValue->getKey());
    StringMapEntryBase *&Bucket = TheTable[BucketNo];
    if (Bucket && Bucket != getTombstoneVal())
      return false;  // Already exists in map.

    if (Bucket == getTombstoneVal())
      --NumTombstones;
    Bucket = KeyValue;
    ++NumItems;
    assert(NumItems + NumTombstones <= NumBuckets);

    RehashTable();
    return true;
  }

  /// insert - Inserts the specified key/value pair into the map if the key
  /// isn't already in the map. The bool component of the returned pair is true
  /// if and only if the insertion takes place, and the iterator component of
  /// the pair points to the element with key equivalent to the key of the pair.
  std::pair<iterator, bool> insert(std::pair<StringRef, ValueTy> KV) {
    return try_emplace(KV.first, std::move(KV.second));
  }

  /// Inserts an element or assigns to the current element if the key already
  /// exists. The return type is the same as try_emplace.
  template <typename V>
  std::pair<iterator, bool> insert_or_assign(StringRef Key, V &&Val) {
    auto Ret = try_emplace(Key, std::forward<V>(Val));
    if (!Ret.second)
      Ret.first->second = std::forward<V>(Val);
    return Ret;
  }

  /// Emplace a new element for the specified key into the map if the key isn't
  /// already in the map. The bool component of the returned pair is true
  /// if and only if the insertion takes place, and the iterator component of
  /// the pair points to the element with key equivalent to the key of the pair.
  template <typename... ArgsTy>
  std::pair<iterator, bool> try_emplace(StringRef Key, ArgsTy &&... Args) {
    unsigned BucketNo = LookupBucketFor(Key);
    StringMapEntryBase *&Bucket = TheTable[BucketNo];
    if (Bucket && Bucket != getTombstoneVal())
      return std::make_pair(iterator(TheTable + BucketNo, false),
                            false); // Already exists in map.

    if (Bucket == getTombstoneVal())
      --NumTombstones;
    Bucket = MapEntryTy::Create(Key, Allocator, std::forward<ArgsTy>(Args)...);
    ++NumItems;
    assert(NumItems + NumTombstones <= NumBuckets);

    BucketNo = RehashTable(BucketNo);
    return std::make_pair(iterator(TheTable + BucketNo, false), true);
  }

  // clear - Empties out the StringMap
  void clear() {
    if (empty()) return;

    // Zap all values, resetting the keys back to non-present (not tombstone),
    // which is safe because we're removing all elements.
    for (unsigned I = 0, E = NumBuckets; I != E; ++I) {
      StringMapEntryBase *&Bucket = TheTable[I];
      if (Bucket && Bucket != getTombstoneVal()) {
        static_cast<MapEntryTy*>(Bucket)->Destroy(Allocator);
      }
      Bucket = nullptr;
    }

    NumItems = 0;
    NumTombstones = 0;
  }

  /// remove - Remove the specified key/value pair from the map, but do not
  /// erase it.  This aborts if the key is not in the map.
  void remove(MapEntryTy *KeyValue) {
    RemoveKey(KeyValue);
  }

  void erase(iterator I) {
    MapEntryTy &V = *I;
    remove(&V);
    V.Destroy(Allocator);
  }

  bool erase(StringRef Key) {
    iterator I = find(Key);
    if (I == end()) return false;
    erase(I);
    return true;
  }
};

template <typename DerivedTy, typename ValueTy>
class StringMapIterBase
    : public iterator_facade_base<DerivedTy, std::forward_iterator_tag,
                                  ValueTy> {
protected:
  StringMapEntryBase **Ptr = nullptr;

public:
  StringMapIterBase() = default;

  explicit StringMapIterBase(StringMapEntryBase **Bucket,
                             bool NoAdvance = false)
      : Ptr(Bucket) {
    if (!NoAdvance) AdvancePastEmptyBuckets();
  }

  DerivedTy &operator=(const DerivedTy &Other) {
    Ptr = Other.Ptr;
    return static_cast<DerivedTy &>(*this);
  }

  bool operator==(const DerivedTy &RHS) const { return Ptr == RHS.Ptr; }

  DerivedTy &operator++() { // Preincrement
    ++Ptr;
    AdvancePastEmptyBuckets();
    return static_cast<DerivedTy &>(*this);
  }

  DerivedTy operator++(int) { // Post-increment
    DerivedTy Tmp(Ptr);
    ++*this;
    return Tmp;
  }

private:
  void AdvancePastEmptyBuckets() {
    while (*Ptr == nullptr || *Ptr == StringMapImpl::getTombstoneVal())
      ++Ptr;
  }
};

template <typename ValueTy>
class StringMapConstIterator
    : public StringMapIterBase<StringMapConstIterator<ValueTy>,
                               const StringMapEntry<ValueTy>> {
  using base = StringMapIterBase<StringMapConstIterator<ValueTy>,
                                 const StringMapEntry<ValueTy>>;

public:
  StringMapConstIterator() = default;
  explicit StringMapConstIterator(StringMapEntryBase **Bucket,
                                  bool NoAdvance = false)
      : base(Bucket, NoAdvance) {}

  const StringMapEntry<ValueTy> &operator*() const {
    return *static_cast<const StringMapEntry<ValueTy> *>(*this->Ptr);
  }
};

template <typename ValueTy>
class StringMapIterator : public StringMapIterBase<StringMapIterator<ValueTy>,
                                                   StringMapEntry<ValueTy>> {
  using base =
      StringMapIterBase<StringMapIterator<ValueTy>, StringMapEntry<ValueTy>>;

public:
  StringMapIterator() = default;
  explicit StringMapIterator(StringMapEntryBase **Bucket,
                             bool NoAdvance = false)
      : base(Bucket, NoAdvance) {}

  StringMapEntry<ValueTy> &operator*() const {
    return *static_cast<StringMapEntry<ValueTy> *>(*this->Ptr);
  }

  operator StringMapConstIterator<ValueTy>() const {
    return StringMapConstIterator<ValueTy>(this->Ptr, true);
  }
};

template <typename ValueTy>
class StringMapKeyIterator
    : public iterator_adaptor_base<StringMapKeyIterator<ValueTy>,
                                   StringMapConstIterator<ValueTy>,
                                   std::forward_iterator_tag, StringRef> {
  using base = iterator_adaptor_base<StringMapKeyIterator<ValueTy>,
                                     StringMapConstIterator<ValueTy>,
                                     std::forward_iterator_tag, StringRef>;

public:
  StringMapKeyIterator() = default;
  explicit StringMapKeyIterator(StringMapConstIterator<ValueTy> Iter)
      : base(std::move(Iter)) {}

  StringRef &operator*() {
    Key = this->wrapped()->getKey();
    return Key;
  }

private:
  StringRef Key;
};

} // end namespace llvm

#endif // LLVM_ADT_STRINGMAP_H
# 593 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringMap.h"
# 23 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Allocator.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h" 1
//===- Allocator.h - Simple memory allocation abstraction -------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
/// \file
///
/// This file defines the BumpPtrAllocator interface. BumpPtrAllocator conforms
/// to the LLVM "Allocator" concept and is similar to MallocAllocator, but
/// objects cannot be deallocated. Their lifetime is tied to the lifetime of the
/// allocator.
///
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_ALLOCATOR_H
#define LLVM_SUPPORT_ALLOCATOR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Optional.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Alignment.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h" 1
//===-- llvm/Support/Alignment.h - Useful alignment functions ---*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file contains types to represent alignments.
// They are instrumented to guarantee some invariants are preserved and prevent
// invalid manipulations.
//
// - Align represents an alignment in bytes, it is always set and always a valid
// power of two, its minimum value is 1 which means no alignment requirements.
//
// - MaybeAlign is an optional type, it may be undefined or set. When it's set
// you can get the underlying Align type by using the getValue() method.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_ALIGNMENT_H_
#define LLVM_SUPPORT_ALIGNMENT_H_

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Optional.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MathExtras.h"
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"

namespace llvm {

#define ALIGN_CHECK_ISPOSITIVE(decl)                                           \
  assert(decl > 0 && (#decl " should be defined"))
#define ALIGN_CHECK_ISSET(decl)                                                \
  assert(decl.hasValue() && (#decl " should be defined"))

/// This struct is a compact representation of a valid (non-zero power of two)
/// alignment.
/// It is suitable for use as static global constants.
struct Align {
private:
  uint8_t ShiftValue = 0; /// The log2 of the required alignment.
                          /// ShiftValue is less than 64 by construction.

  friend struct MaybeAlign;
  friend unsigned Log2(Align);
  friend bool operator==(Align Lhs, Align Rhs);
  friend bool operator!=(Align Lhs, Align Rhs);
  friend bool operator<=(Align Lhs, Align Rhs);
  friend bool operator>=(Align Lhs, Align Rhs);
  friend bool operator<(Align Lhs, Align Rhs);
  friend bool operator>(Align Lhs, Align Rhs);
  friend unsigned encode(struct MaybeAlign A);
  friend struct MaybeAlign decodeMaybeAlign(unsigned Value);

  /// A trivial type to allow construction of constexpr Align.
  /// This is currently needed to workaround a bug in GCC 5.3 which prevents
  /// definition of constexpr assign operators.
  /// https://stackoverflow.com/questions/46756288/explicitly-defaulted-function-cannot-be-declared-as-constexpr-because-the-implic
  /// FIXME: Remove this, make all assign operators constexpr and introduce user
  /// defined literals when we don't have to support GCC 5.3 anymore.
  /// https://llvm.org/docs/GettingStarted.html#getting-a-modern-host-c-toolchain
  struct LogValue {
    uint8_t Log;
  };

public:
  /// Default is byte-aligned.
  constexpr Align() = default;
  /// Do not perform checks in case of copy/move construct/assign, because the
  /// checks have been performed when building `Other`.
  constexpr Align(const Align &Other) = default;
  constexpr Align(Align &&Other) = default;
  Align &operator=(const Align &Other) = default;
  Align &operator=(Align &&Other) = default;

  explicit Align(uint64_t Value) {
    assert(Value > 0 && "Value must not be 0");
    assert(llvm::isPowerOf2_64(Value) && "Alignment is not a power of 2");
    ShiftValue = Log2_64(Value);
    assert(ShiftValue < 64 && "Broken invariant");
  }

  /// This is a hole in the type system and should not be abused.
  /// Needed to interact with C for instance.
  uint64_t value() const { return uint64_t(1) << ShiftValue; }

  /// Returns a default constructed Align which corresponds to no alignment.
  /// It was decided to deprecate Align::None because it's too close to
  /// llvm::None which can be used to initialize `MaybeAlign`.
  /// MaybeAlign = llvm::None means unspecified alignment,
  /// Align = Align::None() means alignment of one byte.
  LLVM_ATTRIBUTE_DEPRECATED(constexpr static const Align None(),
                            "Use Align() or Align(1) instead") {
    return Align();
  }

  /// Allow constructions of constexpr Align.
  template <size_t kValue> constexpr static LogValue Constant() {
    return LogValue{static_cast<uint8_t>(CTLog2<kValue>())};
  }

  /// Allow constructions of constexpr Align from types.
  /// Compile time equivalent to Align(alignof(T)).
  template <typename T> constexpr static LogValue Of() {
    return Constant<std::alignment_of<T>::value>();
  }

  /// Constexpr constructor from LogValue type.
  constexpr Align(LogValue CA) : ShiftValue(CA.Log) {}
};

/// Treats the value 0 as a 1, so Align is always at least 1.
inline Align assumeAligned(uint64_t Value) {
  return Value ? Align(Value) : Align();
}

/// This struct is a compact representation of a valid (power of two) or
/// undefined (0) alignment.
struct MaybeAlign : public llvm::Optional<Align> {
private:
  using UP = llvm::Optional<Align>;

public:
  /// Default is undefined.
  MaybeAlign() = default;
  /// Do not perform checks in case of copy/move construct/assign, because the
  /// checks have been performed when building `Other`.
  MaybeAlign(const MaybeAlign &Other) = default;
  MaybeAlign &operator=(const MaybeAlign &Other) = default;
  MaybeAlign(MaybeAlign &&Other) = default;
  MaybeAlign &operator=(MaybeAlign &&Other) = default;

  /// Use llvm::Optional<Align> constructor.
  using UP::UP;

  explicit MaybeAlign(uint64_t Value) {
    assert((Value == 0 || llvm::isPowerOf2_64(Value)) &&
           "Alignment is neither 0 nor a power of 2");
    if (Value)
      emplace(Value);
  }

  /// For convenience, returns a valid alignment or 1 if undefined.
  Align valueOrOne() const { return hasValue() ? getValue() : Align(); }
};

/// Checks that SizeInBytes is a multiple of the alignment.
inline bool isAligned(Align Lhs, uint64_t SizeInBytes) {
  return SizeInBytes % Lhs.value() == 0;
}

/// Checks that SizeInBytes is a multiple of the alignment.
/// Returns false if the alignment is undefined.
inline bool isAligned(MaybeAlign Lhs, uint64_t SizeInBytes) {
  ALIGN_CHECK_ISSET(Lhs);
  return SizeInBytes % (*Lhs).value() == 0;
}

/// Checks that Addr is a multiple of the alignment.
inline bool isAddrAligned(Align Lhs, const void *Addr) {
  return isAligned(Lhs, reinterpret_cast<uintptr_t>(Addr));
}

/// Returns a multiple of A needed to store `Size` bytes.
inline uint64_t alignTo(uint64_t Size, Align A) {
  const uint64_t value = A.value();
  // The following line is equivalent to `(Size + value - 1) / value * value`.

  // The division followed by a multiplication can be thought of as a right
  // shift followed by a left shift which zeros out the extra bits produced in
  // the bump; `~(value - 1)` is a mask where all those bits being zeroed out
  // are just zero.

  // Most compilers can generate this code but the pattern may be missed when
  // multiple functions gets inlined.
  return (Size + value - 1) & ~(value - 1);
}

/// Returns a multiple of A needed to store `Size` bytes.
/// Returns `Size` if current alignment is undefined.
inline uint64_t alignTo(uint64_t Size, MaybeAlign A) {
  return A ? alignTo(Size, A.getValue()) : Size;
}

/// Aligns `Addr` to `Alignment` bytes, rounding up.
inline uintptr_t alignAddr(const void *Addr, Align Alignment) {
  uintptr_t ArithAddr = reinterpret_cast<uintptr_t>(Addr);
  assert(static_cast<uintptr_t>(ArithAddr + Alignment.value() - 1) >=
             ArithAddr &&
         "Overflow");
  return alignTo(ArithAddr, Alignment);
}

/// Returns the offset to the next integer (mod 2**64) that is greater than
/// or equal to \p Value and is a multiple of \p Align.
inline uint64_t offsetToAlignment(uint64_t Value, Align Alignment) {
  return alignTo(Value, Alignment) - Value;
}

/// Returns the necessary adjustment for aligning `Addr` to `Alignment`
/// bytes, rounding up.
inline uint64_t offsetToAlignedAddr(const void *Addr, Align Alignment) {
  return offsetToAlignment(reinterpret_cast<uintptr_t>(Addr), Alignment);
}

/// Returns the log2 of the alignment.
inline unsigned Log2(Align A) { return A.ShiftValue; }

/// Returns the log2 of the alignment.
/// \pre A must be defined.
inline unsigned Log2(MaybeAlign A) {
  ALIGN_CHECK_ISSET(A);
  return Log2(A.getValue());
}

/// Returns the alignment that satisfies both alignments.
/// Same semantic as MinAlign.
inline Align commonAlignment(Align A, Align B) { return std::min(A, B); }

/// Returns the alignment that satisfies both alignments.
/// Same semantic as MinAlign.
inline Align commonAlignment(Align A, uint64_t Offset) {
  return Align(MinAlign(A.value(), Offset));
}

/// Returns the alignment that satisfies both alignments.
/// Same semantic as MinAlign.
inline MaybeAlign commonAlignment(MaybeAlign A, MaybeAlign B) {
  return A && B ? commonAlignment(*A, *B) : A ? A : B;
}

/// Returns the alignment that satisfies both alignments.
/// Same semantic as MinAlign.
inline MaybeAlign commonAlignment(MaybeAlign A, uint64_t Offset) {
  return MaybeAlign(MinAlign((*A).value(), Offset));
}

/// Returns a representation of the alignment that encodes undefined as 0.
inline unsigned encode(MaybeAlign A) { return A ? A->ShiftValue + 1 : 0; }

/// Dual operation of the encode function above.
inline MaybeAlign decodeMaybeAlign(unsigned Value) {
  if (Value == 0)
    return MaybeAlign();
  Align Out;
  Out.ShiftValue = Value - 1;
  return Out;
}

/// Returns a representation of the alignment, the encoded value is positive by
/// definition.
inline unsigned encode(Align A) { return encode(MaybeAlign(A)); }

/// Comparisons between Align and scalars. Rhs must be positive.
inline bool operator==(Align Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return Lhs.value() == Rhs;
}
inline bool operator!=(Align Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return Lhs.value() != Rhs;
}
inline bool operator<=(Align Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return Lhs.value() <= Rhs;
}
inline bool operator>=(Align Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return Lhs.value() >= Rhs;
}
inline bool operator<(Align Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return Lhs.value() < Rhs;
}
inline bool operator>(Align Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return Lhs.value() > Rhs;
}

/// Comparisons between MaybeAlign and scalars.
inline bool operator==(MaybeAlign Lhs, uint64_t Rhs) {
  return Lhs ? (*Lhs).value() == Rhs : Rhs == 0;
}
inline bool operator!=(MaybeAlign Lhs, uint64_t Rhs) {
  return Lhs ? (*Lhs).value() != Rhs : Rhs != 0;
}
inline bool operator<=(MaybeAlign Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return (*Lhs).value() <= Rhs;
}
inline bool operator>=(MaybeAlign Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return (*Lhs).value() >= Rhs;
}
inline bool operator<(MaybeAlign Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return (*Lhs).value() < Rhs;
}
inline bool operator>(MaybeAlign Lhs, uint64_t Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  ALIGN_CHECK_ISPOSITIVE(Rhs);
  return (*Lhs).value() > Rhs;
}

/// Comparisons operators between Align.
inline bool operator==(Align Lhs, Align Rhs) {
  return Lhs.ShiftValue == Rhs.ShiftValue;
}
inline bool operator!=(Align Lhs, Align Rhs) {
  return Lhs.ShiftValue != Rhs.ShiftValue;
}
inline bool operator<=(Align Lhs, Align Rhs) {
  return Lhs.ShiftValue <= Rhs.ShiftValue;
}
inline bool operator>=(Align Lhs, Align Rhs) {
  return Lhs.ShiftValue >= Rhs.ShiftValue;
}
inline bool operator<(Align Lhs, Align Rhs) {
  return Lhs.ShiftValue < Rhs.ShiftValue;
}
inline bool operator>(Align Lhs, Align Rhs) {
  return Lhs.ShiftValue > Rhs.ShiftValue;
}

/// Comparisons operators between Align and MaybeAlign.
inline bool operator==(Align Lhs, MaybeAlign Rhs) {
  ALIGN_CHECK_ISSET(Rhs);
  return Lhs.value() == (*Rhs).value();
}
inline bool operator!=(Align Lhs, MaybeAlign Rhs) {
  ALIGN_CHECK_ISSET(Rhs);
  return Lhs.value() != (*Rhs).value();
}
inline bool operator<=(Align Lhs, MaybeAlign Rhs) {
  ALIGN_CHECK_ISSET(Rhs);
  return Lhs.value() <= (*Rhs).value();
}
inline bool operator>=(Align Lhs, MaybeAlign Rhs) {
  ALIGN_CHECK_ISSET(Rhs);
  return Lhs.value() >= (*Rhs).value();
}
inline bool operator<(Align Lhs, MaybeAlign Rhs) {
  ALIGN_CHECK_ISSET(Rhs);
  return Lhs.value() < (*Rhs).value();
}
inline bool operator>(Align Lhs, MaybeAlign Rhs) {
  ALIGN_CHECK_ISSET(Rhs);
  return Lhs.value() > (*Rhs).value();
}

/// Comparisons operators between MaybeAlign and Align.
inline bool operator==(MaybeAlign Lhs, Align Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  return Lhs && (*Lhs).value() == Rhs.value();
}
inline bool operator!=(MaybeAlign Lhs, Align Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  return Lhs && (*Lhs).value() != Rhs.value();
}
inline bool operator<=(MaybeAlign Lhs, Align Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  return Lhs && (*Lhs).value() <= Rhs.value();
}
inline bool operator>=(MaybeAlign Lhs, Align Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  return Lhs && (*Lhs).value() >= Rhs.value();
}
inline bool operator<(MaybeAlign Lhs, Align Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  return Lhs && (*Lhs).value() < Rhs.value();
}
inline bool operator>(MaybeAlign Lhs, Align Rhs) {
  ALIGN_CHECK_ISSET(Lhs);
  return Lhs && (*Lhs).value() > Rhs.value();
}

inline Align operator/(Align Lhs, uint64_t Divisor) {
  assert(llvm::isPowerOf2_64(Divisor) &&
         "Divisor must be positive and a power of 2");
  assert(Lhs != 1 && "Can't halve byte alignment");
  return Align(Lhs.value() / Divisor);
}

inline MaybeAlign operator/(MaybeAlign Lhs, uint64_t Divisor) {
  assert(llvm::isPowerOf2_64(Divisor) &&
         "Divisor must be positive and a power of 2");
  return Lhs ? Lhs.getValue() / Divisor : MaybeAlign();
}

inline Align max(MaybeAlign Lhs, Align Rhs) {
  return Lhs && *Lhs > Rhs ? *Lhs : Rhs;
}

inline Align max(Align Lhs, MaybeAlign Rhs) {
  return Rhs && *Rhs > Lhs ? *Rhs : Lhs;
}

#undef ALIGN_CHECK_ISPOSITIVE
#undef ALIGN_CHECK_ISSET

} // namespace llvm

#endif // LLVM_SUPPORT_ALIGNMENT_H_
# 408 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Alignment.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/AllocatorBase.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MathExtras.h"
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MemAlloc.h"
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"

namespace llvm {

namespace detail {

// We call out to an external function to actually print the message as the
// printing code uses Allocator.h in its implementation.
void printBumpPtrAllocatorStats(unsigned NumSlabs, size_t BytesAllocated,
                                size_t TotalMemory);

} // end namespace detail

/// Allocate memory in an ever growing pool, as if by bump-pointer.
///
/// This isn't strictly a bump-pointer allocator as it uses backing slabs of
/// memory rather than relying on a boundless contiguous heap. However, it has
/// bump-pointer semantics in that it is a monotonically growing pool of memory
/// where every allocation is found by merely allocating the next N bytes in
/// the slab, or the next N bytes in the next slab.
///
/// Note that this also has a threshold for forcing allocations above a certain
/// size into their own slab.
///
/// The BumpPtrAllocatorImpl template defaults to using a MallocAllocator
/// object, which wraps malloc, to allocate memory, but it can be changed to
/// use a custom allocator.
///
/// The GrowthDelay specifies after how many allocated slabs the allocator
/// increases the size of the slabs.
template <typename AllocatorT = MallocAllocator, size_t SlabSize = 4096,
          size_t SizeThreshold = SlabSize, size_t GrowthDelay = 128>
class BumpPtrAllocatorImpl
    : public AllocatorBase<BumpPtrAllocatorImpl<AllocatorT, SlabSize,
                                                SizeThreshold, GrowthDelay>> {
public:
  static_assert(SizeThreshold <= SlabSize,
                "The SizeThreshold must be at most the SlabSize to ensure "
                "that objects larger than a slab go into their own memory "
                "allocation.");
  static_assert(GrowthDelay > 0,
                "GrowthDelay must be at least 1 which already increases the"
                "slab size after each allocated slab.");

  BumpPtrAllocatorImpl() = default;

  template <typename T>
  BumpPtrAllocatorImpl(T &&Allocator)
      : Allocator(std::forward<T &&>(Allocator)) {}

  // Manually implement a move constructor as we must clear the old allocator's
  // slabs as a matter of correctness.
  BumpPtrAllocatorImpl(BumpPtrAllocatorImpl &&Old)
      : CurPtr(Old.CurPtr), End(Old.End), Slabs(std::move(Old.Slabs)),
        CustomSizedSlabs(std::move(Old.CustomSizedSlabs)),
        BytesAllocated(Old.BytesAllocated), RedZoneSize(Old.RedZoneSize),
        Allocator(std::move(Old.Allocator)) {
    Old.CurPtr = Old.End = nullptr;
    Old.BytesAllocated = 0;
    Old.Slabs.clear();
    Old.CustomSizedSlabs.clear();
  }

  ~BumpPtrAllocatorImpl() {
    DeallocateSlabs(Slabs.begin(), Slabs.end());
    DeallocateCustomSizedSlabs();
  }

  BumpPtrAllocatorImpl &operator=(BumpPtrAllocatorImpl &&RHS) {
    DeallocateSlabs(Slabs.begin(), Slabs.end());
    DeallocateCustomSizedSlabs();

    CurPtr = RHS.CurPtr;
    End = RHS.End;
    BytesAllocated = RHS.BytesAllocated;
    RedZoneSize = RHS.RedZoneSize;
    Slabs = std::move(RHS.Slabs);
    CustomSizedSlabs = std::move(RHS.CustomSizedSlabs);
    Allocator = std::move(RHS.Allocator);

    RHS.CurPtr = RHS.End = nullptr;
    RHS.BytesAllocated = 0;
    RHS.Slabs.clear();
    RHS.CustomSizedSlabs.clear();
    return *this;
  }

  /// Deallocate all but the current slab and reset the current pointer
  /// to the beginning of it, freeing all memory allocated so far.
  void Reset() {
    // Deallocate all but the first slab, and deallocate all custom-sized slabs.
    DeallocateCustomSizedSlabs();
    CustomSizedSlabs.clear();

    if (Slabs.empty())
      return;

    // Reset the state.
    BytesAllocated = 0;
    CurPtr = (char *)Slabs.front();
    End = CurPtr + SlabSize;

    __asan_poison_memory_region(*Slabs.begin(), computeSlabSize(0));
    DeallocateSlabs(std::next(Slabs.begin()), Slabs.end());
    Slabs.erase(std::next(Slabs.begin()), Slabs.end());
  }

  /// Allocate space at the specified alignment.
  LLVM_ATTRIBUTE_RETURNS_NONNULL LLVM_ATTRIBUTE_RETURNS_NOALIAS void *
  Allocate(size_t Size, Align Alignment) {
    // Keep track of how many bytes we've allocated.
    BytesAllocated += Size;

    size_t Adjustment = offsetToAlignedAddr(CurPtr, Alignment);
    assert(Adjustment + Size >= Size && "Adjustment + Size must not overflow");

    size_t SizeToAllocate = Size;
#if 0 /* disabled by -frewrite-includes */
#if LLVM_ADDRESS_SANITIZER_BUILD
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 153 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
    // Add trailing bytes as a "red zone" under ASan.
    SizeToAllocate += RedZoneSize;
#endif
# 156 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"

    // Check if we have enough space.
    if (Adjustment + SizeToAllocate <= size_t(End - CurPtr)) {
      char *AlignedPtr = CurPtr + Adjustment;
      CurPtr = AlignedPtr + SizeToAllocate;
      // Update the allocation point of this memory block in MemorySanitizer.
      // Without this, MemorySanitizer messages for values originated from here
      // will point to the allocation of the entire slab.
      __msan_allocated_memory(AlignedPtr, Size);
      // Similarly, tell ASan about this space.
      __asan_unpoison_memory_region(AlignedPtr, Size);
      return AlignedPtr;
    }

    // If Size is really big, allocate a separate slab for it.
    size_t PaddedSize = SizeToAllocate + Alignment.value() - 1;
    if (PaddedSize > SizeThreshold) {
      void *NewSlab = Allocator.Allocate(PaddedSize, 0);
      // We own the new slab and don't want anyone reading anyting other than
      // pieces returned from this method.  So poison the whole slab.
      __asan_poison_memory_region(NewSlab, PaddedSize);
      CustomSizedSlabs.push_back(std::make_pair(NewSlab, PaddedSize));

      uintptr_t AlignedAddr = alignAddr(NewSlab, Alignment);
      assert(AlignedAddr + Size <= (uintptr_t)NewSlab + PaddedSize);
      char *AlignedPtr = (char*)AlignedAddr;
      __msan_allocated_memory(AlignedPtr, Size);
      __asan_unpoison_memory_region(AlignedPtr, Size);
      return AlignedPtr;
    }

    // Otherwise, start a new slab and try again.
    StartNewSlab();
    uintptr_t AlignedAddr = alignAddr(CurPtr, Alignment);
    assert(AlignedAddr + SizeToAllocate <= (uintptr_t)End &&
           "Unable to allocate memory!");
    char *AlignedPtr = (char*)AlignedAddr;
    CurPtr = AlignedPtr + SizeToAllocate;
    __msan_allocated_memory(AlignedPtr, Size);
    __asan_unpoison_memory_region(AlignedPtr, Size);
    return AlignedPtr;
  }

  inline LLVM_ATTRIBUTE_RETURNS_NONNULL LLVM_ATTRIBUTE_RETURNS_NOALIAS void *
  Allocate(size_t Size, size_t Alignment) {
    assert(Alignment > 0 && "0-byte alignment is not allowed. Use 1 instead.");
    return Allocate(Size, Align(Alignment));
  }

  // Pull in base class overloads.
  using AllocatorBase<BumpPtrAllocatorImpl>::Allocate;

  // Bump pointer allocators are expected to never free their storage; and
  // clients expect pointers to remain valid for non-dereferencing uses even
  // after deallocation.
  void Deallocate(const void *Ptr, size_t Size) {
    __asan_poison_memory_region(Ptr, Size);
  }

  // Pull in base class overloads.
  using AllocatorBase<BumpPtrAllocatorImpl>::Deallocate;

  size_t GetNumSlabs() const { return Slabs.size() + CustomSizedSlabs.size(); }

  /// \return An index uniquely and reproducibly identifying
  /// an input pointer \p Ptr in the given allocator.
  /// The returned value is negative iff the object is inside a custom-size
  /// slab.
  /// Returns an empty optional if the pointer is not found in the allocator.
  llvm::Optional<int64_t> identifyObject(const void *Ptr) {
    const char *P = static_cast<const char *>(Ptr);
    int64_t InSlabIdx = 0;
    for (size_t Idx = 0, E = Slabs.size(); Idx < E; Idx++) {
      const char *S = static_cast<const char *>(Slabs[Idx]);
      if (P >= S && P < S + computeSlabSize(Idx))
        return InSlabIdx + static_cast<int64_t>(P - S);
      InSlabIdx += static_cast<int64_t>(computeSlabSize(Idx));
    }

    // Use negative index to denote custom sized slabs.
    int64_t InCustomSizedSlabIdx = -1;
    for (size_t Idx = 0, E = CustomSizedSlabs.size(); Idx < E; Idx++) {
      const char *S = static_cast<const char *>(CustomSizedSlabs[Idx].first);
      size_t Size = CustomSizedSlabs[Idx].second;
      if (P >= S && P < S + Size)
        return InCustomSizedSlabIdx - static_cast<int64_t>(P - S);
      InCustomSizedSlabIdx -= static_cast<int64_t>(Size);
    }
    return None;
  }

  /// A wrapper around identifyObject that additionally asserts that
  /// the object is indeed within the allocator.
  /// \return An index uniquely and reproducibly identifying
  /// an input pointer \p Ptr in the given allocator.
  int64_t identifyKnownObject(const void *Ptr) {
    Optional<int64_t> Out = identifyObject(Ptr);
    assert(Out && "Wrong allocator used");
    return *Out;
  }

  /// A wrapper around identifyKnownObject. Accepts type information
  /// about the object and produces a smaller identifier by relying on
  /// the alignment information. Note that sub-classes may have different
  /// alignment, so the most base class should be passed as template parameter
  /// in order to obtain correct results. For that reason automatic template
  /// parameter deduction is disabled.
  /// \return An index uniquely and reproducibly identifying
  /// an input pointer \p Ptr in the given allocator. This identifier is
  /// different from the ones produced by identifyObject and
  /// identifyAlignedObject.
  template <typename T>
  int64_t identifyKnownAlignedObject(const void *Ptr) {
    int64_t Out = identifyKnownObject(Ptr);
    assert(Out % alignof(T) == 0 && "Wrong alignment information");
    return Out / alignof(T);
  }

  size_t getTotalMemory() const {
    size_t TotalMemory = 0;
    for (auto I = Slabs.begin(), E = Slabs.end(); I != E; ++I)
      TotalMemory += computeSlabSize(std::distance(Slabs.begin(), I));
    for (auto &PtrAndSize : CustomSizedSlabs)
      TotalMemory += PtrAndSize.second;
    return TotalMemory;
  }

  size_t getBytesAllocated() const { return BytesAllocated; }

  void setRedZoneSize(size_t NewSize) {
    RedZoneSize = NewSize;
  }

  void PrintStats() const {
    detail::printBumpPtrAllocatorStats(Slabs.size(), BytesAllocated,
                                       getTotalMemory());
  }

private:
  /// The current pointer into the current slab.
  ///
  /// This points to the next free byte in the slab.
  char *CurPtr = nullptr;

  /// The end of the current slab.
  char *End = nullptr;

  /// The slabs allocated so far.
  SmallVector<void *, 4> Slabs;

  /// Custom-sized slabs allocated for too-large allocation requests.
  SmallVector<std::pair<void *, size_t>, 0> CustomSizedSlabs;

  /// How many bytes we've allocated.
  ///
  /// Used so that we can compute how much space was wasted.
  size_t BytesAllocated = 0;

  /// The number of bytes to put between allocations when running under
  /// a sanitizer.
  size_t RedZoneSize = 1;

  /// The allocator instance we use to get slabs of memory.
  AllocatorT Allocator;

  static size_t computeSlabSize(unsigned SlabIdx) {
    // Scale the actual allocated slab size based on the number of slabs
    // allocated. Every GrowthDelay slabs allocated, we double
    // the allocated size to reduce allocation frequency, but saturate at
    // multiplying the slab size by 2^30.
    return SlabSize *
           ((size_t)1 << std::min<size_t>(30, SlabIdx / GrowthDelay));
  }

  /// Allocate a new slab and move the bump pointers over into the new
  /// slab, modifying CurPtr and End.
  void StartNewSlab() {
    size_t AllocatedSlabSize = computeSlabSize(Slabs.size());

    void *NewSlab = Allocator.Allocate(AllocatedSlabSize, 0);
    // We own the new slab and don't want anyone reading anything other than
    // pieces returned from this method.  So poison the whole slab.
    __asan_poison_memory_region(NewSlab, AllocatedSlabSize);

    Slabs.push_back(NewSlab);
    CurPtr = (char *)(NewSlab);
    End = ((char *)NewSlab) + AllocatedSlabSize;
  }

  /// Deallocate a sequence of slabs.
  void DeallocateSlabs(SmallVectorImpl<void *>::iterator I,
                       SmallVectorImpl<void *>::iterator E) {
    for (; I != E; ++I) {
      size_t AllocatedSlabSize =
          computeSlabSize(std::distance(Slabs.begin(), I));
      Allocator.Deallocate(*I, AllocatedSlabSize);
    }
  }

  /// Deallocate all memory for custom sized slabs.
  void DeallocateCustomSizedSlabs() {
    for (auto &PtrAndSize : CustomSizedSlabs) {
      void *Ptr = PtrAndSize.first;
      size_t Size = PtrAndSize.second;
      Allocator.Deallocate(Ptr, Size);
    }
  }

  template <typename T> friend class SpecificBumpPtrAllocator;
};

/// The standard BumpPtrAllocator which just uses the default template
/// parameters.
typedef BumpPtrAllocatorImpl<> BumpPtrAllocator;

/// A BumpPtrAllocator that allows only elements of a specific type to be
/// allocated.
///
/// This allows calling the destructor in DestroyAll() and when the allocator is
/// destroyed.
template <typename T> class SpecificBumpPtrAllocator {
  BumpPtrAllocator Allocator;

public:
  SpecificBumpPtrAllocator() {
    // Because SpecificBumpPtrAllocator walks the memory to call destructors,
    // it can't have red zones between allocations.
    Allocator.setRedZoneSize(0);
  }
  SpecificBumpPtrAllocator(SpecificBumpPtrAllocator &&Old)
      : Allocator(std::move(Old.Allocator)) {}
  ~SpecificBumpPtrAllocator() { DestroyAll(); }

  SpecificBumpPtrAllocator &operator=(SpecificBumpPtrAllocator &&RHS) {
    Allocator = std::move(RHS.Allocator);
    return *this;
  }

  /// Call the destructor of each allocated object and deallocate all but the
  /// current slab and reset the current pointer to the beginning of it, freeing
  /// all memory allocated so far.
  void DestroyAll() {
    auto DestroyElements = [](char *Begin, char *End) {
      assert(Begin == (char *)alignAddr(Begin, Align::Of<T>()));
      for (char *Ptr = Begin; Ptr + sizeof(T) <= End; Ptr += sizeof(T))
        reinterpret_cast<T *>(Ptr)->~T();
    };

    for (auto I = Allocator.Slabs.begin(), E = Allocator.Slabs.end(); I != E;
         ++I) {
      size_t AllocatedSlabSize = BumpPtrAllocator::computeSlabSize(
          std::distance(Allocator.Slabs.begin(), I));
      char *Begin = (char *)alignAddr(*I, Align::Of<T>());
      char *End = *I == Allocator.Slabs.back() ? Allocator.CurPtr
                                               : (char *)*I + AllocatedSlabSize;

      DestroyElements(Begin, End);
    }

    for (auto &PtrAndSize : Allocator.CustomSizedSlabs) {
      void *Ptr = PtrAndSize.first;
      size_t Size = PtrAndSize.second;
      DestroyElements((char *)alignAddr(Ptr, Align::Of<T>()),
                      (char *)Ptr + Size);
    }

    Allocator.Reset();
  }

  /// Allocate space for an array of objects without constructing them.
  T *Allocate(size_t num = 1) { return Allocator.Allocate<T>(num); }
};

} // end namespace llvm

template <typename AllocatorT, size_t SlabSize, size_t SizeThreshold,
          size_t GrowthDelay>
void *
operator new(size_t Size,
             llvm::BumpPtrAllocatorImpl<AllocatorT, SlabSize, SizeThreshold,
                                        GrowthDelay> &Allocator) {
  struct S {
    char c;
    union {
      double D;
      long double LD;
      long long L;
      void *P;
    } x;
  };
  return Allocator.Allocate(
      Size, std::min((size_t)llvm::NextPowerOf2(Size), offsetof(S, x)));
}

template <typename AllocatorT, size_t SlabSize, size_t SizeThreshold,
          size_t GrowthDelay>
void operator delete(void *,
                     llvm::BumpPtrAllocatorImpl<AllocatorT, SlabSize,
                                                SizeThreshold, GrowthDelay> &) {
}

#endif // LLVM_SUPPORT_ALLOCATOR_H
# 458 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Allocator.h"
# 25 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorOr.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 26 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/FileSystem.h"
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h" 1
//===- llvm/Support/FileSystem.h - File System OS Concept -------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file declares the llvm::sys::fs namespace. It is designed after
// TR2/boost filesystem (v3), but modified to remove exception handling and the
// path class.
//
// All functions return an error_code and their actual work via the last out
// argument. The out argument is defined if and only if errc::success is
// returned. A function may return any error code in the generic or system
// category. However, they shall be equivalent to any error conditions listed
// in each functions respective documentation if the condition applies. [ note:
// this does not guarantee that error_code will be in the set of explicitly
// listed codes, but it does guarantee that if any of the explicitly listed
// errors occur, the correct error_code will be used ]. All functions may
// return errc::not_enough_memory if there is not enough memory to complete the
// operation.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_FILESYSTEM_H
#define LLVM_SUPPORT_FILESYSTEM_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallString.h"
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Twine.h"
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Config/llvm-config.h"
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Chrono.h"
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h" 1
//===- llvm/Support/Chrono.h - Utilities for Timing Manipulation-*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_CHRONO_H
#define LLVM_SUPPORT_CHRONO_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h"
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/FormatProviders.h"
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h" 1
//===- FormatProviders.h - Formatters for common LLVM types -----*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file implements format providers for many common LLVM types, for example
// allowing precision and width specifiers for scalar and string types.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_FORMATPROVIDERS_H
#define LLVM_SUPPORT_FORMATPROVIDERS_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Optional.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/STLExtras.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringSwitch.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h" 1
//===--- StringSwitch.h - Switch-on-literal-string Construct --------------===/
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//===----------------------------------------------------------------------===/
//
//  This file implements the StringSwitch template, which mimics a switch()
//  statement whose cases are string literals.
//
//===----------------------------------------------------------------------===/
#ifndef LLVM_ADT_STRINGSWITCH_H
#define LLVM_ADT_STRINGSWITCH_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h"
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h"

namespace llvm {

/// A switch()-like statement whose cases are string literals.
///
/// The StringSwitch class is a simple form of a switch() statement that
/// determines whether the given string matches one of the given string
/// literals. The template type parameter \p T is the type of the value that
/// will be returned from the string-switch expression. For example,
/// the following code switches on the name of a color in \c argv[i]:
///
/// \code
/// Color color = StringSwitch<Color>(argv[i])
///   .Case("red", Red)
///   .Case("orange", Orange)
///   .Case("yellow", Yellow)
///   .Case("green", Green)
///   .Case("blue", Blue)
///   .Case("indigo", Indigo)
///   .Cases("violet", "purple", Violet)
///   .Default(UnknownColor);
/// \endcode
template<typename T, typename R = T>
class StringSwitch {
  /// The string we are matching.
  const StringRef Str;

  /// The pointer to the result of this switch statement, once known,
  /// null before that.
  Optional<T> Result;

public:
  explicit StringSwitch(StringRef S)
  : Str(S), Result() { }

  // StringSwitch is not copyable.
  StringSwitch(const StringSwitch &) = delete;

  // StringSwitch is not assignable due to 'Str' being 'const'.
  void operator=(const StringSwitch &) = delete;
  void operator=(StringSwitch &&other) = delete;

  StringSwitch(StringSwitch &&other)
    : Str(other.Str), Result(std::move(other.Result)) { }

  ~StringSwitch() = default;

  // Case-sensitive case matchers
  StringSwitch &Case(StringLiteral S, T Value) {
    if (!Result && Str == S) {
      Result = std::move(Value);
    }
    return *this;
  }

  StringSwitch& EndsWith(StringLiteral S, T Value) {
    if (!Result && Str.endswith(S)) {
      Result = std::move(Value);
    }
    return *this;
  }

  StringSwitch& StartsWith(StringLiteral S, T Value) {
    if (!Result && Str.startswith(S)) {
      Result = std::move(Value);
    }
    return *this;
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, T Value) {
    return Case(S0, Value).Case(S1, Value);
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                      T Value) {
    return Case(S0, Value).Cases(S1, S2, Value);
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                      StringLiteral S3, T Value) {
    return Case(S0, Value).Cases(S1, S2, S3, Value);
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                      StringLiteral S3, StringLiteral S4, T Value) {
    return Case(S0, Value).Cases(S1, S2, S3, S4, Value);
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                      StringLiteral S3, StringLiteral S4, StringLiteral S5,
                      T Value) {
    return Case(S0, Value).Cases(S1, S2, S3, S4, S5, Value);
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                      StringLiteral S3, StringLiteral S4, StringLiteral S5,
                      StringLiteral S6, T Value) {
    return Case(S0, Value).Cases(S1, S2, S3, S4, S5, S6, Value);
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                      StringLiteral S3, StringLiteral S4, StringLiteral S5,
                      StringLiteral S6, StringLiteral S7, T Value) {
    return Case(S0, Value).Cases(S1, S2, S3, S4, S5, S6, S7, Value);
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                      StringLiteral S3, StringLiteral S4, StringLiteral S5,
                      StringLiteral S6, StringLiteral S7, StringLiteral S8,
                      T Value) {
    return Case(S0, Value).Cases(S1, S2, S3, S4, S5, S6, S7, S8, Value);
  }

  StringSwitch &Cases(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                      StringLiteral S3, StringLiteral S4, StringLiteral S5,
                      StringLiteral S6, StringLiteral S7, StringLiteral S8,
                      StringLiteral S9, T Value) {
    return Case(S0, Value).Cases(S1, S2, S3, S4, S5, S6, S7, S8, S9, Value);
  }

  // Case-insensitive case matchers.
  StringSwitch &CaseLower(StringLiteral S, T Value) {
    if (!Result && Str.equals_lower(S))
      Result = std::move(Value);

    return *this;
  }

  StringSwitch &EndsWithLower(StringLiteral S, T Value) {
    if (!Result && Str.endswith_lower(S))
      Result = Value;

    return *this;
  }

  StringSwitch &StartsWithLower(StringLiteral S, T Value) {
    if (!Result && Str.startswith_lower(S))
      Result = std::move(Value);

    return *this;
  }

  StringSwitch &CasesLower(StringLiteral S0, StringLiteral S1, T Value) {
    return CaseLower(S0, Value).CaseLower(S1, Value);
  }

  StringSwitch &CasesLower(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                           T Value) {
    return CaseLower(S0, Value).CasesLower(S1, S2, Value);
  }

  StringSwitch &CasesLower(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                           StringLiteral S3, T Value) {
    return CaseLower(S0, Value).CasesLower(S1, S2, S3, Value);
  }

  StringSwitch &CasesLower(StringLiteral S0, StringLiteral S1, StringLiteral S2,
                           StringLiteral S3, StringLiteral S4, T Value) {
    return CaseLower(S0, Value).CasesLower(S1, S2, S3, S4, Value);
  }

  LLVM_NODISCARD
  R Default(T Value) {
    if (Result)
      return std::move(*Result);
    return Value;
  }

  LLVM_NODISCARD
  operator R() {
    assert(Result && "Fell off the end of a string-switch");
    return std::move(*Result);
  }
};

} // end namespace llvm

#endif // LLVM_ADT_STRINGSWITCH_H
# 197 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/StringSwitch.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Twine.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/FormatVariadicDetails.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatVariadicDetails.h" 1
//===- FormatVariadicDetails.h - Helpers for FormatVariadic.h ----*- C++-*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_FORMATVARIADIC_DETAILS_H
#define LLVM_SUPPORT_FORMATVARIADIC_DETAILS_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatVariadicDetails.h"
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatVariadicDetails.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/raw_ostream.h"
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatVariadicDetails.h"
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatVariadicDetails.h"

#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatVariadicDetails.h"
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatVariadicDetails.h"

namespace llvm {
template <typename T, typename Enable = void> struct format_provider {};
class Error;

namespace detail {
class format_adapter {
  virtual void anchor();

protected:
  virtual ~format_adapter() {}

public:
  virtual void format(raw_ostream &S, StringRef Options) = 0;
};

template <typename T> class provider_format_adapter : public format_adapter {
  T Item;

public:
  explicit provider_format_adapter(T &&Item) : Item(std::forward<T>(Item)) {}

  void format(llvm::raw_ostream &S, StringRef Options) override {
    format_provider<std::decay_t<T>>::format(Item, S, Options);
  }
};

template <typename T>
class stream_operator_format_adapter : public format_adapter {
  T Item;

public:
  explicit stream_operator_format_adapter(T &&Item)
      : Item(std::forward<T>(Item)) {}

  void format(llvm::raw_ostream &S, StringRef Options) override { S << Item; }
};

template <typename T> class missing_format_adapter;

// Test if format_provider<T> is defined on T and contains a member function
// with the signature:
//   static void format(const T&, raw_stream &, StringRef);
//
template <class T> class has_FormatProvider {
public:
  using Decayed = std::decay_t<T>;
  typedef void (*Signature_format)(const Decayed &, llvm::raw_ostream &,
                                   StringRef);

  template <typename U>
  static char test(SameType<Signature_format, &U::format> *);

  template <typename U> static double test(...);

  static bool const value =
      (sizeof(test<llvm::format_provider<Decayed>>(nullptr)) == 1);
};

// Test if raw_ostream& << T -> raw_ostream& is findable via ADL.
template <class T> class has_StreamOperator {
public:
  using ConstRefT = const std::decay_t<T> &;

  template <typename U>
  static char test(
      std::enable_if_t<std::is_same<decltype(std::declval<llvm::raw_ostream &>()
                                             << std::declval<U>()),
                                    llvm::raw_ostream &>::value,
                       int *>);

  template <typename U> static double test(...);

  static bool const value = (sizeof(test<ConstRefT>(nullptr)) == 1);
};

// Simple template that decides whether a type T should use the member-function
// based format() invocation.
template <typename T>
struct uses_format_member
    : public std::integral_constant<
          bool,
          std::is_base_of<format_adapter, std::remove_reference_t<T>>::value> {
};

// Simple template that decides whether a type T should use the format_provider
// based format() invocation.  The member function takes priority, so this test
// will only be true if there is not ALSO a format member.
template <typename T>
struct uses_format_provider
    : public std::integral_constant<
          bool, !uses_format_member<T>::value && has_FormatProvider<T>::value> {
};

// Simple template that decides whether a type T should use the operator<<
// based format() invocation.  This takes last priority.
template <typename T>
struct uses_stream_operator
    : public std::integral_constant<bool, !uses_format_member<T>::value &&
                                              !uses_format_provider<T>::value &&
                                              has_StreamOperator<T>::value> {};

// Simple template that decides whether a type T has neither a member-function
// nor format_provider based implementation that it can use.  Mostly used so
// that the compiler spits out a nice diagnostic when a type with no format
// implementation can be located.
template <typename T>
struct uses_missing_provider
    : public std::integral_constant<bool, !uses_format_member<T>::value &&
                                              !uses_format_provider<T>::value &&
                                              !uses_stream_operator<T>::value> {
};

template <typename T>
std::enable_if_t<uses_format_member<T>::value, T>
build_format_adapter(T &&Item) {
  return std::forward<T>(Item);
}

template <typename T>
std::enable_if_t<uses_format_provider<T>::value, provider_format_adapter<T>>
build_format_adapter(T &&Item) {
  return provider_format_adapter<T>(std::forward<T>(Item));
}

template <typename T>
std::enable_if_t<uses_stream_operator<T>::value,
                 stream_operator_format_adapter<T>>
build_format_adapter(T &&Item) {
  // If the caller passed an Error by value, then stream_operator_format_adapter
  // would be responsible for consuming it.
  // Make the caller opt into this by calling fmt_consume().
  static_assert(
      !std::is_same<llvm::Error, std::remove_cv_t<T>>::value,
      "llvm::Error-by-value must be wrapped in fmt_consume() for formatv");
  return stream_operator_format_adapter<T>(std::forward<T>(Item));
}

template <typename T>
std::enable_if_t<uses_missing_provider<T>::value, missing_format_adapter<T>>
build_format_adapter(T &&Item) {
  return missing_format_adapter<T>();
}
}
}

#endif
# 163 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatVariadicDetails.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/NativeFormatting.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/NativeFormatting.h" 1
//===- NativeFormatting.h - Low level formatting helpers ---------*- C++-*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_NATIVE_FORMATTING_H
#define LLVM_SUPPORT_NATIVE_FORMATTING_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Optional.h"
#endif /* expanded by -frewrite-includes */
# 12 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/NativeFormatting.h"
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/NativeFormatting.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/raw_ostream.h"
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/NativeFormatting.h"
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/NativeFormatting.h"

#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/NativeFormatting.h"
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/NativeFormatting.h"

namespace llvm {
enum class FloatStyle { Exponent, ExponentUpper, Fixed, Percent };
enum class IntegerStyle {
  Integer,
  Number,
};
enum class HexPrintStyle { Upper, Lower, PrefixUpper, PrefixLower };

size_t getDefaultPrecision(FloatStyle Style);

bool isPrefixedHexStyle(HexPrintStyle S);

void write_integer(raw_ostream &S, unsigned int N, size_t MinDigits,
                   IntegerStyle Style);
void write_integer(raw_ostream &S, int N, size_t MinDigits, IntegerStyle Style);
void write_integer(raw_ostream &S, unsigned long N, size_t MinDigits,
                   IntegerStyle Style);
void write_integer(raw_ostream &S, long N, size_t MinDigits,
                   IntegerStyle Style);
void write_integer(raw_ostream &S, unsigned long long N, size_t MinDigits,
                   IntegerStyle Style);
void write_integer(raw_ostream &S, long long N, size_t MinDigits,
                   IntegerStyle Style);

void write_hex(raw_ostream &S, uint64_t N, HexPrintStyle Style,
               Optional<size_t> Width = None);
void write_double(raw_ostream &S, double D, FloatStyle Style,
                  Optional<size_t> Precision = None);
}

#endif
# 48 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/NativeFormatting.h"

# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h" 2

#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"

namespace llvm {
namespace detail {
template <typename T>
struct use_integral_formatter
    : public std::integral_constant<
          bool, is_one_of<T, uint8_t, int16_t, uint16_t, int32_t, uint32_t,
                          int64_t, uint64_t, int, unsigned, long, unsigned long,
                          long long, unsigned long long>::value> {};

template <typename T>
struct use_char_formatter
    : public std::integral_constant<bool, std::is_same<T, char>::value> {};

template <typename T>
struct is_cstring
    : public std::integral_constant<bool,
                                    is_one_of<T, char *, const char *>::value> {
};

template <typename T>
struct use_string_formatter
    : public std::integral_constant<bool,
                                    std::is_convertible<T, llvm::StringRef>::value> {};

template <typename T>
struct use_pointer_formatter
    : public std::integral_constant<bool, std::is_pointer<T>::value &&
                                              !is_cstring<T>::value> {};

template <typename T>
struct use_double_formatter
    : public std::integral_constant<bool, std::is_floating_point<T>::value> {};

class HelperFunctions {
protected:
  static Optional<size_t> parseNumericPrecision(StringRef Str) {
    size_t Prec;
    Optional<size_t> Result;
    if (Str.empty())
      Result = None;
    else if (Str.getAsInteger(10, Prec)) {
      assert(false && "Invalid precision specifier");
      Result = None;
    } else {
      assert(Prec < 100 && "Precision out of range");
      Result = std::min<size_t>(99u, Prec);
    }
    return Result;
  }

  static bool consumeHexStyle(StringRef &Str, HexPrintStyle &Style) {
    if (!Str.startswith_lower("x"))
      return false;

    if (Str.consume_front("x-"))
      Style = HexPrintStyle::Lower;
    else if (Str.consume_front("X-"))
      Style = HexPrintStyle::Upper;
    else if (Str.consume_front("x+") || Str.consume_front("x"))
      Style = HexPrintStyle::PrefixLower;
    else if (Str.consume_front("X+") || Str.consume_front("X"))
      Style = HexPrintStyle::PrefixUpper;
    return true;
  }

  static size_t consumeNumHexDigits(StringRef &Str, HexPrintStyle Style,
                                    size_t Default) {
    Str.consumeInteger(10, Default);
    if (isPrefixedHexStyle(Style))
      Default += 2;
    return Default;
  }
};
}

/// Implementation of format_provider<T> for integral arithmetic types.
///
/// The options string of an integral type has the grammar:
///
///   integer_options   :: [style][digits]
///   style             :: <see table below>
///   digits            :: <non-negative integer> 0-99
///
///   ==========================================================================
///   |  style  |     Meaning          |      Example     | Digits Meaning     |
///   --------------------------------------------------------------------------
///   |         |                      |  Input |  Output |                    |
///   ==========================================================================
///   |   x-    | Hex no prefix, lower |   42   |    2a   | Minimum # digits   |
///   |   X-    | Hex no prefix, upper |   42   |    2A   | Minimum # digits   |
///   | x+ / x  | Hex + prefix, lower  |   42   |   0x2a  | Minimum # digits   |
///   | X+ / X  | Hex + prefix, upper  |   42   |   0x2A  | Minimum # digits   |
///   | N / n   | Digit grouped number | 123456 | 123,456 | Ignored            |
///   | D / d   | Integer              | 100000 | 100000  | Ignored            |
///   | (empty) | Same as D / d        |        |         |                    |
///   ==========================================================================
///

template <typename T>
struct format_provider<
    T, std::enable_if_t<detail::use_integral_formatter<T>::value>>
    : public detail::HelperFunctions {
private:
public:
  static void format(const T &V, llvm::raw_ostream &Stream, StringRef Style) {
    HexPrintStyle HS;
    size_t Digits = 0;
    if (consumeHexStyle(Style, HS)) {
      Digits = consumeNumHexDigits(Style, HS, 0);
      write_hex(Stream, V, HS, Digits);
      return;
    }

    IntegerStyle IS = IntegerStyle::Integer;
    if (Style.consume_front("N") || Style.consume_front("n"))
      IS = IntegerStyle::Number;
    else if (Style.consume_front("D") || Style.consume_front("d"))
      IS = IntegerStyle::Integer;

    Style.consumeInteger(10, Digits);
    assert(Style.empty() && "Invalid integral format style!");
    write_integer(Stream, V, Digits, IS);
  }
};

/// Implementation of format_provider<T> for integral pointer types.
///
/// The options string of a pointer type has the grammar:
///
///   pointer_options   :: [style][precision]
///   style             :: <see table below>
///   digits            :: <non-negative integer> 0-sizeof(void*)
///
///   ==========================================================================
///   |   S     |     Meaning          |                Example                |
///   --------------------------------------------------------------------------
///   |         |                      |       Input       |      Output       |
///   ==========================================================================
///   |   x-    | Hex no prefix, lower |    0xDEADBEEF     |     deadbeef      |
///   |   X-    | Hex no prefix, upper |    0xDEADBEEF     |     DEADBEEF      |
///   | x+ / x  | Hex + prefix, lower  |    0xDEADBEEF     |    0xdeadbeef     |
///   | X+ / X  | Hex + prefix, upper  |    0xDEADBEEF     |    0xDEADBEEF     |
///   | (empty) | Same as X+ / X       |                   |                   |
///   ==========================================================================
///
/// The default precision is the number of nibbles in a machine word, and in all
/// cases indicates the minimum number of nibbles to print.
template <typename T>
struct format_provider<
    T, std::enable_if_t<detail::use_pointer_formatter<T>::value>>
    : public detail::HelperFunctions {
private:
public:
  static void format(const T &V, llvm::raw_ostream &Stream, StringRef Style) {
    HexPrintStyle HS = HexPrintStyle::PrefixUpper;
    consumeHexStyle(Style, HS);
    size_t Digits = consumeNumHexDigits(Style, HS, sizeof(void *) * 2);
    write_hex(Stream, reinterpret_cast<std::uintptr_t>(V), HS, Digits);
  }
};

/// Implementation of format_provider<T> for c-style strings and string
/// objects such as std::string and llvm::StringRef.
///
/// The options string of a string type has the grammar:
///
///   string_options :: [length]
///
/// where `length` is an optional integer specifying the maximum number of
/// characters in the string to print.  If `length` is omitted, the string is
/// printed up to the null terminator.

template <typename T>
struct format_provider<
    T, std::enable_if_t<detail::use_string_formatter<T>::value>> {
  static void format(const T &V, llvm::raw_ostream &Stream, StringRef Style) {
    size_t N = StringRef::npos;
    if (!Style.empty() && Style.getAsInteger(10, N)) {
      assert(false && "Style is not a valid integer");
    }
    llvm::StringRef S = V;
    Stream << S.substr(0, N);
  }
};

/// Implementation of format_provider<T> for llvm::Twine.
///
/// This follows the same rules as the string formatter.

template <> struct format_provider<Twine> {
  static void format(const Twine &V, llvm::raw_ostream &Stream,
                     StringRef Style) {
    format_provider<std::string>::format(V.str(), Stream, Style);
  }
};

/// Implementation of format_provider<T> for characters.
///
/// The options string of a character type has the grammar:
///
///   char_options :: (empty) | [integer_options]
///
/// If `char_options` is empty, the character is displayed as an ASCII
/// character.  Otherwise, it is treated as an integer options string.
///
template <typename T>
struct format_provider<T,
                       std::enable_if_t<detail::use_char_formatter<T>::value>> {
  static void format(const char &V, llvm::raw_ostream &Stream,
                     StringRef Style) {
    if (Style.empty())
      Stream << V;
    else {
      int X = static_cast<int>(V);
      format_provider<int>::format(X, Stream, Style);
    }
  }
};

/// Implementation of format_provider<T> for type `bool`
///
/// The options string of a boolean type has the grammar:
///
///   bool_options :: "" | "Y" | "y" | "D" | "d" | "T" | "t"
///
///   ==================================
///   |    C    |     Meaning          |
///   ==================================
///   |    Y    |       YES / NO       |
///   |    y    |       yes / no       |
///   |  D / d  |    Integer 0 or 1    |
///   |    T    |     TRUE / FALSE     |
///   |    t    |     true / false     |
///   | (empty) |   Equivalent to 't'  |
///   ==================================
template <> struct format_provider<bool> {
  static void format(const bool &B, llvm::raw_ostream &Stream,
                     StringRef Style) {
    Stream << StringSwitch<const char *>(Style)
                  .Case("Y", B ? "YES" : "NO")
                  .Case("y", B ? "yes" : "no")
                  .CaseLower("D", B ? "1" : "0")
                  .Case("T", B ? "TRUE" : "FALSE")
                  .Cases("t", "", B ? "true" : "false")
                  .Default(B ? "1" : "0");
  }
};

/// Implementation of format_provider<T> for floating point types.
///
/// The options string of a floating point type has the format:
///
///   float_options   :: [style][precision]
///   style           :: <see table below>
///   precision       :: <non-negative integer> 0-99
///
///   =====================================================
///   |  style  |     Meaning          |      Example     |
///   -----------------------------------------------------
///   |         |                      |  Input |  Output |
///   =====================================================
///   | P / p   | Percentage           |  0.05  |  5.00%  |
///   | F / f   | Fixed point          |   1.0  |  1.00   |
///   |   E     | Exponential with E   | 100000 | 1.0E+05 |
///   |   e     | Exponential with e   | 100000 | 1.0e+05 |
///   | (empty) | Same as F / f        |        |         |
///   =====================================================
///
/// The default precision is 6 for exponential (E / e) and 2 for everything
/// else.

template <typename T>
struct format_provider<T,
                       std::enable_if_t<detail::use_double_formatter<T>::value>>
    : public detail::HelperFunctions {
  static void format(const T &V, llvm::raw_ostream &Stream, StringRef Style) {
    FloatStyle S;
    if (Style.consume_front("P") || Style.consume_front("p"))
      S = FloatStyle::Percent;
    else if (Style.consume_front("F") || Style.consume_front("f"))
      S = FloatStyle::Fixed;
    else if (Style.consume_front("E"))
      S = FloatStyle::ExponentUpper;
    else if (Style.consume_front("e"))
      S = FloatStyle::Exponent;
    else
      S = FloatStyle::Fixed;

    Optional<size_t> Precision = parseNumericPrecision(Style);
    if (!Precision.hasValue())
      Precision = getDefaultPrecision(S);

    write_double(Stream, static_cast<double>(V), S, Precision);
  }
};

namespace detail {
template <typename IterT>
using IterValue = typename std::iterator_traits<IterT>::value_type;

template <typename IterT>
struct range_item_has_provider
    : public std::integral_constant<
          bool, !uses_missing_provider<IterValue<IterT>>::value> {};
}

/// Implementation of format_provider<T> for ranges.
///
/// This will print an arbitrary range as a delimited sequence of items.
///
/// The options string of a range type has the grammar:
///
///   range_style       ::= [separator] [element_style]
///   separator         ::= "$" delimeted_expr
///   element_style     ::= "@" delimeted_expr
///   delimeted_expr    ::= "[" expr "]" | "(" expr ")" | "<" expr ">"
///   expr              ::= <any string not containing delimeter>
///
/// where the separator expression is the string to insert between consecutive
/// items in the range and the argument expression is the Style specification to
/// be used when formatting the underlying type.  The default separator if
/// unspecified is ' ' (space).  The syntax of the argument expression follows
/// whatever grammar is dictated by the format provider or format adapter used
/// to format the value type.
///
/// Note that attempting to format an `iterator_range<T>` where no format
/// provider can be found for T will result in a compile error.
///

template <typename IterT> class format_provider<llvm::iterator_range<IterT>> {
  using value = typename std::iterator_traits<IterT>::value_type;
  using reference = typename std::iterator_traits<IterT>::reference;

  static StringRef consumeOneOption(StringRef &Style, char Indicator,
                                    StringRef Default) {
    if (Style.empty())
      return Default;
    if (Style.front() != Indicator)
      return Default;
    Style = Style.drop_front();
    if (Style.empty()) {
      assert(false && "Invalid range style");
      return Default;
    }

    for (const char *D : {"[]", "<>", "()"}) {
      if (Style.front() != D[0])
        continue;
      size_t End = Style.find_first_of(D[1]);
      if (End == StringRef::npos) {
        assert(false && "Missing range option end delimeter!");
        return Default;
      }
      StringRef Result = Style.slice(1, End);
      Style = Style.drop_front(End + 1);
      return Result;
    }
    assert(false && "Invalid range style!");
    return Default;
  }

  static std::pair<StringRef, StringRef> parseOptions(StringRef Style) {
    StringRef Sep = consumeOneOption(Style, '$', ", ");
    StringRef Args = consumeOneOption(Style, '@', "");
    assert(Style.empty() && "Unexpected text in range option string!");
    return std::make_pair(Sep, Args);
  }

public:
  static_assert(detail::range_item_has_provider<IterT>::value,
                "Range value_type does not have a format provider!");
  static void format(const llvm::iterator_range<IterT> &V,
                     llvm::raw_ostream &Stream, StringRef Style) {
    StringRef Sep;
    StringRef ArgStyle;
    std::tie(Sep, ArgStyle) = parseOptions(Style);
    auto Begin = V.begin();
    auto End = V.end();
    if (Begin != End) {
      auto Adapter =
          detail::build_format_adapter(std::forward<reference>(*Begin));
      Adapter.format(Stream, ArgStyle);
      ++Begin;
    }
    while (Begin != End) {
      Stream << Sep;
      auto Adapter =
          detail::build_format_adapter(std::forward<reference>(*Begin));
      Adapter.format(Stream, ArgStyle);
      ++Begin;
    }
  }
};
}

#endif
# 423 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FormatProviders.h"
# 14 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h" 2

#if 0 /* expanded by -frewrite-includes */
#include <chrono>
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 1 3
// -*- C++ -*-
//===---------------------------- chrono ----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CHRONO
#define _LIBCPP_CHRONO

/*
    chrono synopsis

namespace std
{
namespace chrono
{

template <class ToDuration, class Rep, class Period>
constexpr
ToDuration
duration_cast(const duration<Rep, Period>& fd);

template <class Rep> struct treat_as_floating_point : is_floating_point<Rep> {};

template <class Rep> inline constexpr bool treat_as_floating_point_v
    = treat_as_floating_point<Rep>::value;                       // C++17

template <class Rep>
struct duration_values
{
public:
    static constexpr Rep zero(); // noexcept in C++20
    static constexpr Rep max();  // noexcept in C++20
    static constexpr Rep min();  // noexcept in C++20
};

// duration

template <class Rep, class Period = ratio<1>>
class duration
{
    static_assert(!__is_duration<Rep>::value, "A duration representation can not be a duration");
    static_assert(__is_ratio<Period>::value, "Second template parameter of duration must be a std::ratio");
    static_assert(Period::num > 0, "duration period must be positive");
public:
    typedef Rep rep;
    typedef typename _Period::type period;

    constexpr duration() = default;
    template <class Rep2>
        constexpr explicit duration(const Rep2& r,
            typename enable_if
            <
               is_convertible<Rep2, rep>::value &&
               (treat_as_floating_point<rep>::value ||
               !treat_as_floating_point<rep>::value && !treat_as_floating_point<Rep2>::value)
            >::type* = 0);

    // conversions
    template <class Rep2, class Period2>
        constexpr duration(const duration<Rep2, Period2>& d,
            typename enable_if
            <
                treat_as_floating_point<rep>::value ||
                ratio_divide<Period2, period>::type::den == 1
            >::type* = 0);

    // observer

    constexpr rep count() const;

    // arithmetic

    constexpr common_type<duration>::type  operator+() const;
    constexpr common_type<duration>::type  operator-() const;
    constexpr duration& operator++();    // constexpr in C++17
    constexpr duration  operator++(int); // constexpr in C++17
    constexpr duration& operator--();    // constexpr in C++17
    constexpr duration  operator--(int); // constexpr in C++17

    constexpr duration& operator+=(const duration& d);  // constexpr in C++17
    constexpr duration& operator-=(const duration& d);  // constexpr in C++17

    duration& operator*=(const rep& rhs);       // constexpr in C++17
    duration& operator/=(const rep& rhs);       // constexpr in C++17
    duration& operator%=(const rep& rhs);       // constexpr in C++17
    duration& operator%=(const duration& rhs);  // constexpr in C++17

    // special values

    static constexpr duration zero(); // noexcept in C++20
    static constexpr duration min();  // noexcept in C++20
    static constexpr duration max();  // noexcept in C++20
};

typedef duration<long long,         nano> nanoseconds;
typedef duration<long long,        micro> microseconds;
typedef duration<long long,        milli> milliseconds;
typedef duration<long long              > seconds;
typedef duration<     long, ratio<  60> > minutes;
typedef duration<     long, ratio<3600> > hours;

template <class Clock, class Duration = typename Clock::duration>
class time_point
{
public:
    typedef Clock                     clock;
    typedef Duration                  duration;
    typedef typename duration::rep    rep;
    typedef typename duration::period period;
private:
    duration d_;  // exposition only

public:
    time_point();  // has value "epoch" // constexpr in C++14
    explicit time_point(const duration& d);  // same as time_point() + d // constexpr in C++14

    // conversions
    template <class Duration2>
       time_point(const time_point<clock, Duration2>& t); // constexpr in C++14

    // observer

    duration time_since_epoch() const; // constexpr in C++14

    // arithmetic

    time_point& operator+=(const duration& d); // constexpr in C++17
    time_point& operator-=(const duration& d); // constexpr in C++17

    // special values

    static constexpr time_point min();  // noexcept in C++20
    static constexpr time_point max();  // noexcept in C++20
};

} // chrono

// common_type traits
template <class Rep1, class Period1, class Rep2, class Period2>
  struct common_type<chrono::duration<Rep1, Period1>, chrono::duration<Rep2, Period2>>;

template <class Clock, class Duration1, class Duration2>
  struct common_type<chrono::time_point<Clock, Duration1>, chrono::time_point<Clock, Duration2>>;

namespace chrono {


template<class T> struct is_clock;  // C++20
template<class T> inline constexpr bool is_clock_v = is_clock<T>::value;   // C++20


// duration arithmetic
template <class Rep1, class Period1, class Rep2, class Period2>
  constexpr
  typename common_type<duration<Rep1, Period1>, duration<Rep2, Period2>>::type
  operator+(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
  constexpr
  typename common_type<duration<Rep1, Period1>, duration<Rep2, Period2>>::type
  operator-(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period, class Rep2>
  constexpr
  duration<typename common_type<Rep1, Rep2>::type, Period>
  operator*(const duration<Rep1, Period>& d, const Rep2& s);
template <class Rep1, class Period, class Rep2>
  constexpr
  duration<typename common_type<Rep1, Rep2>::type, Period>
  operator*(const Rep1& s, const duration<Rep2, Period>& d);
template <class Rep1, class Period, class Rep2>
  constexpr
  duration<typename common_type<Rep1, Rep2>::type, Period>
  operator/(const duration<Rep1, Period>& d, const Rep2& s);
template <class Rep1, class Period1, class Rep2, class Period2>
  constexpr
  typename common_type<Rep1, Rep2>::type
  operator/(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);

// duration comparisons
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator==(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator!=(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator< (const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator<=(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator> (const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator>=(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);

// duration_cast
template <class ToDuration, class Rep, class Period>
  ToDuration duration_cast(const duration<Rep, Period>& d);

template <class ToDuration, class Rep, class Period>
    constexpr ToDuration floor(const duration<Rep, Period>& d);    // C++17
template <class ToDuration, class Rep, class Period>
    constexpr ToDuration ceil(const duration<Rep, Period>& d);     // C++17
template <class ToDuration, class Rep, class Period>
    constexpr ToDuration round(const duration<Rep, Period>& d);    // C++17

// duration I/O is elsewhere

// time_point arithmetic (all constexpr in C++14)
template <class Clock, class Duration1, class Rep2, class Period2>
  time_point<Clock, typename common_type<Duration1, duration<Rep2, Period2>>::type>
  operator+(const time_point<Clock, Duration1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Clock, class Duration2>
  time_point<Clock, typename common_type<duration<Rep1, Period1>, Duration2>::type>
  operator+(const duration<Rep1, Period1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Rep2, class Period2>
  time_point<Clock, typename common_type<Duration1, duration<Rep2, Period2>>::type>
  operator-(const time_point<Clock, Duration1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Clock, class Duration1, class Duration2>
  typename common_type<Duration1, Duration2>::type
  operator-(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);

// time_point comparisons (all constexpr in C++14)
template <class Clock, class Duration1, class Duration2>
   bool operator==(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator!=(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator< (const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator<=(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator> (const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator>=(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);

// time_point_cast (constexpr in C++14)

template <class ToDuration, class Clock, class Duration>
  time_point<Clock, ToDuration> time_point_cast(const time_point<Clock, Duration>& t);

template <class ToDuration, class Clock, class Duration>
    constexpr time_point<Clock, ToDuration>
    floor(const time_point<Clock, Duration>& tp);                  // C++17

template <class ToDuration, class Clock, class Duration>
    constexpr time_point<Clock, ToDuration>
    ceil(const time_point<Clock, Duration>& tp);                   // C++17

template <class ToDuration, class Clock, class Duration>
    constexpr time_point<Clock, ToDuration>
    round(const time_point<Clock, Duration>& tp);                  // C++17

template <class Rep, class Period>
    constexpr duration<Rep, Period> abs(duration<Rep, Period> d);  // C++17

// Clocks

class system_clock
{
public:
    typedef microseconds                     duration;
    typedef duration::rep                    rep;
    typedef duration::period                 period;
    typedef chrono::time_point<system_clock> time_point;
    static const bool is_steady =            false; // constexpr in C++14

    static time_point now() noexcept;
    static time_t     to_time_t  (const time_point& __t) noexcept;
    static time_point from_time_t(time_t __t) noexcept;
};

template <class Duration>
  using sys_time  = time_point<system_clock, Duration>; // C++20
using sys_seconds = sys_time<seconds>;                  // C++20
using sys_days    = sys_time<days>;                     // C++20

class utc_clock;                                        // C++20

template <class Duration>
  using utc_time  = time_point<utc_clock, Duration>;    // C++20
using utc_seconds = utc_time<seconds>;                  // C++20

class tai_clock;                                        // C++20

template <class Duration>
  using tai_time  = time_point<tai_clock, Duration>;    // C++20
using tai_seconds = tai_time<seconds>;                  // C++20

class file_clock;                                       // C++20

template<class Duration>
  using file_time = time_point<file_clock, Duration>;   // C++20

class steady_clock
{
public:
    typedef nanoseconds                                   duration;
    typedef duration::rep                                 rep;
    typedef duration::period                              period;
    typedef chrono::time_point<steady_clock, duration>    time_point;
    static const bool is_steady =                         true; // constexpr in C++14

    static time_point now() noexcept;
};

typedef steady_clock high_resolution_clock;

// 25.7.8, local time           // C++20
struct local_t {};
template<class Duration>
  using local_time  = time_point<local_t, Duration>;
using local_seconds = local_time<seconds>;
using local_days    = local_time<days>;

// 25.7.9, time_point conversions template<class DestClock, class SourceClock>    // C++20
struct clock_time_conversion;

template<class DestClock, class SourceClock, class Duration>
  auto clock_cast(const time_point<SourceClock, Duration>& t);

// 25.8.2, class last_spec    // C++20
struct last_spec;

// 25.8.3, class day          // C++20

class day;
constexpr bool operator==(const day& x, const day& y) noexcept;
constexpr bool operator!=(const day& x, const day& y) noexcept;
constexpr bool operator< (const day& x, const day& y) noexcept;
constexpr bool operator> (const day& x, const day& y) noexcept;
constexpr bool operator<=(const day& x, const day& y) noexcept;
constexpr bool operator>=(const day& x, const day& y) noexcept;
constexpr day  operator+(const day&  x, const days& y) noexcept;
constexpr day  operator+(const days& x, const day&  y) noexcept;
constexpr day  operator-(const day&  x, const days& y) noexcept;
constexpr days operator-(const day&  x, const day&  y) noexcept;

// 25.8.4, class month    // C++20
class month;
constexpr bool operator==(const month& x, const month& y) noexcept;
constexpr bool operator!=(const month& x, const month& y) noexcept;
constexpr bool operator< (const month& x, const month& y) noexcept;
constexpr bool operator> (const month& x, const month& y) noexcept;
constexpr bool operator<=(const month& x, const month& y) noexcept;
constexpr bool operator>=(const month& x, const month& y) noexcept;
constexpr month  operator+(const month&  x, const months& y) noexcept;
constexpr month  operator+(const months& x,  const month& y) noexcept;
constexpr month  operator-(const month&  x, const months& y) noexcept;
constexpr months operator-(const month&  x,  const month& y) noexcept;

// 25.8.5, class year    // C++20
class year;
constexpr bool operator==(const year& x, const year& y) noexcept;
constexpr bool operator!=(const year& x, const year& y) noexcept;
constexpr bool operator< (const year& x, const year& y) noexcept;
constexpr bool operator> (const year& x, const year& y) noexcept;
constexpr bool operator<=(const year& x, const year& y) noexcept;
constexpr bool operator>=(const year& x, const year& y) noexcept;
constexpr year  operator+(const year&  x, const years& y) noexcept;
constexpr year  operator+(const years& x, const year&  y) noexcept;
constexpr year  operator-(const year&  x, const years& y) noexcept;
constexpr years operator-(const year&  x, const year&  y) noexcept;

// 25.8.6, class weekday    // C++20
class weekday;

constexpr bool operator==(const weekday& x, const weekday& y) noexcept;
constexpr bool operator!=(const weekday& x, const weekday& y) noexcept;
constexpr weekday operator+(const weekday& x, const days&    y) noexcept;
constexpr weekday operator+(const days&    x, const weekday& y) noexcept;
constexpr weekday operator-(const weekday& x, const days&    y) noexcept;
constexpr days    operator-(const weekday& x, const weekday& y) noexcept;

// 25.8.7, class weekday_indexed    // C++20

class weekday_indexed;
constexpr bool operator==(const weekday_indexed& x, const weekday_indexed& y) noexcept;
constexpr bool operator!=(const weekday_indexed& x, const weekday_indexed& y) noexcept;

// 25.8.8, class weekday_last    // C++20
class weekday_last;

constexpr bool operator==(const weekday_last& x, const weekday_last& y) noexcept;
constexpr bool operator!=(const weekday_last& x, const weekday_last& y) noexcept;

// 25.8.9, class month_day    // C++20
class month_day;

constexpr bool operator==(const month_day& x, const month_day& y) noexcept;
constexpr bool operator!=(const month_day& x, const month_day& y) noexcept;
constexpr bool operator< (const month_day& x, const month_day& y) noexcept;
constexpr bool operator> (const month_day& x, const month_day& y) noexcept;
constexpr bool operator<=(const month_day& x, const month_day& y) noexcept;
constexpr bool operator>=(const month_day& x, const month_day& y) noexcept;


// 25.8.10, class month_day_last    // C++20
class month_day_last;

constexpr bool operator==(const month_day_last& x, const month_day_last& y) noexcept;
constexpr bool operator!=(const month_day_last& x, const month_day_last& y) noexcept;
constexpr bool operator< (const month_day_last& x, const month_day_last& y) noexcept;
constexpr bool operator> (const month_day_last& x, const month_day_last& y) noexcept;
constexpr bool operator<=(const month_day_last& x, const month_day_last& y) noexcept;
constexpr bool operator>=(const month_day_last& x, const month_day_last& y) noexcept;

// 25.8.11, class month_weekday    // C++20
class month_weekday;

constexpr bool operator==(const month_weekday& x, const month_weekday& y) noexcept;
constexpr bool operator!=(const month_weekday& x, const month_weekday& y) noexcept;

// 25.8.12, class month_weekday_last    // C++20
class month_weekday_last;

constexpr bool operator==(const month_weekday_last& x, const month_weekday_last& y) noexcept;
constexpr bool operator!=(const month_weekday_last& x, const month_weekday_last& y) noexcept;


// 25.8.13, class year_month    // C++20
class year_month;

constexpr bool operator==(const year_month& x, const year_month& y) noexcept;
constexpr bool operator!=(const year_month& x, const year_month& y) noexcept;
constexpr bool operator< (const year_month& x, const year_month& y) noexcept;
constexpr bool operator> (const year_month& x, const year_month& y) noexcept;
constexpr bool operator<=(const year_month& x, const year_month& y) noexcept;
constexpr bool operator>=(const year_month& x, const year_month& y) noexcept;

constexpr year_month operator+(const year_month& ym, const months& dm) noexcept;
constexpr year_month operator+(const months& dm, const year_month& ym) noexcept;
constexpr year_month operator-(const year_month& ym, const months& dm) noexcept;
constexpr months operator-(const year_month& x, const year_month& y) noexcept;
constexpr year_month operator+(const year_month& ym, const years& dy) noexcept;
constexpr year_month operator+(const years& dy, const year_month& ym) noexcept;
constexpr year_month operator-(const year_month& ym, const years& dy) noexcept;

// 25.8.14, class year_month_day class    // C++20
year_month_day;

constexpr bool operator==(const year_month_day& x, const year_month_day& y) noexcept;
constexpr bool operator!=(const year_month_day& x, const year_month_day& y) noexcept;
constexpr bool operator< (const year_month_day& x, const year_month_day& y) noexcept;
constexpr bool operator> (const year_month_day& x, const year_month_day& y) noexcept;
constexpr bool operator<=(const year_month_day& x, const year_month_day& y) noexcept;
constexpr bool operator>=(const year_month_day& x, const year_month_day& y) noexcept;

constexpr year_month_day operator+(const year_month_day& ymd, const months& dm) noexcept;
constexpr year_month_day operator+(const months& dm, const year_month_day& ymd) noexcept;
constexpr year_month_day operator+(const year_month_day& ymd, const years& dy) noexcept;
constexpr year_month_day operator+(const years& dy, const year_month_day& ymd) noexcept;
constexpr year_month_day operator-(const year_month_day& ymd, const months& dm) noexcept;
constexpr year_month_day operator-(const year_month_day& ymd, const years& dy) noexcept;


// 25.8.15, class year_month_day_last    // C++20
class year_month_day_last;

constexpr bool operator==(const year_month_day_last& x,
                          const year_month_day_last& y) noexcept;
constexpr bool operator!=(const year_month_day_last& x,
                          const year_month_day_last& y) noexcept;
constexpr bool operator< (const year_month_day_last& x,
                          const year_month_day_last& y) noexcept;
constexpr bool operator> (const year_month_day_last& x,
                          const year_month_day_last& y) noexcept;
constexpr bool operator<=(const year_month_day_last& x,
                          const year_month_day_last& y) noexcept;
constexpr bool operator>=(const year_month_day_last& x,
                          const year_month_day_last& y) noexcept;

constexpr year_month_day_last
  operator+(const year_month_day_last& ymdl, const months& dm) noexcept;
constexpr year_month_day_last
  operator+(const months& dm, const year_month_day_last& ymdl) noexcept;
constexpr year_month_day_last
  operator+(const year_month_day_last& ymdl, const years& dy) noexcept;
constexpr year_month_day_last
  operator+(const years& dy, const year_month_day_last& ymdl) noexcept;
constexpr year_month_day_last
  operator-(const year_month_day_last& ymdl, const months& dm) noexcept;
constexpr year_month_day_last
  operator-(const year_month_day_last& ymdl, const years& dy) noexcept;

// 25.8.16, class year_month_weekday    // C++20
class year_month_weekday;

constexpr bool operator==(const year_month_weekday& x,
                          const year_month_weekday& y) noexcept;
constexpr bool operator!=(const year_month_weekday& x,
                          const year_month_weekday& y) noexcept;

constexpr year_month_weekday
  operator+(const year_month_weekday& ymwd, const months& dm) noexcept;
constexpr year_month_weekday
  operator+(const months& dm, const year_month_weekday& ymwd) noexcept;
constexpr year_month_weekday
  operator+(const year_month_weekday& ymwd, const years& dy) noexcept;
constexpr year_month_weekday
  operator+(const years& dy, const year_month_weekday& ymwd) noexcept;
constexpr year_month_weekday
  operator-(const year_month_weekday& ymwd, const months& dm) noexcept;
constexpr year_month_weekday
  operator-(const year_month_weekday& ymwd, const years& dy) noexcept;

// 25.8.17, class year_month_weekday_last    // C++20
class year_month_weekday_last;

constexpr bool operator==(const year_month_weekday_last& x,
                          const year_month_weekday_last& y) noexcept;
constexpr bool operator!=(const year_month_weekday_last& x,
                          const year_month_weekday_last& y) noexcept;
constexpr year_month_weekday_last
  operator+(const year_month_weekday_last& ymwdl, const months& dm) noexcept;
constexpr year_month_weekday_last
  operator+(const months& dm, const year_month_weekday_last& ymwdl) noexcept;
constexpr year_month_weekday_last
  operator+(const year_month_weekday_last& ymwdl, const years& dy) noexcept;
constexpr year_month_weekday_last
  operator+(const years& dy, const year_month_weekday_last& ymwdl) noexcept;
constexpr year_month_weekday_last
  operator-(const year_month_weekday_last& ymwdl, const months& dm) noexcept;
constexpr year_month_weekday_last
  operator-(const year_month_weekday_last& ymwdl, const years& dy) noexcept;

// 25.8.18, civil calendar conventional syntax operators    // C++20
constexpr year_month
  operator/(const year& y, const month& m) noexcept;
constexpr year_month
  operator/(const year& y, int m) noexcept;
constexpr month_day
  operator/(const month& m, const day& d) noexcept;
constexpr month_day
  operator/(const month& m, int d) noexcept;
constexpr month_day
  operator/(int m, const day& d) noexcept;
constexpr month_day
  operator/(const day& d, const month& m) noexcept;
constexpr month_day
  operator/(const day& d, int m) noexcept;
constexpr month_day_last
  operator/(const month& m, last_spec) noexcept;
constexpr month_day_last
  operator/(int m, last_spec) noexcept;
constexpr month_day_last
  operator/(last_spec, const month& m) noexcept;
constexpr month_day_last
  operator/(last_spec, int m) noexcept;
constexpr month_weekday
  operator/(const month& m, const weekday_indexed& wdi) noexcept;
constexpr month_weekday
  operator/(int m, const weekday_indexed& wdi) noexcept;
constexpr month_weekday
  operator/(const weekday_indexed& wdi, const month& m) noexcept;
constexpr month_weekday
  operator/(const weekday_indexed& wdi, int m) noexcept;
constexpr month_weekday_last
  operator/(const month& m, const weekday_last& wdl) noexcept;
constexpr month_weekday_last
  operator/(int m, const weekday_last& wdl) noexcept;
constexpr month_weekday_last
  operator/(const weekday_last& wdl, const month& m) noexcept;
constexpr month_weekday_last
  operator/(const weekday_last& wdl, int m) noexcept;
constexpr year_month_day
  operator/(const year_month& ym, const day& d) noexcept;
constexpr year_month_day
  operator/(const year_month& ym, int d) noexcept;
constexpr year_month_day
  operator/(const year& y, const month_day& md) noexcept;
constexpr year_month_day
  operator/(int y, const month_day& md) noexcept;
constexpr year_month_day
  operator/(const month_day& md, const year& y) noexcept;
constexpr year_month_day
  operator/(const month_day& md, int y) noexcept;
constexpr year_month_day_last
  operator/(const year_month& ym, last_spec) noexcept;
constexpr year_month_day_last
  operator/(const year& y, const month_day_last& mdl) noexcept;
constexpr year_month_day_last
  operator/(int y, const month_day_last& mdl) noexcept;
constexpr year_month_day_last
  operator/(const month_day_last& mdl, const year& y) noexcept;
constexpr year_month_day_last
  operator/(const month_day_last& mdl, int y) noexcept;
constexpr year_month_weekday
  operator/(const year_month& ym, const weekday_indexed& wdi) noexcept;
constexpr year_month_weekday
  operator/(const year& y, const month_weekday& mwd) noexcept;
constexpr year_month_weekday
  operator/(int y, const month_weekday& mwd) noexcept;
constexpr year_month_weekday
  operator/(const month_weekday& mwd, const year& y) noexcept;
constexpr year_month_weekday
  operator/(const month_weekday& mwd, int y) noexcept;
constexpr year_month_weekday_last
  operator/(const year_month& ym, const weekday_last& wdl) noexcept;
constexpr year_month_weekday_last
  operator/(const year& y, const month_weekday_last& mwdl) noexcept;
constexpr year_month_weekday_last
  operator/(int y, const month_weekday_last& mwdl) noexcept;
constexpr year_month_weekday_last
  operator/(const month_weekday_last& mwdl, const year& y) noexcept;
constexpr year_month_weekday_last
  operator/(const month_weekday_last& mwdl, int y) noexcept;

// 26.9, class template hh_mm_ss
template <class Duration>
class hh_mm_ss
{
    bool            is_neg; // exposition only
    chrono::hours   h;      // exposition only
    chrono::minutes m;      // exposition only
    chrono::seconds s;      // exposition only
    precision       ss;     // exposition only

public:
    static unsigned constexpr fractional_width = see below;
    using precision                            = see below;

    constexpr hh_mm_ss() noexcept : hh_mm_ss{Duration::zero()} {}
    constexpr explicit hh_mm_ss(Duration d) noexcept;

    constexpr bool is_negative() const noexcept;
    constexpr chrono::hours hours() const noexcept;
    constexpr chrono::minutes minutes() const noexcept;
    constexpr chrono::seconds seconds() const noexcept;
    constexpr precision subseconds() const noexcept;

    constexpr explicit operator  precision()   const noexcept;
    constexpr          precision to_duration() const noexcept;
};

template <class charT, class traits, class Duration>
  basic_ostream<charT, traits>&
    operator<<(basic_ostream<charT, traits>& os, hh_mm_ss<Duration> const& hms);

// 26.10, 12/24 hour functions
constexpr bool is_am(hours const& h) noexcept;
constexpr bool is_pm(hours const& h) noexcept;
constexpr hours make12(const hours& h) noexcept;
constexpr hours make24(const hours& h, bool is_pm) noexcept;


// 25.10.2, time zone database     // C++20
struct tzdb;
class tzdb_list;

// 25.10.2.3, time zone database access    // C++20
const tzdb& get_tzdb();
tzdb_list& get_tzdb_list();
const time_zone* locate_zone(string_view tz_name);
const time_zone* current_zone();

// 25.10.2.4, remote time zone database support    // C++20
const tzdb& reload_tzdb();
string remote_version();

// 25.10.3, exception classes    // C++20
class nonexistent_local_time;
class ambiguous_local_time;

// 25.10.4, information classes    // C++20
struct sys_info;
struct local_info;

// 25.10.5, class time_zone    // C++20
enum class choose {earliest, latest};
class time_zone;
bool operator==(const time_zone& x, const time_zone& y) noexcept;
bool operator!=(const time_zone& x, const time_zone& y) noexcept;
bool operator<(const time_zone& x, const time_zone& y) noexcept;
bool operator>(const time_zone& x, const time_zone& y) noexcept;
bool operator<=(const time_zone& x, const time_zone& y) noexcept;
bool operator>=(const time_zone& x, const time_zone& y) noexcept;

// 25.10.6, class template zoned_traits    // C++20
template<class T> struct zoned_traits;

// 25.10.7, class template zoned_time    // C++20
template<class Duration, class TimeZonePtr = const time_zone*> class zoned_time;
using zoned_seconds = zoned_time<seconds>;

template<class Duration1, class Duration2, class TimeZonePtr>
  bool operator==(const zoned_time<Duration1, TimeZonePtr>& x,
                  const zoned_time<Duration2, TimeZonePtr>& y);
template<class Duration1, class Duration2, class TimeZonePtr>
  bool operator!=(const zoned_time<Duration1, TimeZonePtr>& x,
                  const zoned_time<Duration2, TimeZonePtr>& y);

// 25.10.8, leap second support    // C++20
class leap;

bool operator==(const leap& x, const leap& y);
bool operator!=(const leap& x, const leap& y);
bool operator< (const leap& x, const leap& y);
bool operator> (const leap& x, const leap& y);
bool operator<=(const leap& x, const leap& y);
bool operator>=(const leap& x, const leap& y);
template<class Duration>
  bool operator==(const leap& x, const sys_time<Duration>& y);
template<class Duration>
  bool operator==(const sys_time<Duration>& x, const leap& y);
template<class Duration>
  bool operator!=(const leap& x, const sys_time<Duration>& y);
template<class Duration>
  bool operator!=(const sys_time<Duration>& x, const leap& y);
template<class Duration>
  bool operator< (const leap& x, const sys_time<Duration>& y);
template<class Duration>
  bool operator< (const sys_time<Duration>& x, const leap& y);
template<class Duration>
  bool operator> (const leap& x, const sys_time<Duration>& y);
template<class Duration>
  bool operator> (const sys_time<Duration>& x, const leap& y);
template<class Duration>
  bool operator<=(const leap& x, const sys_time<Duration>& y);
template<class Duration>
  bool operator<=(const sys_time<Duration>& x, const leap& y);
template<class Duration>
  bool operator>=(const leap& x, const sys_time<Duration>& y);
template<class Duration>
  bool operator>=(const sys_time<Duration>& x, const leap& y);

// 25.10.9, class link    // C++20
class link;
bool operator==(const link& x, const link& y);
bool operator!=(const link& x, const link& y);
bool operator< (const link& x, const link& y);
bool operator> (const link& x, const link& y);
bool operator<=(const link& x, const link& y);
bool operator>=(const link& x, const link& y);

// 25.11, formatting    // C++20
template<class charT, class Streamable>
  basic_string<charT>
    format(const charT* fmt, const Streamable& s);

template<class charT, class Streamable>
  basic_string<charT>
    format(const locale& loc, const charT* fmt, const Streamable& s);

template<class charT, class traits, class Alloc, class Streamable>
  basic_string<charT, traits, Alloc>
    format(const basic_string<charT, traits, Alloc>& fmt, const Streamable& s);

template<class charT, class traits, class Alloc, class Streamable>
  basic_string<charT, traits, Alloc>
    format(const locale& loc, const basic_string<charT, traits, Alloc>& fmt,
           const Streamable& s);

// 25.12, parsing    // C++20
template<class charT, class traits, class Alloc, class Parsable>
unspecified
    parse(const basic_string<charT, traits, Alloc>& format, Parsable& tp);

template<class charT, class traits, class Alloc, class Parsable>
unspecified
    parse(const basic_string<charT, traits, Alloc>& format, Parsable& tp,
          basic_string<charT, traits, Alloc>& abbrev);

template<class charT, class traits, class Alloc, class Parsable>
unspecified
    parse(const basic_string<charT, traits, Alloc>& format, Parsable& tp,
          minutes& offset);

template<class charT, class traits, class Alloc, class Parsable>
unspecified
    parse(const basic_string<charT, traits, Alloc>& format, Parsable& tp,
          basic_string<charT, traits, Alloc>& abbrev, minutes& offset);

// calendrical constants
inline constexpr last_spec                              last{};       // C++20
inline constexpr chrono::weekday                        Sunday{0};    // C++20
inline constexpr chrono::weekday                        Monday{1};    // C++20
inline constexpr chrono::weekday                        Tuesday{2};   // C++20
inline constexpr chrono::weekday                        Wednesday{3}; // C++20
inline constexpr chrono::weekday                        Thursday{4};  // C++20
inline constexpr chrono::weekday                        Friday{5};    // C++20
inline constexpr chrono::weekday                        Saturday{6};  // C++20

inline constexpr chrono::month                          January{1};   // C++20
inline constexpr chrono::month                          February{2};  // C++20
inline constexpr chrono::month                          March{3};     // C++20
inline constexpr chrono::month                          April{4};     // C++20
inline constexpr chrono::month                          May{5};       // C++20
inline constexpr chrono::month                          June{6};      // C++20
inline constexpr chrono::month                          July{7};      // C++20
inline constexpr chrono::month                          August{8};    // C++20
inline constexpr chrono::month                          September{9}; // C++20
inline constexpr chrono::month                          October{10};  // C++20
inline constexpr chrono::month                          November{11}; // C++20
inline constexpr chrono::month                          December{12}; // C++20
}  // chrono

inline namespace literals {
  inline namespace chrono_literals {
constexpr chrono::hours                                 operator ""h(unsigned long long); // C++14
constexpr chrono::duration<unspecified , ratio<3600,1>> operator ""h(long double); // C++14
constexpr chrono::minutes                               operator ""min(unsigned long long); // C++14
constexpr chrono::duration<unspecified , ratio<60,1>>   operator ""min(long double); // C++14
constexpr chrono::seconds                               operator ""s(unsigned long long); // C++14
constexpr chrono::duration<unspecified >                operator ""s(long double); // C++14
constexpr chrono::milliseconds                          operator ""ms(unsigned long long); // C++14
constexpr chrono::duration<unspecified , milli>         operator ""ms(long double); // C++14
constexpr chrono::microseconds                          operator ""us(unsigned long long); // C++14
constexpr chrono::duration<unspecified , micro>         operator ""us(long double); // C++14
constexpr chrono::nanoseconds                           operator ""ns(unsigned long long); // C++14
constexpr chrono::duration<unspecified , nano>          operator ""ns(long double); // C++14
constexpr chrono::day                                   operator ""d(unsigned long long d) noexcept; // C++20
constexpr chrono::year                                  operator ""y(unsigned long long y) noexcept; // C++20
}  // chrono_literals
}  // literals

}  // std
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 826 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
# 827 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
#if 0 /* expanded by -frewrite-includes */
#include <ctime>
#endif /* expanded by -frewrite-includes */
# 827 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 1 3
// -*- C++ -*-
//===---------------------------- ctime -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CTIME
#define _LIBCPP_CTIME

/*
    ctime synopsis

Macros:

    NULL
    CLOCKS_PER_SEC
    TIME_UTC // C++17

namespace std
{

Types:

    clock_t
    size_t
    time_t
    tm
    timespec // C++17

clock_t clock();
double difftime(time_t time1, time_t time0);
time_t mktime(tm* timeptr);
time_t time(time_t* timer);
char* asctime(const tm* timeptr);
char* ctime(const time_t* timer);
tm*    gmtime(const time_t* timer);
tm* localtime(const time_t* timer);
size_t strftime(char* restrict s, size_t maxsize, const char* restrict format,
                const tm* restrict timeptr);
int timespec_get( struct timespec *ts, int base); // C++17
}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 48 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
# 49 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
#if 0 /* expanded by -frewrite-includes */
#include <time.h>
#endif /* expanded by -frewrite-includes */
# 49 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 52 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 53 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
#endif
# 54 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::clock_t;
using ::size_t;
using ::time_t;
using ::tm;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && defined(_LIBCPP_HAS_TIMESPEC_GET)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
using ::timespec;
#endif
# 64 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
using ::clock;
using ::difftime;
using ::mktime;
using ::time;
#ifndef _LIBCPP_HAS_NO_THREAD_UNSAFE_C_FUNCTIONS
using ::asctime;
using ::ctime;
using ::gmtime;
using ::localtime;
#endif
# 74 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
using ::strftime;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && defined(_LIBCPP_HAS_TIMESPEC_GET)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 76 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
using ::timespec_get;
#endif
# 78 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CTIME
# 82 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ctime" 3
# 828 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 828 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
# 829 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
#if 0 /* expanded by -frewrite-includes */
#include <ratio>
#endif /* expanded by -frewrite-includes */
# 829 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 1 3
// -*- C++ -*-
//===---------------------------- ratio -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_RATIO
#define _LIBCPP_RATIO

/*
    ratio synopsis

namespace std
{

template <intmax_t N, intmax_t D = 1>
class ratio
{
public:
    static constexpr intmax_t num;
    static constexpr intmax_t den;
    typedef ratio<num, den> type;
};

// ratio arithmetic
template <class R1, class R2> using ratio_add = ...;
template <class R1, class R2> using ratio_subtract = ...;
template <class R1, class R2> using ratio_multiply = ...;
template <class R1, class R2> using ratio_divide = ...;

// ratio comparison
template <class R1, class R2> struct ratio_equal;
template <class R1, class R2> struct ratio_not_equal;
template <class R1, class R2> struct ratio_less;
template <class R1, class R2> struct ratio_less_equal;
template <class R1, class R2> struct ratio_greater;
template <class R1, class R2> struct ratio_greater_equal;

// convenience SI typedefs
typedef ratio<1, 1000000000000000000000000> yocto;  // not supported
typedef ratio<1,    1000000000000000000000> zepto;  // not supported
typedef ratio<1,       1000000000000000000> atto;
typedef ratio<1,          1000000000000000> femto;
typedef ratio<1,             1000000000000> pico;
typedef ratio<1,                1000000000> nano;
typedef ratio<1,                   1000000> micro;
typedef ratio<1,                      1000> milli;
typedef ratio<1,                       100> centi;
typedef ratio<1,                        10> deci;
typedef ratio<                       10, 1> deca;
typedef ratio<                      100, 1> hecto;
typedef ratio<                     1000, 1> kilo;
typedef ratio<                  1000000, 1> mega;
typedef ratio<               1000000000, 1> giga;
typedef ratio<            1000000000000, 1> tera;
typedef ratio<         1000000000000000, 1> peta;
typedef ratio<      1000000000000000000, 1> exa;
typedef ratio<   1000000000000000000000, 1> zetta;  // not supported
typedef ratio<1000000000000000000000000, 1> yotta;  // not supported

  // 20.11.5, ratio comparison
  template <class R1, class R2> inline constexpr bool ratio_equal_v
    = ratio_equal<R1, R2>::value;                                       // C++17
  template <class R1, class R2> inline constexpr bool ratio_not_equal_v
    = ratio_not_equal<R1, R2>::value;                                   // C++17
  template <class R1, class R2> inline constexpr bool ratio_less_v
    = ratio_less<R1, R2>::value;                                        // C++17
  template <class R1, class R2> inline constexpr bool ratio_less_equal_v
    = ratio_less_equal<R1, R2>::value;                                  // C++17
  template <class R1, class R2> inline constexpr bool ratio_greater_v
    = ratio_greater<R1, R2>::value;                                     // C++17
  template <class R1, class R2> inline constexpr bool ratio_greater_equal_v
    = ratio_greater_equal<R1, R2>::value;                               // C++17
}
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 80 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
# 81 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 81 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
# 82 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
#if 0 /* expanded by -frewrite-includes */
#include <climits>
#endif /* expanded by -frewrite-includes */
# 82 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
# 83 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 83 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
# 84 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 86 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 87 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
#endif
# 88 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 90 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

// __static_gcd

template <intmax_t _Xp, intmax_t _Yp>
struct __static_gcd
{
    static const intmax_t value = __static_gcd<_Yp, _Xp % _Yp>::value;
};

template <intmax_t _Xp>
struct __static_gcd<_Xp, 0>
{
    static const intmax_t value = _Xp;
};

template <>
struct __static_gcd<0, 0>
{
    static const intmax_t value = 1;
};

// __static_lcm

template <intmax_t _Xp, intmax_t _Yp>
struct __static_lcm
{
    static const intmax_t value = _Xp / __static_gcd<_Xp, _Yp>::value * _Yp;
};

template <intmax_t _Xp>
struct __static_abs
{
    static const intmax_t value = _Xp < 0 ? -_Xp : _Xp;
};

template <intmax_t _Xp>
struct __static_sign
{
    static const intmax_t value = _Xp == 0 ? 0 : (_Xp < 0 ? -1 : 1);
};

template <intmax_t _Xp, intmax_t _Yp, intmax_t = __static_sign<_Yp>::value>
class __ll_add;

template <intmax_t _Xp, intmax_t _Yp>
class __ll_add<_Xp, _Yp, 1>
{
    static const intmax_t min = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1;
    static const intmax_t max = -min;

    static_assert(_Xp <= max - _Yp, "overflow in __ll_add");
public:
    static const intmax_t value = _Xp + _Yp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_add<_Xp, _Yp, 0>
{
public:
    static const intmax_t value = _Xp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_add<_Xp, _Yp, -1>
{
    static const intmax_t min = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1;
    static const intmax_t max = -min;

    static_assert(min - _Yp <= _Xp, "overflow in __ll_add");
public:
    static const intmax_t value = _Xp + _Yp;
};

template <intmax_t _Xp, intmax_t _Yp, intmax_t = __static_sign<_Yp>::value>
class __ll_sub;

template <intmax_t _Xp, intmax_t _Yp>
class __ll_sub<_Xp, _Yp, 1>
{
    static const intmax_t min = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1;
    static const intmax_t max = -min;

    static_assert(min + _Yp <= _Xp, "overflow in __ll_sub");
public:
    static const intmax_t value = _Xp - _Yp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_sub<_Xp, _Yp, 0>
{
public:
    static const intmax_t value = _Xp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_sub<_Xp, _Yp, -1>
{
    static const intmax_t min = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1;
    static const intmax_t max = -min;

    static_assert(_Xp <= max + _Yp, "overflow in __ll_sub");
public:
    static const intmax_t value = _Xp - _Yp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_mul
{
    static const intmax_t nan = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1));
    static const intmax_t min = nan + 1;
    static const intmax_t max = -min;
    static const intmax_t __a_x = __static_abs<_Xp>::value;
    static const intmax_t __a_y = __static_abs<_Yp>::value;

    static_assert(_Xp != nan && _Yp != nan && __a_x <= max / __a_y, "overflow in __ll_mul");
public:
    static const intmax_t value = _Xp * _Yp;
};

template <intmax_t _Yp>
class __ll_mul<0, _Yp>
{
public:
    static const intmax_t value = 0;
};

template <intmax_t _Xp>
class __ll_mul<_Xp, 0>
{
public:
    static const intmax_t value = 0;
};

template <>
class __ll_mul<0, 0>
{
public:
    static const intmax_t value = 0;
};

// Not actually used but left here in case needed in future maintenance
template <intmax_t _Xp, intmax_t _Yp>
class __ll_div
{
    static const intmax_t nan = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1));
    static const intmax_t min = nan + 1;
    static const intmax_t max = -min;

    static_assert(_Xp != nan && _Yp != nan && _Yp != 0, "overflow in __ll_div");
public:
    static const intmax_t value = _Xp / _Yp;
};

template <intmax_t _Num, intmax_t _Den = 1>
class _LIBCPP_TEMPLATE_VIS ratio
{
    static_assert(__static_abs<_Num>::value >= 0, "ratio numerator is out of range");
    static_assert(_Den != 0, "ratio divide by 0");
    static_assert(__static_abs<_Den>::value >  0, "ratio denominator is out of range");
    static _LIBCPP_CONSTEXPR const intmax_t __na = __static_abs<_Num>::value;
    static _LIBCPP_CONSTEXPR const intmax_t __da = __static_abs<_Den>::value;
    static _LIBCPP_CONSTEXPR const intmax_t __s = __static_sign<_Num>::value * __static_sign<_Den>::value;
    static _LIBCPP_CONSTEXPR const intmax_t __gcd = __static_gcd<__na, __da>::value;
public:
    static _LIBCPP_CONSTEXPR const intmax_t num = __s * __na / __gcd;
    static _LIBCPP_CONSTEXPR const intmax_t den = __da / __gcd;

    typedef ratio<num, den> type;
};

template <intmax_t _Num, intmax_t _Den>
_LIBCPP_CONSTEXPR const intmax_t ratio<_Num, _Den>::num;

template <intmax_t _Num, intmax_t _Den>
_LIBCPP_CONSTEXPR const intmax_t ratio<_Num, _Den>::den;

template <class _Tp>                    struct __is_ratio                     : false_type {};
template <intmax_t _Num, intmax_t _Den> struct __is_ratio<ratio<_Num, _Den> > : true_type  {};

typedef ratio<1LL, 1000000000000000000LL> atto;
typedef ratio<1LL,    1000000000000000LL> femto;
typedef ratio<1LL,       1000000000000LL> pico;
typedef ratio<1LL,          1000000000LL> nano;
typedef ratio<1LL,             1000000LL> micro;
typedef ratio<1LL,                1000LL> milli;
typedef ratio<1LL,                 100LL> centi;
typedef ratio<1LL,                  10LL> deci;
typedef ratio<                 10LL, 1LL> deca;
typedef ratio<                100LL, 1LL> hecto;
typedef ratio<               1000LL, 1LL> kilo;
typedef ratio<            1000000LL, 1LL> mega;
typedef ratio<         1000000000LL, 1LL> giga;
typedef ratio<      1000000000000LL, 1LL> tera;
typedef ratio<   1000000000000000LL, 1LL> peta;
typedef ratio<1000000000000000000LL, 1LL> exa;

template <class _R1, class _R2>
struct __ratio_multiply
{
private:
    static const intmax_t __gcd_n1_d2 = __static_gcd<_R1::num, _R2::den>::value;
    static const intmax_t __gcd_d1_n2 = __static_gcd<_R1::den, _R2::num>::value;
public:
    typedef typename ratio
        <
            __ll_mul<_R1::num / __gcd_n1_d2, _R2::num / __gcd_d1_n2>::value,
            __ll_mul<_R2::den / __gcd_n1_d2, _R1::den / __gcd_d1_n2>::value
        >::type type;
};

#ifndef _LIBCPP_CXX03_LANG

template <class _R1, class _R2> using ratio_multiply
                                    = typename __ratio_multiply<_R1, _R2>::type;

#else  // _LIBCPP_CXX03_LANG
# 310 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_multiply
    : public __ratio_multiply<_R1, _R2>::type {};

#endif  // _LIBCPP_CXX03_LANG
# 316 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct __ratio_divide
{
private:
    static const intmax_t __gcd_n1_n2 = __static_gcd<_R1::num, _R2::num>::value;
    static const intmax_t __gcd_d1_d2 = __static_gcd<_R1::den, _R2::den>::value;
public:
    typedef typename ratio
        <
            __ll_mul<_R1::num / __gcd_n1_n2, _R2::den / __gcd_d1_d2>::value,
            __ll_mul<_R2::num / __gcd_n1_n2, _R1::den / __gcd_d1_d2>::value
        >::type type;
};

#ifndef _LIBCPP_CXX03_LANG

template <class _R1, class _R2> using ratio_divide
                                      = typename __ratio_divide<_R1, _R2>::type;

#else  // _LIBCPP_CXX03_LANG
# 337 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_divide
    : public __ratio_divide<_R1, _R2>::type {};

#endif  // _LIBCPP_CXX03_LANG
# 343 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct __ratio_add
{
private:
    static const intmax_t __gcd_n1_n2 = __static_gcd<_R1::num, _R2::num>::value;
    static const intmax_t __gcd_d1_d2 = __static_gcd<_R1::den, _R2::den>::value;
public:
    typedef typename ratio_multiply
        <
            ratio<__gcd_n1_n2, _R1::den / __gcd_d1_d2>,
            ratio
            <
                __ll_add
                <
                    __ll_mul<_R1::num / __gcd_n1_n2, _R2::den / __gcd_d1_d2>::value,
                    __ll_mul<_R2::num / __gcd_n1_n2, _R1::den / __gcd_d1_d2>::value
                >::value,
                _R2::den
            >
        >::type type;
};

#ifndef _LIBCPP_CXX03_LANG

template <class _R1, class _R2> using ratio_add
                                         = typename __ratio_add<_R1, _R2>::type;

#else  // _LIBCPP_CXX03_LANG
# 372 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_add
    : public __ratio_add<_R1, _R2>::type {};

#endif  // _LIBCPP_CXX03_LANG
# 378 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct __ratio_subtract
{
private:
    static const intmax_t __gcd_n1_n2 = __static_gcd<_R1::num, _R2::num>::value;
    static const intmax_t __gcd_d1_d2 = __static_gcd<_R1::den, _R2::den>::value;
public:
    typedef typename ratio_multiply
        <
            ratio<__gcd_n1_n2, _R1::den / __gcd_d1_d2>,
            ratio
            <
                __ll_sub
                <
                    __ll_mul<_R1::num / __gcd_n1_n2, _R2::den / __gcd_d1_d2>::value,
                    __ll_mul<_R2::num / __gcd_n1_n2, _R1::den / __gcd_d1_d2>::value
                >::value,
                _R2::den
            >
        >::type type;
};

#ifndef _LIBCPP_CXX03_LANG

template <class _R1, class _R2> using ratio_subtract
                                    = typename __ratio_subtract<_R1, _R2>::type;

#else  // _LIBCPP_CXX03_LANG
# 407 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_subtract
    : public __ratio_subtract<_R1, _R2>::type {};

#endif  // _LIBCPP_CXX03_LANG
# 413 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

// ratio_equal

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_equal
    : public _LIBCPP_BOOL_CONSTANT((_R1::num == _R2::num && _R1::den == _R2::den)) {};

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_not_equal
    : public _LIBCPP_BOOL_CONSTANT((!ratio_equal<_R1, _R2>::value)) {};

// ratio_less

template <class _R1, class _R2, bool _Odd = false,
          intmax_t _Q1 = _R1::num / _R1::den, intmax_t _M1 = _R1::num % _R1::den,
          intmax_t _Q2 = _R2::num / _R2::den, intmax_t _M2 = _R2::num % _R2::den>
struct __ratio_less1
{
    static const bool value = _Odd ? _Q2 < _Q1 : _Q1 < _Q2;
};

template <class _R1, class _R2, bool _Odd, intmax_t _Qp>
struct __ratio_less1<_R1, _R2, _Odd, _Qp, 0, _Qp, 0>
{
    static const bool value = false;
};

template <class _R1, class _R2, bool _Odd, intmax_t _Qp, intmax_t _M2>
struct __ratio_less1<_R1, _R2, _Odd, _Qp, 0, _Qp, _M2>
{
    static const bool value = !_Odd;
};

template <class _R1, class _R2, bool _Odd, intmax_t _Qp, intmax_t _M1>
struct __ratio_less1<_R1, _R2, _Odd, _Qp, _M1, _Qp, 0>
{
    static const bool value = _Odd;
};

template <class _R1, class _R2, bool _Odd, intmax_t _Qp, intmax_t _M1,
                                                        intmax_t _M2>
struct __ratio_less1<_R1, _R2, _Odd, _Qp, _M1, _Qp, _M2>
{
    static const bool value = __ratio_less1<ratio<_R1::den, _M1>,
                                            ratio<_R2::den, _M2>, !_Odd>::value;
};

template <class _R1, class _R2, intmax_t _S1 = __static_sign<_R1::num>::value,
                                intmax_t _S2 = __static_sign<_R2::num>::value>
struct __ratio_less
{
    static const bool value = _S1 < _S2;
};

template <class _R1, class _R2>
struct __ratio_less<_R1, _R2, 1LL, 1LL>
{
    static const bool value = __ratio_less1<_R1, _R2>::value;
};

template <class _R1, class _R2>
struct __ratio_less<_R1, _R2, -1LL, -1LL>
{
    static const bool value = __ratio_less1<ratio<-_R2::num, _R2::den>, ratio<-_R1::num, _R1::den> >::value;
};

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_less
    : public _LIBCPP_BOOL_CONSTANT((__ratio_less<_R1, _R2>::value)) {};

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_less_equal
    : public _LIBCPP_BOOL_CONSTANT((!ratio_less<_R2, _R1>::value)) {};

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_greater
    : public _LIBCPP_BOOL_CONSTANT((ratio_less<_R2, _R1>::value)) {};

template <class _R1, class _R2>
struct _LIBCPP_TEMPLATE_VIS ratio_greater_equal
    : public _LIBCPP_BOOL_CONSTANT((!ratio_less<_R1, _R2>::value)) {};

template <class _R1, class _R2>
struct __ratio_gcd
{
    typedef ratio<__static_gcd<_R1::num, _R2::num>::value,
                  __static_lcm<_R1::den, _R2::den>::value> type;
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 503 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
template <class _R1, class _R2>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool ratio_equal_v
    = ratio_equal<_R1, _R2>::value;

template <class _R1, class _R2>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool ratio_not_equal_v
    = ratio_not_equal<_R1, _R2>::value;

template <class _R1, class _R2>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool ratio_less_v
    = ratio_less<_R1, _R2>::value;

template <class _R1, class _R2>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool ratio_less_equal_v
    = ratio_less_equal<_R1, _R2>::value;

template <class _R1, class _R2>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool ratio_greater_v
    = ratio_greater<_R1, _R2>::value;

template <class _R1, class _R2>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool ratio_greater_equal_v
    = ratio_greater_equal<_R1, _R2>::value;
#endif
# 527 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3

_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_RATIO
# 533 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/ratio" 3
# 830 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 830 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
# 831 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 831 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
# 832 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 834 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 835 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
#endif
# 836 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 838 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 839 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 2 3

#ifndef _LIBCPP_CXX03_LANG
_LIBCPP_BEGIN_NAMESPACE_FILESYSTEM
struct _FilesystemClock;
_LIBCPP_END_NAMESPACE_FILESYSTEM
#endif // !_LIBCPP_CXX03_LANG
# 845 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

_LIBCPP_BEGIN_NAMESPACE_STD

namespace chrono
{

template <class _Rep, class _Period = ratio<1> > class _LIBCPP_TEMPLATE_VIS duration;

template <class _Tp>
struct __is_duration : false_type {};

template <class _Rep, class _Period>
struct __is_duration<duration<_Rep, _Period> > : true_type  {};

template <class _Rep, class _Period>
struct __is_duration<const duration<_Rep, _Period> > : true_type  {};

template <class _Rep, class _Period>
struct __is_duration<volatile duration<_Rep, _Period> > : true_type  {};

template <class _Rep, class _Period>
struct __is_duration<const volatile duration<_Rep, _Period> > : true_type  {};

} // chrono

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
struct _LIBCPP_TEMPLATE_VIS common_type<chrono::duration<_Rep1, _Period1>,
                                         chrono::duration<_Rep2, _Period2> >
{
    typedef chrono::duration<typename common_type<_Rep1, _Rep2>::type,
                             typename __ratio_gcd<_Period1, _Period2>::type> type;
};

namespace chrono {

// duration_cast

template <class _FromDuration, class _ToDuration,
          class _Period = typename ratio_divide<typename _FromDuration::period, typename _ToDuration::period>::type,
          bool = _Period::num == 1,
          bool = _Period::den == 1>
struct __duration_cast;

template <class _FromDuration, class _ToDuration, class _Period>
struct __duration_cast<_FromDuration, _ToDuration, _Period, true, true>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    _ToDuration operator()(const _FromDuration& __fd) const
    {
        return _ToDuration(static_cast<typename _ToDuration::rep>(__fd.count()));
    }
};

template <class _FromDuration, class _ToDuration, class _Period>
struct __duration_cast<_FromDuration, _ToDuration, _Period, true, false>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    _ToDuration operator()(const _FromDuration& __fd) const
    {
        typedef typename common_type<typename _ToDuration::rep, typename _FromDuration::rep, intmax_t>::type _Ct;
        return _ToDuration(static_cast<typename _ToDuration::rep>(
                           static_cast<_Ct>(__fd.count()) / static_cast<_Ct>(_Period::den)));
    }
};

template <class _FromDuration, class _ToDuration, class _Period>
struct __duration_cast<_FromDuration, _ToDuration, _Period, false, true>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    _ToDuration operator()(const _FromDuration& __fd) const
    {
        typedef typename common_type<typename _ToDuration::rep, typename _FromDuration::rep, intmax_t>::type _Ct;
        return _ToDuration(static_cast<typename _ToDuration::rep>(
                           static_cast<_Ct>(__fd.count()) * static_cast<_Ct>(_Period::num)));
    }
};

template <class _FromDuration, class _ToDuration, class _Period>
struct __duration_cast<_FromDuration, _ToDuration, _Period, false, false>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    _ToDuration operator()(const _FromDuration& __fd) const
    {
        typedef typename common_type<typename _ToDuration::rep, typename _FromDuration::rep, intmax_t>::type _Ct;
        return _ToDuration(static_cast<typename _ToDuration::rep>(
                           static_cast<_Ct>(__fd.count()) * static_cast<_Ct>(_Period::num)
                                                          / static_cast<_Ct>(_Period::den)));
    }
};

template <class _ToDuration, class _Rep, class _Period>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename enable_if
<
    __is_duration<_ToDuration>::value,
    _ToDuration
>::type
duration_cast(const duration<_Rep, _Period>& __fd)
{
    return __duration_cast<duration<_Rep, _Period>, _ToDuration>()(__fd);
}

template <class _Rep>
struct _LIBCPP_TEMPLATE_VIS treat_as_floating_point : is_floating_point<_Rep> {};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14 && !defined(_LIBCPP_HAS_NO_VARIABLE_TEMPLATES)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 952 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
template <class _Rep>
_LIBCPP_INLINE_VAR _LIBCPP_CONSTEXPR bool treat_as_floating_point_v
    = treat_as_floating_point<_Rep>::value;
#endif
# 956 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

template <class _Rep>
struct _LIBCPP_TEMPLATE_VIS duration_values
{
public:
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR _Rep zero() _NOEXCEPT {return _Rep(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR _Rep max()  _NOEXCEPT {return numeric_limits<_Rep>::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR _Rep min()  _NOEXCEPT {return numeric_limits<_Rep>::lowest();}
};

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 967 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
template <class _ToDuration, class _Rep, class _Period>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    __is_duration<_ToDuration>::value,
    _ToDuration
>::type
floor(const duration<_Rep, _Period>& __d)
{
    _ToDuration __t = duration_cast<_ToDuration>(__d);
    if (__t > __d)
        __t = __t - _ToDuration{1};
    return __t;
}

template <class _ToDuration, class _Rep, class _Period>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    __is_duration<_ToDuration>::value,
    _ToDuration
>::type
ceil(const duration<_Rep, _Period>& __d)
{
    _ToDuration __t = duration_cast<_ToDuration>(__d);
    if (__t < __d)
        __t = __t + _ToDuration{1};
    return __t;
}

template <class _ToDuration, class _Rep, class _Period>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    __is_duration<_ToDuration>::value,
    _ToDuration
>::type
round(const duration<_Rep, _Period>& __d)
{
    _ToDuration __lower = floor<_ToDuration>(__d);
    _ToDuration __upper = __lower + _ToDuration{1};
    auto __lowerDiff = __d - __lower;
    auto __upperDiff = __upper - __d;
    if (__lowerDiff < __upperDiff)
        return __lower;
    if (__lowerDiff > __upperDiff)
        return __upper;
    return __lower.count() & 1 ? __upper : __lower;
}
#endif
# 1017 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

// duration

template <class _Rep, class _Period>
class _LIBCPP_TEMPLATE_VIS duration
{
    static_assert(!__is_duration<_Rep>::value, "A duration representation can not be a duration");
    static_assert(__is_ratio<_Period>::value, "Second template parameter of duration must be a std::ratio");
    static_assert(_Period::num > 0, "duration period must be positive");

    template <class _R1, class _R2>
    struct __no_overflow
    {
    private:
        static const intmax_t __gcd_n1_n2 = __static_gcd<_R1::num, _R2::num>::value;
        static const intmax_t __gcd_d1_d2 = __static_gcd<_R1::den, _R2::den>::value;
        static const intmax_t __n1 = _R1::num / __gcd_n1_n2;
        static const intmax_t __d1 = _R1::den / __gcd_d1_d2;
        static const intmax_t __n2 = _R2::num / __gcd_n1_n2;
        static const intmax_t __d2 = _R2::den / __gcd_d1_d2;
        static const intmax_t max = -((intmax_t(1) << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1);

        template <intmax_t _Xp, intmax_t _Yp, bool __overflow>
        struct __mul    // __overflow == false
        {
            static const intmax_t value = _Xp * _Yp;
        };

        template <intmax_t _Xp, intmax_t _Yp>
        struct __mul<_Xp, _Yp, true>
        {
            static const intmax_t value = 1;
        };

    public:
        static const bool value = (__n1 <= max / __d2) && (__n2 <= max / __d1);
        typedef ratio<__mul<__n1, __d2, !value>::value,
                      __mul<__n2, __d1, !value>::value> type;
    };

public:
    typedef _Rep rep;
    typedef typename _Period::type period;
private:
    rep __rep_;
public:

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
#ifndef _LIBCPP_CXX03_LANG
        duration() = default;
#else
# 1068 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
        duration() {}
#endif
# 1070 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

    template <class _Rep2>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
        explicit duration(const _Rep2& __r,
            typename enable_if
            <
               is_convertible<_Rep2, rep>::value &&
               (treat_as_floating_point<rep>::value ||
               !treat_as_floating_point<_Rep2>::value)
            >::type* = 0)
                : __rep_(__r) {}

    // conversions
    template <class _Rep2, class _Period2>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
        duration(const duration<_Rep2, _Period2>& __d,
            typename enable_if
            <
                __no_overflow<_Period2, period>::value && (
                treat_as_floating_point<rep>::value ||
                (__no_overflow<_Period2, period>::type::den == 1 &&
                 !treat_as_floating_point<_Rep2>::value))
            >::type* = 0)
                : __rep_(_VSTD::chrono::duration_cast<duration>(__d).count()) {}

    // observer

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR rep count() const {return __rep_;}

    // arithmetic

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR typename common_type<duration>::type operator+() const {return typename common_type<duration>::type(*this);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR typename common_type<duration>::type operator-() const {return typename common_type<duration>::type(-__rep_);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration& operator++()      {++__rep_; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration  operator++(int)   {return duration(__rep_++);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration& operator--()      {--__rep_; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration  operator--(int)   {return duration(__rep_--);}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration& operator+=(const duration& __d) {__rep_ += __d.count(); return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration& operator-=(const duration& __d) {__rep_ -= __d.count(); return *this;}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration& operator*=(const rep& rhs) {__rep_ *= rhs; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration& operator/=(const rep& rhs) {__rep_ /= rhs; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration& operator%=(const rep& rhs) {__rep_ %= rhs; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 duration& operator%=(const duration& rhs) {__rep_ %= rhs.count(); return *this;}

    // special values

    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR duration zero() _NOEXCEPT {return duration(duration_values<rep>::zero());}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR duration min()  _NOEXCEPT {return duration(duration_values<rep>::min());}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR duration max()  _NOEXCEPT {return duration(duration_values<rep>::max());}
};

typedef duration<long long,         nano> nanoseconds;
typedef duration<long long,        micro> microseconds;
typedef duration<long long,        milli> milliseconds;
typedef duration<long long              > seconds;
typedef duration<     long, ratio<  60> > minutes;
typedef duration<     long, ratio<3600> > hours;
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1130 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
typedef duration<     int, ratio_multiply<ratio<24>, hours::period>>         days;
typedef duration<     int, ratio_multiply<ratio<7>,   days::period>>         weeks;
typedef duration<     int, ratio_multiply<ratio<146097, 400>, days::period>> years;
typedef duration<     int, ratio_divide<years::period, ratio<12>>>           months;
#endif
# 1135 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
// Duration ==

template <class _LhsDuration, class _RhsDuration>
struct __duration_eq
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool operator()(const _LhsDuration& __lhs, const _RhsDuration& __rhs) const
        {
            typedef typename common_type<_LhsDuration, _RhsDuration>::type _Ct;
            return _Ct(__lhs).count() == _Ct(__rhs).count();
        }
};

template <class _LhsDuration>
struct __duration_eq<_LhsDuration, _LhsDuration>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool operator()(const _LhsDuration& __lhs, const _LhsDuration& __rhs) const
        {return __lhs.count() == __rhs.count();}
};

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator==(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return __duration_eq<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >()(__lhs, __rhs);
}

// Duration !=

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator!=(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return !(__lhs == __rhs);
}

// Duration <

template <class _LhsDuration, class _RhsDuration>
struct __duration_lt
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool operator()(const _LhsDuration& __lhs, const _RhsDuration& __rhs) const
        {
            typedef typename common_type<_LhsDuration, _RhsDuration>::type _Ct;
            return _Ct(__lhs).count() < _Ct(__rhs).count();
        }
};

template <class _LhsDuration>
struct __duration_lt<_LhsDuration, _LhsDuration>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool operator()(const _LhsDuration& __lhs, const _LhsDuration& __rhs) const
        {return __lhs.count() < __rhs.count();}
};

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator< (const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return __duration_lt<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >()(__lhs, __rhs);
}

// Duration >

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator> (const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return __rhs < __lhs;
}

// Duration <=

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator<=(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return !(__rhs < __lhs);
}

// Duration >=

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator>=(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return !(__lhs < __rhs);
}

// Duration +

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type
operator+(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type _Cd;
    return _Cd(_Cd(__lhs).count() + _Cd(__rhs).count());
}

// Duration -

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type
operator-(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type _Cd;
    return _Cd(_Cd(__lhs).count() - _Cd(__rhs).count());
}

// Duration *

template <class _Rep1, class _Period, class _Rep2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename enable_if
<
    is_convertible<_Rep2, typename common_type<_Rep1, _Rep2>::type>::value,
    duration<typename common_type<_Rep1, _Rep2>::type, _Period>
>::type
operator*(const duration<_Rep1, _Period>& __d, const _Rep2& __s)
{
    typedef typename common_type<_Rep1, _Rep2>::type _Cr;
    typedef duration<_Cr, _Period> _Cd;
    return _Cd(_Cd(__d).count() * static_cast<_Cr>(__s));
}

template <class _Rep1, class _Period, class _Rep2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename enable_if
<
    is_convertible<_Rep1, typename common_type<_Rep1, _Rep2>::type>::value,
    duration<typename common_type<_Rep1, _Rep2>::type, _Period>
>::type
operator*(const _Rep1& __s, const duration<_Rep2, _Period>& __d)
{
    return __d * __s;
}

// Duration /

template <class _Rep1, class _Period, class _Rep2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename enable_if
<
    !__is_duration<_Rep2>::value &&
      is_convertible<_Rep2, typename common_type<_Rep1, _Rep2>::type>::value,
    duration<typename common_type<_Rep1, _Rep2>::type, _Period>
>::type
operator/(const duration<_Rep1, _Period>& __d, const _Rep2& __s)
{
    typedef typename common_type<_Rep1, _Rep2>::type _Cr;
    typedef duration<_Cr, _Period> _Cd;
    return _Cd(_Cd(__d).count() / static_cast<_Cr>(__s));
}

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename common_type<_Rep1, _Rep2>::type
operator/(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type _Ct;
    return _Ct(__lhs).count() / _Ct(__rhs).count();
}

// Duration %

template <class _Rep1, class _Period, class _Rep2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename enable_if
<
    !__is_duration<_Rep2>::value &&
      is_convertible<_Rep2, typename common_type<_Rep1, _Rep2>::type>::value,
    duration<typename common_type<_Rep1, _Rep2>::type, _Period>
>::type
operator%(const duration<_Rep1, _Period>& __d, const _Rep2& __s)
{
    typedef typename common_type<_Rep1, _Rep2>::type _Cr;
    typedef duration<_Cr, _Period> _Cd;
    return _Cd(_Cd(__d).count() % static_cast<_Cr>(__s));
}

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type
operator%(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef typename common_type<_Rep1, _Rep2>::type _Cr;
    typedef typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type _Cd;
    return _Cd(static_cast<_Cr>(_Cd(__lhs).count()) % static_cast<_Cr>(_Cd(__rhs).count()));
}

//////////////////////////////////////////////////////////
///////////////////// time_point /////////////////////////
//////////////////////////////////////////////////////////

template <class _Clock, class _Duration = typename _Clock::duration>
class _LIBCPP_TEMPLATE_VIS time_point
{
    static_assert(__is_duration<_Duration>::value,
                  "Second template parameter of time_point must be a std::chrono::duration");
public:
    typedef _Clock                    clock;
    typedef _Duration                 duration;
    typedef typename duration::rep    rep;
    typedef typename duration::period period;
private:
    duration __d_;

public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 time_point() : __d_(duration::zero()) {}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 explicit time_point(const duration& __d) : __d_(__d) {}

    // conversions
    template <class _Duration2>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    time_point(const time_point<clock, _Duration2>& t,
        typename enable_if
        <
            is_convertible<_Duration2, duration>::value
        >::type* = 0)
            : __d_(t.time_since_epoch()) {}

    // observer

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 duration time_since_epoch() const {return __d_;}

    // arithmetic

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 time_point& operator+=(const duration& __d) {__d_ += __d; return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX14 time_point& operator-=(const duration& __d) {__d_ -= __d; return *this;}

    // special values

    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR time_point min() _NOEXCEPT {return time_point(duration::min());}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR time_point max() _NOEXCEPT {return time_point(duration::max());}
};

} // chrono

template <class _Clock, class _Duration1, class _Duration2>
struct _LIBCPP_TEMPLATE_VIS common_type<chrono::time_point<_Clock, _Duration1>,
                                         chrono::time_point<_Clock, _Duration2> >
{
    typedef chrono::time_point<_Clock, typename common_type<_Duration1, _Duration2>::type> type;
};

namespace chrono {

template <class _ToDuration, class _Clock, class _Duration>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
time_point<_Clock, _ToDuration>
time_point_cast(const time_point<_Clock, _Duration>& __t)
{
    return time_point<_Clock, _ToDuration>(_VSTD::chrono::duration_cast<_ToDuration>(__t.time_since_epoch()));
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1416 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
template <class _ToDuration, class _Clock, class _Duration>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    __is_duration<_ToDuration>::value,
    time_point<_Clock, _ToDuration>
>::type
floor(const time_point<_Clock, _Duration>& __t)
{
    return time_point<_Clock, _ToDuration>{floor<_ToDuration>(__t.time_since_epoch())};
}

template <class _ToDuration, class _Clock, class _Duration>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    __is_duration<_ToDuration>::value,
    time_point<_Clock, _ToDuration>
>::type
ceil(const time_point<_Clock, _Duration>& __t)
{
    return time_point<_Clock, _ToDuration>{ceil<_ToDuration>(__t.time_since_epoch())};
}

template <class _ToDuration, class _Clock, class _Duration>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    __is_duration<_ToDuration>::value,
    time_point<_Clock, _ToDuration>
>::type
round(const time_point<_Clock, _Duration>& __t)
{
    return time_point<_Clock, _ToDuration>{round<_ToDuration>(__t.time_since_epoch())};
}

template <class _Rep, class _Period>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
typename enable_if
<
    numeric_limits<_Rep>::is_signed,
    duration<_Rep, _Period>
>::type
abs(duration<_Rep, _Period> __d)
{
    return __d >= __d.zero() ? +__d : -__d;
}
#endif
# 1464 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

// time_point ==

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator==(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __lhs.time_since_epoch() == __rhs.time_since_epoch();
}

// time_point !=

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator!=(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return !(__lhs == __rhs);
}

// time_point <

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __lhs.time_since_epoch() < __rhs.time_since_epoch();
}

// time_point >

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __rhs < __lhs;
}

// time_point <=

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<=(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return !(__rhs < __lhs);
}

// time_point >=

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>=(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return !(__lhs < __rhs);
}

// time_point operator+(time_point x, duration y);

template <class _Clock, class _Duration1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
time_point<_Clock, typename common_type<_Duration1, duration<_Rep2, _Period2> >::type>
operator+(const time_point<_Clock, _Duration1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef time_point<_Clock, typename common_type<_Duration1, duration<_Rep2, _Period2> >::type> _Tr;
    return _Tr (__lhs.time_since_epoch() + __rhs);
}

// time_point operator+(duration x, time_point y);

template <class _Rep1, class _Period1, class _Clock, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
time_point<_Clock, typename common_type<duration<_Rep1, _Period1>, _Duration2>::type>
operator+(const duration<_Rep1, _Period1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __rhs + __lhs;
}

// time_point operator-(time_point x, duration y);

template <class _Clock, class _Duration1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
time_point<_Clock, typename common_type<_Duration1, duration<_Rep2, _Period2> >::type>
operator-(const time_point<_Clock, _Duration1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef time_point<_Clock, typename common_type<_Duration1, duration<_Rep2, _Period2> >::type> _Ret;
    return _Ret(__lhs.time_since_epoch() -__rhs);
}

// duration operator-(time_point x, time_point y);

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename common_type<_Duration1, _Duration2>::type
operator-(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __lhs.time_since_epoch() - __rhs.time_since_epoch();
}

//////////////////////////////////////////////////////////
/////////////////////// clocks ///////////////////////////
//////////////////////////////////////////////////////////

class _LIBCPP_TYPE_VIS system_clock
{
public:
    typedef microseconds                     duration;
    typedef duration::rep                    rep;
    typedef duration::period                 period;
    typedef chrono::time_point<system_clock> time_point;
    static _LIBCPP_CONSTEXPR_AFTER_CXX11 const bool is_steady = false;

    static time_point now() _NOEXCEPT;
    static time_t     to_time_t  (const time_point& __t) _NOEXCEPT;
    static time_point from_time_t(time_t __t) _NOEXCEPT;
};

#ifndef _LIBCPP_HAS_NO_MONOTONIC_CLOCK
class _LIBCPP_TYPE_VIS steady_clock
{
public:
    typedef nanoseconds                                   duration;
    typedef duration::rep                                 rep;
    typedef duration::period                              period;
    typedef chrono::time_point<steady_clock, duration>    time_point;
    static _LIBCPP_CONSTEXPR_AFTER_CXX11 const bool is_steady = true;

    static time_point now() _NOEXCEPT;
};

typedef steady_clock high_resolution_clock;
#else
# 1600 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
typedef system_clock high_resolution_clock;
#endif
# 1602 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1604 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
// [time.clock.file], type file_clock
using file_clock = _VSTD_FS::_FilesystemClock;

template<class _Duration>
using file_time = time_point<file_clock, _Duration>;


template <class _Duration>
using sys_time    = time_point<system_clock, _Duration>;
using sys_seconds = sys_time<seconds>;
using sys_days    = sys_time<days>;

struct local_t {};
template<class Duration>
using local_time  = time_point<local_t, Duration>;
using local_seconds = local_time<seconds>;
using local_days    = local_time<days>;


struct last_spec { explicit last_spec() = default; };

class day {
private:
    unsigned char __d;
public:
    day() = default;
    explicit inline constexpr day(unsigned __val) noexcept : __d(static_cast<unsigned char>(__val)) {}
    inline constexpr day& operator++()    noexcept { ++__d; return *this; }
    inline constexpr day  operator++(int) noexcept { day __tmp = *this; ++(*this); return __tmp; }
    inline constexpr day& operator--()    noexcept { --__d; return *this; }
    inline constexpr day  operator--(int) noexcept { day __tmp = *this; --(*this); return __tmp; }
           constexpr day& operator+=(const days& __dd) noexcept;
           constexpr day& operator-=(const days& __dd) noexcept;
    explicit inline constexpr operator unsigned() const noexcept { return __d; }
    inline constexpr bool ok() const noexcept { return __d >= 1 && __d <= 31; }
  };


inline constexpr
bool operator==(const day& __lhs, const day& __rhs) noexcept
{ return static_cast<unsigned>(__lhs) == static_cast<unsigned>(__rhs); }

inline constexpr
bool operator!=(const day& __lhs, const day& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
bool operator< (const day& __lhs, const day& __rhs) noexcept
{ return static_cast<unsigned>(__lhs) <  static_cast<unsigned>(__rhs); }

inline constexpr
bool operator> (const day& __lhs, const day& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const day& __lhs, const day& __rhs) noexcept
{ return !(__rhs < __lhs);}

inline constexpr
bool operator>=(const day& __lhs, const day& __rhs) noexcept
{ return !(__lhs < __rhs); }

inline constexpr
day operator+ (const day& __lhs, const days& __rhs) noexcept
{ return day(static_cast<unsigned>(__lhs) + __rhs.count()); }

inline constexpr
day operator+ (const days& __lhs, const day& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
day operator- (const day& __lhs, const days& __rhs) noexcept
{ return __lhs + -__rhs; }

inline constexpr
days operator-(const day& __lhs, const day& __rhs) noexcept
{ return days(static_cast<int>(static_cast<unsigned>(__lhs)) -
              static_cast<int>(static_cast<unsigned>(__rhs))); }

inline constexpr day& day::operator+=(const days& __dd) noexcept
{ *this = *this + __dd; return *this; }

inline constexpr day& day::operator-=(const days& __dd) noexcept
{ *this = *this - __dd; return *this; }


class month {
private:
    unsigned char __m;
public:
    month() = default;
    explicit inline constexpr month(unsigned __val) noexcept : __m(static_cast<unsigned char>(__val)) {}
    inline constexpr month& operator++()    noexcept { ++__m; return *this; }
    inline constexpr month  operator++(int) noexcept { month __tmp = *this; ++(*this); return __tmp; }
    inline constexpr month& operator--()    noexcept { --__m; return *this; }
    inline constexpr month  operator--(int) noexcept { month __tmp = *this; --(*this); return __tmp; }
           constexpr month& operator+=(const months& __m1) noexcept;
           constexpr month& operator-=(const months& __m1) noexcept;
    explicit inline constexpr operator unsigned() const noexcept { return __m; }
    inline constexpr bool ok() const noexcept { return __m >= 1 && __m <= 12; }
};


inline constexpr
bool operator==(const month& __lhs, const month& __rhs) noexcept
{ return static_cast<unsigned>(__lhs) == static_cast<unsigned>(__rhs); }

inline constexpr
bool operator!=(const month& __lhs, const month& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
bool operator< (const month& __lhs, const month& __rhs) noexcept
{ return static_cast<unsigned>(__lhs)  < static_cast<unsigned>(__rhs); }

inline constexpr
bool operator> (const month& __lhs, const month& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const month& __lhs, const month& __rhs) noexcept
{ return !(__rhs < __lhs); }

inline constexpr
bool operator>=(const month& __lhs, const month& __rhs) noexcept
{ return !(__lhs < __rhs); }

inline constexpr
month operator+ (const month& __lhs, const months& __rhs) noexcept
{
    auto const __mu = static_cast<long long>(static_cast<unsigned>(__lhs)) + (__rhs.count() - 1);
    auto const __yr = (__mu >= 0 ? __mu : __mu - 11) / 12;
    return month{static_cast<unsigned>(__mu - __yr * 12 + 1)};
}

inline constexpr
month operator+ (const months& __lhs, const month& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
month operator- (const month& __lhs, const months& __rhs) noexcept
{ return __lhs + -__rhs; }

inline constexpr
months operator-(const month& __lhs, const month& __rhs) noexcept
{
    auto const __dm = static_cast<unsigned>(__lhs) - static_cast<unsigned>(__rhs);
    return months(__dm <= 11 ? __dm : __dm + 12);
}

inline constexpr month& month::operator+=(const months& __dm) noexcept
{ *this = *this + __dm; return *this; }

inline constexpr month& month::operator-=(const months& __dm) noexcept
{ *this = *this - __dm; return *this; }


class year {
private:
    short __y;
public:
    year() = default;
    explicit inline constexpr year(int __val) noexcept : __y(static_cast<short>(__val)) {}

    inline constexpr year& operator++()    noexcept { ++__y; return *this; }
    inline constexpr year  operator++(int) noexcept { year __tmp = *this; ++(*this); return __tmp; }
    inline constexpr year& operator--()    noexcept { --__y; return *this; }
    inline constexpr year  operator--(int) noexcept { year __tmp = *this; --(*this); return __tmp; }
           constexpr year& operator+=(const years& __dy) noexcept;
           constexpr year& operator-=(const years& __dy) noexcept;
    inline constexpr year operator+() const noexcept { return *this; }
    inline constexpr year operator-() const noexcept { return year{-__y}; }

    inline constexpr bool is_leap() const noexcept { return __y % 4 == 0 && (__y % 100 != 0 || __y % 400 == 0); }
    explicit inline constexpr operator int() const noexcept { return __y; }
           constexpr bool ok() const noexcept;
    static inline constexpr year min() noexcept { return year{-32767}; }
    static inline constexpr year max() noexcept { return year{ 32767}; }
};


inline constexpr
bool operator==(const year& __lhs, const year& __rhs) noexcept
{ return static_cast<int>(__lhs) == static_cast<int>(__rhs); }

inline constexpr
bool operator!=(const year& __lhs, const year& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
bool operator< (const year& __lhs, const year& __rhs) noexcept
{ return static_cast<int>(__lhs)  < static_cast<int>(__rhs); }

inline constexpr
bool operator> (const year& __lhs, const year& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const year& __lhs, const year& __rhs) noexcept
{ return !(__rhs < __lhs); }

inline constexpr
bool operator>=(const year& __lhs, const year& __rhs) noexcept
{ return !(__lhs < __rhs); }

inline constexpr
year operator+ (const year& __lhs, const years& __rhs) noexcept
{ return year(static_cast<int>(__lhs) + __rhs.count()); }

inline constexpr
year operator+ (const years& __lhs, const year& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year operator- (const year& __lhs, const years& __rhs) noexcept
{ return __lhs + -__rhs; }

inline constexpr
years operator-(const year& __lhs, const year& __rhs) noexcept
{ return years{static_cast<int>(__lhs) - static_cast<int>(__rhs)}; }


inline constexpr year& year::operator+=(const years& __dy) noexcept
{ *this = *this + __dy; return *this; }

inline constexpr year& year::operator-=(const years& __dy) noexcept
{ *this = *this - __dy; return *this; }

inline constexpr bool year::ok() const noexcept
{ return static_cast<int>(min()) <= __y && __y <= static_cast<int>(max()); }

class weekday_indexed;
class weekday_last;

class weekday {
private:
    unsigned char __wd;
public:
  weekday() = default;
  inline explicit constexpr weekday(unsigned __val) noexcept : __wd(static_cast<unsigned char>(__val == 7 ? 0 : __val)) {}
  inline constexpr          weekday(const sys_days& __sysd) noexcept
          : __wd(__weekday_from_days(__sysd.time_since_epoch().count())) {}
  inline explicit constexpr weekday(const local_days& __locd) noexcept
          : __wd(__weekday_from_days(__locd.time_since_epoch().count())) {}

  inline constexpr weekday& operator++()    noexcept { __wd = (__wd == 6 ? 0 : __wd + 1); return *this; }
  inline constexpr weekday  operator++(int) noexcept { weekday __tmp = *this; ++(*this); return __tmp; }
  inline constexpr weekday& operator--()    noexcept { __wd = (__wd == 0 ? 6 : __wd - 1); return *this; }
  inline constexpr weekday  operator--(int) noexcept { weekday __tmp = *this; --(*this); return __tmp; }
         constexpr weekday& operator+=(const days& __dd) noexcept;
         constexpr weekday& operator-=(const days& __dd) noexcept;
  inline constexpr unsigned c_encoding()   const noexcept { return __wd; }
  inline constexpr unsigned iso_encoding() const noexcept { return __wd == 0u ? 7 : __wd; }
  inline constexpr bool ok() const noexcept { return __wd <= 6; }
         constexpr weekday_indexed operator[](unsigned __index) const noexcept;
         constexpr weekday_last    operator[](last_spec) const noexcept;

  // TODO: Make private?
  static constexpr unsigned char __weekday_from_days(int __days) noexcept;
};


// https://howardhinnant.github.io/date_algorithms.html#weekday_from_days
inline constexpr
unsigned char weekday::__weekday_from_days(int __days) noexcept
{
    return static_cast<unsigned char>(
              static_cast<unsigned>(__days >= -4 ? (__days+4) % 7 : (__days+5) % 7 + 6)
           );
}

inline constexpr
bool operator==(const weekday& __lhs, const weekday& __rhs) noexcept
{ return __lhs.c_encoding() == __rhs.c_encoding(); }

inline constexpr
bool operator!=(const weekday& __lhs, const weekday& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
bool operator< (const weekday& __lhs, const weekday& __rhs) noexcept
{ return __lhs.c_encoding() < __rhs.c_encoding(); }

inline constexpr
bool operator> (const weekday& __lhs, const weekday& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const weekday& __lhs, const weekday& __rhs) noexcept
{ return !(__rhs < __lhs);}

inline constexpr
bool operator>=(const weekday& __lhs, const weekday& __rhs) noexcept
{ return !(__lhs < __rhs); }

constexpr weekday operator+(const weekday& __lhs, const days& __rhs) noexcept
{
    auto const __mu = static_cast<long long>(__lhs.c_encoding()) + __rhs.count();
    auto const __yr = (__mu >= 0 ? __mu : __mu - 6) / 7;
    return weekday{static_cast<unsigned>(__mu - __yr * 7)};
}

constexpr weekday operator+(const days& __lhs, const weekday& __rhs) noexcept
{ return __rhs + __lhs; }

constexpr weekday operator-(const weekday& __lhs, const days& __rhs) noexcept
{ return __lhs + -__rhs; }

constexpr days operator-(const weekday& __lhs, const weekday& __rhs) noexcept
{
    const int __wdu = __lhs.c_encoding() - __rhs.c_encoding();
    const int __wk = (__wdu >= 0 ? __wdu : __wdu-6) / 7;
    return days{__wdu - __wk * 7};
}

inline constexpr weekday& weekday::operator+=(const days& __dd) noexcept
{ *this = *this + __dd; return *this; }

inline constexpr weekday& weekday::operator-=(const days& __dd) noexcept
{ *this = *this - __dd; return *this; }


class weekday_indexed {
private:
    _VSTD::chrono::weekday __wd;
    unsigned char          __idx;
public:
    weekday_indexed() = default;
    inline constexpr weekday_indexed(const _VSTD::chrono::weekday& __wdval, unsigned __idxval) noexcept
        : __wd{__wdval}, __idx(__idxval) {}
    inline constexpr _VSTD::chrono::weekday weekday() const noexcept { return __wd; }
    inline constexpr unsigned                 index() const noexcept { return __idx; }
    inline constexpr bool ok() const noexcept { return __wd.ok() && __idx >= 1 && __idx <= 5; }
};

inline constexpr
bool operator==(const weekday_indexed& __lhs, const weekday_indexed& __rhs) noexcept
{ return __lhs.weekday() == __rhs.weekday() && __lhs.index() == __rhs.index(); }

inline constexpr
bool operator!=(const weekday_indexed& __lhs, const weekday_indexed& __rhs) noexcept
{ return !(__lhs == __rhs); }


class weekday_last {
private:
    _VSTD::chrono::weekday __wd;
public:
    explicit constexpr weekday_last(const _VSTD::chrono::weekday& __val) noexcept
        : __wd{__val} {}
    constexpr _VSTD::chrono::weekday weekday() const noexcept { return __wd; }
    constexpr bool ok() const noexcept { return __wd.ok(); }
};

inline constexpr
bool operator==(const weekday_last& __lhs, const weekday_last& __rhs) noexcept
{ return __lhs.weekday() == __rhs.weekday(); }

inline constexpr
bool operator!=(const weekday_last& __lhs, const weekday_last& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
weekday_indexed weekday::operator[](unsigned __index) const noexcept { return weekday_indexed{*this, __index}; }

inline constexpr
weekday_last    weekday::operator[](last_spec) const noexcept { return weekday_last{*this}; }


inline constexpr last_spec last{};
inline constexpr weekday   Sunday{0};
inline constexpr weekday   Monday{1};
inline constexpr weekday   Tuesday{2};
inline constexpr weekday   Wednesday{3};
inline constexpr weekday   Thursday{4};
inline constexpr weekday   Friday{5};
inline constexpr weekday   Saturday{6};

inline constexpr month January{1};
inline constexpr month February{2};
inline constexpr month March{3};
inline constexpr month April{4};
inline constexpr month May{5};
inline constexpr month June{6};
inline constexpr month July{7};
inline constexpr month August{8};
inline constexpr month September{9};
inline constexpr month October{10};
inline constexpr month November{11};
inline constexpr month December{12};


class month_day {
private:
   chrono::month __m;
   chrono::day   __d;
public:
    month_day() = default;
    constexpr month_day(const chrono::month& __mval, const chrono::day& __dval) noexcept
        : __m{__mval}, __d{__dval} {}
    inline constexpr chrono::month month() const noexcept { return __m; }
    inline constexpr chrono::day   day()   const noexcept { return __d; }
    constexpr bool ok() const noexcept;
};

inline constexpr
bool month_day::ok() const noexcept
{
    if (!__m.ok()) return false;
    const unsigned __dval = static_cast<unsigned>(__d);
    if (__dval < 1 || __dval > 31) return false;
    if (__dval <= 29) return true;
//  Now we've got either 30 or 31
    const unsigned __mval = static_cast<unsigned>(__m);
    if (__mval == 2) return false;
    if (__mval == 4 || __mval == 6 || __mval == 9 || __mval == 11)
        return __dval == 30;
    return true;
}

inline constexpr
bool operator==(const month_day& __lhs, const month_day& __rhs) noexcept
{ return __lhs.month() == __rhs.month() && __lhs.day() == __rhs.day(); }

inline constexpr
bool operator!=(const month_day& __lhs, const month_day& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
month_day operator/(const month& __lhs, const day& __rhs) noexcept
{ return month_day{__lhs, __rhs}; }

constexpr
month_day operator/(const day& __lhs, const month& __rhs) noexcept
{ return __rhs / __lhs; }

inline constexpr
month_day operator/(const month& __lhs, int __rhs) noexcept
{ return __lhs / day(__rhs); }

constexpr
month_day operator/(int __lhs, const day& __rhs) noexcept
{ return month(__lhs) / __rhs; }

constexpr
month_day operator/(const day& __lhs, int __rhs) noexcept
{ return month(__rhs) / __lhs; }


inline constexpr
bool operator< (const month_day& __lhs, const month_day& __rhs) noexcept
{ return __lhs.month() != __rhs.month() ? __lhs.month() < __rhs.month() : __lhs.day() < __rhs.day(); }

inline constexpr
bool operator> (const month_day& __lhs, const month_day& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const month_day& __lhs, const month_day& __rhs) noexcept
{ return !(__rhs < __lhs);}

inline constexpr
bool operator>=(const month_day& __lhs, const month_day& __rhs) noexcept
{ return !(__lhs < __rhs); }



class month_day_last {
private:
    chrono::month __m;
public:
    explicit constexpr month_day_last(const chrono::month& __val) noexcept
        : __m{__val} {}
    inline constexpr chrono::month month() const noexcept { return __m; }
    inline constexpr bool ok() const noexcept { return __m.ok(); }
};

inline constexpr
bool operator==(const month_day_last& __lhs, const month_day_last& __rhs) noexcept
{ return __lhs.month() == __rhs.month(); }

inline constexpr
bool operator!=(const month_day_last& __lhs, const month_day_last& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
bool operator< (const month_day_last& __lhs, const month_day_last& __rhs) noexcept
{ return __lhs.month() < __rhs.month(); }

inline constexpr
bool operator> (const month_day_last& __lhs, const month_day_last& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const month_day_last& __lhs, const month_day_last& __rhs) noexcept
{ return !(__rhs < __lhs);}

inline constexpr
bool operator>=(const month_day_last& __lhs, const month_day_last& __rhs) noexcept
{ return !(__lhs < __rhs); }

inline constexpr
month_day_last operator/(const month& __lhs, last_spec) noexcept
{ return month_day_last{__lhs}; }

inline constexpr
month_day_last operator/(last_spec, const month& __rhs) noexcept
{ return month_day_last{__rhs}; }

inline constexpr
month_day_last operator/(int __lhs, last_spec) noexcept
{ return month_day_last{month(__lhs)}; }

inline constexpr
month_day_last operator/(last_spec, int __rhs) noexcept
{ return month_day_last{month(__rhs)}; }


class month_weekday {
private:
    chrono::month __m;
    chrono::weekday_indexed __wdi;
public:
    month_weekday() = default;
    constexpr month_weekday(const chrono::month& __mval, const chrono::weekday_indexed& __wdival) noexcept
        : __m{__mval}, __wdi{__wdival} {}
    inline constexpr chrono::month                     month() const noexcept { return __m; }
    inline constexpr chrono::weekday_indexed weekday_indexed() const noexcept { return __wdi; }
    inline constexpr bool                                 ok() const noexcept { return __m.ok() && __wdi.ok(); }
};

inline constexpr
bool operator==(const month_weekday& __lhs, const month_weekday& __rhs) noexcept
{ return __lhs.month() == __rhs.month() && __lhs.weekday_indexed() == __rhs.weekday_indexed(); }

inline constexpr
bool operator!=(const month_weekday& __lhs, const month_weekday& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
month_weekday operator/(const month& __lhs, const weekday_indexed& __rhs) noexcept
{ return month_weekday{__lhs, __rhs}; }

inline constexpr
month_weekday operator/(int __lhs, const weekday_indexed& __rhs) noexcept
{ return month_weekday{month(__lhs), __rhs}; }

inline constexpr
month_weekday operator/(const weekday_indexed& __lhs, const month& __rhs) noexcept
{ return month_weekday{__rhs, __lhs}; }

inline constexpr
month_weekday operator/(const weekday_indexed& __lhs, int __rhs) noexcept
{ return month_weekday{month(__rhs), __lhs}; }


class month_weekday_last {
    chrono::month        __m;
    chrono::weekday_last __wdl;
  public:
    constexpr month_weekday_last(const chrono::month& __mval, const chrono::weekday_last& __wdlval) noexcept
        : __m{__mval}, __wdl{__wdlval} {}
    inline constexpr chrono::month               month() const noexcept { return __m; }
    inline constexpr chrono::weekday_last weekday_last() const noexcept { return __wdl; }
    inline constexpr bool                           ok() const noexcept { return __m.ok() && __wdl.ok(); }
};

inline constexpr
bool operator==(const month_weekday_last& __lhs, const month_weekday_last& __rhs) noexcept
{ return __lhs.month() == __rhs.month() && __lhs.weekday_last() == __rhs.weekday_last(); }

inline constexpr
bool operator!=(const month_weekday_last& __lhs, const month_weekday_last& __rhs) noexcept
{ return !(__lhs == __rhs); }


inline constexpr
month_weekday_last operator/(const month& __lhs, const weekday_last& __rhs) noexcept
{ return month_weekday_last{__lhs, __rhs}; }

inline constexpr
month_weekday_last operator/(int __lhs, const weekday_last& __rhs) noexcept
{ return month_weekday_last{month(__lhs), __rhs}; }

inline constexpr
month_weekday_last operator/(const weekday_last& __lhs, const month& __rhs) noexcept
{ return month_weekday_last{__rhs, __lhs}; }

inline constexpr
month_weekday_last operator/(const weekday_last& __lhs, int __rhs) noexcept
{ return month_weekday_last{month(__rhs), __lhs}; }


class year_month {
    chrono::year  __y;
    chrono::month __m;
public:
    year_month() = default;
    constexpr year_month(const chrono::year& __yval, const chrono::month& __mval) noexcept
        : __y{__yval}, __m{__mval} {}
    inline constexpr chrono::year  year()  const noexcept { return __y; }
    inline constexpr chrono::month month() const noexcept { return __m; }
    inline constexpr year_month& operator+=(const months& __dm) noexcept { this->__m += __dm; return *this; }
    inline constexpr year_month& operator-=(const months& __dm) noexcept { this->__m -= __dm; return *this; }
    inline constexpr year_month& operator+=(const years& __dy)  noexcept { this->__y += __dy; return *this; }
    inline constexpr year_month& operator-=(const years& __dy)  noexcept { this->__y -= __dy; return *this; }
    inline constexpr bool ok() const noexcept { return __y.ok() && __m.ok(); }
};

inline constexpr
year_month operator/(const year& __y, const month& __m) noexcept { return year_month{__y, __m}; }

inline constexpr
year_month operator/(const year& __y, int __m) noexcept { return year_month{__y, month(__m)}; }

inline constexpr
bool operator==(const year_month& __lhs, const year_month& __rhs) noexcept
{ return __lhs.year() == __rhs.year() && __lhs.month() == __rhs.month(); }

inline constexpr
bool operator!=(const year_month& __lhs, const year_month& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
bool operator< (const year_month& __lhs, const year_month& __rhs) noexcept
{ return __lhs.year() != __rhs.year() ? __lhs.year() < __rhs.year() : __lhs.month() < __rhs.month(); }

inline constexpr
bool operator> (const year_month& __lhs, const year_month& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const year_month& __lhs, const year_month& __rhs) noexcept
{ return !(__rhs < __lhs);}

inline constexpr
bool operator>=(const year_month& __lhs, const year_month& __rhs) noexcept
{ return !(__lhs < __rhs); }

constexpr year_month operator+(const year_month& __lhs, const months& __rhs) noexcept
{
    int __dmi = static_cast<int>(static_cast<unsigned>(__lhs.month())) - 1 + __rhs.count();
    const int __dy = (__dmi >= 0 ? __dmi : __dmi-11) / 12;
    __dmi = __dmi - __dy * 12 + 1;
    return (__lhs.year() + years(__dy)) / month(static_cast<unsigned>(__dmi));
}

constexpr year_month operator+(const months& __lhs, const year_month& __rhs) noexcept
{ return __rhs + __lhs; }

constexpr year_month operator+(const year_month& __lhs, const years& __rhs) noexcept
{ return (__lhs.year() + __rhs) / __lhs.month(); }

constexpr year_month operator+(const years& __lhs, const year_month& __rhs) noexcept
{ return __rhs + __lhs; }

constexpr months     operator-(const year_month& __lhs, const year_month& __rhs) noexcept
{ return (__lhs.year() - __rhs.year()) + months(static_cast<unsigned>(__lhs.month()) - static_cast<unsigned>(__rhs.month())); }

constexpr year_month operator-(const year_month& __lhs, const months& __rhs) noexcept
{ return __lhs + -__rhs; }

constexpr year_month operator-(const year_month& __lhs, const years& __rhs) noexcept
{ return __lhs + -__rhs; }

class year_month_day_last;

class year_month_day {
private:
    chrono::year  __y;
    chrono::month __m;
    chrono::day   __d;
public:
     year_month_day() = default;
     inline constexpr year_month_day(
            const chrono::year& __yval, const chrono::month& __mval, const chrono::day& __dval) noexcept
            : __y{__yval}, __m{__mval}, __d{__dval} {}
            constexpr year_month_day(const year_month_day_last& __ymdl) noexcept;
     inline constexpr year_month_day(const sys_days& __sysd) noexcept
            : year_month_day(__from_days(__sysd.time_since_epoch())) {}
     inline explicit constexpr year_month_day(const local_days& __locd) noexcept
            : year_month_day(__from_days(__locd.time_since_epoch())) {}

            constexpr year_month_day& operator+=(const months& __dm) noexcept;
            constexpr year_month_day& operator-=(const months& __dm) noexcept;
            constexpr year_month_day& operator+=(const years& __dy)  noexcept;
            constexpr year_month_day& operator-=(const years& __dy)  noexcept;

     inline constexpr chrono::year   year() const noexcept { return __y; }
     inline constexpr chrono::month month() const noexcept { return __m; }
     inline constexpr chrono::day     day() const noexcept { return __d; }
     inline constexpr operator   sys_days() const noexcept          { return   sys_days{__to_days()}; }
     inline explicit constexpr operator local_days() const noexcept { return local_days{__to_days()}; }

            constexpr bool             ok() const noexcept;

     static constexpr year_month_day __from_days(days __d) noexcept;
     constexpr days __to_days() const noexcept;
};


// https://howardhinnant.github.io/date_algorithms.html#civil_from_days
inline constexpr
year_month_day
year_month_day::__from_days(days __d) noexcept
{
    static_assert(std::numeric_limits<unsigned>::digits >= 18, "");
    static_assert(std::numeric_limits<int>::digits >= 20     , "");
    const int      __z = __d.count() + 719468;
    const int      __era = (__z >= 0 ? __z : __z - 146096) / 146097;
    const unsigned __doe = static_cast<unsigned>(__z - __era * 146097);              // [0, 146096]
    const unsigned __yoe = (__doe - __doe/1460 + __doe/36524 - __doe/146096) / 365;  // [0, 399]
    const int      __yr = static_cast<int>(__yoe) + __era * 400;
    const unsigned __doy = __doe - (365 * __yoe + __yoe/4 - __yoe/100);              // [0, 365]
    const unsigned __mp = (5 * __doy + 2)/153;                                       // [0, 11]
    const unsigned __dy = __doy - (153 * __mp + 2)/5 + 1;                            // [1, 31]
    const unsigned __mth = __mp + (__mp < 10 ? 3 : -9);                              // [1, 12]
    return year_month_day{chrono::year{__yr + (__mth <= 2)}, chrono::month{__mth}, chrono::day{__dy}};
}

// https://howardhinnant.github.io/date_algorithms.html#days_from_civil
inline constexpr days year_month_day::__to_days() const noexcept
{
    static_assert(std::numeric_limits<unsigned>::digits >= 18, "");
    static_assert(std::numeric_limits<int>::digits >= 20     , "");

    const int      __yr  = static_cast<int>(__y) - (__m <= February);
    const unsigned __mth = static_cast<unsigned>(__m);
    const unsigned __dy  = static_cast<unsigned>(__d);

    const int      __era = (__yr >= 0 ? __yr : __yr - 399) / 400;
    const unsigned __yoe = static_cast<unsigned>(__yr - __era * 400);                // [0, 399]
    const unsigned __doy = (153 * (__mth + (__mth > 2 ? -3 : 9)) + 2) / 5 + __dy-1;  // [0, 365]
    const unsigned __doe = __yoe * 365 + __yoe/4 - __yoe/100 + __doy;                // [0, 146096]
    return days{__era * 146097 + static_cast<int>(__doe) - 719468};
}

inline constexpr
bool operator==(const year_month_day& __lhs, const year_month_day& __rhs) noexcept
{ return __lhs.year() == __rhs.year() && __lhs.month() == __rhs.month() && __lhs.day() == __rhs.day(); }

inline constexpr
bool operator!=(const year_month_day& __lhs, const year_month_day& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
bool operator< (const year_month_day& __lhs, const year_month_day& __rhs) noexcept
{
    if (__lhs.year() < __rhs.year()) return true;
    if (__lhs.year() > __rhs.year()) return false;
    if (__lhs.month() < __rhs.month()) return true;
    if (__lhs.month() > __rhs.month()) return false;
    return __lhs.day() < __rhs.day();
}

inline constexpr
bool operator> (const year_month_day& __lhs, const year_month_day& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const year_month_day& __lhs, const year_month_day& __rhs) noexcept
{ return !(__rhs < __lhs);}

inline constexpr
bool operator>=(const year_month_day& __lhs, const year_month_day& __rhs) noexcept
{ return !(__lhs < __rhs); }

inline constexpr
year_month_day operator/(const year_month& __lhs, const day& __rhs) noexcept
{ return year_month_day{__lhs.year(), __lhs.month(), __rhs}; }

inline constexpr
year_month_day operator/(const year_month& __lhs, int __rhs) noexcept
{ return __lhs / day(__rhs); }

inline constexpr
year_month_day operator/(const year& __lhs, const month_day& __rhs) noexcept
{ return __lhs / __rhs.month() / __rhs.day(); }

inline constexpr
year_month_day operator/(int __lhs, const month_day& __rhs) noexcept
{ return year(__lhs) / __rhs; }

inline constexpr
year_month_day operator/(const month_day& __lhs, const year& __rhs) noexcept
{ return __rhs / __lhs; }

inline constexpr
year_month_day operator/(const month_day& __lhs, int __rhs) noexcept
{ return year(__rhs) / __lhs; }


inline constexpr
year_month_day operator+(const year_month_day& __lhs, const months& __rhs) noexcept
{ return (__lhs.year()/__lhs.month() + __rhs)/__lhs.day(); }

inline constexpr
year_month_day operator+(const months& __lhs, const year_month_day& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year_month_day operator-(const year_month_day& __lhs, const months& __rhs) noexcept
{ return __lhs + -__rhs; }

inline constexpr
year_month_day operator+(const year_month_day& __lhs, const years& __rhs) noexcept
{ return (__lhs.year() + __rhs) / __lhs.month() / __lhs.day(); }

inline constexpr
year_month_day operator+(const years& __lhs, const year_month_day& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year_month_day operator-(const year_month_day& __lhs, const years& __rhs) noexcept
{ return __lhs + -__rhs; }

inline constexpr year_month_day& year_month_day::operator+=(const months& __dm) noexcept { *this = *this + __dm; return *this; }
inline constexpr year_month_day& year_month_day::operator-=(const months& __dm) noexcept { *this = *this - __dm; return *this; }
inline constexpr year_month_day& year_month_day::operator+=(const years& __dy)  noexcept { *this = *this + __dy; return *this; }
inline constexpr year_month_day& year_month_day::operator-=(const years& __dy)  noexcept { *this = *this - __dy; return *this; }

class year_month_day_last {
private:
    chrono::year           __y;
    chrono::month_day_last __mdl;
public:
     constexpr year_month_day_last(const year& __yval, const month_day_last& __mdlval) noexcept
        : __y{__yval}, __mdl{__mdlval} {}

     constexpr year_month_day_last& operator+=(const months& __m) noexcept;
     constexpr year_month_day_last& operator-=(const months& __m) noexcept;
     constexpr year_month_day_last& operator+=(const years& __y)  noexcept;
     constexpr year_month_day_last& operator-=(const years& __y)  noexcept;

     inline constexpr chrono::year                     year() const noexcept { return __y; }
     inline constexpr chrono::month                   month() const noexcept { return __mdl.month(); }
     inline constexpr chrono::month_day_last month_day_last() const noexcept { return __mdl; }
            constexpr chrono::day                       day() const noexcept;
     inline constexpr operator                     sys_days() const noexcept { return   sys_days{year()/month()/day()}; }
     inline explicit constexpr operator          local_days() const noexcept { return local_days{year()/month()/day()}; }
     inline constexpr bool                               ok() const noexcept { return __y.ok() && __mdl.ok(); }
};

inline constexpr
chrono::day year_month_day_last::day() const noexcept
{
    constexpr chrono::day __d[] =
    {
        chrono::day(31), chrono::day(28), chrono::day(31),
        chrono::day(30), chrono::day(31), chrono::day(30),
        chrono::day(31), chrono::day(31), chrono::day(30),
        chrono::day(31), chrono::day(30), chrono::day(31)
    };
    return month() != February || !__y.is_leap() ?
        __d[static_cast<unsigned>(month()) - 1] : chrono::day{29};
}

inline constexpr
bool operator==(const year_month_day_last& __lhs, const year_month_day_last& __rhs) noexcept
{ return __lhs.year() == __rhs.year() && __lhs.month_day_last() == __rhs.month_day_last(); }

inline constexpr
bool operator!=(const year_month_day_last& __lhs, const year_month_day_last& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
bool operator< (const year_month_day_last& __lhs, const year_month_day_last& __rhs) noexcept
{
    if (__lhs.year() < __rhs.year()) return true;
    if (__lhs.year() > __rhs.year()) return false;
    return __lhs.month_day_last() < __rhs.month_day_last();
}

inline constexpr
bool operator> (const year_month_day_last& __lhs, const year_month_day_last& __rhs) noexcept
{ return __rhs < __lhs; }

inline constexpr
bool operator<=(const year_month_day_last& __lhs, const year_month_day_last& __rhs) noexcept
{ return !(__rhs < __lhs);}

inline constexpr
bool operator>=(const year_month_day_last& __lhs, const year_month_day_last& __rhs) noexcept
{ return !(__lhs < __rhs); }

inline constexpr year_month_day_last operator/(const year_month& __lhs, last_spec) noexcept
{ return year_month_day_last{__lhs.year(), month_day_last{__lhs.month()}}; }

inline constexpr year_month_day_last operator/(const year& __lhs, const month_day_last& __rhs) noexcept
{ return year_month_day_last{__lhs, __rhs}; }

inline constexpr year_month_day_last operator/(int __lhs, const month_day_last& __rhs) noexcept
{ return year_month_day_last{year{__lhs}, __rhs}; }

inline constexpr year_month_day_last operator/(const month_day_last& __lhs, const year& __rhs) noexcept
{ return __rhs / __lhs; }

inline constexpr year_month_day_last operator/(const month_day_last& __lhs, int __rhs) noexcept
{ return year{__rhs} / __lhs; }


inline constexpr
year_month_day_last operator+(const year_month_day_last& __lhs, const months& __rhs) noexcept
{ return (__lhs.year() / __lhs.month() + __rhs) / last; }

inline constexpr
year_month_day_last operator+(const months& __lhs, const year_month_day_last& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year_month_day_last operator-(const year_month_day_last& __lhs, const months& __rhs) noexcept
{ return __lhs + (-__rhs); }

inline constexpr
year_month_day_last operator+(const year_month_day_last& __lhs, const years& __rhs) noexcept
{ return year_month_day_last{__lhs.year() + __rhs, __lhs.month_day_last()}; }

inline constexpr
year_month_day_last operator+(const years& __lhs, const year_month_day_last& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year_month_day_last operator-(const year_month_day_last& __lhs, const years& __rhs) noexcept
{ return __lhs + (-__rhs); }

inline constexpr year_month_day_last& year_month_day_last::operator+=(const months& __dm) noexcept { *this = *this + __dm; return *this; }
inline constexpr year_month_day_last& year_month_day_last::operator-=(const months& __dm) noexcept { *this = *this - __dm; return *this; }
inline constexpr year_month_day_last& year_month_day_last::operator+=(const years& __dy)  noexcept { *this = *this + __dy; return *this; }
inline constexpr year_month_day_last& year_month_day_last::operator-=(const years& __dy)  noexcept { *this = *this - __dy; return *this; }

inline constexpr year_month_day::year_month_day(const year_month_day_last& __ymdl) noexcept
    : __y{__ymdl.year()}, __m{__ymdl.month()}, __d{__ymdl.day()} {}

inline constexpr bool year_month_day::ok() const noexcept
{
    if (!__y.ok() || !__m.ok()) return false;
    return chrono::day{1} <= __d && __d <= (__y / __m / last).day();
}

class year_month_weekday {
    chrono::year            __y;
    chrono::month           __m;
    chrono::weekday_indexed __wdi;
public:
    year_month_weekday() = default;
    constexpr year_month_weekday(const chrono::year& __yval, const chrono::month& __mval,
                               const chrono::weekday_indexed& __wdival) noexcept
        : __y{__yval}, __m{__mval}, __wdi{__wdival} {}
    constexpr year_month_weekday(const sys_days& __sysd) noexcept
            : year_month_weekday(__from_days(__sysd.time_since_epoch())) {}
    inline explicit constexpr year_month_weekday(const local_days& __locd) noexcept
            : year_month_weekday(__from_days(__locd.time_since_epoch())) {}
    constexpr year_month_weekday& operator+=(const months& m) noexcept;
    constexpr year_month_weekday& operator-=(const months& m) noexcept;
    constexpr year_month_weekday& operator+=(const years& y)  noexcept;
    constexpr year_month_weekday& operator-=(const years& y)  noexcept;

    inline constexpr chrono::year                       year() const noexcept { return __y; }
    inline constexpr chrono::month                     month() const noexcept { return __m; }
    inline constexpr chrono::weekday                 weekday() const noexcept { return __wdi.weekday(); }
    inline constexpr unsigned                          index() const noexcept { return __wdi.index(); }
    inline constexpr chrono::weekday_indexed weekday_indexed() const noexcept { return __wdi; }

    inline constexpr                       operator sys_days() const noexcept { return   sys_days{__to_days()}; }
    inline explicit constexpr operator            local_days() const noexcept { return local_days{__to_days()}; }
    inline constexpr bool ok() const noexcept
    {
        if (!__y.ok() || !__m.ok() || !__wdi.ok()) return false;
        if (__wdi.index() <= 4) return true;
        auto __nth_weekday_day =
            __wdi.weekday() -
            chrono::weekday{static_cast<sys_days>(__y / __m / 1)} +
            days{(__wdi.index() - 1) * 7 + 1};
        return static_cast<unsigned>(__nth_weekday_day.count()) <=
               static_cast<unsigned>((__y / __m / last).day());
    }

    static constexpr year_month_weekday __from_days(days __d) noexcept;
    constexpr days __to_days() const noexcept;
};

inline constexpr
year_month_weekday year_month_weekday::__from_days(days __d) noexcept
{
    const sys_days      __sysd{__d};
    const chrono::weekday __wd = chrono::weekday(__sysd);
    const year_month_day __ymd = year_month_day(__sysd);
    return year_month_weekday{__ymd.year(), __ymd.month(),
                              __wd[(static_cast<unsigned>(__ymd.day())-1)/7+1]};
}

inline constexpr
days year_month_weekday::__to_days() const noexcept
{
    const sys_days __sysd = sys_days(__y/__m/1);
    return (__sysd + (__wdi.weekday() - chrono::weekday(__sysd) + days{(__wdi.index()-1)*7}))
                .time_since_epoch();
}

inline constexpr
bool operator==(const year_month_weekday& __lhs, const year_month_weekday& __rhs) noexcept
{ return __lhs.year() == __rhs.year() && __lhs.month() == __rhs.month() && __lhs.weekday_indexed() == __rhs.weekday_indexed(); }

inline constexpr
bool operator!=(const year_month_weekday& __lhs, const year_month_weekday& __rhs) noexcept
{ return !(__lhs == __rhs); }

inline constexpr
year_month_weekday operator/(const year_month& __lhs, const weekday_indexed& __rhs) noexcept
{ return year_month_weekday{__lhs.year(), __lhs.month(), __rhs}; }

inline constexpr
year_month_weekday operator/(const year& __lhs, const month_weekday& __rhs) noexcept
{ return year_month_weekday{__lhs, __rhs.month(), __rhs.weekday_indexed()}; }

inline constexpr
year_month_weekday operator/(int __lhs, const month_weekday& __rhs) noexcept
{ return year(__lhs) / __rhs; }

inline constexpr
year_month_weekday operator/(const month_weekday& __lhs, const year& __rhs) noexcept
{ return __rhs / __lhs; }

inline constexpr
year_month_weekday operator/(const month_weekday& __lhs, int __rhs) noexcept
{ return year(__rhs) / __lhs; }


inline constexpr
year_month_weekday operator+(const year_month_weekday& __lhs, const months& __rhs) noexcept
{ return (__lhs.year() / __lhs.month() + __rhs) / __lhs.weekday_indexed(); }

inline constexpr
year_month_weekday operator+(const months& __lhs, const year_month_weekday& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year_month_weekday operator-(const year_month_weekday& __lhs, const months& __rhs) noexcept
{ return __lhs + (-__rhs); }

inline constexpr
year_month_weekday operator+(const year_month_weekday& __lhs, const years& __rhs) noexcept
{ return year_month_weekday{__lhs.year() + __rhs, __lhs.month(), __lhs.weekday_indexed()}; }

inline constexpr
year_month_weekday operator+(const years& __lhs, const year_month_weekday& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year_month_weekday operator-(const year_month_weekday& __lhs, const years& __rhs) noexcept
{ return __lhs + (-__rhs); }


inline constexpr year_month_weekday& year_month_weekday::operator+=(const months& __dm) noexcept { *this = *this + __dm; return *this; }
inline constexpr year_month_weekday& year_month_weekday::operator-=(const months& __dm) noexcept { *this = *this - __dm; return *this; }
inline constexpr year_month_weekday& year_month_weekday::operator+=(const years& __dy)  noexcept { *this = *this + __dy; return *this; }
inline constexpr year_month_weekday& year_month_weekday::operator-=(const years& __dy)  noexcept { *this = *this - __dy; return *this; }

class year_month_weekday_last {
private:
    chrono::year         __y;
    chrono::month        __m;
    chrono::weekday_last __wdl;
public:
    constexpr year_month_weekday_last(const chrono::year& __yval, const chrono::month& __mval,
                                      const chrono::weekday_last& __wdlval) noexcept
                : __y{__yval}, __m{__mval}, __wdl{__wdlval} {}
    constexpr year_month_weekday_last& operator+=(const months& __dm) noexcept;
    constexpr year_month_weekday_last& operator-=(const months& __dm) noexcept;
    constexpr year_month_weekday_last& operator+=(const years& __dy)  noexcept;
    constexpr year_month_weekday_last& operator-=(const years& __dy)  noexcept;

    inline constexpr chrono::year                 year() const noexcept { return __y; }
    inline constexpr chrono::month               month() const noexcept { return __m; }
    inline constexpr chrono::weekday           weekday() const noexcept { return __wdl.weekday(); }
    inline constexpr chrono::weekday_last weekday_last() const noexcept { return __wdl; }
    inline constexpr operator                 sys_days() const noexcept { return   sys_days{__to_days()}; }
    inline explicit constexpr operator      local_days() const noexcept { return local_days{__to_days()}; }
    inline constexpr bool ok() const noexcept { return __y.ok() && __m.ok() && __wdl.ok(); }

    constexpr days __to_days() const noexcept;

};

inline constexpr
days year_month_weekday_last::__to_days() const noexcept
{
    const sys_days __last = sys_days{__y/__m/last};
    return (__last - (chrono::weekday{__last} - __wdl.weekday())).time_since_epoch();

}

inline constexpr
bool operator==(const year_month_weekday_last& __lhs, const year_month_weekday_last& __rhs) noexcept
{ return __lhs.year() == __rhs.year() && __lhs.month() == __rhs.month() && __lhs.weekday_last() == __rhs.weekday_last(); }

inline constexpr
bool operator!=(const year_month_weekday_last& __lhs, const year_month_weekday_last& __rhs) noexcept
{ return !(__lhs == __rhs); }


inline constexpr
year_month_weekday_last operator/(const year_month& __lhs, const weekday_last& __rhs) noexcept
{ return year_month_weekday_last{__lhs.year(), __lhs.month(), __rhs}; }

inline constexpr
year_month_weekday_last operator/(const year& __lhs, const month_weekday_last& __rhs) noexcept
{ return year_month_weekday_last{__lhs, __rhs.month(), __rhs.weekday_last()}; }

inline constexpr
year_month_weekday_last operator/(int __lhs, const month_weekday_last& __rhs) noexcept
{ return year(__lhs) / __rhs; }

inline constexpr
year_month_weekday_last operator/(const month_weekday_last& __lhs, const year& __rhs) noexcept
{ return __rhs / __lhs; }

inline constexpr
year_month_weekday_last operator/(const month_weekday_last& __lhs, int __rhs) noexcept
{ return year(__rhs) / __lhs; }


inline constexpr
year_month_weekday_last operator+(const year_month_weekday_last& __lhs, const months& __rhs) noexcept
{ return (__lhs.year() / __lhs.month() + __rhs) / __lhs.weekday_last(); }

inline constexpr
year_month_weekday_last operator+(const months& __lhs, const year_month_weekday_last& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year_month_weekday_last operator-(const year_month_weekday_last& __lhs, const months& __rhs) noexcept
{ return __lhs + (-__rhs); }

inline constexpr
year_month_weekday_last operator+(const year_month_weekday_last& __lhs, const years& __rhs) noexcept
{ return year_month_weekday_last{__lhs.year() + __rhs, __lhs.month(), __lhs.weekday_last()}; }

inline constexpr
year_month_weekday_last operator+(const years& __lhs, const year_month_weekday_last& __rhs) noexcept
{ return __rhs + __lhs; }

inline constexpr
year_month_weekday_last operator-(const year_month_weekday_last& __lhs, const years& __rhs) noexcept
{ return __lhs + (-__rhs); }

inline constexpr year_month_weekday_last& year_month_weekday_last::operator+=(const months& __dm) noexcept { *this = *this + __dm; return *this; }
inline constexpr year_month_weekday_last& year_month_weekday_last::operator-=(const months& __dm) noexcept { *this = *this - __dm; return *this; }
inline constexpr year_month_weekday_last& year_month_weekday_last::operator+=(const years& __dy)  noexcept { *this = *this + __dy; return *this; }
inline constexpr year_month_weekday_last& year_month_weekday_last::operator-=(const years& __dy)  noexcept { *this = *this - __dy; return *this; }


template <class _Duration>
class hh_mm_ss
{
private:
    static_assert(__is_duration<_Duration>::value, "template parameter of hh_mm_ss must be a std::chrono::duration");
    using __CommonType = common_type_t<_Duration, chrono::seconds>;

    static constexpr uint64_t __pow10(unsigned __exp)
    {
        uint64_t __ret = 1;
        for (unsigned __i = 0; __i < __exp; ++__i)
            __ret *= 10U;
        return __ret;
    }

    static constexpr unsigned __width(uint64_t __n, uint64_t __d = 10, unsigned __w = 0)
    {
        if (__n >= 2 && __d != 0 && __w < 19)
            return 1 + __width(__n, __d % __n * 10, __w+1);
        return 0;
    }

public:
    static unsigned constexpr fractional_width = __width(__CommonType::period::den) < 19 ?
                                                 __width(__CommonType::period::den) : 6u;
    using precision = duration<typename __CommonType::rep, ratio<1, __pow10(fractional_width)>>;

    constexpr hh_mm_ss() noexcept : hh_mm_ss{_Duration::zero()} {}

    constexpr explicit hh_mm_ss(_Duration __d) noexcept :
        __is_neg(__d < _Duration(0)),
        __h(duration_cast<chrono::hours>  (abs(__d))),
        __m(duration_cast<chrono::minutes>(abs(__d) - hours())),
        __s(duration_cast<chrono::seconds>(abs(__d) - hours() - minutes())),
        __f(duration_cast<precision>      (abs(__d) - hours() - minutes() - seconds()))
        {}

    constexpr bool is_negative()        const noexcept { return __is_neg; }
    constexpr chrono::hours hours()     const noexcept { return __h; }
    constexpr chrono::minutes minutes() const noexcept { return __m; }
    constexpr chrono::seconds seconds() const noexcept { return __s; }
    constexpr precision subseconds()    const noexcept { return __f; }

    constexpr precision to_duration() const noexcept
    {
        auto __dur = __h + __m + __s + __f;
        return __is_neg ? -__dur : __dur;
    }

    constexpr explicit operator precision() const noexcept { return to_duration(); }

private:
    bool            __is_neg;
    chrono::hours   __h;
    chrono::minutes __m;
    chrono::seconds __s;
    precision       __f;
};

constexpr bool is_am(const hours& __h) noexcept { return __h >= hours( 0) && __h < hours(12); }
constexpr bool is_pm(const hours& __h) noexcept { return __h >= hours(12) && __h < hours(24); }

constexpr hours make12(const hours& __h) noexcept
{
    if      (__h == hours( 0)) return hours(12);
    else if (__h <= hours(12)) return __h;
    else                       return __h - hours(12);
}

constexpr hours make24(const hours& __h, bool __is_pm) noexcept
{
    if (__is_pm)
        return __h == hours(12) ? __h : __h + hours(12);
    else
        return __h == hours(12) ? hours(0) : __h;
}

#endif // _LIBCPP_STD_VER > 17
# 2834 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
} // chrono

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2837 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
// Suffixes for duration literals [time.duration.literals]
inline namespace literals
{
  inline namespace chrono_literals
  {

    constexpr chrono::hours operator""h(unsigned long long __h)
    {
        return chrono::hours(static_cast<chrono::hours::rep>(__h));
    }

    constexpr chrono::duration<long double, ratio<3600,1>> operator""h(long double __h)
    {
        return chrono::duration<long double, ratio<3600,1>>(__h);
    }


    constexpr chrono::minutes operator""min(unsigned long long __m)
    {
        return chrono::minutes(static_cast<chrono::minutes::rep>(__m));
    }

    constexpr chrono::duration<long double, ratio<60,1>> operator""min(long double __m)
    {
        return chrono::duration<long double, ratio<60,1>> (__m);
    }


    constexpr chrono::seconds operator""s(unsigned long long __s)
    {
        return chrono::seconds(static_cast<chrono::seconds::rep>(__s));
    }

    constexpr chrono::duration<long double> operator""s(long double __s)
    {
        return chrono::duration<long double> (__s);
    }


    constexpr chrono::milliseconds operator""ms(unsigned long long __ms)
    {
        return chrono::milliseconds(static_cast<chrono::milliseconds::rep>(__ms));
    }

    constexpr chrono::duration<long double, milli> operator""ms(long double __ms)
    {
        return chrono::duration<long double, milli>(__ms);
    }


    constexpr chrono::microseconds operator""us(unsigned long long __us)
    {
        return chrono::microseconds(static_cast<chrono::microseconds::rep>(__us));
    }

    constexpr chrono::duration<long double, micro> operator""us(long double __us)
    {
        return chrono::duration<long double, micro> (__us);
    }


    constexpr chrono::nanoseconds operator""ns(unsigned long long __ns)
    {
        return chrono::nanoseconds(static_cast<chrono::nanoseconds::rep>(__ns));
    }

    constexpr chrono::duration<long double, nano> operator""ns(long double __ns)
    {
        return chrono::duration<long double, nano> (__ns);
    }

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17 && !defined(_LIBCPP_HAS_NO_CXX20_CHRONO_LITERALS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2909 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
    constexpr chrono::day operator ""d(unsigned long long __d) noexcept
    {
        return chrono::day(static_cast<unsigned>(__d));
    }

    constexpr chrono::year operator ""y(unsigned long long __y) noexcept
    {
        return chrono::year(static_cast<int>(__y));
    }
#endif
# 2919 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
}}

namespace chrono { // hoist the literals into namespace std::chrono
   using namespace literals::chrono_literals;
}

#endif
# 2926 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

_LIBCPP_END_NAMESPACE_STD

#ifndef _LIBCPP_CXX03_LANG
_LIBCPP_BEGIN_NAMESPACE_FILESYSTEM
struct _FilesystemClock {
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_INT128)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2933 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
  typedef __int128_t rep;
  typedef nano period;
#else
# 2936 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
  typedef long long rep;
  typedef nano period;
#endif
# 2939 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

  typedef chrono::duration<rep, period> duration;
  typedef chrono::time_point<_FilesystemClock> time_point;

  _LIBCPP_EXPORTED_FROM_ABI
  static _LIBCPP_CONSTEXPR_AFTER_CXX11 const bool is_steady = false;

  _LIBCPP_AVAILABILITY_FILESYSTEM _LIBCPP_FUNC_VIS static time_point now() noexcept;

  _LIBCPP_INLINE_VISIBILITY
  static time_t to_time_t(const time_point& __t) noexcept {
      typedef chrono::duration<rep> __secs;
      return time_t(
          chrono::duration_cast<__secs>(__t.time_since_epoch()).count());
  }

  _LIBCPP_INLINE_VISIBILITY
  static time_point from_time_t(time_t __t) noexcept {
      typedef chrono::duration<rep> __secs;
      return time_point(__secs(__t));
  }
};
_LIBCPP_END_NAMESPACE_FILESYSTEM
#endif // !_LIBCPP_CXX03_LANG
# 2963 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_CHRONO
# 2967 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/chrono" 3
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <ctime>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h"

namespace llvm {

class raw_ostream;

namespace sys {

/// A time point on the system clock. This is provided for two reasons:
/// - to insulate us agains subtle differences in behavoir to differences in
///   system clock precision (which is implementation-defined and differs between
///   platforms).
/// - to shorten the type name
/// The default precision is nanoseconds. If need a specific precision specify
/// it explicitly. If unsure, use the default. If you need a time point on a
/// clock other than the system_clock, use std::chrono directly.
template <typename D = std::chrono::nanoseconds>
using TimePoint = std::chrono::time_point<std::chrono::system_clock, D>;

/// Convert a TimePoint to std::time_t
inline std::time_t toTimeT(TimePoint<> TP) {
  using namespace std::chrono;
  return system_clock::to_time_t(
      time_point_cast<system_clock::time_point::duration>(TP));
}

/// Convert a std::time_t to a TimePoint
inline TimePoint<std::chrono::seconds>
toTimePoint(std::time_t T) {
  using namespace std::chrono;
  return time_point_cast<seconds>(system_clock::from_time_t(T));
}

/// Convert a std::time_t + nanoseconds to a TimePoint
inline TimePoint<>
toTimePoint(std::time_t T, uint32_t nsec) {
  using namespace std::chrono;
  return time_point_cast<nanoseconds>(system_clock::from_time_t(T))
    + nanoseconds(nsec);
}

} // namespace sys

raw_ostream &operator<<(raw_ostream &OS, sys::TimePoint<> TP);

/// Format provider for TimePoint<>
///
/// The options string is a strftime format string, with extensions:
///   - %L is millis: 000-999
///   - %f is micros: 000000-999999
///   - %N is nanos: 000000000 - 999999999
///
/// If no options are given, the default format is "%Y-%m-%d %H:%M:%S.%N".
template <>
struct format_provider<sys::TimePoint<>> {
  static void format(const sys::TimePoint<> &TP, llvm::raw_ostream &OS,
                     StringRef Style);
};

/// Implementation of format_provider<T> for duration types.
///
/// The options string of a duration  type has the grammar:
///
///   duration_options  ::= [unit][show_unit [number_options]]
///   unit              ::= `h`|`m`|`s`|`ms|`us`|`ns`
///   show_unit         ::= `+` | `-`
///   number_options    ::= options string for a integral or floating point type
///
///   Examples
///   =================================
///   |  options  | Input | Output    |
///   =================================
///   | ""        | 1s    | 1 s       |
///   | "ms"      | 1s    | 1000 ms   |
///   | "ms-"     | 1s    | 1000      |
///   | "ms-n"    | 1s    | 1,000     |
///   | ""        | 1.0s  | 1.00 s    |
///   =================================
///
///  If the unit of the duration type is not one of the units specified above,
///  it is still possible to format it, provided you explicitly request a
///  display unit or you request that the unit is not displayed.

namespace detail {
template <typename Period> struct unit { static const char value[]; };
template <typename Period> const char unit<Period>::value[] = "";

template <> struct unit<std::ratio<3600>> { static const char value[]; };
template <> struct unit<std::ratio<60>> { static const char value[]; };
template <> struct unit<std::ratio<1>> { static const char value[]; };
template <> struct unit<std::milli> { static const char value[]; };
template <> struct unit<std::micro> { static const char value[]; };
template <> struct unit<std::nano> { static const char value[]; };
} // namespace detail

template <typename Rep, typename Period>
struct format_provider<std::chrono::duration<Rep, Period>> {
private:
  typedef std::chrono::duration<Rep, Period> Dur;
  typedef std::conditional_t<std::chrono::treat_as_floating_point<Rep>::value,
                             double, intmax_t>
      InternalRep;

  template <typename AsPeriod> static InternalRep getAs(const Dur &D) {
    using namespace std::chrono;
    return duration_cast<duration<InternalRep, AsPeriod>>(D).count();
  }

  static std::pair<InternalRep, StringRef> consumeUnit(StringRef &Style,
                                                        const Dur &D) {
    using namespace std::chrono;
    if (Style.consume_front("ns"))
      return {getAs<std::nano>(D), "ns"};
    if (Style.consume_front("us"))
      return {getAs<std::micro>(D), "us"};
    if (Style.consume_front("ms"))
      return {getAs<std::milli>(D), "ms"};
    if (Style.consume_front("s"))
      return {getAs<std::ratio<1>>(D), "s"};
    if (Style.consume_front("m"))
      return {getAs<std::ratio<60>>(D), "m"};
    if (Style.consume_front("h"))
      return {getAs<std::ratio<3600>>(D), "h"};
    return {D.count(), detail::unit<Period>::value};
  }

  static bool consumeShowUnit(StringRef &Style) {
    if (Style.empty())
      return true;
    if (Style.consume_front("-"))
      return false;
    if (Style.consume_front("+"))
      return true;
    assert(0 && "Unrecognised duration format");
    return true;
  }

public:
  static void format(const Dur &D, llvm::raw_ostream &Stream, StringRef Style) {
    InternalRep count;
    StringRef unit;
    std::tie(count, unit) = consumeUnit(Style, D);
    bool show_unit = consumeShowUnit(Style);

    format_provider<InternalRep>::format(count, Stream, Style);

    if (show_unit) {
      assert(!unit.empty());
      Stream << " " << unit;
    }
  }
};

} // namespace llvm

#endif // LLVM_SUPPORT_CHRONO_H
# 172 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Chrono.h"
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Error.h"
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorOr.h"
#endif /* expanded by -frewrite-includes */
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 37 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MD5.h"
#endif /* expanded by -frewrite-includes */
# 37 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h" 1
/* -*- C++ -*-
 * This code is derived from (original license follows):
 *
 * This is an OpenSSL-compatible implementation of the RSA Data Security, Inc.
 * MD5 Message-Digest Algorithm (RFC 1321).
 *
 * Homepage:
 * http://openwall.info/wiki/people/solar/software/public-domain-source-code/md5
 *
 * Author:
 * Alexander Peslyak, better known as Solar Designer <solar at openwall.com>
 *
 * This software was written by Alexander Peslyak in 2001.  No copyright is
 * claimed, and the software is hereby placed in the public domain.
 * In case this attempt to disclaim copyright and place the software in the
 * public domain is deemed null and void, then the software is
 * Copyright (c) 2001 Alexander Peslyak and it is hereby released to the
 * general public under the following terms:
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted.
 *
 * There's ABSOLUTELY NO WARRANTY, express or implied.
 *
 * See md5.c for more information.
 */

#ifndef LLVM_SUPPORT_MD5_H
#define LLVM_SUPPORT_MD5_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallString.h"
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Endian.h"
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h" 1
//===- Endian.h - Utilities for IO with endian specific data ----*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file declares generic functions to read and write endian specific data.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_ENDIAN_H
#define LLVM_SUPPORT_ENDIAN_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/AlignOf.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Host.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Host.h" 1
//===- llvm/Support/Host.h - Host machine characteristics --------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// Methods for querying the nature of the host machine.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_HOST_H
#define LLVM_SUPPORT_HOST_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringMap.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Host.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Host.h"

#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Host.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Host.h"

namespace llvm {
namespace sys {

  /// getDefaultTargetTriple() - Return the default target triple the compiler
  /// has been configured to produce code for.
  ///
  /// The target triple is a string in the format of:
  ///   CPU_TYPE-VENDOR-OPERATING_SYSTEM
  /// or
  ///   CPU_TYPE-VENDOR-KERNEL-OPERATING_SYSTEM
  std::string getDefaultTargetTriple();

  /// getProcessTriple() - Return an appropriate target triple for generating
  /// code to be loaded into the current process, e.g. when using the JIT.
  std::string getProcessTriple();

  /// getHostCPUName - Get the LLVM name for the host CPU. The particular format
  /// of the name is target dependent, and suitable for passing as -mcpu to the
  /// target which matches the host.
  ///
  /// \return - The host CPU name, or empty if the CPU could not be determined.
  StringRef getHostCPUName();

  /// getHostCPUFeatures - Get the LLVM names for the host CPU features.
  /// The particular format of the names are target dependent, and suitable for
  /// passing as -mattr to the target which matches the host.
  ///
  /// \param Features - A string mapping feature names to either
  /// true (if enabled) or false (if disabled). This routine makes no guarantees
  /// about exactly which features may appear in this map, except that they are
  /// all valid LLVM feature names.
  ///
  /// \return - True on success.
  bool getHostCPUFeatures(StringMap<bool> &Features);

  /// Get the number of physical cores (as opposed to logical cores returned
  /// from thread::hardware_concurrency(), which includes hyperthreads).
  /// Returns -1 if unknown for the current host system.
  int getHostNumPhysicalCores();

  namespace detail {
  /// Helper functions to extract HostCPUName from /proc/cpuinfo on linux.
  StringRef getHostCPUNameForPowerPC(StringRef ProcCpuinfoContent);
  StringRef getHostCPUNameForARM(StringRef ProcCpuinfoContent);
  StringRef getHostCPUNameForS390x(StringRef ProcCpuinfoContent);
  StringRef getHostCPUNameForBPF();
  }
}
}

#endif
# 71 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Host.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/SwapByteOrder.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"

namespace llvm {
namespace support {

enum endianness {big, little, native};

// These are named values for common alignments.
enum {aligned = 0, unaligned = 1};

namespace detail {

/// ::value is either alignment, or alignof(T) if alignment is 0.
template<class T, int alignment>
struct PickAlignment {
 enum { value = alignment == 0 ? alignof(T) : alignment };
};

} // end namespace detail

namespace endian {

constexpr endianness system_endianness() {
  return sys::IsBigEndianHost ? big : little;
}

template <typename value_type>
inline value_type byte_swap(value_type value, endianness endian) {
  if ((endian != native) && (endian != system_endianness()))
    sys::swapByteOrder(value);
  return value;
}

/// Swap the bytes of value to match the given endianness.
template<typename value_type, endianness endian>
inline value_type byte_swap(value_type value) {
  return byte_swap(value, endian);
}

/// Read a value of a particular endianness from memory.
template <typename value_type, std::size_t alignment>
inline value_type read(const void *memory, endianness endian) {
  value_type ret;

  memcpy(&ret,
         LLVM_ASSUME_ALIGNED(
             memory, (detail::PickAlignment<value_type, alignment>::value)),
         sizeof(value_type));
  return byte_swap<value_type>(ret, endian);
}

template<typename value_type,
         endianness endian,
         std::size_t alignment>
inline value_type read(const void *memory) {
  return read<value_type, alignment>(memory, endian);
}

/// Read a value of a particular endianness from a buffer, and increment the
/// buffer past that value.
template <typename value_type, std::size_t alignment, typename CharT>
inline value_type readNext(const CharT *&memory, endianness endian) {
  value_type ret = read<value_type, alignment>(memory, endian);
  memory += sizeof(value_type);
  return ret;
}

template<typename value_type, endianness endian, std::size_t alignment,
         typename CharT>
inline value_type readNext(const CharT *&memory) {
  return readNext<value_type, alignment, CharT>(memory, endian);
}

/// Write a value to memory with a particular endianness.
template <typename value_type, std::size_t alignment>
inline void write(void *memory, value_type value, endianness endian) {
  value = byte_swap<value_type>(value, endian);
  memcpy(LLVM_ASSUME_ALIGNED(
             memory, (detail::PickAlignment<value_type, alignment>::value)),
         &value, sizeof(value_type));
}

template<typename value_type,
         endianness endian,
         std::size_t alignment>
inline void write(void *memory, value_type value) {
  write<value_type, alignment>(memory, value, endian);
}

template <typename value_type>
using make_unsigned_t = std::make_unsigned_t<value_type>;

/// Read a value of a particular endianness from memory, for a location
/// that starts at the given bit offset within the first byte.
template <typename value_type, endianness endian, std::size_t alignment>
inline value_type readAtBitAlignment(const void *memory, uint64_t startBit) {
  assert(startBit < 8);
  if (startBit == 0)
    return read<value_type, endian, alignment>(memory);
  else {
    // Read two values and compose the result from them.
    value_type val[2];
    memcpy(&val[0],
           LLVM_ASSUME_ALIGNED(
               memory, (detail::PickAlignment<value_type, alignment>::value)),
           sizeof(value_type) * 2);
    val[0] = byte_swap<value_type, endian>(val[0]);
    val[1] = byte_swap<value_type, endian>(val[1]);

    // Shift bits from the lower value into place.
    make_unsigned_t<value_type> lowerVal = val[0] >> startBit;
    // Mask off upper bits after right shift in case of signed type.
    make_unsigned_t<value_type> numBitsFirstVal =
        (sizeof(value_type) * 8) - startBit;
    lowerVal &= ((make_unsigned_t<value_type>)1 << numBitsFirstVal) - 1;

    // Get the bits from the upper value.
    make_unsigned_t<value_type> upperVal =
        val[1] & (((make_unsigned_t<value_type>)1 << startBit) - 1);
    // Shift them in to place.
    upperVal <<= numBitsFirstVal;

    return lowerVal | upperVal;
  }
}

/// Write a value to memory with a particular endianness, for a location
/// that starts at the given bit offset within the first byte.
template <typename value_type, endianness endian, std::size_t alignment>
inline void writeAtBitAlignment(void *memory, value_type value,
                                uint64_t startBit) {
  assert(startBit < 8);
  if (startBit == 0)
    write<value_type, endian, alignment>(memory, value);
  else {
    // Read two values and shift the result into them.
    value_type val[2];
    memcpy(&val[0],
           LLVM_ASSUME_ALIGNED(
               memory, (detail::PickAlignment<value_type, alignment>::value)),
           sizeof(value_type) * 2);
    val[0] = byte_swap<value_type, endian>(val[0]);
    val[1] = byte_swap<value_type, endian>(val[1]);

    // Mask off any existing bits in the upper part of the lower value that
    // we want to replace.
    val[0] &= ((make_unsigned_t<value_type>)1 << startBit) - 1;
    make_unsigned_t<value_type> numBitsFirstVal =
        (sizeof(value_type) * 8) - startBit;
    make_unsigned_t<value_type> lowerVal = value;
    if (startBit > 0) {
      // Mask off the upper bits in the new value that are not going to go into
      // the lower value. This avoids a left shift of a negative value, which
      // is undefined behavior.
      lowerVal &= (((make_unsigned_t<value_type>)1 << numBitsFirstVal) - 1);
      // Now shift the new bits into place
      lowerVal <<= startBit;
    }
    val[0] |= lowerVal;

    // Mask off any existing bits in the lower part of the upper value that
    // we want to replace.
    val[1] &= ~(((make_unsigned_t<value_type>)1 << startBit) - 1);
    // Next shift the bits that go into the upper value into position.
    make_unsigned_t<value_type> upperVal = value >> numBitsFirstVal;
    // Mask off upper bits after right shift in case of signed type.
    upperVal &= ((make_unsigned_t<value_type>)1 << startBit) - 1;
    val[1] |= upperVal;

    // Finally, rewrite values.
    val[0] = byte_swap<value_type, endian>(val[0]);
    val[1] = byte_swap<value_type, endian>(val[1]);
    memcpy(LLVM_ASSUME_ALIGNED(
               memory, (detail::PickAlignment<value_type, alignment>::value)),
           &val[0], sizeof(value_type) * 2);
  }
}

} // end namespace endian

namespace detail {

template <typename ValueType, endianness Endian, std::size_t Alignment,
          std::size_t ALIGN = PickAlignment<ValueType, Alignment>::value>
struct packed_endian_specific_integral {
  using value_type = ValueType;
  static constexpr endianness endian = Endian;
  static constexpr std::size_t alignment = Alignment;

  packed_endian_specific_integral() = default;

  explicit packed_endian_specific_integral(value_type val) { *this = val; }

  operator value_type() const {
    return endian::read<value_type, endian, alignment>(
      (const void*)Value.buffer);
  }

  void operator=(value_type newValue) {
    endian::write<value_type, endian, alignment>(
      (void*)Value.buffer, newValue);
  }

  packed_endian_specific_integral &operator+=(value_type newValue) {
    *this = *this + newValue;
    return *this;
  }

  packed_endian_specific_integral &operator-=(value_type newValue) {
    *this = *this - newValue;
    return *this;
  }

  packed_endian_specific_integral &operator|=(value_type newValue) {
    *this = *this | newValue;
    return *this;
  }

  packed_endian_specific_integral &operator&=(value_type newValue) {
    *this = *this & newValue;
    return *this;
  }

private:
  struct {
    alignas(ALIGN) char buffer[sizeof(value_type)];
  } Value;

public:
  struct ref {
    explicit ref(void *Ptr) : Ptr(Ptr) {}

    operator value_type() const {
      return endian::read<value_type, endian, alignment>(Ptr);
    }

    void operator=(value_type NewValue) {
      endian::write<value_type, endian, alignment>(Ptr, NewValue);
    }

  private:
    void *Ptr;
  };
};

} // end namespace detail

using ulittle16_t =
    detail::packed_endian_specific_integral<uint16_t, little, unaligned>;
using ulittle32_t =
    detail::packed_endian_specific_integral<uint32_t, little, unaligned>;
using ulittle64_t =
    detail::packed_endian_specific_integral<uint64_t, little, unaligned>;

using little16_t =
    detail::packed_endian_specific_integral<int16_t, little, unaligned>;
using little32_t =
    detail::packed_endian_specific_integral<int32_t, little, unaligned>;
using little64_t =
    detail::packed_endian_specific_integral<int64_t, little, unaligned>;

using aligned_ulittle16_t =
    detail::packed_endian_specific_integral<uint16_t, little, aligned>;
using aligned_ulittle32_t =
    detail::packed_endian_specific_integral<uint32_t, little, aligned>;
using aligned_ulittle64_t =
    detail::packed_endian_specific_integral<uint64_t, little, aligned>;

using aligned_little16_t =
    detail::packed_endian_specific_integral<int16_t, little, aligned>;
using aligned_little32_t =
    detail::packed_endian_specific_integral<int32_t, little, aligned>;
using aligned_little64_t =
    detail::packed_endian_specific_integral<int64_t, little, aligned>;

using ubig16_t =
    detail::packed_endian_specific_integral<uint16_t, big, unaligned>;
using ubig32_t =
    detail::packed_endian_specific_integral<uint32_t, big, unaligned>;
using ubig64_t =
    detail::packed_endian_specific_integral<uint64_t, big, unaligned>;

using big16_t =
    detail::packed_endian_specific_integral<int16_t, big, unaligned>;
using big32_t =
    detail::packed_endian_specific_integral<int32_t, big, unaligned>;
using big64_t =
    detail::packed_endian_specific_integral<int64_t, big, unaligned>;

using aligned_ubig16_t =
    detail::packed_endian_specific_integral<uint16_t, big, aligned>;
using aligned_ubig32_t =
    detail::packed_endian_specific_integral<uint32_t, big, aligned>;
using aligned_ubig64_t =
    detail::packed_endian_specific_integral<uint64_t, big, aligned>;

using aligned_big16_t =
    detail::packed_endian_specific_integral<int16_t, big, aligned>;
using aligned_big32_t =
    detail::packed_endian_specific_integral<int32_t, big, aligned>;
using aligned_big64_t =
    detail::packed_endian_specific_integral<int64_t, big, aligned>;

using unaligned_uint16_t =
    detail::packed_endian_specific_integral<uint16_t, native, unaligned>;
using unaligned_uint32_t =
    detail::packed_endian_specific_integral<uint32_t, native, unaligned>;
using unaligned_uint64_t =
    detail::packed_endian_specific_integral<uint64_t, native, unaligned>;

using unaligned_int16_t =
    detail::packed_endian_specific_integral<int16_t, native, unaligned>;
using unaligned_int32_t =
    detail::packed_endian_specific_integral<int32_t, native, unaligned>;
using unaligned_int64_t =
    detail::packed_endian_specific_integral<int64_t, native, unaligned>;

template <typename T>
using little_t = detail::packed_endian_specific_integral<T, little, unaligned>;
template <typename T>
using big_t = detail::packed_endian_specific_integral<T, big, unaligned>;

template <typename T>
using aligned_little_t =
    detail::packed_endian_specific_integral<T, little, aligned>;
template <typename T>
using aligned_big_t = detail::packed_endian_specific_integral<T, big, aligned>;

namespace endian {

template <typename T> inline T read(const void *P, endianness E) {
  return read<T, unaligned>(P, E);
}

template <typename T, endianness E> inline T read(const void *P) {
  return *(const detail::packed_endian_specific_integral<T, E, unaligned> *)P;
}

inline uint16_t read16(const void *P, endianness E) {
  return read<uint16_t>(P, E);
}
inline uint32_t read32(const void *P, endianness E) {
  return read<uint32_t>(P, E);
}
inline uint64_t read64(const void *P, endianness E) {
  return read<uint64_t>(P, E);
}

template <endianness E> inline uint16_t read16(const void *P) {
  return read<uint16_t, E>(P);
}
template <endianness E> inline uint32_t read32(const void *P) {
  return read<uint32_t, E>(P);
}
template <endianness E> inline uint64_t read64(const void *P) {
  return read<uint64_t, E>(P);
}

inline uint16_t read16le(const void *P) { return read16<little>(P); }
inline uint32_t read32le(const void *P) { return read32<little>(P); }
inline uint64_t read64le(const void *P) { return read64<little>(P); }
inline uint16_t read16be(const void *P) { return read16<big>(P); }
inline uint32_t read32be(const void *P) { return read32<big>(P); }
inline uint64_t read64be(const void *P) { return read64<big>(P); }

template <typename T> inline void write(void *P, T V, endianness E) {
  write<T, unaligned>(P, V, E);
}

template <typename T, endianness E> inline void write(void *P, T V) {
  *(detail::packed_endian_specific_integral<T, E, unaligned> *)P = V;
}

inline void write16(void *P, uint16_t V, endianness E) {
  write<uint16_t>(P, V, E);
}
inline void write32(void *P, uint32_t V, endianness E) {
  write<uint32_t>(P, V, E);
}
inline void write64(void *P, uint64_t V, endianness E) {
  write<uint64_t>(P, V, E);
}

template <endianness E> inline void write16(void *P, uint16_t V) {
  write<uint16_t, E>(P, V);
}
template <endianness E> inline void write32(void *P, uint32_t V) {
  write<uint32_t, E>(P, V);
}
template <endianness E> inline void write64(void *P, uint64_t V) {
  write<uint64_t, E>(P, V);
}

inline void write16le(void *P, uint16_t V) { write16<little>(P, V); }
inline void write32le(void *P, uint32_t V) { write32<little>(P, V); }
inline void write64le(void *P, uint64_t V) { write64<little>(P, V); }
inline void write16be(void *P, uint16_t V) { write16<big>(P, V); }
inline void write32be(void *P, uint32_t V) { write32<big>(P, V); }
inline void write64be(void *P, uint64_t V) { write64<big>(P, V); }

} // end namespace endian

} // end namespace support
} // end namespace llvm

#endif // LLVM_SUPPORT_ENDIAN_H
# 430 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Endian.h"
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <array>
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"

namespace llvm {

template <typename T> class ArrayRef;

class MD5 {
  // Any 32-bit or wider unsigned integer data type will do.
  typedef uint32_t MD5_u32plus;

  MD5_u32plus a = 0x67452301;
  MD5_u32plus b = 0xefcdab89;
  MD5_u32plus c = 0x98badcfe;
  MD5_u32plus d = 0x10325476;
  MD5_u32plus hi = 0;
  MD5_u32plus lo = 0;
  uint8_t buffer[64];
  MD5_u32plus block[16];

public:
  struct MD5Result {
    std::array<uint8_t, 16> Bytes;

    operator std::array<uint8_t, 16>() const { return Bytes; }

    const uint8_t &operator[](size_t I) const { return Bytes[I]; }
    uint8_t &operator[](size_t I) { return Bytes[I]; }

    SmallString<32> digest() const;

    uint64_t low() const {
      // Our MD5 implementation returns the result in little endian, so the low
      // word is first.
      using namespace support;
      return endian::read<uint64_t, little, unaligned>(Bytes.data());
    }

    uint64_t high() const {
      using namespace support;
      return endian::read<uint64_t, little, unaligned>(Bytes.data() + 8);
    }
    std::pair<uint64_t, uint64_t> words() const {
      using namespace support;
      return std::make_pair(high(), low());
    }
  };

  MD5();

  /// Updates the hash for the byte stream provided.
  void update(ArrayRef<uint8_t> Data);

  /// Updates the hash for the StringRef provided.
  void update(StringRef Str);

  /// Finishes off the hash and puts the result in result.
  void final(MD5Result &Result);

  /// Translates the bytes in \p Res to a hex string that is
  /// deposited into \p Str. The result will be of length 32.
  static void stringifyResult(MD5Result &Result, SmallString<32> &Str);

  /// Computes the hash for a given bytes.
  static std::array<uint8_t, 16> hash(ArrayRef<uint8_t> Data);

private:
  const uint8_t *body(ArrayRef<uint8_t> Data);
};

inline bool operator==(const MD5::MD5Result &LHS, const MD5::MD5Result &RHS) {
  return LHS.Bytes == RHS.Bytes;
}

/// Helper to compute and return lower 64 bits of the given string's MD5 hash.
inline uint64_t MD5Hash(StringRef Str) {
  using namespace support;

  MD5 Hash;
  Hash.update(Str);
  MD5::MD5Result Result;
  Hash.final(Result);
  // Return the least significant word.
  return Result.low();
}

} // end namespace llvm

#endif // LLVM_SUPPORT_MD5_H
# 123 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MD5.h"
# 38 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 38 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 39 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 39 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <ctime>
#endif /* expanded by -frewrite-includes */
# 40 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 41 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 41 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 42 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <stack>
#endif /* expanded by -frewrite-includes */
# 42 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 1 3
// -*- C++ -*-
//===---------------------------- stack -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STACK
#define _LIBCPP_STACK

/*
    stack synopsis

namespace std
{

template <class T, class Container = deque<T>>
class stack
{
public:
    typedef Container                                container_type;
    typedef typename container_type::value_type      value_type;
    typedef typename container_type::reference       reference;
    typedef typename container_type::const_reference const_reference;
    typedef typename container_type::size_type       size_type;

protected:
    container_type c;

public:
    stack() = default;
    ~stack() = default;

    stack(const stack& q) = default;
    stack(stack&& q) = default;

    stack& operator=(const stack& q) = default;
    stack& operator=(stack&& q) = default;

    explicit stack(const container_type& c);
    explicit stack(container_type&& c);
    template <class Alloc> explicit stack(const Alloc& a);
    template <class Alloc> stack(const container_type& c, const Alloc& a);
    template <class Alloc> stack(container_type&& c, const Alloc& a);
    template <class Alloc> stack(const stack& c, const Alloc& a);
    template <class Alloc> stack(stack&& c, const Alloc& a);

    bool empty() const;
    size_type size() const;
    reference top();
    const_reference top() const;

    void push(const value_type& x);
    void push(value_type&& x);
    template <class... Args> reference emplace(Args&&... args); // reference in C++17
    void pop();

    void swap(stack& c) noexcept(is_nothrow_swappable_v<Container>)
};

template<class Container>
  stack(Container) -> stack<typename Container::value_type, Container>;  // C++17

template<class Container, class Allocator>
  stack(Container, Allocator) -> stack<typename Container::value_type, Container>; // C++17

template <class T, class Container>
  bool operator==(const stack<T, Container>& x, const stack<T, Container>& y);
template <class T, class Container>
  bool operator< (const stack<T, Container>& x, const stack<T, Container>& y);
template <class T, class Container>
  bool operator!=(const stack<T, Container>& x, const stack<T, Container>& y);
template <class T, class Container>
  bool operator> (const stack<T, Container>& x, const stack<T, Container>& y);
template <class T, class Container>
  bool operator>=(const stack<T, Container>& x, const stack<T, Container>& y);
template <class T, class Container>
  bool operator<=(const stack<T, Container>& x, const stack<T, Container>& y);

template <class T, class Container>
  void swap(stack<T, Container>& x, stack<T, Container>& y)
  noexcept(noexcept(x.swap(y)));

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 90 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
#if 0 /* expanded by -frewrite-includes */
#include <deque>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 1 3
// -*- C++ -*-
//===---------------------------- deque -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_DEQUE
#define _LIBCPP_DEQUE

/*
    deque synopsis

namespace std
{

template <class T, class Allocator = allocator<T> >
class deque
{
public:
    // types:
    typedef T value_type;
    typedef Allocator allocator_type;

    typedef typename allocator_type::reference       reference;
    typedef typename allocator_type::const_reference const_reference;
    typedef implementation-defined                   iterator;
    typedef implementation-defined                   const_iterator;
    typedef typename allocator_type::size_type       size_type;
    typedef typename allocator_type::difference_type difference_type;

    typedef typename allocator_type::pointer         pointer;
    typedef typename allocator_type::const_pointer   const_pointer;
    typedef std::reverse_iterator<iterator>          reverse_iterator;
    typedef std::reverse_iterator<const_iterator>    const_reverse_iterator;

    // construct/copy/destroy:
    deque() noexcept(is_nothrow_default_constructible<allocator_type>::value);
    explicit deque(const allocator_type& a);
    explicit deque(size_type n);
    explicit deque(size_type n, const allocator_type& a); // C++14
    deque(size_type n, const value_type& v);
    deque(size_type n, const value_type& v, const allocator_type& a);
    template <class InputIterator>
        deque(InputIterator f, InputIterator l);
    template <class InputIterator>
        deque(InputIterator f, InputIterator l, const allocator_type& a);
    deque(const deque& c);
    deque(deque&& c)
        noexcept(is_nothrow_move_constructible<allocator_type>::value);
    deque(initializer_list<value_type> il, const Allocator& a = allocator_type());
    deque(const deque& c, const allocator_type& a);
    deque(deque&& c, const allocator_type& a);
    ~deque();

    deque& operator=(const deque& c);
    deque& operator=(deque&& c)
        noexcept(
             allocator_type::propagate_on_container_move_assignment::value &&
             is_nothrow_move_assignable<allocator_type>::value);
    deque& operator=(initializer_list<value_type> il);

    template <class InputIterator>
        void assign(InputIterator f, InputIterator l);
    void assign(size_type n, const value_type& v);
    void assign(initializer_list<value_type> il);

    allocator_type get_allocator() const noexcept;

    // iterators:

    iterator       begin() noexcept;
    const_iterator begin() const noexcept;
    iterator       end() noexcept;
    const_iterator end() const noexcept;

    reverse_iterator       rbegin() noexcept;
    const_reverse_iterator rbegin() const noexcept;
    reverse_iterator       rend() noexcept;
    const_reverse_iterator rend() const noexcept;

    const_iterator         cbegin() const noexcept;
    const_iterator         cend() const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend() const noexcept;

    // capacity:
    size_type size() const noexcept;
    size_type max_size() const noexcept;
    void resize(size_type n);
    void resize(size_type n, const value_type& v);
    void shrink_to_fit();
    bool empty() const noexcept;

    // element access:
    reference operator[](size_type i);
    const_reference operator[](size_type i) const;
    reference at(size_type i);
    const_reference at(size_type i) const;
    reference front();
    const_reference front() const;
    reference back();
    const_reference back() const;

    // modifiers:
    void push_front(const value_type& v);
    void push_front(value_type&& v);
    void push_back(const value_type& v);
    void push_back(value_type&& v);
    template <class... Args> reference emplace_front(Args&&... args);  // reference in C++17
    template <class... Args> reference emplace_back(Args&&... args);   // reference in C++17
    template <class... Args> iterator emplace(const_iterator p, Args&&... args);
    iterator insert(const_iterator p, const value_type& v);
    iterator insert(const_iterator p, value_type&& v);
    iterator insert(const_iterator p, size_type n, const value_type& v);
    template <class InputIterator>
        iterator insert(const_iterator p, InputIterator f, InputIterator l);
    iterator insert(const_iterator p, initializer_list<value_type> il);
    void pop_front();
    void pop_back();
    iterator erase(const_iterator p);
    iterator erase(const_iterator f, const_iterator l);
    void swap(deque& c)
        noexcept(allocator_traits<allocator_type>::is_always_equal::value);  // C++17
    void clear() noexcept;
};

template <class InputIterator, class Allocator = allocator<typename iterator_traits<InputIterator>::value_type>>
   deque(InputIterator, InputIterator, Allocator = Allocator())
   -> deque<typename iterator_traits<InputIterator>::value_type, Allocator>;

template <class T, class Allocator>
    bool operator==(const deque<T,Allocator>& x, const deque<T,Allocator>& y);
template <class T, class Allocator>
    bool operator< (const deque<T,Allocator>& x, const deque<T,Allocator>& y);
template <class T, class Allocator>
    bool operator!=(const deque<T,Allocator>& x, const deque<T,Allocator>& y);
template <class T, class Allocator>
    bool operator> (const deque<T,Allocator>& x, const deque<T,Allocator>& y);
template <class T, class Allocator>
    bool operator>=(const deque<T,Allocator>& x, const deque<T,Allocator>& y);
template <class T, class Allocator>
    bool operator<=(const deque<T,Allocator>& x, const deque<T,Allocator>& y);

// specialized algorithms:
template <class T, class Allocator>
    void swap(deque<T,Allocator>& x, deque<T,Allocator>& y)
         noexcept(noexcept(x.swap(y)));

template <class T, class Allocator, class U>
    void erase(deque<T, Allocator>& c, const U& value);       // C++20
template <class T, class Allocator, class Predicate>
    void erase_if(deque<T, Allocator>& c, Predicate pred);    // C++20

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 161 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 162 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#if 0 /* expanded by -frewrite-includes */
#include <__split_buffer>
#endif /* expanded by -frewrite-includes */
# 162 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 163 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 163 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 164 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 165 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 165 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 166 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 167 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 167 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 168 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#if 0 /* expanded by -frewrite-includes */
#include <version>
#endif /* expanded by -frewrite-includes */
# 168 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 169 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 171 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 172 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
#endif
# 173 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3

_LIBCPP_PUSH_MACROS
#if 0 /* expanded by -frewrite-includes */
#include <__undef_macros>
#endif /* expanded by -frewrite-includes */
# 175 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 1 3
// -*- C++ -*-
//===------------------------ __undef_macros ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//


#ifdef min
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef min
#endif
# 22 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3

#ifdef max
#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_DISABLE_MACRO_CONFLICT_WARNINGS)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_WARNING)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 26 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 31 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#endif
# 32 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
#undef max
#endif
# 34 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/__undef_macros" 3
# 176 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 2 3


_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Tp, class _Allocator> class __deque_base;
template <class _Tp, class _Allocator = allocator<_Tp> > class _LIBCPP_TEMPLATE_VIS deque;

template <class _ValueType, class _Pointer, class _Reference, class _MapPointer,
          class _DiffType, _DiffType _BlockSize>
class _LIBCPP_TEMPLATE_VIS __deque_iterator;

template <class _RAIter,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
copy(_RAIter __f,
     _RAIter __l,
     __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
     typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type* = 0);

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _OutputIterator>
_OutputIterator
copy(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
     __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
     _OutputIterator __r);

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
copy(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
     __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
     __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r);

template <class _RAIter,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
copy_backward(_RAIter __f,
              _RAIter __l,
              __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
              typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type* = 0);

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _OutputIterator>
_OutputIterator
copy_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
              __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
              _OutputIterator __r);

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
copy_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
              __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
              __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r);

template <class _RAIter,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
move(_RAIter __f,
     _RAIter __l,
     __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
     typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type* = 0);

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _OutputIterator>
_OutputIterator
move(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
     __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
     _OutputIterator __r);

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
move(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
     __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
     __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r);

template <class _RAIter,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
move_backward(_RAIter __f,
              _RAIter __l,
              __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
              typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type* = 0);

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _OutputIterator>
_OutputIterator
move_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
              __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
              _OutputIterator __r);

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
move_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
              __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
              __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r);

template <class _ValueType, class _DiffType>
struct __deque_block_size {
  static const _DiffType value = sizeof(_ValueType) < 256 ? 4096 / sizeof(_ValueType) : 16;
};

template <class _ValueType, class _Pointer, class _Reference, class _MapPointer,
          class _DiffType, _DiffType _BS =
#ifdef _LIBCPP_ABI_INCOMPLETE_TYPES_IN_DEQUE
// Keep template parameter to avoid changing all template declarations thoughout
// this file.
                               0
#else
# 287 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
                               __deque_block_size<_ValueType, _DiffType>::value
#endif
# 289 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
          >
class _LIBCPP_TEMPLATE_VIS __deque_iterator
{
    typedef _MapPointer __map_iterator;
public:
    typedef _Pointer  pointer;
    typedef _DiffType difference_type;
private:
    __map_iterator __m_iter_;
    pointer        __ptr_;

    static const difference_type __block_size;
public:
    typedef _ValueType                  value_type;
    typedef random_access_iterator_tag  iterator_category;
    typedef _Reference                  reference;

    _LIBCPP_INLINE_VISIBILITY __deque_iterator() _NOEXCEPT
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 308 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
     : __m_iter_(nullptr), __ptr_(nullptr)
#endif
# 310 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
     {}

    template <class _Pp, class _Rp, class _MP>
    _LIBCPP_INLINE_VISIBILITY
    __deque_iterator(const __deque_iterator<value_type, _Pp, _Rp, _MP, difference_type, _BS>& __it,
                typename enable_if<is_convertible<_Pp, pointer>::value>::type* = 0) _NOEXCEPT
        : __m_iter_(__it.__m_iter_), __ptr_(__it.__ptr_) {}

    _LIBCPP_INLINE_VISIBILITY reference operator*() const {return *__ptr_;}
    _LIBCPP_INLINE_VISIBILITY pointer operator->() const {return __ptr_;}

    _LIBCPP_INLINE_VISIBILITY __deque_iterator& operator++()
    {
        if (++__ptr_ - *__m_iter_ == __block_size)
        {
            ++__m_iter_;
            __ptr_ = *__m_iter_;
        }
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY __deque_iterator operator++(int)
    {
        __deque_iterator __tmp = *this;
        ++(*this);
        return __tmp;
    }

    _LIBCPP_INLINE_VISIBILITY __deque_iterator& operator--()
    {
        if (__ptr_ == *__m_iter_)
        {
            --__m_iter_;
            __ptr_ = *__m_iter_ + __block_size;
        }
        --__ptr_;
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY __deque_iterator operator--(int)
    {
        __deque_iterator __tmp = *this;
        --(*this);
        return __tmp;
    }

    _LIBCPP_INLINE_VISIBILITY __deque_iterator& operator+=(difference_type __n)
    {
        if (__n != 0)
        {
            __n += __ptr_ - *__m_iter_;
            if (__n > 0)
            {
                __m_iter_ += __n / __block_size;
                __ptr_ = *__m_iter_ + __n % __block_size;
            }
            else // (__n < 0)
            {
                difference_type __z = __block_size - 1 - __n;
                __m_iter_ -= __z / __block_size;
                __ptr_ = *__m_iter_ + (__block_size - 1 - __z % __block_size);
            }
        }
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY __deque_iterator& operator-=(difference_type __n)
    {
        return *this += -__n;
    }

    _LIBCPP_INLINE_VISIBILITY __deque_iterator operator+(difference_type __n) const
    {
        __deque_iterator __t(*this);
        __t += __n;
        return __t;
    }

    _LIBCPP_INLINE_VISIBILITY __deque_iterator operator-(difference_type __n) const
    {
        __deque_iterator __t(*this);
        __t -= __n;
        return __t;
    }

    _LIBCPP_INLINE_VISIBILITY
    friend __deque_iterator operator+(difference_type __n, const __deque_iterator& __it)
        {return __it + __n;}

    _LIBCPP_INLINE_VISIBILITY
    friend difference_type operator-(const __deque_iterator& __x, const __deque_iterator& __y)
    {
        if (__x != __y)
            return (__x.__m_iter_ - __y.__m_iter_) * __block_size
                 + (__x.__ptr_ - *__x.__m_iter_)
                 - (__y.__ptr_ - *__y.__m_iter_);
        return 0;
    }

    _LIBCPP_INLINE_VISIBILITY reference operator[](difference_type __n) const
        {return *(*this + __n);}

    _LIBCPP_INLINE_VISIBILITY friend
        bool operator==(const __deque_iterator& __x, const __deque_iterator& __y)
        {return __x.__ptr_ == __y.__ptr_;}

    _LIBCPP_INLINE_VISIBILITY friend
        bool operator!=(const __deque_iterator& __x, const __deque_iterator& __y)
        {return !(__x == __y);}

    _LIBCPP_INLINE_VISIBILITY friend
        bool operator<(const __deque_iterator& __x, const __deque_iterator& __y)
        {return __x.__m_iter_ < __y.__m_iter_ ||
               (__x.__m_iter_ == __y.__m_iter_ && __x.__ptr_ < __y.__ptr_);}

    _LIBCPP_INLINE_VISIBILITY friend
        bool operator>(const __deque_iterator& __x, const __deque_iterator& __y)
        {return __y < __x;}

    _LIBCPP_INLINE_VISIBILITY friend
        bool operator<=(const __deque_iterator& __x, const __deque_iterator& __y)
        {return !(__y < __x);}

    _LIBCPP_INLINE_VISIBILITY friend
        bool operator>=(const __deque_iterator& __x, const __deque_iterator& __y)
        {return !(__x < __y);}

private:
    _LIBCPP_INLINE_VISIBILITY __deque_iterator(__map_iterator __m, pointer __p) _NOEXCEPT
        : __m_iter_(__m), __ptr_(__p) {}

    template <class _Tp, class _Ap> friend class __deque_base;
    template <class _Tp, class _Ap> friend class _LIBCPP_TEMPLATE_VIS deque;
    template <class _Vp, class _Pp, class _Rp, class _MP, class _Dp, _Dp>
        friend class _LIBCPP_TEMPLATE_VIS __deque_iterator;

    template <class _RAIter,
              class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
    friend
    __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
    copy(_RAIter __f,
         _RAIter __l,
         __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
         typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*);

    template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
              class _OutputIterator>
    friend
    _OutputIterator
    copy(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
         __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
         _OutputIterator __r);

    template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
              class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
    friend
    __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
    copy(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
         __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
         __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r);

    template <class _RAIter,
              class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
    friend
    __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
    copy_backward(_RAIter __f,
                  _RAIter __l,
                  __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
                  typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*);

    template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
              class _OutputIterator>
    friend
    _OutputIterator
    copy_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
                  __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
                  _OutputIterator __r);

    template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
              class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
    friend
    __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
    copy_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
                  __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
                  __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r);

    template <class _RAIter,
              class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
    friend
    __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
    move(_RAIter __f,
         _RAIter __l,
         __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
         typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*);

    template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
              class _OutputIterator>
    friend
    _OutputIterator
    move(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
         __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
         _OutputIterator __r);

    template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
              class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
    friend
    __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
    move(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
         __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
         __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r);

    template <class _RAIter,
              class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
    friend
    __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
    move_backward(_RAIter __f,
                  _RAIter __l,
                  __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
                  typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*);

    template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
              class _OutputIterator>
    friend
    _OutputIterator
    move_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
                  __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
                  _OutputIterator __r);

    template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
              class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
    friend
    __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
    move_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
                  __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
                  __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r);
};

template <class _ValueType, class _Pointer, class _Reference, class _MapPointer,
          class _DiffType, _DiffType _BlockSize>
const _DiffType __deque_iterator<_ValueType, _Pointer, _Reference, _MapPointer,
                                 _DiffType, _BlockSize>::__block_size =
    __deque_block_size<_ValueType, _DiffType>::value;

// copy

template <class _RAIter,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
copy(_RAIter __f,
     _RAIter __l,
     __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
     typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*)
{
    typedef typename __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::difference_type difference_type;
    typedef typename __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::pointer pointer;
    const difference_type __block_size = __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::__block_size;
    while (__f != __l)
    {
        pointer __rb = __r.__ptr_;
        pointer __re = *__r.__m_iter_ + __block_size;
        difference_type __bs = __re - __rb;
        difference_type __n = __l - __f;
        _RAIter __m = __l;
        if (__n > __bs)
        {
            __n = __bs;
            __m = __f + __n;
        }
        _VSTD::copy(__f, __m, __rb);
        __f = __m;
        __r += __n;
    }
    return __r;
}

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _OutputIterator>
_OutputIterator
copy(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
     __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
     _OutputIterator __r)
{
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::difference_type difference_type;
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::pointer pointer;
    const difference_type __block_size = __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::__block_size;
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        pointer __fb = __f.__ptr_;
        pointer __fe = *__f.__m_iter_ + __block_size;
        difference_type __bs = __fe - __fb;
        if (__bs > __n)
        {
            __bs = __n;
            __fe = __fb + __bs;
        }
        __r = _VSTD::copy(__fb, __fe, __r);
        __n -= __bs;
        __f += __bs;
    }
    return __r;
}

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
copy(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
     __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
     __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r)
{
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::difference_type difference_type;
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::pointer pointer;
    const difference_type __block_size = __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::__block_size;
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        pointer __fb = __f.__ptr_;
        pointer __fe = *__f.__m_iter_ + __block_size;
        difference_type __bs = __fe - __fb;
        if (__bs > __n)
        {
            __bs = __n;
            __fe = __fb + __bs;
        }
        __r = _VSTD::copy(__fb, __fe, __r);
        __n -= __bs;
        __f += __bs;
    }
    return __r;
}

// copy_backward

template <class _RAIter,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
copy_backward(_RAIter __f,
              _RAIter __l,
              __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
              typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*)
{
    typedef typename __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::difference_type difference_type;
    typedef typename __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::pointer pointer;
    while (__f != __l)
    {
        __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __rp = _VSTD::prev(__r);
        pointer __rb = *__rp.__m_iter_;
        pointer __re = __rp.__ptr_ + 1;
        difference_type __bs = __re - __rb;
        difference_type __n = __l - __f;
        _RAIter __m = __f;
        if (__n > __bs)
        {
            __n = __bs;
            __m = __l - __n;
        }
        _VSTD::copy_backward(__m, __l, __re);
        __l = __m;
        __r -= __n;
    }
    return __r;
}

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _OutputIterator>
_OutputIterator
copy_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
              __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
              _OutputIterator __r)
{
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::difference_type difference_type;
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::pointer pointer;
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        --__l;
        pointer __lb = *__l.__m_iter_;
        pointer __le = __l.__ptr_ + 1;
        difference_type __bs = __le - __lb;
        if (__bs > __n)
        {
            __bs = __n;
            __lb = __le - __bs;
        }
        __r = _VSTD::copy_backward(__lb, __le, __r);
        __n -= __bs;
        __l -= __bs - 1;
    }
    return __r;
}

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
copy_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
              __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
              __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r)
{
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::difference_type difference_type;
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::pointer pointer;
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        --__l;
        pointer __lb = *__l.__m_iter_;
        pointer __le = __l.__ptr_ + 1;
        difference_type __bs = __le - __lb;
        if (__bs > __n)
        {
            __bs = __n;
            __lb = __le - __bs;
        }
        __r = _VSTD::copy_backward(__lb, __le, __r);
        __n -= __bs;
        __l -= __bs - 1;
    }
    return __r;
}

// move

template <class _RAIter,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
move(_RAIter __f,
     _RAIter __l,
     __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
     typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*)
{
    typedef typename __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::difference_type difference_type;
    typedef typename __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::pointer pointer;
    const difference_type __block_size = __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::__block_size;
    while (__f != __l)
    {
        pointer __rb = __r.__ptr_;
        pointer __re = *__r.__m_iter_ + __block_size;
        difference_type __bs = __re - __rb;
        difference_type __n = __l - __f;
        _RAIter __m = __l;
        if (__n > __bs)
        {
            __n = __bs;
            __m = __f + __n;
        }
        _VSTD::move(__f, __m, __rb);
        __f = __m;
        __r += __n;
    }
    return __r;
}

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _OutputIterator>
_OutputIterator
move(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
     __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
     _OutputIterator __r)
{
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::difference_type difference_type;
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::pointer pointer;
    const difference_type __block_size = __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::__block_size;
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        pointer __fb = __f.__ptr_;
        pointer __fe = *__f.__m_iter_ + __block_size;
        difference_type __bs = __fe - __fb;
        if (__bs > __n)
        {
            __bs = __n;
            __fe = __fb + __bs;
        }
        __r = _VSTD::move(__fb, __fe, __r);
        __n -= __bs;
        __f += __bs;
    }
    return __r;
}

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
move(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
     __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
     __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r)
{
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::difference_type difference_type;
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::pointer pointer;
    const difference_type __block_size = __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::__block_size;
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        pointer __fb = __f.__ptr_;
        pointer __fe = *__f.__m_iter_ + __block_size;
        difference_type __bs = __fe - __fb;
        if (__bs > __n)
        {
            __bs = __n;
            __fe = __fb + __bs;
        }
        __r = _VSTD::move(__fb, __fe, __r);
        __n -= __bs;
        __f += __bs;
    }
    return __r;
}

// move_backward

template <class _RAIter,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
move_backward(_RAIter __f,
              _RAIter __l,
              __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r,
              typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*)
{
    typedef typename __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::difference_type difference_type;
    typedef typename __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>::pointer pointer;
    while (__f != __l)
    {
        __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __rp = _VSTD::prev(__r);
        pointer __rb = *__rp.__m_iter_;
        pointer __re = __rp.__ptr_ + 1;
        difference_type __bs = __re - __rb;
        difference_type __n = __l - __f;
        _RAIter __m = __f;
        if (__n > __bs)
        {
            __n = __bs;
            __m = __l - __n;
        }
        _VSTD::move_backward(__m, __l, __re);
        __l = __m;
        __r -= __n;
    }
    return __r;
}

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _OutputIterator>
_OutputIterator
move_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
              __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
              _OutputIterator __r)
{
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::difference_type difference_type;
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::pointer pointer;
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        --__l;
        pointer __lb = *__l.__m_iter_;
        pointer __le = __l.__ptr_ + 1;
        difference_type __bs = __le - __lb;
        if (__bs > __n)
        {
            __bs = __n;
            __lb = __le - __bs;
        }
        __r = _VSTD::move_backward(__lb, __le, __r);
        __n -= __bs;
        __l -= __bs - 1;
    }
    return __r;
}

template <class _V1, class _P1, class _R1, class _M1, class _D1, _D1 _B1,
          class _V2, class _P2, class _R2, class _M2, class _D2, _D2 _B2>
__deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2>
move_backward(__deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __f,
              __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1> __l,
              __deque_iterator<_V2, _P2, _R2, _M2, _D2, _B2> __r)
{
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::difference_type difference_type;
    typedef typename __deque_iterator<_V1, _P1, _R1, _M1, _D1, _B1>::pointer pointer;
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        --__l;
        pointer __lb = *__l.__m_iter_;
        pointer __le = __l.__ptr_ + 1;
        difference_type __bs = __le - __lb;
        if (__bs > __n)
        {
            __bs = __n;
            __lb = __le - __bs;
        }
        __r = _VSTD::move_backward(__lb, __le, __r);
        __n -= __bs;
        __l -= __bs - 1;
    }
    return __r;
}

template <bool>
class __deque_base_common
{
protected:
    _LIBCPP_NORETURN void __throw_length_error() const;
    _LIBCPP_NORETURN void __throw_out_of_range() const;
};

template <bool __b>
void
__deque_base_common<__b>::__throw_length_error() const
{
    _VSTD::__throw_length_error("deque");
}

template <bool __b>
void
__deque_base_common<__b>::__throw_out_of_range() const
{
    _VSTD::__throw_out_of_range("deque");
}

template <class _Tp, class _Allocator>
class __deque_base
    : protected __deque_base_common<true>
{
    __deque_base(const __deque_base& __c);
    __deque_base& operator=(const __deque_base& __c);
public:
    typedef _Allocator                               allocator_type;
    typedef allocator_traits<allocator_type>         __alloc_traits;
    typedef typename __alloc_traits::size_type       size_type;

    typedef _Tp                                      value_type;
    typedef value_type&                              reference;
    typedef const value_type&                        const_reference;
    typedef typename __alloc_traits::difference_type difference_type;
    typedef typename __alloc_traits::pointer         pointer;
    typedef typename __alloc_traits::const_pointer   const_pointer;

    static const difference_type __block_size;

    typedef typename __rebind_alloc_helper<__alloc_traits, pointer>::type __pointer_allocator;
    typedef allocator_traits<__pointer_allocator>        __map_traits;
    typedef typename __map_traits::pointer               __map_pointer;
    typedef typename __rebind_alloc_helper<__alloc_traits, const_pointer>::type __const_pointer_allocator;
    typedef typename allocator_traits<__const_pointer_allocator>::const_pointer __map_const_pointer;
    typedef __split_buffer<pointer, __pointer_allocator> __map;

    typedef __deque_iterator<value_type, pointer, reference, __map_pointer,
                             difference_type>    iterator;
    typedef __deque_iterator<value_type, const_pointer, const_reference, __map_const_pointer,
                             difference_type>    const_iterator;

    struct __deque_block_range {
      explicit __deque_block_range(pointer __b, pointer __e) _NOEXCEPT : __begin_(__b), __end_(__e) {}
      const pointer __begin_;
      const pointer __end_;
    };

    struct __deque_range {
      iterator __pos_;
      const iterator __end_;

      __deque_range(iterator __pos, iterator __e) _NOEXCEPT
        : __pos_(__pos), __end_(__e) {}

      explicit operator bool() const _NOEXCEPT {
        return __pos_ != __end_;
      }

      __deque_range begin() const {
        return *this;
      }

      __deque_range end() const {
        return __deque_range(__end_, __end_);
      }
      __deque_block_range operator*() const _NOEXCEPT {
         if (__pos_.__m_iter_ == __end_.__m_iter_) {
          return __deque_block_range(__pos_.__ptr_, __end_.__ptr_);
        }
        return __deque_block_range(__pos_.__ptr_, *__pos_.__m_iter_ + __block_size);
      }

      __deque_range& operator++() _NOEXCEPT {
        if (__pos_.__m_iter_ == __end_.__m_iter_) {
          __pos_ = __end_;
        } else {
          ++__pos_.__m_iter_;
          __pos_.__ptr_ = *__pos_.__m_iter_;
        }
        return *this;
      }


      friend bool operator==(__deque_range const& __lhs, __deque_range const& __rhs) {
        return __lhs.__pos_ == __rhs.__pos_;
      }
      friend bool operator!=(__deque_range const& __lhs, __deque_range const& __rhs) {
        return !(__lhs == __rhs);
      }
    };



    struct _ConstructTransaction {
      _ConstructTransaction(__deque_base* __db, __deque_block_range& __r)
        : __pos_(__r.__begin_), __end_(__r.__end_), __begin_(__r.__begin_), __base_(__db) {}


      ~_ConstructTransaction() {
        __base_->size() += (__pos_ - __begin_);
      }

      pointer __pos_;
      const pointer __end_;
    private:
      const pointer __begin_;
      __deque_base * const __base_;
    };

protected:
    __map __map_;
    size_type __start_;
    __compressed_pair<size_type, allocator_type> __size_;

    iterator       begin() _NOEXCEPT;
    const_iterator begin() const _NOEXCEPT;
    iterator       end() _NOEXCEPT;
    const_iterator end() const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY size_type&            size()          {return __size_.first();}
    _LIBCPP_INLINE_VISIBILITY
    const size_type& size() const _NOEXCEPT {return __size_.first();}
    _LIBCPP_INLINE_VISIBILITY allocator_type&       __alloc()       {return __size_.second();}
    _LIBCPP_INLINE_VISIBILITY
    const allocator_type& __alloc() const _NOEXCEPT {return __size_.second();}

    _LIBCPP_INLINE_VISIBILITY
    __deque_base()
        _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value);
    _LIBCPP_INLINE_VISIBILITY
    explicit __deque_base(const allocator_type& __a);
public:
    ~__deque_base();

#ifndef _LIBCPP_CXX03_LANG
    __deque_base(__deque_base&& __c)
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value);
    __deque_base(__deque_base&& __c, const allocator_type& __a);
#endif  // _LIBCPP_CXX03_LANG
# 1057 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3

    void swap(__deque_base& __c)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1060 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        _NOEXCEPT;
#else
# 1062 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value);
#endif
# 1065 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
protected:
    void clear() _NOEXCEPT;

    bool __invariants() const;

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign(__deque_base& __c)
        _NOEXCEPT_(__alloc_traits::propagate_on_container_move_assignment::value &&
                   is_nothrow_move_assignable<allocator_type>::value)
    {
        __map_ = _VSTD::move(__c.__map_);
        __start_ = __c.__start_;
        size() = __c.size();
        __move_assign_alloc(__c);
        __c.__start_ = __c.size() = 0;
    }

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__deque_base& __c)
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_move_assignment::value ||
                   is_nothrow_move_assignable<allocator_type>::value)
        {__move_assign_alloc(__c, integral_constant<bool,
                      __alloc_traits::propagate_on_container_move_assignment::value>());}

private:
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__deque_base& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
        {
            __alloc() = _VSTD::move(__c.__alloc());
        }

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(__deque_base&, false_type) _NOEXCEPT
        {}
};

template <class _Tp, class _Allocator>
const typename __deque_base<_Tp, _Allocator>::difference_type
    __deque_base<_Tp, _Allocator>::__block_size =
        __deque_block_size<value_type, difference_type>::value;

template <class _Tp, class _Allocator>
bool
__deque_base<_Tp, _Allocator>::__invariants() const
{
    if (!__map_.__invariants())
        return false;
    if (__map_.size() >= size_type(-1) / __block_size)
        return false;
    for (typename __map::const_iterator __i = __map_.begin(), __e = __map_.end();
         __i != __e; ++__i)
        if (*__i == nullptr)
            return false;
    if (__map_.size() != 0)
    {
        if (size() >= __map_.size() * __block_size)
            return false;
        if (__start_ >= __map_.size() * __block_size - size())
            return false;
    }
    else
    {
        if (size() != 0)
            return false;
        if (__start_ != 0)
            return false;
    }
    return true;
}

template <class _Tp, class _Allocator>
typename __deque_base<_Tp, _Allocator>::iterator
__deque_base<_Tp, _Allocator>::begin() _NOEXCEPT
{
    __map_pointer __mp = __map_.begin() + __start_ / __block_size;
    return iterator(__mp, __map_.empty() ? 0 : *__mp + __start_ % __block_size);
}

template <class _Tp, class _Allocator>
typename __deque_base<_Tp, _Allocator>::const_iterator
__deque_base<_Tp, _Allocator>::begin() const _NOEXCEPT
{
    __map_const_pointer __mp = static_cast<__map_const_pointer>(__map_.begin() + __start_ / __block_size);
    return const_iterator(__mp, __map_.empty() ? 0 : *__mp + __start_ % __block_size);
}

template <class _Tp, class _Allocator>
typename __deque_base<_Tp, _Allocator>::iterator
__deque_base<_Tp, _Allocator>::end() _NOEXCEPT
{
    size_type __p = size() + __start_;
    __map_pointer __mp = __map_.begin() + __p / __block_size;
    return iterator(__mp, __map_.empty() ? 0 : *__mp + __p % __block_size);
}

template <class _Tp, class _Allocator>
typename __deque_base<_Tp, _Allocator>::const_iterator
__deque_base<_Tp, _Allocator>::end() const _NOEXCEPT
{
    size_type __p = size() + __start_;
    __map_const_pointer __mp = static_cast<__map_const_pointer>(__map_.begin() + __p / __block_size);
    return const_iterator(__mp, __map_.empty() ? 0 : *__mp + __p % __block_size);
}

template <class _Tp, class _Allocator>
inline
__deque_base<_Tp, _Allocator>::__deque_base()
    _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value)
    : __start_(0), __size_(0, __default_init_tag()) {}

template <class _Tp, class _Allocator>
inline
__deque_base<_Tp, _Allocator>::__deque_base(const allocator_type& __a)
    : __map_(__pointer_allocator(__a)), __start_(0), __size_(0, __a) {}

template <class _Tp, class _Allocator>
__deque_base<_Tp, _Allocator>::~__deque_base()
{
    clear();
    typename __map::iterator __i = __map_.begin();
    typename __map::iterator __e = __map_.end();
    for (; __i != __e; ++__i)
        __alloc_traits::deallocate(__alloc(), *__i, __block_size);
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Allocator>
__deque_base<_Tp, _Allocator>::__deque_base(__deque_base&& __c)
    _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value)
    : __map_(_VSTD::move(__c.__map_)),
      __start_(_VSTD::move(__c.__start_)),
      __size_(_VSTD::move(__c.__size_))
{
    __c.__start_ = 0;
    __c.size() = 0;
}

template <class _Tp, class _Allocator>
__deque_base<_Tp, _Allocator>::__deque_base(__deque_base&& __c, const allocator_type& __a)
    : __map_(_VSTD::move(__c.__map_), __pointer_allocator(__a)),
      __start_(_VSTD::move(__c.__start_)),
      __size_(_VSTD::move(__c.size()), __a)
{
    if (__a == __c.__alloc())
    {
        __c.__start_ = 0;
        __c.size() = 0;
    }
    else
    {
        __map_.clear();
        __start_ = 0;
        size() = 0;
    }
}

#endif  // _LIBCPP_CXX03_LANG
# 1224 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3

template <class _Tp, class _Allocator>
void
__deque_base<_Tp, _Allocator>::swap(__deque_base& __c)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1229 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        _NOEXCEPT
#else
# 1231 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value)
#endif
# 1234 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
{
    __map_.swap(__c.__map_);
    _VSTD::swap(__start_, __c.__start_);
    _VSTD::swap(size(), __c.size());
    __swap_allocator(__alloc(), __c.__alloc());
}

template <class _Tp, class _Allocator>
void
__deque_base<_Tp, _Allocator>::clear() _NOEXCEPT
{
    allocator_type& __a = __alloc();
    for (iterator __i = begin(), __e = end(); __i != __e; ++__i)
        __alloc_traits::destroy(__a, _VSTD::addressof(*__i));
    size() = 0;
    while (__map_.size() > 2)
    {
        __alloc_traits::deallocate(__a, __map_.front(), __block_size);
        __map_.pop_front();
    }
    switch (__map_.size())
    {
    case 1:
        __start_ = __block_size / 2;
        break;
    case 2:
        __start_ = __block_size;
        break;
    }
}

template <class _Tp, class _Allocator /*= allocator<_Tp>*/>
class _LIBCPP_TEMPLATE_VIS deque
    : private __deque_base<_Tp, _Allocator>
{
public:
    // types:

    typedef _Tp value_type;
    typedef _Allocator allocator_type;

    static_assert((is_same<typename allocator_type::value_type, value_type>::value),
                  "Allocator::value_type must be same type as value_type");

    typedef __deque_base<value_type, allocator_type> __base;

    typedef typename __base::__alloc_traits        __alloc_traits;
    typedef typename __base::reference             reference;
    typedef typename __base::const_reference       const_reference;
    typedef typename __base::iterator              iterator;
    typedef typename __base::const_iterator        const_iterator;
    typedef typename __base::size_type             size_type;
    typedef typename __base::difference_type       difference_type;

    typedef typename __base::pointer               pointer;
    typedef typename __base::const_pointer         const_pointer;
    typedef _VSTD::reverse_iterator<iterator>       reverse_iterator;
    typedef _VSTD::reverse_iterator<const_iterator> const_reverse_iterator;

    using typename __base::__deque_range;
    using typename __base::__deque_block_range;
    using typename __base::_ConstructTransaction;

    // construct/copy/destroy:
    _LIBCPP_INLINE_VISIBILITY
    deque()
        _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value)
        {}
    _LIBCPP_INLINE_VISIBILITY explicit deque(const allocator_type& __a) : __base(__a) {}
    explicit deque(size_type __n);
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1305 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    explicit deque(size_type __n, const _Allocator& __a);
#endif
# 1307 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    deque(size_type __n, const value_type& __v);
    deque(size_type __n, const value_type& __v, const allocator_type& __a);
    template <class _InputIter>
        deque(_InputIter __f, _InputIter __l,
              typename enable_if<__is_cpp17_input_iterator<_InputIter>::value>::type* = 0);
    template <class _InputIter>
        deque(_InputIter __f, _InputIter __l, const allocator_type& __a,
              typename enable_if<__is_cpp17_input_iterator<_InputIter>::value>::type* = 0);
    deque(const deque& __c);
    deque(const deque& __c, const allocator_type& __a);

    deque& operator=(const deque& __c);

#ifndef _LIBCPP_CXX03_LANG
    deque(initializer_list<value_type> __il);
    deque(initializer_list<value_type> __il, const allocator_type& __a);

    _LIBCPP_INLINE_VISIBILITY
    deque& operator=(initializer_list<value_type> __il) {assign(__il); return *this;}

    _LIBCPP_INLINE_VISIBILITY
    deque(deque&& __c) _NOEXCEPT_(is_nothrow_move_constructible<__base>::value);
    _LIBCPP_INLINE_VISIBILITY
    deque(deque&& __c, const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    deque& operator=(deque&& __c)
        _NOEXCEPT_(__alloc_traits::propagate_on_container_move_assignment::value &&
                   is_nothrow_move_assignable<allocator_type>::value);

    _LIBCPP_INLINE_VISIBILITY
    void assign(initializer_list<value_type> __il) {assign(__il.begin(), __il.end());}
#endif  // _LIBCPP_CXX03_LANG
# 1339 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3

    template <class _InputIter>
        void assign(_InputIter __f, _InputIter __l,
                    typename enable_if<__is_cpp17_input_iterator<_InputIter>::value &&
                                      !__is_cpp17_random_access_iterator<_InputIter>::value>::type* = 0);
    template <class _RAIter>
        void assign(_RAIter __f, _RAIter __l,
                    typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type* = 0);
    void assign(size_type __n, const value_type& __v);

    _LIBCPP_INLINE_VISIBILITY
    allocator_type get_allocator() const _NOEXCEPT;

    // iterators:

    _LIBCPP_INLINE_VISIBILITY
    iterator       begin() _NOEXCEPT       {return __base::begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT {return __base::begin();}
    _LIBCPP_INLINE_VISIBILITY
    iterator       end() _NOEXCEPT         {return __base::end();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end()   const _NOEXCEPT {return __base::end();}

    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator       rbegin() _NOEXCEPT
        {return       reverse_iterator(__base::end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin() const _NOEXCEPT
        {return const_reverse_iterator(__base::end());}
    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator       rend() _NOEXCEPT
        {return       reverse_iterator(__base::begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend()   const _NOEXCEPT
        {return const_reverse_iterator(__base::begin());}

    _LIBCPP_INLINE_VISIBILITY
    const_iterator         cbegin()  const _NOEXCEPT
        {return __base::begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator         cend()    const _NOEXCEPT
        {return __base::end();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT
        {return const_reverse_iterator(__base::end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend()   const _NOEXCEPT
        {return const_reverse_iterator(__base::begin());}

    // capacity:
    _LIBCPP_INLINE_VISIBILITY
    size_type size() const _NOEXCEPT {return __base::size();}
    _LIBCPP_INLINE_VISIBILITY
    size_type max_size() const _NOEXCEPT
        {return std::min<size_type>(
            __alloc_traits::max_size(__base::__alloc()),
            numeric_limits<difference_type>::max());}
    void resize(size_type __n);
    void resize(size_type __n, const value_type& __v);
    void shrink_to_fit() _NOEXCEPT;
    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool empty() const _NOEXCEPT {return __base::size() == 0;}

    // element access:
    _LIBCPP_INLINE_VISIBILITY
    reference operator[](size_type __i) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    const_reference operator[](size_type __i) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    reference at(size_type __i);
    _LIBCPP_INLINE_VISIBILITY
    const_reference at(size_type __i) const;
    _LIBCPP_INLINE_VISIBILITY
    reference front() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    const_reference front() const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    reference back() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    const_reference back() const _NOEXCEPT;

    // 23.2.2.3 modifiers:
    void push_front(const value_type& __v);
    void push_back(const value_type& __v);
#ifndef _LIBCPP_CXX03_LANG
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1426 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    template <class... _Args> reference emplace_front(_Args&&... __args);
    template <class... _Args> reference emplace_back (_Args&&... __args);
#else
# 1429 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    template <class... _Args> void      emplace_front(_Args&&... __args);
    template <class... _Args> void      emplace_back (_Args&&... __args);
#endif
# 1432 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    template <class... _Args> iterator emplace(const_iterator __p, _Args&&... __args);

    void push_front(value_type&& __v);
    void push_back(value_type&& __v);
    iterator insert(const_iterator __p, value_type&& __v);

    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __p, initializer_list<value_type> __il)
        {return insert(__p, __il.begin(), __il.end());}
#endif  // _LIBCPP_CXX03_LANG
# 1442 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    iterator insert(const_iterator __p, const value_type& __v);
    iterator insert(const_iterator __p, size_type __n, const value_type& __v);
    template <class _InputIter>
        iterator insert(const_iterator __p, _InputIter __f, _InputIter __l,
                         typename enable_if<__is_cpp17_input_iterator<_InputIter>::value
                                         &&!__is_cpp17_forward_iterator<_InputIter>::value>::type* = 0);
    template <class _ForwardIterator>
        iterator insert(const_iterator __p, _ForwardIterator __f, _ForwardIterator __l,
                               typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value
                                         &&!__is_cpp17_bidirectional_iterator<_ForwardIterator>::value>::type* = 0);
    template <class _BiIter>
        iterator insert(const_iterator __p, _BiIter __f, _BiIter __l,
                         typename enable_if<__is_cpp17_bidirectional_iterator<_BiIter>::value>::type* = 0);

    void pop_front();
    void pop_back();
    iterator erase(const_iterator __p);
    iterator erase(const_iterator __f, const_iterator __l);

    _LIBCPP_INLINE_VISIBILITY
    void swap(deque& __c)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1464 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        _NOEXCEPT;
#else
# 1466 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                   __is_nothrow_swappable<allocator_type>::value);
#endif
# 1469 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    bool __invariants() const {return __base::__invariants();}

    typedef typename __base::__map_const_pointer __map_const_pointer;

    _LIBCPP_INLINE_VISIBILITY
    static size_type __recommend_blocks(size_type __n)
    {
        return __n / __base::__block_size + (__n % __base::__block_size != 0);
    }
    _LIBCPP_INLINE_VISIBILITY
    size_type __capacity() const
    {
        return __base::__map_.size() == 0 ? 0 : __base::__map_.size() * __base::__block_size - 1;
    }
    _LIBCPP_INLINE_VISIBILITY
    size_type __block_count() const
    {
        return __base::__map_.size();
    }

    _LIBCPP_INLINE_VISIBILITY
    size_type __front_spare() const
    {
        return __base::__start_;
    }
    _LIBCPP_INLINE_VISIBILITY
    size_type __front_spare_blocks() const {
      return __front_spare() / __base::__block_size;
    }
    _LIBCPP_INLINE_VISIBILITY
    size_type __back_spare() const
    {
        return __capacity() - (__base::__start_ + __base::size());
    }
    _LIBCPP_INLINE_VISIBILITY
    size_type __back_spare_blocks() const {
      return __back_spare() / __base::__block_size;
    }

 private:
    _LIBCPP_INLINE_VISIBILITY
    bool __maybe_remove_front_spare(bool __keep_one = true) {
      if (__front_spare_blocks() >= 2 || (!__keep_one && __front_spare_blocks())) {
        __alloc_traits::deallocate(__base::__alloc(), __base::__map_.front(),
                                   __base::__block_size);
        __base::__map_.pop_front();
        __base::__start_ -= __base::__block_size;
        return true;
      }
      return false;
    }

    _LIBCPP_INLINE_VISIBILITY
    bool __maybe_remove_back_spare(bool __keep_one = true) {
      if (__back_spare_blocks() >= 2 || (!__keep_one && __back_spare_blocks())) {
        __alloc_traits::deallocate(__base::__alloc(), __base::__map_.back(),
                                   __base::__block_size);
        __base::__map_.pop_back();
        return true;
      }
      return false;
    }

    template <class _InpIter>
        void __append(_InpIter __f, _InpIter __l,
                 typename enable_if<__is_cpp17_input_iterator<_InpIter>::value &&
                                   !__is_cpp17_forward_iterator<_InpIter>::value>::type* = 0);
    template <class _ForIter>
        void __append(_ForIter __f, _ForIter __l,
                      typename enable_if<__is_cpp17_forward_iterator<_ForIter>::value>::type* = 0);
    void __append(size_type __n);
    void __append(size_type __n, const value_type& __v);
    void __erase_to_end(const_iterator __f);
    void __add_front_capacity();
    void __add_front_capacity(size_type __n);
    void __add_back_capacity();
    void __add_back_capacity(size_type __n);
    iterator __move_and_check(iterator __f, iterator __l, iterator __r,
                              const_pointer& __vt);
    iterator __move_backward_and_check(iterator __f, iterator __l, iterator __r,
                                       const_pointer& __vt);
    void __move_construct_and_check(iterator __f, iterator __l,
                                    iterator __r, const_pointer& __vt);
    void __move_construct_backward_and_check(iterator __f, iterator __l,
                                             iterator __r, const_pointer& __vt);

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const deque& __c)
        {__copy_assign_alloc(__c, integral_constant<bool,
                      __alloc_traits::propagate_on_container_copy_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const deque& __c, true_type)
        {
            if (__base::__alloc() != __c.__alloc())
            {
                clear();
                shrink_to_fit();
            }
            __base::__alloc() = __c.__alloc();
            __base::__map_.__alloc() = __c.__map_.__alloc();
        }

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const deque&, false_type)
        {}

    void __move_assign(deque& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value);
    void __move_assign(deque& __c, false_type);
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _InputIterator,
         class _Alloc = typename std::allocator<typename iterator_traits<_InputIterator>::value_type>,
         class = typename enable_if<__is_allocator<_Alloc>::value, void>::type
         >
deque(_InputIterator, _InputIterator)
  -> deque<typename iterator_traits<_InputIterator>::value_type, _Alloc>;

template<class _InputIterator,
         class _Alloc,
         class = typename enable_if<__is_allocator<_Alloc>::value, void>::type
         >
deque(_InputIterator, _InputIterator, _Alloc)
  -> deque<typename iterator_traits<_InputIterator>::value_type, _Alloc>;
#endif
# 1600 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3


template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>::deque(size_type __n)
{
    if (__n > 0)
        __append(__n);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 11
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 1610 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>::deque(size_type __n, const _Allocator& __a)
    : __base(__a)
{
    if (__n > 0)
        __append(__n);
}
#endif
# 1618 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3

template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>::deque(size_type __n, const value_type& __v)
{
    if (__n > 0)
        __append(__n, __v);
}

template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>::deque(size_type __n, const value_type& __v, const allocator_type& __a)
    : __base(__a)
{
    if (__n > 0)
        __append(__n, __v);
}

template <class _Tp, class _Allocator>
template <class _InputIter>
deque<_Tp, _Allocator>::deque(_InputIter __f, _InputIter __l,
              typename enable_if<__is_cpp17_input_iterator<_InputIter>::value>::type*)
{
    __append(__f, __l);
}

template <class _Tp, class _Allocator>
template <class _InputIter>
deque<_Tp, _Allocator>::deque(_InputIter __f, _InputIter __l, const allocator_type& __a,
              typename enable_if<__is_cpp17_input_iterator<_InputIter>::value>::type*)
    : __base(__a)
{
    __append(__f, __l);
}

template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>::deque(const deque& __c)
    : __base(__alloc_traits::select_on_container_copy_construction(__c.__alloc()))
{
    __append(__c.begin(), __c.end());
}

template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>::deque(const deque& __c, const allocator_type& __a)
    : __base(__a)
{
    __append(__c.begin(), __c.end());
}

template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>&
deque<_Tp, _Allocator>::operator=(const deque& __c)
{
    if (this != &__c)
    {
        __copy_assign_alloc(__c);
        assign(__c.begin(), __c.end());
    }
    return *this;
}

#ifndef _LIBCPP_CXX03_LANG

template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>::deque(initializer_list<value_type> __il)
{
    __append(__il.begin(), __il.end());
}

template <class _Tp, class _Allocator>
deque<_Tp, _Allocator>::deque(initializer_list<value_type> __il, const allocator_type& __a)
    : __base(__a)
{
    __append(__il.begin(), __il.end());
}

template <class _Tp, class _Allocator>
inline
deque<_Tp, _Allocator>::deque(deque&& __c)
    _NOEXCEPT_(is_nothrow_move_constructible<__base>::value)
    : __base(_VSTD::move(__c))
{
}

template <class _Tp, class _Allocator>
inline
deque<_Tp, _Allocator>::deque(deque&& __c, const allocator_type& __a)
    : __base(_VSTD::move(__c), __a)
{
    if (__a != __c.__alloc())
    {
        typedef move_iterator<iterator> _Ip;
        assign(_Ip(__c.begin()), _Ip(__c.end()));
    }
}

template <class _Tp, class _Allocator>
inline
deque<_Tp, _Allocator>&
deque<_Tp, _Allocator>::operator=(deque&& __c)
        _NOEXCEPT_(__alloc_traits::propagate_on_container_move_assignment::value &&
                   is_nothrow_move_assignable<allocator_type>::value)
{
    __move_assign(__c, integral_constant<bool,
          __alloc_traits::propagate_on_container_move_assignment::value>());
    return *this;
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__move_assign(deque& __c, false_type)
{
    if (__base::__alloc() != __c.__alloc())
    {
        typedef move_iterator<iterator> _Ip;
        assign(_Ip(__c.begin()), _Ip(__c.end()));
    }
    else
        __move_assign(__c, true_type());
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__move_assign(deque& __c, true_type)
    _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
{
    clear();
    shrink_to_fit();
    __base::__move_assign(__c);
}

#endif  // _LIBCPP_CXX03_LANG
# 1748 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3

template <class _Tp, class _Allocator>
template <class _InputIter>
void
deque<_Tp, _Allocator>::assign(_InputIter __f, _InputIter __l,
                               typename enable_if<__is_cpp17_input_iterator<_InputIter>::value &&
                                                 !__is_cpp17_random_access_iterator<_InputIter>::value>::type*)
{
    iterator __i = __base::begin();
    iterator __e = __base::end();
    for (; __f != __l && __i != __e; ++__f, (void) ++__i)
        *__i = *__f;
    if (__f != __l)
        __append(__f, __l);
    else
        __erase_to_end(__i);
}

template <class _Tp, class _Allocator>
template <class _RAIter>
void
deque<_Tp, _Allocator>::assign(_RAIter __f, _RAIter __l,
                               typename enable_if<__is_cpp17_random_access_iterator<_RAIter>::value>::type*)
{
    if (static_cast<size_type>(__l - __f) > __base::size())
    {
        _RAIter __m = __f + __base::size();
        _VSTD::copy(__f, __m, __base::begin());
        __append(__m, __l);
    }
    else
        __erase_to_end(_VSTD::copy(__f, __l, __base::begin()));
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::assign(size_type __n, const value_type& __v)
{
    if (__n > __base::size())
    {
        _VSTD::fill_n(__base::begin(), __base::size(), __v);
        __n -= __base::size();
        __append(__n, __v);
    }
    else
        __erase_to_end(_VSTD::fill_n(__base::begin(), __n, __v));
}

template <class _Tp, class _Allocator>
inline
_Allocator
deque<_Tp, _Allocator>::get_allocator() const _NOEXCEPT
{
    return __base::__alloc();
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::resize(size_type __n)
{
    if (__n > __base::size())
        __append(__n - __base::size());
    else if (__n < __base::size())
        __erase_to_end(__base::begin() + __n);
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::resize(size_type __n, const value_type& __v)
{
    if (__n > __base::size())
        __append(__n - __base::size(), __v);
    else if (__n < __base::size())
        __erase_to_end(__base::begin() + __n);
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::shrink_to_fit() _NOEXCEPT
{
    allocator_type& __a = __base::__alloc();
    if (empty())
    {
        while (__base::__map_.size() > 0)
        {
            __alloc_traits::deallocate(__a, __base::__map_.back(), __base::__block_size);
            __base::__map_.pop_back();
        }
        __base::__start_ = 0;
    }
    else
    {
      __maybe_remove_front_spare(/*__keep_one=*/false);
      __maybe_remove_back_spare(/*__keep_one=*/false);
    }
    __base::__map_.shrink_to_fit();
}

template <class _Tp, class _Allocator>
inline
typename deque<_Tp, _Allocator>::reference
deque<_Tp, _Allocator>::operator[](size_type __i) _NOEXCEPT
{
    size_type __p = __base::__start_ + __i;
    return *(*(__base::__map_.begin() + __p / __base::__block_size) + __p % __base::__block_size);
}

template <class _Tp, class _Allocator>
inline
typename deque<_Tp, _Allocator>::const_reference
deque<_Tp, _Allocator>::operator[](size_type __i) const _NOEXCEPT
{
    size_type __p = __base::__start_ + __i;
    return *(*(__base::__map_.begin() + __p / __base::__block_size) + __p % __base::__block_size);
}

template <class _Tp, class _Allocator>
inline
typename deque<_Tp, _Allocator>::reference
deque<_Tp, _Allocator>::at(size_type __i)
{
    if (__i >= __base::size())
        __base::__throw_out_of_range();
    size_type __p = __base::__start_ + __i;
    return *(*(__base::__map_.begin() + __p / __base::__block_size) + __p % __base::__block_size);
}

template <class _Tp, class _Allocator>
inline
typename deque<_Tp, _Allocator>::const_reference
deque<_Tp, _Allocator>::at(size_type __i) const
{
    if (__i >= __base::size())
        __base::__throw_out_of_range();
    size_type __p = __base::__start_ + __i;
    return *(*(__base::__map_.begin() + __p / __base::__block_size) + __p % __base::__block_size);
}

template <class _Tp, class _Allocator>
inline
typename deque<_Tp, _Allocator>::reference
deque<_Tp, _Allocator>::front() _NOEXCEPT
{
    return *(*(__base::__map_.begin() + __base::__start_ / __base::__block_size)
                                      + __base::__start_ % __base::__block_size);
}

template <class _Tp, class _Allocator>
inline
typename deque<_Tp, _Allocator>::const_reference
deque<_Tp, _Allocator>::front() const _NOEXCEPT
{
    return *(*(__base::__map_.begin() + __base::__start_ / __base::__block_size)
                                      + __base::__start_ % __base::__block_size);
}

template <class _Tp, class _Allocator>
inline
typename deque<_Tp, _Allocator>::reference
deque<_Tp, _Allocator>::back() _NOEXCEPT
{
    size_type __p = __base::size() + __base::__start_ - 1;
    return *(*(__base::__map_.begin() + __p / __base::__block_size) + __p % __base::__block_size);
}

template <class _Tp, class _Allocator>
inline
typename deque<_Tp, _Allocator>::const_reference
deque<_Tp, _Allocator>::back() const _NOEXCEPT
{
    size_type __p = __base::size() + __base::__start_ - 1;
    return *(*(__base::__map_.begin() + __p / __base::__block_size) + __p % __base::__block_size);
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::push_back(const value_type& __v)
{
    allocator_type& __a = __base::__alloc();
    if (__back_spare() == 0)
        __add_back_capacity();
    // __back_spare() >= 1
    __alloc_traits::construct(__a, _VSTD::addressof(*__base::end()), __v);
    ++__base::size();
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::push_front(const value_type& __v)
{
    allocator_type& __a = __base::__alloc();
    if (__front_spare() == 0)
        __add_front_capacity();
    // __front_spare() >= 1
    __alloc_traits::construct(__a, _VSTD::addressof(*--__base::begin()), __v);
    --__base::__start_;
    ++__base::size();
}

#ifndef _LIBCPP_CXX03_LANG
template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::push_back(value_type&& __v)
{
    allocator_type& __a = __base::__alloc();
    if (__back_spare() == 0)
        __add_back_capacity();
    // __back_spare() >= 1
    __alloc_traits::construct(__a, _VSTD::addressof(*__base::end()), _VSTD::move(__v));
    ++__base::size();
}

template <class _Tp, class _Allocator>
template <class... _Args>
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1963 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
typename deque<_Tp, _Allocator>::reference
#else
# 1965 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
void
#endif
# 1967 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
deque<_Tp, _Allocator>::emplace_back(_Args&&... __args)
{
    allocator_type& __a = __base::__alloc();
    if (__back_spare() == 0)
        __add_back_capacity();
    // __back_spare() >= 1
    __alloc_traits::construct(__a, _VSTD::addressof(*__base::end()),
                              _VSTD::forward<_Args>(__args)...);
    ++__base::size();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1977 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    return *--__base::end();
#endif
# 1979 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::push_front(value_type&& __v)
{
    allocator_type& __a = __base::__alloc();
    if (__front_spare() == 0)
        __add_front_capacity();
    // __front_spare() >= 1
    __alloc_traits::construct(__a, _VSTD::addressof(*--__base::begin()), _VSTD::move(__v));
    --__base::__start_;
    ++__base::size();
}


template <class _Tp, class _Allocator>
template <class... _Args>
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 1998 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
typename deque<_Tp, _Allocator>::reference
#else
# 2000 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
void
#endif
# 2002 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
deque<_Tp, _Allocator>::emplace_front(_Args&&... __args)
{
    allocator_type& __a = __base::__alloc();
    if (__front_spare() == 0)
        __add_front_capacity();
    // __front_spare() >= 1
    __alloc_traits::construct(__a, _VSTD::addressof(*--__base::begin()), _VSTD::forward<_Args>(__args)...);
    --__base::__start_;
    ++__base::size();
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 2012 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
    return *__base::begin();
#endif
# 2014 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
}

template <class _Tp, class _Allocator>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::insert(const_iterator __p, value_type&& __v)
{
    size_type __pos = __p - __base::begin();
    size_type __to_end = __base::size() - __pos;
    allocator_type& __a = __base::__alloc();
    if (__pos < __to_end)
    {   // insert by shifting things backward
        if (__front_spare() == 0)
            __add_front_capacity();
        // __front_spare() >= 1
        if (__pos == 0)
        {
            __alloc_traits::construct(__a, _VSTD::addressof(*--__base::begin()), _VSTD::move(__v));
            --__base::__start_;
            ++__base::size();
        }
        else
        {
            iterator __b = __base::begin();
            iterator __bm1 = _VSTD::prev(__b);
            __alloc_traits::construct(__a, _VSTD::addressof(*__bm1), _VSTD::move(*__b));
            --__base::__start_;
            ++__base::size();
            if (__pos > 1)
                __b = _VSTD::move(_VSTD::next(__b), __b + __pos, __b);
            *__b = _VSTD::move(__v);
        }
    }
    else
    {   // insert by shifting things forward
        if (__back_spare() == 0)
            __add_back_capacity();
        // __back_capacity >= 1
        size_type __de = __base::size() - __pos;
        if (__de == 0)
        {
            __alloc_traits::construct(__a, _VSTD::addressof(*__base::end()), _VSTD::move(__v));
            ++__base::size();
        }
        else
        {
            iterator __e = __base::end();
            iterator __em1 = _VSTD::prev(__e);
            __alloc_traits::construct(__a, _VSTD::addressof(*__e), _VSTD::move(*__em1));
            ++__base::size();
            if (__de > 1)
                __e = _VSTD::move_backward(__e - __de, __em1, __e);
            *--__e = _VSTD::move(__v);
        }
    }
    return __base::begin() + __pos;
}

template <class _Tp, class _Allocator>
template <class... _Args>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::emplace(const_iterator __p, _Args&&... __args)
{
    size_type __pos = __p - __base::begin();
    size_type __to_end = __base::size() - __pos;
    allocator_type& __a = __base::__alloc();
    if (__pos < __to_end)
    {   // insert by shifting things backward
        if (__front_spare() == 0)
            __add_front_capacity();
        // __front_spare() >= 1
        if (__pos == 0)
        {
            __alloc_traits::construct(__a, _VSTD::addressof(*--__base::begin()), _VSTD::forward<_Args>(__args)...);
            --__base::__start_;
            ++__base::size();
        }
        else
        {
            __temp_value<value_type, _Allocator> __tmp(this->__alloc(), _VSTD::forward<_Args>(__args)...);
            iterator __b = __base::begin();
            iterator __bm1 = _VSTD::prev(__b);
            __alloc_traits::construct(__a, _VSTD::addressof(*__bm1), _VSTD::move(*__b));
            --__base::__start_;
            ++__base::size();
            if (__pos > 1)
                __b = _VSTD::move(_VSTD::next(__b), __b + __pos, __b);
            *__b = _VSTD::move(__tmp.get());
        }
    }
    else
    {   // insert by shifting things forward
        if (__back_spare() == 0)
            __add_back_capacity();
        // __back_capacity >= 1
        size_type __de = __base::size() - __pos;
        if (__de == 0)
        {
            __alloc_traits::construct(__a, _VSTD::addressof(*__base::end()), _VSTD::forward<_Args>(__args)...);
            ++__base::size();
        }
        else
        {
            __temp_value<value_type, _Allocator> __tmp(this->__alloc(), _VSTD::forward<_Args>(__args)...);
            iterator __e = __base::end();
            iterator __em1 = _VSTD::prev(__e);
            __alloc_traits::construct(__a, _VSTD::addressof(*__e), _VSTD::move(*__em1));
            ++__base::size();
            if (__de > 1)
                __e = _VSTD::move_backward(__e - __de, __em1, __e);
            *--__e = _VSTD::move(__tmp.get());
        }
    }
    return __base::begin() + __pos;
}

#endif  // _LIBCPP_CXX03_LANG
# 2130 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3


template <class _Tp, class _Allocator>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::insert(const_iterator __p, const value_type& __v)
{
    size_type __pos = __p - __base::begin();
    size_type __to_end = __base::size() - __pos;
    allocator_type& __a = __base::__alloc();
    if (__pos < __to_end)
    {   // insert by shifting things backward
        if (__front_spare() == 0)
            __add_front_capacity();
        // __front_spare() >= 1
        if (__pos == 0)
        {
            __alloc_traits::construct(__a, _VSTD::addressof(*--__base::begin()), __v);
            --__base::__start_;
            ++__base::size();
        }
        else
        {
            const_pointer __vt = pointer_traits<const_pointer>::pointer_to(__v);
            iterator __b = __base::begin();
            iterator __bm1 = _VSTD::prev(__b);
            if (__vt == pointer_traits<const_pointer>::pointer_to(*__b))
                __vt = pointer_traits<const_pointer>::pointer_to(*__bm1);
            __alloc_traits::construct(__a, _VSTD::addressof(*__bm1), _VSTD::move(*__b));
            --__base::__start_;
            ++__base::size();
            if (__pos > 1)
                __b = __move_and_check(_VSTD::next(__b), __b + __pos, __b, __vt);
            *__b = *__vt;
        }
    }
    else
    {   // insert by shifting things forward
        if (__back_spare() == 0)
            __add_back_capacity();
        // __back_capacity >= 1
        size_type __de = __base::size() - __pos;
        if (__de == 0)
        {
            __alloc_traits::construct(__a, _VSTD::addressof(*__base::end()), __v);
            ++__base::size();
        }
        else
        {
            const_pointer __vt = pointer_traits<const_pointer>::pointer_to(__v);
            iterator __e = __base::end();
            iterator __em1 = _VSTD::prev(__e);
            if (__vt == pointer_traits<const_pointer>::pointer_to(*__em1))
                __vt = pointer_traits<const_pointer>::pointer_to(*__e);
            __alloc_traits::construct(__a, _VSTD::addressof(*__e), _VSTD::move(*__em1));
            ++__base::size();
            if (__de > 1)
                __e = __move_backward_and_check(__e - __de, __em1, __e, __vt);
            *--__e = *__vt;
        }
    }
    return __base::begin() + __pos;
}

template <class _Tp, class _Allocator>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::insert(const_iterator __p, size_type __n, const value_type& __v)
{
    size_type __pos = __p - __base::begin();
    size_type __to_end = __base::size() - __pos;
    allocator_type& __a = __base::__alloc();
    if (__pos < __to_end)
    {   // insert by shifting things backward
        if (__n > __front_spare())
            __add_front_capacity(__n - __front_spare());
        // __n <= __front_spare()
        iterator __old_begin = __base::begin();
        iterator __i = __old_begin;
        if (__n > __pos)
        {
            for (size_type __m = __n - __pos; __m; --__m, --__base::__start_, ++__base::size())
                __alloc_traits::construct(__a, _VSTD::addressof(*--__i), __v);
            __n = __pos;
        }
        if (__n > 0)
        {
            const_pointer __vt = pointer_traits<const_pointer>::pointer_to(__v);
            iterator __obn = __old_begin + __n;
            __move_construct_backward_and_check(__old_begin, __obn, __i, __vt);
            if (__n < __pos)
                __old_begin = __move_and_check(__obn, __old_begin + __pos, __old_begin, __vt);
            _VSTD::fill_n(__old_begin, __n, *__vt);
        }
    }
    else
    {   // insert by shifting things forward
        size_type __back_capacity = __back_spare();
        if (__n > __back_capacity)
            __add_back_capacity(__n - __back_capacity);
        // __n <= __back_capacity
        iterator __old_end = __base::end();
        iterator __i = __old_end;
        size_type __de = __base::size() - __pos;
        if (__n > __de)
        {
            for (size_type __m = __n - __de; __m; --__m, ++__i, ++__base::size())
                __alloc_traits::construct(__a, _VSTD::addressof(*__i), __v);
            __n = __de;
        }
        if (__n > 0)
        {
            const_pointer __vt = pointer_traits<const_pointer>::pointer_to(__v);
            iterator __oen = __old_end - __n;
            __move_construct_and_check(__oen, __old_end, __i, __vt);
            if (__n < __de)
                __old_end = __move_backward_and_check(__old_end - __de, __oen, __old_end, __vt);
            _VSTD::fill_n(__old_end - __n, __n, *__vt);
        }
    }
    return __base::begin() + __pos;
}

template <class _Tp, class _Allocator>
template <class _InputIter>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::insert(const_iterator __p, _InputIter __f, _InputIter __l,
                               typename enable_if<__is_cpp17_input_iterator<_InputIter>::value
                                               &&!__is_cpp17_forward_iterator<_InputIter>::value>::type*)
{
    __split_buffer<value_type, allocator_type&> __buf(__base::__alloc());
    __buf.__construct_at_end(__f, __l);
    typedef typename __split_buffer<value_type, allocator_type&>::iterator __bi;
    return insert(__p, move_iterator<__bi>(__buf.begin()), move_iterator<__bi>(__buf.end()));
}

template <class _Tp, class _Allocator>
template <class _ForwardIterator>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::insert(const_iterator __p, _ForwardIterator __f, _ForwardIterator __l,
                               typename enable_if<__is_cpp17_forward_iterator<_ForwardIterator>::value
                                               &&!__is_cpp17_bidirectional_iterator<_ForwardIterator>::value>::type*)
{
    size_type __n = _VSTD::distance(__f, __l);
    __split_buffer<value_type, allocator_type&> __buf(__n, 0, __base::__alloc());
    __buf.__construct_at_end(__f, __l);
    typedef typename __split_buffer<value_type, allocator_type&>::iterator __fwd;
    return insert(__p, move_iterator<__fwd>(__buf.begin()), move_iterator<__fwd>(__buf.end()));
}

template <class _Tp, class _Allocator>
template <class _BiIter>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::insert(const_iterator __p, _BiIter __f, _BiIter __l,
                               typename enable_if<__is_cpp17_bidirectional_iterator<_BiIter>::value>::type*)
{
    size_type __n = _VSTD::distance(__f, __l);
    size_type __pos = __p - __base::begin();
    size_type __to_end = __base::size() - __pos;
    allocator_type& __a = __base::__alloc();
    if (__pos < __to_end)
    {   // insert by shifting things backward
        if (__n > __front_spare())
            __add_front_capacity(__n - __front_spare());
        // __n <= __front_spare()
        iterator __old_begin = __base::begin();
        iterator __i = __old_begin;
        _BiIter __m = __f;
        if (__n > __pos)
        {
            __m = __pos < __n / 2 ? _VSTD::prev(__l, __pos) : _VSTD::next(__f, __n - __pos);
            for (_BiIter __j = __m; __j != __f; --__base::__start_, ++__base::size())
                __alloc_traits::construct(__a, _VSTD::addressof(*--__i), *--__j);
            __n = __pos;
        }
        if (__n > 0)
        {
            iterator __obn = __old_begin + __n;
            for (iterator __j = __obn; __j != __old_begin;)
            {
                __alloc_traits::construct(__a, _VSTD::addressof(*--__i), _VSTD::move(*--__j));
                --__base::__start_;
                ++__base::size();
            }
            if (__n < __pos)
                __old_begin = _VSTD::move(__obn, __old_begin + __pos, __old_begin);
            _VSTD::copy(__m, __l, __old_begin);
        }
    }
    else
    {   // insert by shifting things forward
        size_type __back_capacity = __back_spare();
        if (__n > __back_capacity)
            __add_back_capacity(__n - __back_capacity);
        // __n <= __back_capacity
        iterator __old_end = __base::end();
        iterator __i = __old_end;
        _BiIter __m = __l;
        size_type __de = __base::size() - __pos;
        if (__n > __de)
        {
            __m = __de < __n / 2 ? _VSTD::next(__f, __de) : _VSTD::prev(__l, __n - __de);
            for (_BiIter __j = __m; __j != __l; ++__i, (void) ++__j, ++__base::size())
                __alloc_traits::construct(__a, _VSTD::addressof(*__i), *__j);
            __n = __de;
        }
        if (__n > 0)
        {
            iterator __oen = __old_end - __n;
            for (iterator __j = __oen; __j != __old_end; ++__i, ++__j, ++__base::size())
                __alloc_traits::construct(__a, _VSTD::addressof(*__i), _VSTD::move(*__j));
            if (__n < __de)
                __old_end = _VSTD::move_backward(__old_end - __de, __oen, __old_end);
            _VSTD::copy_backward(__f, __m, __old_end);
        }
    }
    return __base::begin() + __pos;
}

template <class _Tp, class _Allocator>
template <class _InpIter>
void
deque<_Tp, _Allocator>::__append(_InpIter __f, _InpIter __l,
                                 typename enable_if<__is_cpp17_input_iterator<_InpIter>::value &&
                                                   !__is_cpp17_forward_iterator<_InpIter>::value>::type*)
{
    for (; __f != __l; ++__f)
#ifdef _LIBCPP_CXX03_LANG
        push_back(*__f);
#else
# 2358 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        emplace_back(*__f);
#endif
# 2360 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
}

template <class _Tp, class _Allocator>
template <class _ForIter>
void
deque<_Tp, _Allocator>::__append(_ForIter __f, _ForIter __l,
                                 typename enable_if<__is_cpp17_forward_iterator<_ForIter>::value>::type*)
{
    size_type __n = _VSTD::distance(__f, __l);
    allocator_type& __a = __base::__alloc();
    size_type __back_capacity = __back_spare();
    if (__n > __back_capacity)
        __add_back_capacity(__n - __back_capacity);
    // __n <= __back_capacity
    for (__deque_block_range __br : __deque_range(__base::end(), __base::end() + __n)) {
      _ConstructTransaction __tx(this, __br);
      for (; __tx.__pos_ != __tx.__end_; ++__tx.__pos_, (void)++__f) {
        __alloc_traits::construct(__a, std::__to_address(__tx.__pos_), *__f);
      }
    }
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__append(size_type __n)
{
    allocator_type& __a = __base::__alloc();
    size_type __back_capacity = __back_spare();
    if (__n > __back_capacity)
        __add_back_capacity(__n - __back_capacity);
    // __n <= __back_capacity
    for (__deque_block_range __br : __deque_range(__base::end(), __base::end() + __n)) {
      _ConstructTransaction __tx(this, __br);
      for (; __tx.__pos_ != __tx.__end_; ++__tx.__pos_) {
        __alloc_traits::construct(__a, std::__to_address(__tx.__pos_));
      }
    }
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__append(size_type __n, const value_type& __v)
{
    allocator_type& __a = __base::__alloc();
    size_type __back_capacity = __back_spare();
    if (__n > __back_capacity)
        __add_back_capacity(__n - __back_capacity);
    // __n <= __back_capacity
    for (__deque_block_range __br : __deque_range(__base::end(), __base::end() + __n)) {
      _ConstructTransaction __tx(this, __br);
      for (; __tx.__pos_ != __tx.__end_; ++__tx.__pos_) {
        __alloc_traits::construct(__a, std::__to_address(__tx.__pos_), __v);
      }
    }

}

// Create front capacity for one block of elements.
// Strong guarantee.  Either do it or don't touch anything.
template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__add_front_capacity()
{
    allocator_type& __a = __base::__alloc();
    if (__back_spare() >= __base::__block_size)
    {
        __base::__start_ += __base::__block_size;
        pointer __pt = __base::__map_.back();
        __base::__map_.pop_back();
        __base::__map_.push_front(__pt);
    }
    // Else if __base::__map_.size() < __base::__map_.capacity() then we need to allocate 1 buffer
    else if (__base::__map_.size() < __base::__map_.capacity())
    {   // we can put the new buffer into the map, but don't shift things around
        // until all buffers are allocated.  If we throw, we don't need to fix
        // anything up (any added buffers are undetectible)
        if (__base::__map_.__front_spare() > 0)
            __base::__map_.push_front(__alloc_traits::allocate(__a, __base::__block_size));
        else
        {
            __base::__map_.push_back(__alloc_traits::allocate(__a, __base::__block_size));
            // Done allocating, reorder capacity
            pointer __pt = __base::__map_.back();
            __base::__map_.pop_back();
            __base::__map_.push_front(__pt);
        }
        __base::__start_ = __base::__map_.size() == 1 ?
                               __base::__block_size / 2 :
                               __base::__start_ + __base::__block_size;
    }
    // Else need to allocate 1 buffer, *and* we need to reallocate __map_.
    else
    {
        __split_buffer<pointer, typename __base::__pointer_allocator&>
            __buf(max<size_type>(2 * __base::__map_.capacity(), 1),
                  0, __base::__map_.__alloc());

        typedef __allocator_destructor<_Allocator> _Dp;
        unique_ptr<pointer, _Dp> __hold(
            __alloc_traits::allocate(__a, __base::__block_size),
                _Dp(__a, __base::__block_size));
        __buf.push_back(__hold.get());
        __hold.release();

        for (typename __base::__map_pointer __i = __base::__map_.begin();
                __i != __base::__map_.end(); ++__i)
            __buf.push_back(*__i);
        _VSTD::swap(__base::__map_.__first_, __buf.__first_);
        _VSTD::swap(__base::__map_.__begin_, __buf.__begin_);
        _VSTD::swap(__base::__map_.__end_, __buf.__end_);
        _VSTD::swap(__base::__map_.__end_cap(), __buf.__end_cap());
        __base::__start_ = __base::__map_.size() == 1 ?
                               __base::__block_size / 2 :
                               __base::__start_ + __base::__block_size;
    }
}

// Create front capacity for __n elements.
// Strong guarantee.  Either do it or don't touch anything.
template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__add_front_capacity(size_type __n)
{
    allocator_type& __a = __base::__alloc();
    size_type __nb = __recommend_blocks(__n + __base::__map_.empty());
    // Number of unused blocks at back:
    size_type __back_capacity = __back_spare() / __base::__block_size;
    __back_capacity = _VSTD::min(__back_capacity, __nb);  // don't take more than you need
    __nb -= __back_capacity;  // number of blocks need to allocate
    // If __nb == 0, then we have sufficient capacity.
    if (__nb == 0)
    {
        __base::__start_ += __base::__block_size * __back_capacity;
        for (; __back_capacity > 0; --__back_capacity)
        {
            pointer __pt = __base::__map_.back();
            __base::__map_.pop_back();
            __base::__map_.push_front(__pt);
        }
    }
    // Else if __nb <= __map_.capacity() - __map_.size() then we need to allocate __nb buffers
    else if (__nb <= __base::__map_.capacity() - __base::__map_.size())
    {   // we can put the new buffers into the map, but don't shift things around
        // until all buffers are allocated.  If we throw, we don't need to fix
        // anything up (any added buffers are undetectible)
        for (; __nb > 0; --__nb, __base::__start_ += __base::__block_size - (__base::__map_.size() == 1))
        {
            if (__base::__map_.__front_spare() == 0)
                break;
            __base::__map_.push_front(__alloc_traits::allocate(__a, __base::__block_size));
        }
        for (; __nb > 0; --__nb, ++__back_capacity)
            __base::__map_.push_back(__alloc_traits::allocate(__a, __base::__block_size));
        // Done allocating, reorder capacity
        __base::__start_ += __back_capacity * __base::__block_size;
        for (; __back_capacity > 0; --__back_capacity)
        {
            pointer __pt = __base::__map_.back();
            __base::__map_.pop_back();
            __base::__map_.push_front(__pt);
        }
    }
    // Else need to allocate __nb buffers, *and* we need to reallocate __map_.
    else
    {
        size_type __ds = (__nb + __back_capacity) * __base::__block_size - __base::__map_.empty();
        __split_buffer<pointer, typename __base::__pointer_allocator&>
            __buf(max<size_type>(2* __base::__map_.capacity(),
                                 __nb + __base::__map_.size()),
                  0, __base::__map_.__alloc());
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2534 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
            for (; __nb > 0; --__nb)
                __buf.push_back(__alloc_traits::allocate(__a, __base::__block_size));
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
            for (typename __base::__map_pointer __i = __buf.begin();
                    __i != __buf.end(); ++__i)
                __alloc_traits::deallocate(__a, *__i, __base::__block_size);
            throw;
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2546 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        for (; __back_capacity > 0; --__back_capacity)
        {
            __buf.push_back(__base::__map_.back());
            __base::__map_.pop_back();
        }
        for (typename __base::__map_pointer __i = __base::__map_.begin();
                __i != __base::__map_.end(); ++__i)
            __buf.push_back(*__i);
        _VSTD::swap(__base::__map_.__first_, __buf.__first_);
        _VSTD::swap(__base::__map_.__begin_, __buf.__begin_);
        _VSTD::swap(__base::__map_.__end_, __buf.__end_);
        _VSTD::swap(__base::__map_.__end_cap(), __buf.__end_cap());
        __base::__start_ += __ds;
    }
}

// Create back capacity for one block of elements.
// Strong guarantee.  Either do it or don't touch anything.
template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__add_back_capacity()
{
    allocator_type& __a = __base::__alloc();
    if (__front_spare() >= __base::__block_size)
    {
        __base::__start_ -= __base::__block_size;
        pointer __pt = __base::__map_.front();
        __base::__map_.pop_front();
        __base::__map_.push_back(__pt);
    }
    // Else if __nb <= __map_.capacity() - __map_.size() then we need to allocate __nb buffers
    else if (__base::__map_.size() < __base::__map_.capacity())
    {   // we can put the new buffer into the map, but don't shift things around
        // until it is allocated.  If we throw, we don't need to fix
        // anything up (any added buffers are undetectible)
        if (__base::__map_.__back_spare() != 0)
            __base::__map_.push_back(__alloc_traits::allocate(__a, __base::__block_size));
        else
        {
            __base::__map_.push_front(__alloc_traits::allocate(__a, __base::__block_size));
            // Done allocating, reorder capacity
            pointer __pt = __base::__map_.front();
            __base::__map_.pop_front();
            __base::__map_.push_back(__pt);
        }
    }
    // Else need to allocate 1 buffer, *and* we need to reallocate __map_.
    else
    {
        __split_buffer<pointer, typename __base::__pointer_allocator&>
            __buf(max<size_type>(2* __base::__map_.capacity(), 1),
                  __base::__map_.size(),
                  __base::__map_.__alloc());

        typedef __allocator_destructor<_Allocator> _Dp;
        unique_ptr<pointer, _Dp> __hold(
            __alloc_traits::allocate(__a, __base::__block_size),
                _Dp(__a, __base::__block_size));
        __buf.push_back(__hold.get());
        __hold.release();

        for (typename __base::__map_pointer __i = __base::__map_.end();
                __i != __base::__map_.begin();)
            __buf.push_front(*--__i);
        _VSTD::swap(__base::__map_.__first_, __buf.__first_);
        _VSTD::swap(__base::__map_.__begin_, __buf.__begin_);
        _VSTD::swap(__base::__map_.__end_, __buf.__end_);
        _VSTD::swap(__base::__map_.__end_cap(), __buf.__end_cap());
    }
}

// Create back capacity for __n elements.
// Strong guarantee.  Either do it or don't touch anything.
template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__add_back_capacity(size_type __n)
{
    allocator_type& __a = __base::__alloc();
    size_type __nb = __recommend_blocks(__n + __base::__map_.empty());
    // Number of unused blocks at front:
    size_type __front_capacity = __front_spare() / __base::__block_size;
    __front_capacity = _VSTD::min(__front_capacity, __nb);  // don't take more than you need
    __nb -= __front_capacity;  // number of blocks need to allocate
    // If __nb == 0, then we have sufficient capacity.
    if (__nb == 0)
    {
        __base::__start_ -= __base::__block_size * __front_capacity;
        for (; __front_capacity > 0; --__front_capacity)
        {
            pointer __pt = __base::__map_.front();
            __base::__map_.pop_front();
            __base::__map_.push_back(__pt);
        }
    }
    // Else if __nb <= __map_.capacity() - __map_.size() then we need to allocate __nb buffers
    else if (__nb <= __base::__map_.capacity() - __base::__map_.size())
    {   // we can put the new buffers into the map, but don't shift things around
        // until all buffers are allocated.  If we throw, we don't need to fix
        // anything up (any added buffers are undetectible)
        for (; __nb > 0; --__nb)
        {
            if (__base::__map_.__back_spare() == 0)
                break;
            __base::__map_.push_back(__alloc_traits::allocate(__a, __base::__block_size));
        }
        for (; __nb > 0; --__nb, ++__front_capacity, __base::__start_ +=
                                 __base::__block_size - (__base::__map_.size() == 1))
            __base::__map_.push_front(__alloc_traits::allocate(__a, __base::__block_size));
        // Done allocating, reorder capacity
        __base::__start_ -= __base::__block_size * __front_capacity;
        for (; __front_capacity > 0; --__front_capacity)
        {
            pointer __pt = __base::__map_.front();
            __base::__map_.pop_front();
            __base::__map_.push_back(__pt);
        }
    }
    // Else need to allocate __nb buffers, *and* we need to reallocate __map_.
    else
    {
        size_type __ds = __front_capacity * __base::__block_size;
        __split_buffer<pointer, typename __base::__pointer_allocator&>
            __buf(max<size_type>(2* __base::__map_.capacity(),
                                 __nb + __base::__map_.size()),
                  __base::__map_.size() - __front_capacity,
                  __base::__map_.__alloc());
#ifndef _LIBCPP_NO_EXCEPTIONS
        try
        {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2676 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
            for (; __nb > 0; --__nb)
                __buf.push_back(__alloc_traits::allocate(__a, __base::__block_size));
#ifndef _LIBCPP_NO_EXCEPTIONS
        }
        catch (...)
        {
            for (typename __base::__map_pointer __i = __buf.begin();
                    __i != __buf.end(); ++__i)
                __alloc_traits::deallocate(__a, *__i, __base::__block_size);
            throw;
        }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2688 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        for (; __front_capacity > 0; --__front_capacity)
        {
            __buf.push_back(__base::__map_.front());
            __base::__map_.pop_front();
        }
        for (typename __base::__map_pointer __i = __base::__map_.end();
                __i != __base::__map_.begin();)
            __buf.push_front(*--__i);
        _VSTD::swap(__base::__map_.__first_, __buf.__first_);
        _VSTD::swap(__base::__map_.__begin_, __buf.__begin_);
        _VSTD::swap(__base::__map_.__end_, __buf.__end_);
        _VSTD::swap(__base::__map_.__end_cap(), __buf.__end_cap());
        __base::__start_ -= __ds;
    }
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::pop_front()
{
    allocator_type& __a = __base::__alloc();
    __alloc_traits::destroy(__a, __to_address(*(__base::__map_.begin() +
                                                    __base::__start_ / __base::__block_size) +
                                                    __base::__start_ % __base::__block_size));
    --__base::size();
    ++__base::__start_;
    __maybe_remove_front_spare();
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::pop_back()
{
    _LIBCPP_ASSERT(!empty(), "deque::pop_back called for empty deque");
    allocator_type& __a = __base::__alloc();
    size_type __p = __base::size() + __base::__start_ - 1;
    __alloc_traits::destroy(__a, __to_address(*(__base::__map_.begin() +
                                                    __p / __base::__block_size) +
                                                    __p % __base::__block_size));
    --__base::size();
    __maybe_remove_back_spare();
}

// move assign [__f, __l) to [__r, __r + (__l-__f)).
// If __vt points into [__f, __l), then subtract (__f - __r) from __vt.
template <class _Tp, class _Allocator>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::__move_and_check(iterator __f, iterator __l, iterator __r,
                                         const_pointer& __vt)
{
    // as if
    //   for (; __f != __l; ++__f, ++__r)
    //       *__r = _VSTD::move(*__f);
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        pointer __fb = __f.__ptr_;
        pointer __fe = *__f.__m_iter_ + __base::__block_size;
        difference_type __bs = __fe - __fb;
        if (__bs > __n)
        {
            __bs = __n;
            __fe = __fb + __bs;
        }
        if (__fb <= __vt && __vt < __fe)
            __vt = (const_iterator(static_cast<__map_const_pointer>(__f.__m_iter_), __vt) -= __f - __r).__ptr_;
        __r = _VSTD::move(__fb, __fe, __r);
        __n -= __bs;
        __f += __bs;
    }
    return __r;
}

// move assign [__f, __l) to [__r - (__l-__f), __r) backwards.
// If __vt points into [__f, __l), then add (__r - __l) to __vt.
template <class _Tp, class _Allocator>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::__move_backward_and_check(iterator __f, iterator __l, iterator __r,
                                                  const_pointer& __vt)
{
    // as if
    //   while (__f != __l)
    //       *--__r = _VSTD::move(*--__l);
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        --__l;
        pointer __lb = *__l.__m_iter_;
        pointer __le = __l.__ptr_ + 1;
        difference_type __bs = __le - __lb;
        if (__bs > __n)
        {
            __bs = __n;
            __lb = __le - __bs;
        }
        if (__lb <= __vt && __vt < __le)
            __vt = (const_iterator(static_cast<__map_const_pointer>(__l.__m_iter_), __vt) += __r - __l - 1).__ptr_;
        __r = _VSTD::move_backward(__lb, __le, __r);
        __n -= __bs;
        __l -= __bs - 1;
    }
    return __r;
}

// move construct [__f, __l) to [__r, __r + (__l-__f)).
// If __vt points into [__f, __l), then add (__r - __f) to __vt.
template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__move_construct_and_check(iterator __f, iterator __l,
                                                   iterator __r, const_pointer& __vt)
{
    allocator_type& __a = __base::__alloc();
    // as if
    //   for (; __f != __l; ++__r, ++__f, ++__base::size())
    //       __alloc_traits::construct(__a, _VSTD::addressof(*__r), _VSTD::move(*__f));
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        pointer __fb = __f.__ptr_;
        pointer __fe = *__f.__m_iter_ + __base::__block_size;
        difference_type __bs = __fe - __fb;
        if (__bs > __n)
        {
            __bs = __n;
            __fe = __fb + __bs;
        }
        if (__fb <= __vt && __vt < __fe)
            __vt = (const_iterator(static_cast<__map_const_pointer>(__f.__m_iter_), __vt) += __r - __f).__ptr_;
        for (; __fb != __fe; ++__fb, ++__r, ++__base::size())
            __alloc_traits::construct(__a, _VSTD::addressof(*__r), _VSTD::move(*__fb));
        __n -= __bs;
        __f += __bs;
    }
}

// move construct [__f, __l) to [__r - (__l-__f), __r) backwards.
// If __vt points into [__f, __l), then subtract (__l - __r) from __vt.
template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__move_construct_backward_and_check(iterator __f, iterator __l,
                                                            iterator __r, const_pointer& __vt)
{
    allocator_type& __a = __base::__alloc();
    // as if
    //   for (iterator __j = __l; __j != __f;)
    //   {
    //       __alloc_traitsconstruct(__a, _VSTD::addressof(*--__r), _VSTD::move(*--__j));
    //       --__base::__start_;
    //       ++__base::size();
    //   }
    difference_type __n = __l - __f;
    while (__n > 0)
    {
        --__l;
        pointer __lb = *__l.__m_iter_;
        pointer __le = __l.__ptr_ + 1;
        difference_type __bs = __le - __lb;
        if (__bs > __n)
        {
            __bs = __n;
            __lb = __le - __bs;
        }
        if (__lb <= __vt && __vt < __le)
            __vt = (const_iterator(static_cast<__map_const_pointer>(__l.__m_iter_), __vt) -= __l - __r + 1).__ptr_;
        while (__le != __lb)
        {
            __alloc_traits::construct(__a, _VSTD::addressof(*--__r), _VSTD::move(*--__le));
            --__base::__start_;
            ++__base::size();
        }
        __n -= __bs;
        __l -= __bs - 1;
    }
}

template <class _Tp, class _Allocator>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::erase(const_iterator __f)
{
    iterator __b = __base::begin();
    difference_type __pos = __f - __b;
    iterator __p = __b + __pos;
    allocator_type& __a = __base::__alloc();
    if (static_cast<size_t>(__pos) <= (__base::size() - 1) / 2)
    {   // erase from front
        _VSTD::move_backward(__b, __p, _VSTD::next(__p));
        __alloc_traits::destroy(__a, _VSTD::addressof(*__b));
        --__base::size();
        ++__base::__start_;
        __maybe_remove_front_spare();
    }
    else
    {   // erase from back
        iterator __i = _VSTD::move(_VSTD::next(__p), __base::end(), __p);
        __alloc_traits::destroy(__a, _VSTD::addressof(*__i));
        --__base::size();
        __maybe_remove_back_spare();
    }
    return __base::begin() + __pos;
}

template <class _Tp, class _Allocator>
typename deque<_Tp, _Allocator>::iterator
deque<_Tp, _Allocator>::erase(const_iterator __f, const_iterator __l)
{
    difference_type __n = __l - __f;
    iterator __b = __base::begin();
    difference_type __pos = __f - __b;
    iterator __p = __b + __pos;
    if (__n > 0)
    {
        allocator_type& __a = __base::__alloc();
        if (static_cast<size_t>(__pos) <= (__base::size() - __n) / 2)
        {   // erase from front
            iterator __i = _VSTD::move_backward(__b, __p, __p + __n);
            for (; __b != __i; ++__b)
                __alloc_traits::destroy(__a, _VSTD::addressof(*__b));
            __base::size() -= __n;
            __base::__start_ += __n;
            while (__maybe_remove_front_spare()) {
            }
        }
        else
        {   // erase from back
            iterator __i = _VSTD::move(__p + __n, __base::end(), __p);
            for (iterator __e = __base::end(); __i != __e; ++__i)
                __alloc_traits::destroy(__a, _VSTD::addressof(*__i));
            __base::size() -= __n;
            while (__maybe_remove_back_spare()) {
            }
        }
    }
    return __base::begin() + __pos;
}

template <class _Tp, class _Allocator>
void
deque<_Tp, _Allocator>::__erase_to_end(const_iterator __f)
{
    iterator __e = __base::end();
    difference_type __n = __e - __f;
    if (__n > 0)
    {
        allocator_type& __a = __base::__alloc();
        iterator __b = __base::begin();
        difference_type __pos = __f - __b;
        for (iterator __p = __b + __pos; __p != __e; ++__p)
            __alloc_traits::destroy(__a, _VSTD::addressof(*__p));
        __base::size() -= __n;
        while (__maybe_remove_back_spare()) {
        }
    }
}

template <class _Tp, class _Allocator>
inline
void
deque<_Tp, _Allocator>::swap(deque& __c)
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER >= 14
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2947 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        _NOEXCEPT
#else
# 2949 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                    __is_nothrow_swappable<allocator_type>::value)
#endif
# 2952 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
{
    __base::swap(__c);
}

template <class _Tp, class _Allocator>
inline
void
deque<_Tp, _Allocator>::clear() _NOEXCEPT
{
    __base::clear();
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const deque<_Tp, _Allocator>& __x, const deque<_Tp, _Allocator>& __y)
{
    const typename deque<_Tp, _Allocator>::size_type __sz = __x.size();
    return __sz == __y.size() && _VSTD::equal(__x.begin(), __x.end(), __y.begin());
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const deque<_Tp, _Allocator>& __x, const deque<_Tp, _Allocator>& __y)
{
    return !(__x == __y);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const deque<_Tp, _Allocator>& __x, const deque<_Tp, _Allocator>& __y)
{
    return _VSTD::lexicographical_compare(__x.begin(), __x.end(), __y.begin(), __y.end());
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const deque<_Tp, _Allocator>& __x, const deque<_Tp, _Allocator>& __y)
{
    return __y < __x;
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const deque<_Tp, _Allocator>& __x, const deque<_Tp, _Allocator>& __y)
{
    return !(__x < __y);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const deque<_Tp, _Allocator>& __x, const deque<_Tp, _Allocator>& __y)
{
    return !(__y < __x);
}

template <class _Tp, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(deque<_Tp, _Allocator>& __x, deque<_Tp, _Allocator>& __y)
    _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 17
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 3023 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
template <class _Tp, class _Allocator, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
void erase(deque<_Tp, _Allocator>& __c, const _Up& __v)
{ __c.erase(_VSTD::remove(__c.begin(), __c.end(), __v), __c.end()); }

template <class _Tp, class _Allocator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
void erase_if(deque<_Tp, _Allocator>& __c, _Predicate __pred)
{ __c.erase(_VSTD::remove_if(__c.begin(), __c.end(), __pred), __c.end()); }
#endif
# 3033 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3


_LIBCPP_END_NAMESPACE_STD

_LIBCPP_POP_MACROS

#endif  // _LIBCPP_DEQUE
# 3040 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/deque" 3
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Tp, class _Container = deque<_Tp> > class _LIBCPP_TEMPLATE_VIS stack;

template <class _Tp, class _Container>
_LIBCPP_INLINE_VISIBILITY
bool
operator==(const stack<_Tp, _Container>& __x, const stack<_Tp, _Container>& __y);

template <class _Tp, class _Container>
_LIBCPP_INLINE_VISIBILITY
bool
operator< (const stack<_Tp, _Container>& __x, const stack<_Tp, _Container>& __y);

template <class _Tp, class _Container /*= deque<_Tp>*/>
class _LIBCPP_TEMPLATE_VIS stack
{
public:
    typedef _Container                               container_type;
    typedef typename container_type::value_type      value_type;
    typedef typename container_type::reference       reference;
    typedef typename container_type::const_reference const_reference;
    typedef typename container_type::size_type       size_type;
    static_assert((is_same<_Tp, value_type>::value), "" );

protected:
    container_type c;

public:
    _LIBCPP_INLINE_VISIBILITY
    stack()
        _NOEXCEPT_(is_nothrow_default_constructible<container_type>::value)
        : c() {}

    _LIBCPP_INLINE_VISIBILITY
    stack(const stack& __q) : c(__q.c) {}

    _LIBCPP_INLINE_VISIBILITY
    stack& operator=(const stack& __q) {c = __q.c; return *this;}


#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    stack(stack&& __q)
        _NOEXCEPT_(is_nothrow_move_constructible<container_type>::value)
        : c(_VSTD::move(__q.c)) {}

    _LIBCPP_INLINE_VISIBILITY
    stack& operator=(stack&& __q)
        _NOEXCEPT_(is_nothrow_move_assignable<container_type>::value)
        {c = _VSTD::move(__q.c); return *this;}

    _LIBCPP_INLINE_VISIBILITY
    explicit stack(container_type&& __c) : c(_VSTD::move(__c)) {}
#endif  // _LIBCPP_CXX03_LANG
# 152 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3

    _LIBCPP_INLINE_VISIBILITY
    explicit stack(const container_type& __c) : c(__c) {}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit stack(const _Alloc& __a,
                       typename enable_if<uses_allocator<container_type,
                                                         _Alloc>::value>::type* = 0)
            : c(__a) {}
    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        stack(const container_type& __c, const _Alloc& __a,
              typename enable_if<uses_allocator<container_type,
                                                _Alloc>::value>::type* = 0)
            : c(__c, __a) {}
    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        stack(const stack& __s, const _Alloc& __a,
              typename enable_if<uses_allocator<container_type,
                                                _Alloc>::value>::type* = 0)
            : c(__s.c, __a) {}
#ifndef _LIBCPP_CXX03_LANG
    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        stack(container_type&& __c, const _Alloc& __a,
              typename enable_if<uses_allocator<container_type,
                                                _Alloc>::value>::type* = 0)
            : c(_VSTD::move(__c), __a) {}
    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        stack(stack&& __s, const _Alloc& __a,
              typename enable_if<uses_allocator<container_type,
                                                _Alloc>::value>::type* = 0)
            : c(_VSTD::move(__s.c), __a) {}
#endif  // _LIBCPP_CXX03_LANG
# 188 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3

    _LIBCPP_NODISCARD_AFTER_CXX17 _LIBCPP_INLINE_VISIBILITY
    bool empty()     const      {return c.empty();}
    _LIBCPP_INLINE_VISIBILITY
    size_type size() const      {return c.size();}
    _LIBCPP_INLINE_VISIBILITY
    reference top()             {return c.back();}
    _LIBCPP_INLINE_VISIBILITY
    const_reference top() const {return c.back();}

    _LIBCPP_INLINE_VISIBILITY
    void push(const value_type& __v) {c.push_back(__v);}
#ifndef _LIBCPP_CXX03_LANG
    _LIBCPP_INLINE_VISIBILITY
    void push(value_type&& __v) {c.push_back(_VSTD::move(__v));}

    template <class... _Args>
        _LIBCPP_INLINE_VISIBILITY
#if 0 /* disabled by -frewrite-includes */
#if _LIBCPP_STD_VER > 14
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 207 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
        decltype(auto) emplace(_Args&&... __args)
        { return c.emplace_back(_VSTD::forward<_Args>(__args)...);}
#else
# 210 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
        void      emplace(_Args&&... __args)
        {        c.emplace_back(_VSTD::forward<_Args>(__args)...);}
#endif
# 213 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
#endif  // _LIBCPP_CXX03_LANG
# 214 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3

    _LIBCPP_INLINE_VISIBILITY
    void pop() {c.pop_back();}

    _LIBCPP_INLINE_VISIBILITY
    void swap(stack& __s)
        _NOEXCEPT_(__is_nothrow_swappable<container_type>::value)
    {
        using _VSTD::swap;
        swap(c, __s.c);
    }

    template <class T1, class _C1>
    friend
    bool
    operator==(const stack<T1, _C1>& __x, const stack<T1, _C1>& __y);

    template <class T1, class _C1>
    friend
    bool
    operator< (const stack<T1, _C1>& __x, const stack<T1, _C1>& __y);
};

#ifndef _LIBCPP_HAS_NO_DEDUCTION_GUIDES
template<class _Container,
         class = typename enable_if<!__is_allocator<_Container>::value, nullptr_t>::type
>
stack(_Container)
    -> stack<typename _Container::value_type, _Container>;

template<class _Container,
         class _Alloc,
         class = typename enable_if<!__is_allocator<_Container>::value, nullptr_t>::type,
         class = typename enable_if< __is_allocator<_Alloc>::value, nullptr_t>::type
         >
stack(_Container, _Alloc)
    -> stack<typename _Container::value_type, _Container>;
#endif
# 252 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3

template <class _Tp, class _Container>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const stack<_Tp, _Container>& __x, const stack<_Tp, _Container>& __y)
{
    return __x.c == __y.c;
}

template <class _Tp, class _Container>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const stack<_Tp, _Container>& __x, const stack<_Tp, _Container>& __y)
{
    return __x.c < __y.c;
}

template <class _Tp, class _Container>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const stack<_Tp, _Container>& __x, const stack<_Tp, _Container>& __y)
{
    return !(__x == __y);
}

template <class _Tp, class _Container>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const stack<_Tp, _Container>& __x, const stack<_Tp, _Container>& __y)
{
    return __y < __x;
}

template <class _Tp, class _Container>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const stack<_Tp, _Container>& __x, const stack<_Tp, _Container>& __y)
{
    return !(__x < __y);
}

template <class _Tp, class _Container>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const stack<_Tp, _Container>& __x, const stack<_Tp, _Container>& __y)
{
    return !(__y < __x);
}

template <class _Tp, class _Container>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<
    __is_swappable<_Container>::value,
    void
>::type
swap(stack<_Tp, _Container>& __x, stack<_Tp, _Container>& __y)
    _NOEXCEPT_(_NOEXCEPT_(__x.swap(__y)))
{
    __x.swap(__y);
}

template <class _Tp, class _Container, class _Alloc>
struct _LIBCPP_TEMPLATE_VIS uses_allocator<stack<_Tp, _Container>, _Alloc>
    : public uses_allocator<_Container, _Alloc>
{
};

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_STACK
# 322 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stack" 3
# 43 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 43 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 44 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <system_error>
#endif /* expanded by -frewrite-includes */
# 44 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 45 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 45 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 46 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 46 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 47 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

#ifdef HAVE_SYS_STAT_H
#if 0 /* expanded by -frewrite-includes */
#include <sys/stat.h>
#endif /* expanded by -frewrite-includes */
# 49 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 50 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
#endif
# 51 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

namespace llvm {
namespace sys {
namespace fs {

#if 0 /* disabled by -frewrite-includes */
#if defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 57 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
// A Win32 HANDLE is a typedef of void*
using file_t = void *;
#else
# 60 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
using file_t = int;
#endif
# 62 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

extern const file_t kInvalidFile;

/// An enumeration for the file system's view of the type.
enum class file_type {
  status_error,
  file_not_found,
  regular_file,
  directory_file,
  symlink_file,
  block_file,
  character_file,
  fifo_file,
  socket_file,
  type_unknown
};

/// space_info - Self explanatory.
struct space_info {
  uint64_t capacity;
  uint64_t free;
  uint64_t available;
};

enum perms {
  no_perms = 0,
  owner_read = 0400,
  owner_write = 0200,
  owner_exe = 0100,
  owner_all = owner_read | owner_write | owner_exe,
  group_read = 040,
  group_write = 020,
  group_exe = 010,
  group_all = group_read | group_write | group_exe,
  others_read = 04,
  others_write = 02,
  others_exe = 01,
  others_all = others_read | others_write | others_exe,
  all_read = owner_read | group_read | others_read,
  all_write = owner_write | group_write | others_write,
  all_exe = owner_exe | group_exe | others_exe,
  all_all = owner_all | group_all | others_all,
  set_uid_on_exe = 04000,
  set_gid_on_exe = 02000,
  sticky_bit = 01000,
  all_perms = all_all | set_uid_on_exe | set_gid_on_exe | sticky_bit,
  perms_not_known = 0xFFFF
};

// Helper functions so that you can use & and | to manipulate perms bits:
inline perms operator|(perms l, perms r) {
  return static_cast<perms>(static_cast<unsigned short>(l) |
                            static_cast<unsigned short>(r));
}
inline perms operator&(perms l, perms r) {
  return static_cast<perms>(static_cast<unsigned short>(l) &
                            static_cast<unsigned short>(r));
}
inline perms &operator|=(perms &l, perms r) {
  l = l | r;
  return l;
}
inline perms &operator&=(perms &l, perms r) {
  l = l & r;
  return l;
}
inline perms operator~(perms x) {
  // Avoid UB by explicitly truncating the (unsigned) ~ result.
  return static_cast<perms>(
      static_cast<unsigned short>(~static_cast<unsigned short>(x)));
}

class UniqueID {
  uint64_t Device;
  uint64_t File;

public:
  UniqueID() = default;
  UniqueID(uint64_t Device, uint64_t File) : Device(Device), File(File) {}

  bool operator==(const UniqueID &Other) const {
    return Device == Other.Device && File == Other.File;
  }
  bool operator!=(const UniqueID &Other) const { return !(*this == Other); }
  bool operator<(const UniqueID &Other) const {
    return std::tie(Device, File) < std::tie(Other.Device, Other.File);
  }

  uint64_t getDevice() const { return Device; }
  uint64_t getFile() const { return File; }
};

/// Represents the result of a call to directory_iterator::status(). This is a
/// subset of the information returned by a regular sys::fs::status() call, and
/// represents the information provided by Windows FileFirstFile/FindNextFile.
class basic_file_status {
protected:
  
#if 0 /* disabled by -frewrite-includes */
#if defined(LLVM_ON_UNIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 160 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  time_t fs_st_atime = 0;
  time_t fs_st_mtime = 0;
  uint32_t fs_st_atime_nsec = 0;
  uint32_t fs_st_mtime_nsec = 0;
  uid_t fs_st_uid = 0;
  gid_t fs_st_gid = 0;
  off_t fs_st_size = 0;
  
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined (_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 168 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  uint32_t LastAccessedTimeHigh = 0;
  uint32_t LastAccessedTimeLow = 0;
  uint32_t LastWriteTimeHigh = 0;
  uint32_t LastWriteTimeLow = 0;
  uint32_t FileSizeHigh = 0;
  uint32_t FileSizeLow = 0;
  #endif
# 175 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  file_type Type = file_type::status_error;
  perms Perms = perms_not_known;

public:
  basic_file_status() = default;

  explicit basic_file_status(file_type Type) : Type(Type) {}

  
#if 0 /* disabled by -frewrite-includes */
#if defined(LLVM_ON_UNIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 184 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  basic_file_status(file_type Type, perms Perms, time_t ATime,
                    uint32_t ATimeNSec, time_t MTime, uint32_t MTimeNSec,
                    uid_t UID, gid_t GID, off_t Size)
      : fs_st_atime(ATime), fs_st_mtime(MTime),
        fs_st_atime_nsec(ATimeNSec), fs_st_mtime_nsec(MTimeNSec),
        fs_st_uid(UID), fs_st_gid(GID),
        fs_st_size(Size), Type(Type), Perms(Perms) {}
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 192 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  basic_file_status(file_type Type, perms Perms, uint32_t LastAccessTimeHigh,
                    uint32_t LastAccessTimeLow, uint32_t LastWriteTimeHigh,
                    uint32_t LastWriteTimeLow, uint32_t FileSizeHigh,
                    uint32_t FileSizeLow)
      : LastAccessedTimeHigh(LastAccessTimeHigh),
        LastAccessedTimeLow(LastAccessTimeLow),
        LastWriteTimeHigh(LastWriteTimeHigh),
        LastWriteTimeLow(LastWriteTimeLow), FileSizeHigh(FileSizeHigh),
        FileSizeLow(FileSizeLow), Type(Type), Perms(Perms) {}
  #endif
# 202 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

  // getters
  file_type type() const { return Type; }
  perms permissions() const { return Perms; }

  /// The file access time as reported from the underlying file system.
  ///
  /// Also see comments on \c getLastModificationTime() related to the precision
  /// of the returned value.
  TimePoint<> getLastAccessedTime() const;

  /// The file modification time as reported from the underlying file system.
  ///
  /// The returned value allows for nanosecond precision but the actual
  /// resolution is an implementation detail of the underlying file system.
  /// There is no guarantee for what kind of resolution you can expect, the
  /// resolution can differ across platforms and even across mountpoints on the
  /// same machine.
  TimePoint<> getLastModificationTime() const;

  
#if 0 /* disabled by -frewrite-includes */
#if defined(LLVM_ON_UNIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 223 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  uint32_t getUser() const { return fs_st_uid; }
  uint32_t getGroup() const { return fs_st_gid; }
  uint64_t getSize() const { return fs_st_size; }
  
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined (_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 227 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  uint32_t getUser() const {
    return 9999; // Not applicable to Windows, so...
  }

  uint32_t getGroup() const {
    return 9999; // Not applicable to Windows, so...
  }

  uint64_t getSize() const {
    return (uint64_t(FileSizeHigh) << 32) + FileSizeLow;
  }
  #endif
# 239 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

  // setters
  void type(file_type v) { Type = v; }
  void permissions(perms p) { Perms = p; }
};

/// Represents the result of a call to sys::fs::status().
class file_status : public basic_file_status {
  friend bool equivalent(file_status A, file_status B);

  
#if 0 /* disabled by -frewrite-includes */
#if defined(LLVM_ON_UNIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 250 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  dev_t fs_st_dev = 0;
  nlink_t fs_st_nlinks = 0;
  ino_t fs_st_ino = 0;
  
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined (_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 254 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  uint32_t NumLinks = 0;
  uint32_t VolumeSerialNumber = 0;
  uint32_t FileIndexHigh = 0;
  uint32_t FileIndexLow = 0;
  #endif
# 259 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

public:
  file_status() = default;

  explicit file_status(file_type Type) : basic_file_status(Type) {}

  
#if 0 /* disabled by -frewrite-includes */
#if defined(LLVM_ON_UNIX)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 266 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  file_status(file_type Type, perms Perms, dev_t Dev, nlink_t Links, ino_t Ino,
              time_t ATime, uint32_t ATimeNSec,
              time_t MTime, uint32_t MTimeNSec,
              uid_t UID, gid_t GID, off_t Size)
      : basic_file_status(Type, Perms, ATime, ATimeNSec, MTime, MTimeNSec,
                          UID, GID, Size),
        fs_st_dev(Dev), fs_st_nlinks(Links), fs_st_ino(Ino) {}
  
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 274 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  file_status(file_type Type, perms Perms, uint32_t LinkCount,
              uint32_t LastAccessTimeHigh, uint32_t LastAccessTimeLow,
              uint32_t LastWriteTimeHigh, uint32_t LastWriteTimeLow,
              uint32_t VolumeSerialNumber, uint32_t FileSizeHigh,
              uint32_t FileSizeLow, uint32_t FileIndexHigh,
              uint32_t FileIndexLow)
      : basic_file_status(Type, Perms, LastAccessTimeHigh, LastAccessTimeLow,
                          LastWriteTimeHigh, LastWriteTimeLow, FileSizeHigh,
                          FileSizeLow),
        NumLinks(LinkCount), VolumeSerialNumber(VolumeSerialNumber),
        FileIndexHigh(FileIndexHigh), FileIndexLow(FileIndexLow) {}
  #endif
# 286 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

  UniqueID getUniqueID() const;
  uint32_t getLinkCount() const;
};

/// @}
/// @name Physical Operators
/// @{

/// Make \a path an absolute path.
///
/// Makes \a path absolute using the \a current_directory if it is not already.
/// An empty \a path will result in the \a current_directory.
///
/// /absolute/path   => /absolute/path
/// relative/../path => <current-directory>/relative/../path
///
/// @param path A path that is modified to be an absolute path.
void make_absolute(const Twine &current_directory, SmallVectorImpl<char> &path);

/// Make \a path an absolute path.
///
/// Makes \a path absolute using the current directory if it is not already. An
/// empty \a path will result in the current directory.
///
/// /absolute/path   => /absolute/path
/// relative/../path => <current-directory>/relative/../path
///
/// @param path A path that is modified to be an absolute path.
/// @returns errc::success if \a path has been made absolute, otherwise a
///          platform-specific error_code.
std::error_code make_absolute(SmallVectorImpl<char> &path);

/// Create all the non-existent directories in path.
///
/// @param path Directories to create.
/// @returns errc::success if is_directory(path), otherwise a platform
///          specific error_code. If IgnoreExisting is false, also returns
///          error if the directory already existed.
std::error_code create_directories(const Twine &path,
                                   bool IgnoreExisting = true,
                                   perms Perms = owner_all | group_all);

/// Create the directory in path.
///
/// @param path Directory to create.
/// @returns errc::success if is_directory(path), otherwise a platform
///          specific error_code. If IgnoreExisting is false, also returns
///          error if the directory already existed.
std::error_code create_directory(const Twine &path, bool IgnoreExisting = true,
                                 perms Perms = owner_all | group_all);

/// Create a link from \a from to \a to.
///
/// The link may be a soft or a hard link, depending on the platform. The caller
/// may not assume which one. Currently on windows it creates a hard link since
/// soft links require extra privileges. On unix, it creates a soft link since
/// hard links don't work on SMB file systems.
///
/// @param to The path to hard link to.
/// @param from The path to hard link from. This is created.
/// @returns errc::success if the link was created, otherwise a platform
/// specific error_code.
std::error_code create_link(const Twine &to, const Twine &from);

/// Create a hard link from \a from to \a to, or return an error.
///
/// @param to The path to hard link to.
/// @param from The path to hard link from. This is created.
/// @returns errc::success if the link was created, otherwise a platform
/// specific error_code.
std::error_code create_hard_link(const Twine &to, const Twine &from);

/// Collapse all . and .. patterns, resolve all symlinks, and optionally
///        expand ~ expressions to the user's home directory.
///
/// @param path The path to resolve.
/// @param output The location to store the resolved path.
/// @param expand_tilde If true, resolves ~ expressions to the user's home
///                     directory.
std::error_code real_path(const Twine &path, SmallVectorImpl<char> &output,
                          bool expand_tilde = false);

/// Expands ~ expressions to the user's home directory. On Unix ~user
/// directories are resolved as well.
///
/// @param path The path to resolve.
void expand_tilde(const Twine &path, SmallVectorImpl<char> &output);

/// Get the current path.
///
/// @param result Holds the current path on return.
/// @returns errc::success if the current path has been stored in result,
///          otherwise a platform-specific error_code.
std::error_code current_path(SmallVectorImpl<char> &result);

/// Set the current path.
///
/// @param path The path to set.
/// @returns errc::success if the current path was successfully set,
///          otherwise a platform-specific error_code.
std::error_code set_current_path(const Twine &path);

/// Remove path. Equivalent to POSIX remove().
///
/// @param path Input path.
/// @returns errc::success if path has been removed or didn't exist, otherwise a
///          platform-specific error code. If IgnoreNonExisting is false, also
///          returns error if the file didn't exist.
std::error_code remove(const Twine &path, bool IgnoreNonExisting = true);

/// Recursively delete a directory.
///
/// @param path Input path.
/// @returns errc::success if path has been removed or didn't exist, otherwise a
///          platform-specific error code.
std::error_code remove_directories(const Twine &path, bool IgnoreErrors = true);

/// Rename \a from to \a to.
///
/// Files are renamed as if by POSIX rename(), except that on Windows there may
/// be a short interval of time during which the destination file does not
/// exist.
///
/// @param from The path to rename from.
/// @param to The path to rename to. This is created.
std::error_code rename(const Twine &from, const Twine &to);

/// Copy the contents of \a From to \a To.
///
/// @param From The path to copy from.
/// @param To The path to copy to. This is created.
std::error_code copy_file(const Twine &From, const Twine &To);

/// Copy the contents of \a From to \a To.
///
/// @param From The path to copy from.
/// @param ToFD The open file descriptor of the destination file.
std::error_code copy_file(const Twine &From, int ToFD);

/// Resize path to size. File is resized as if by POSIX truncate().
///
/// @param FD Input file descriptor.
/// @param Size Size to resize to.
/// @returns errc::success if \a path has been resized to \a size, otherwise a
///          platform-specific error_code.
std::error_code resize_file(int FD, uint64_t Size);

/// Compute an MD5 hash of a file's contents.
///
/// @param FD Input file descriptor.
/// @returns An MD5Result with the hash computed, if successful, otherwise a
///          std::error_code.
ErrorOr<MD5::MD5Result> md5_contents(int FD);

/// Version of compute_md5 that doesn't require an open file descriptor.
ErrorOr<MD5::MD5Result> md5_contents(const Twine &Path);

/// @}
/// @name Physical Observers
/// @{

/// Does file exist?
///
/// @param status A basic_file_status previously returned from stat.
/// @returns True if the file represented by status exists, false if it does
///          not.
bool exists(const basic_file_status &status);

enum class AccessMode { Exist, Write, Execute };

/// Can the file be accessed?
///
/// @param Path Input path.
/// @returns errc::success if the path can be accessed, otherwise a
///          platform-specific error_code.
std::error_code access(const Twine &Path, AccessMode Mode);

/// Does file exist?
///
/// @param Path Input path.
/// @returns True if it exists, false otherwise.
inline bool exists(const Twine &Path) {
  return !access(Path, AccessMode::Exist);
}

/// Can we execute this file?
///
/// @param Path Input path.
/// @returns True if we can execute it, false otherwise.
bool can_execute(const Twine &Path);

/// Can we write this file?
///
/// @param Path Input path.
/// @returns True if we can write to it, false otherwise.
inline bool can_write(const Twine &Path) {
  return !access(Path, AccessMode::Write);
}

/// Do file_status's represent the same thing?
///
/// @param A Input file_status.
/// @param B Input file_status.
///
/// assert(status_known(A) || status_known(B));
///
/// @returns True if A and B both represent the same file system entity, false
///          otherwise.
bool equivalent(file_status A, file_status B);

/// Do paths represent the same thing?
///
/// assert(status_known(A) || status_known(B));
///
/// @param A Input path A.
/// @param B Input path B.
/// @param result Set to true if stat(A) and stat(B) have the same device and
///               inode (or equivalent).
/// @returns errc::success if result has been successfully set, otherwise a
///          platform-specific error_code.
std::error_code equivalent(const Twine &A, const Twine &B, bool &result);

/// Simpler version of equivalent for clients that don't need to
///        differentiate between an error and false.
inline bool equivalent(const Twine &A, const Twine &B) {
  bool result;
  return !equivalent(A, B, result) && result;
}

/// Is the file mounted on a local filesystem?
///
/// @param path Input path.
/// @param result Set to true if \a path is on fixed media such as a hard disk,
///               false if it is not.
/// @returns errc::success if result has been successfully set, otherwise a
///          platform specific error_code.
std::error_code is_local(const Twine &path, bool &result);

/// Version of is_local accepting an open file descriptor.
std::error_code is_local(int FD, bool &result);

/// Simpler version of is_local for clients that don't need to
///        differentiate between an error and false.
inline bool is_local(const Twine &Path) {
  bool Result;
  return !is_local(Path, Result) && Result;
}

/// Simpler version of is_local accepting an open file descriptor for
///        clients that don't need to differentiate between an error and false.
inline bool is_local(int FD) {
  bool Result;
  return !is_local(FD, Result) && Result;
}

/// Does status represent a directory?
///
/// @param Path The path to get the type of.
/// @param Follow For symbolic links, indicates whether to return the file type
///               of the link itself, or of the target.
/// @returns A value from the file_type enumeration indicating the type of file.
file_type get_file_type(const Twine &Path, bool Follow = true);

/// Does status represent a directory?
///
/// @param status A basic_file_status previously returned from status.
/// @returns status.type() == file_type::directory_file.
bool is_directory(const basic_file_status &status);

/// Is path a directory?
///
/// @param path Input path.
/// @param result Set to true if \a path is a directory (after following
///               symlinks, false if it is not. Undefined otherwise.
/// @returns errc::success if result has been successfully set, otherwise a
///          platform-specific error_code.
std::error_code is_directory(const Twine &path, bool &result);

/// Simpler version of is_directory for clients that don't need to
///        differentiate between an error and false.
inline bool is_directory(const Twine &Path) {
  bool Result;
  return !is_directory(Path, Result) && Result;
}

/// Does status represent a regular file?
///
/// @param status A basic_file_status previously returned from status.
/// @returns status_known(status) && status.type() == file_type::regular_file.
bool is_regular_file(const basic_file_status &status);

/// Is path a regular file?
///
/// @param path Input path.
/// @param result Set to true if \a path is a regular file (after following
///               symlinks), false if it is not. Undefined otherwise.
/// @returns errc::success if result has been successfully set, otherwise a
///          platform-specific error_code.
std::error_code is_regular_file(const Twine &path, bool &result);

/// Simpler version of is_regular_file for clients that don't need to
///        differentiate between an error and false.
inline bool is_regular_file(const Twine &Path) {
  bool Result;
  if (is_regular_file(Path, Result))
    return false;
  return Result;
}

/// Does status represent a symlink file?
///
/// @param status A basic_file_status previously returned from status.
/// @returns status_known(status) && status.type() == file_type::symlink_file.
bool is_symlink_file(const basic_file_status &status);

/// Is path a symlink file?
///
/// @param path Input path.
/// @param result Set to true if \a path is a symlink file, false if it is not.
///               Undefined otherwise.
/// @returns errc::success if result has been successfully set, otherwise a
///          platform-specific error_code.
std::error_code is_symlink_file(const Twine &path, bool &result);

/// Simpler version of is_symlink_file for clients that don't need to
///        differentiate between an error and false.
inline bool is_symlink_file(const Twine &Path) {
  bool Result;
  if (is_symlink_file(Path, Result))
    return false;
  return Result;
}

/// Does this status represent something that exists but is not a
///        directory or regular file?
///
/// @param status A basic_file_status previously returned from status.
/// @returns exists(s) && !is_regular_file(s) && !is_directory(s)
bool is_other(const basic_file_status &status);

/// Is path something that exists but is not a directory,
///        regular file, or symlink?
///
/// @param path Input path.
/// @param result Set to true if \a path exists, but is not a directory, regular
///               file, or a symlink, false if it does not. Undefined otherwise.
/// @returns errc::success if result has been successfully set, otherwise a
///          platform-specific error_code.
std::error_code is_other(const Twine &path, bool &result);

/// Get file status as if by POSIX stat().
///
/// @param path Input path.
/// @param result Set to the file status.
/// @param follow When true, follows symlinks.  Otherwise, the symlink itself is
///               statted.
/// @returns errc::success if result has been successfully set, otherwise a
///          platform-specific error_code.
std::error_code status(const Twine &path, file_status &result,
                       bool follow = true);

/// A version for when a file descriptor is already available.
std::error_code status(int FD, file_status &Result);

#ifdef _WIN32
/// A version for when a file descriptor is already available.
std::error_code status(file_t FD, file_status &Result);
#endif
# 655 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

/// Get file creation mode mask of the process.
///
/// @returns Mask reported by umask(2)
/// @note There is no umask on Windows. This function returns 0 always
///       on Windows. This function does not return an error_code because
///       umask(2) never fails. It is not thread safe.
unsigned getUmask();

/// Set file permissions.
///
/// @param Path File to set permissions on.
/// @param Permissions New file permissions.
/// @returns errc::success if the permissions were successfully set, otherwise
///          a platform-specific error_code.
/// @note On Windows, all permissions except *_write are ignored. Using any of
///       owner_write, group_write, or all_write will make the file writable.
///       Otherwise, the file will be marked as read-only.
std::error_code setPermissions(const Twine &Path, perms Permissions);

/// Vesion of setPermissions accepting a file descriptor.
/// TODO Delete the path based overload once we implement the FD based overload
/// on Windows.
std::error_code setPermissions(int FD, perms Permissions);

/// Get file permissions.
///
/// @param Path File to get permissions from.
/// @returns the permissions if they were successfully retrieved, otherwise a
///          platform-specific error_code.
/// @note On Windows, if the file does not have the FILE_ATTRIBUTE_READONLY
///       attribute, all_all will be returned. Otherwise, all_read | all_exe
///       will be returned.
ErrorOr<perms> getPermissions(const Twine &Path);

/// Get file size.
///
/// @param Path Input path.
/// @param Result Set to the size of the file in \a Path.
/// @returns errc::success if result has been successfully set, otherwise a
///          platform-specific error_code.
inline std::error_code file_size(const Twine &Path, uint64_t &Result) {
  file_status Status;
  std::error_code EC = status(Path, Status);
  if (EC)
    return EC;
  Result = Status.getSize();
  return std::error_code();
}

/// Set the file modification and access time.
///
/// @returns errc::success if the file times were successfully set, otherwise a
///          platform-specific error_code or errc::function_not_supported on
///          platforms where the functionality isn't available.
std::error_code setLastAccessAndModificationTime(int FD, TimePoint<> AccessTime,
                                                 TimePoint<> ModificationTime);

/// Simpler version that sets both file modification and access time to the same
/// time.
inline std::error_code setLastAccessAndModificationTime(int FD,
                                                        TimePoint<> Time) {
  return setLastAccessAndModificationTime(FD, Time, Time);
}

/// Is status available?
///
/// @param s Input file status.
/// @returns True if status() != status_error.
bool status_known(const basic_file_status &s);

/// Is status available?
///
/// @param path Input path.
/// @param result Set to true if status() != status_error.
/// @returns errc::success if result has been successfully set, otherwise a
///          platform-specific error_code.
std::error_code status_known(const Twine &path, bool &result);

enum CreationDisposition : unsigned {
  /// CD_CreateAlways - When opening a file:
  ///   * If it already exists, truncate it.
  ///   * If it does not already exist, create a new file.
  CD_CreateAlways = 0,

  /// CD_CreateNew - When opening a file:
  ///   * If it already exists, fail.
  ///   * If it does not already exist, create a new file.
  CD_CreateNew = 1,

  /// CD_OpenExisting - When opening a file:
  ///   * If it already exists, open the file with the offset set to 0.
  ///   * If it does not already exist, fail.
  CD_OpenExisting = 2,

  /// CD_OpenAlways - When opening a file:
  ///   * If it already exists, open the file with the offset set to 0.
  ///   * If it does not already exist, create a new file.
  CD_OpenAlways = 3,
};

enum FileAccess : unsigned {
  FA_Read = 1,
  FA_Write = 2,
};

enum OpenFlags : unsigned {
  OF_None = 0,
  F_None = 0, // For compatibility

  /// The file should be opened in text mode on platforms that make this
  /// distinction.
  OF_Text = 1,
  F_Text = 1, // For compatibility

  /// The file should be opened in append mode.
  OF_Append = 2,
  F_Append = 2, // For compatibility

  /// Delete the file on close. Only makes a difference on windows.
  OF_Delete = 4,

  /// When a child process is launched, this file should remain open in the
  /// child process.
  OF_ChildInherit = 8,

  /// Force files Atime to be updated on access. Only makes a difference on windows.
  OF_UpdateAtime = 16,
};

/// Create a potentially unique file name but does not create it.
///
/// Generates a unique path suitable for a temporary file but does not
/// open or create the file. The name is based on \a Model with '%'
/// replaced by a random char in [0-9a-f]. If \a MakeAbsolute is true
/// then the system's temp directory is prepended first. If \a MakeAbsolute
/// is false the current directory will be used instead.
///
/// This function does not check if the file exists. If you want to be sure
/// that the file does not yet exist, you should use use enough '%' characters
/// in your model to ensure this. Each '%' gives 4-bits of entropy so you can
/// use 32 of them to get 128 bits of entropy.
///
/// Example: clang-%%-%%-%%-%%-%%.s => clang-a0-b1-c2-d3-e4.s
///
/// @param Model Name to base unique path off of.
/// @param ResultPath Set to the file's path.
/// @param MakeAbsolute Whether to use the system temp directory.
void createUniquePath(const Twine &Model, SmallVectorImpl<char> &ResultPath,
                      bool MakeAbsolute);

/// Create a uniquely named file.
///
/// Generates a unique path suitable for a temporary file and then opens it as a
/// file. The name is based on \a Model with '%' replaced by a random char in
/// [0-9a-f]. If \a Model is not an absolute path, the temporary file will be
/// created in the current directory.
///
/// Example: clang-%%-%%-%%-%%-%%.s => clang-a0-b1-c2-d3-e4.s
///
/// This is an atomic operation. Either the file is created and opened, or the
/// file system is left untouched.
///
/// The intended use is for files that are to be kept, possibly after
/// renaming them. For example, when running 'clang -c foo.o', the file can
/// be first created as foo-abc123.o and then renamed.
///
/// @param Model Name to base unique path off of.
/// @param ResultFD Set to the opened file's file descriptor.
/// @param ResultPath Set to the opened file's absolute path.
/// @returns errc::success if Result{FD,Path} have been successfully set,
///          otherwise a platform-specific error_code.
std::error_code createUniqueFile(const Twine &Model, int &ResultFD,
                                 SmallVectorImpl<char> &ResultPath,
                                 unsigned Mode = all_read | all_write);

/// Simpler version for clients that don't want an open file. An empty
/// file will still be created.
std::error_code createUniqueFile(const Twine &Model,
                                 SmallVectorImpl<char> &ResultPath,
                                 unsigned Mode = all_read | all_write);

/// Represents a temporary file.
///
/// The temporary file must be eventually discarded or given a final name and
/// kept.
///
/// The destructor doesn't implicitly discard because there is no way to
/// properly handle errors in a destructor.
class TempFile {
  bool Done = false;
  TempFile(StringRef Name, int FD);

public:
  /// This creates a temporary file with createUniqueFile and schedules it for
  /// deletion with sys::RemoveFileOnSignal.
  static Expected<TempFile> create(const Twine &Model,
                                   unsigned Mode = all_read | all_write);
  TempFile(TempFile &&Other);
  TempFile &operator=(TempFile &&Other);

  // Name of the temporary file.
  std::string TmpName;

  // The open file descriptor.
  int FD = -1;

  // Keep this with the given name.
  Error keep(const Twine &Name);

  // Keep this with the temporary name.
  Error keep();

  // Delete the file.
  Error discard();

  // This checks that keep or delete was called.
  ~TempFile();
};

/// Create a file in the system temporary directory.
///
/// The filename is of the form prefix-random_chars.suffix. Since the directory
/// is not know to the caller, Prefix and Suffix cannot have path separators.
/// The files are created with mode 0600.
///
/// This should be used for things like a temporary .s that is removed after
/// running the assembler.
std::error_code createTemporaryFile(const Twine &Prefix, StringRef Suffix,
                                    int &ResultFD,
                                    SmallVectorImpl<char> &ResultPath);

/// Simpler version for clients that don't want an open file. An empty
/// file will still be created.
std::error_code createTemporaryFile(const Twine &Prefix, StringRef Suffix,
                                    SmallVectorImpl<char> &ResultPath);

std::error_code createUniqueDirectory(const Twine &Prefix,
                                      SmallVectorImpl<char> &ResultPath);

/// Get a unique name, not currently exisiting in the filesystem. Subject
/// to race conditions, prefer to use createUniqueFile instead.
///
/// Similar to createUniqueFile, but instead of creating a file only
/// checks if it exists. This function is subject to race conditions, if you
/// want to use the returned name to actually create a file, use
/// createUniqueFile instead.
std::error_code getPotentiallyUniqueFileName(const Twine &Model,
                                             SmallVectorImpl<char> &ResultPath);

/// Get a unique temporary file name, not currently exisiting in the
/// filesystem. Subject to race conditions, prefer to use createTemporaryFile
/// instead.
///
/// Similar to createTemporaryFile, but instead of creating a file only
/// checks if it exists. This function is subject to race conditions, if you
/// want to use the returned name to actually create a file, use
/// createTemporaryFile instead.
std::error_code
getPotentiallyUniqueTempFileName(const Twine &Prefix, StringRef Suffix,
                                 SmallVectorImpl<char> &ResultPath);

inline OpenFlags operator|(OpenFlags A, OpenFlags B) {
  return OpenFlags(unsigned(A) | unsigned(B));
}

inline OpenFlags &operator|=(OpenFlags &A, OpenFlags B) {
  A = A | B;
  return A;
}

inline FileAccess operator|(FileAccess A, FileAccess B) {
  return FileAccess(unsigned(A) | unsigned(B));
}

inline FileAccess &operator|=(FileAccess &A, FileAccess B) {
  A = A | B;
  return A;
}

/// @brief Opens a file with the specified creation disposition, access mode,
/// and flags and returns a file descriptor.
///
/// The caller is responsible for closing the file descriptor once they are
/// finished with it.
///
/// @param Name The path of the file to open, relative or absolute.
/// @param ResultFD If the file could be opened successfully, its descriptor
///                 is stored in this location. Otherwise, this is set to -1.
/// @param Disp Value specifying the existing-file behavior.
/// @param Access Value specifying whether to open the file in read, write, or
///               read-write mode.
/// @param Flags Additional flags.
/// @param Mode The access permissions of the file, represented in octal.
/// @returns errc::success if \a Name has been opened, otherwise a
///          platform-specific error_code.
std::error_code openFile(const Twine &Name, int &ResultFD,
                         CreationDisposition Disp, FileAccess Access,
                         OpenFlags Flags, unsigned Mode = 0666);

/// @brief Opens a file with the specified creation disposition, access mode,
/// and flags and returns a platform-specific file object.
///
/// The caller is responsible for closing the file object once they are
/// finished with it.
///
/// @param Name The path of the file to open, relative or absolute.
/// @param Disp Value specifying the existing-file behavior.
/// @param Access Value specifying whether to open the file in read, write, or
///               read-write mode.
/// @param Flags Additional flags.
/// @param Mode The access permissions of the file, represented in octal.
/// @returns errc::success if \a Name has been opened, otherwise a
///          platform-specific error_code.
Expected<file_t> openNativeFile(const Twine &Name, CreationDisposition Disp,
                                FileAccess Access, OpenFlags Flags,
                                unsigned Mode = 0666);

/// Converts from a Posix file descriptor number to a native file handle.
/// On Windows, this retreives the underlying handle. On non-Windows, this is a
/// no-op.
file_t convertFDToNativeFile(int FD);

#ifndef _WIN32
inline file_t convertFDToNativeFile(int FD) { return FD; }
#endif
# 981 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"

/// Return an open handle to standard in. On Unix, this is typically FD 0.
/// Returns kInvalidFile when the stream is closed.
file_t getStdinHandle();

/// Return an open handle to standard out. On Unix, this is typically FD 1.
/// Returns kInvalidFile when the stream is closed.
file_t getStdoutHandle();

/// Return an open handle to standard error. On Unix, this is typically FD 2.
/// Returns kInvalidFile when the stream is closed.
file_t getStderrHandle();

/// Reads \p Buf.size() bytes from \p FileHandle into \p Buf. Returns the number
/// of bytes actually read. On Unix, this is equivalent to `return ::read(FD,
/// Buf.data(), Buf.size())`, with error reporting. Returns 0 when reaching EOF.
///
/// @param FileHandle File to read from.
/// @param Buf Buffer to read into.
/// @returns The number of bytes read, or error.
Expected<size_t> readNativeFile(file_t FileHandle, MutableArrayRef<char> Buf);

/// Reads \p Buf.size() bytes from \p FileHandle at offset \p Offset into \p
/// Buf. If 'pread' is available, this will use that, otherwise it will use
/// 'lseek'. Returns the number of bytes actually read. Returns 0 when reaching
/// EOF.
///
/// @param FileHandle File to read from.
/// @param Buf Buffer to read into.
/// @param Offset Offset into the file at which the read should occur.
/// @returns The number of bytes read, or error.
Expected<size_t> readNativeFileSlice(file_t FileHandle,
                                     MutableArrayRef<char> Buf,
                                     uint64_t Offset);

/// @brief Opens the file with the given name in a write-only or read-write
/// mode, returning its open file descriptor. If the file does not exist, it
/// is created.
///
/// The caller is responsible for closing the file descriptor once they are
/// finished with it.
///
/// @param Name The path of the file to open, relative or absolute.
/// @param ResultFD If the file could be opened successfully, its descriptor
///                 is stored in this location. Otherwise, this is set to -1.
/// @param Flags Additional flags used to determine whether the file should be
///              opened in, for example, read-write or in write-only mode.
/// @param Mode The access permissions of the file, represented in octal.
/// @returns errc::success if \a Name has been opened, otherwise a
///          platform-specific error_code.
inline std::error_code
openFileForWrite(const Twine &Name, int &ResultFD,
                 CreationDisposition Disp = CD_CreateAlways,
                 OpenFlags Flags = OF_None, unsigned Mode = 0666) {
  return openFile(Name, ResultFD, Disp, FA_Write, Flags, Mode);
}

/// @brief Opens the file with the given name in a write-only or read-write
/// mode, returning its open file descriptor. If the file does not exist, it
/// is created.
///
/// The caller is responsible for closing the freeing the file once they are
/// finished with it.
///
/// @param Name The path of the file to open, relative or absolute.
/// @param Flags Additional flags used to determine whether the file should be
///              opened in, for example, read-write or in write-only mode.
/// @param Mode The access permissions of the file, represented in octal.
/// @returns a platform-specific file descriptor if \a Name has been opened,
///          otherwise an error object.
inline Expected<file_t> openNativeFileForWrite(const Twine &Name,
                                               CreationDisposition Disp,
                                               OpenFlags Flags,
                                               unsigned Mode = 0666) {
  return openNativeFile(Name, Disp, FA_Write, Flags, Mode);
}

/// @brief Opens the file with the given name in a write-only or read-write
/// mode, returning its open file descriptor. If the file does not exist, it
/// is created.
///
/// The caller is responsible for closing the file descriptor once they are
/// finished with it.
///
/// @param Name The path of the file to open, relative or absolute.
/// @param ResultFD If the file could be opened successfully, its descriptor
///                 is stored in this location. Otherwise, this is set to -1.
/// @param Flags Additional flags used to determine whether the file should be
///              opened in, for example, read-write or in write-only mode.
/// @param Mode The access permissions of the file, represented in octal.
/// @returns errc::success if \a Name has been opened, otherwise a
///          platform-specific error_code.
inline std::error_code openFileForReadWrite(const Twine &Name, int &ResultFD,
                                            CreationDisposition Disp,
                                            OpenFlags Flags,
                                            unsigned Mode = 0666) {
  return openFile(Name, ResultFD, Disp, FA_Write | FA_Read, Flags, Mode);
}

/// @brief Opens the file with the given name in a write-only or read-write
/// mode, returning its open file descriptor. If the file does not exist, it
/// is created.
///
/// The caller is responsible for closing the freeing the file once they are
/// finished with it.
///
/// @param Name The path of the file to open, relative or absolute.
/// @param Flags Additional flags used to determine whether the file should be
///              opened in, for example, read-write or in write-only mode.
/// @param Mode The access permissions of the file, represented in octal.
/// @returns a platform-specific file descriptor if \a Name has been opened,
///          otherwise an error object.
inline Expected<file_t> openNativeFileForReadWrite(const Twine &Name,
                                                   CreationDisposition Disp,
                                                   OpenFlags Flags,
                                                   unsigned Mode = 0666) {
  return openNativeFile(Name, Disp, FA_Write | FA_Read, Flags, Mode);
}

/// @brief Opens the file with the given name in a read-only mode, returning
/// its open file descriptor.
///
/// The caller is responsible for closing the file descriptor once they are
/// finished with it.
///
/// @param Name The path of the file to open, relative or absolute.
/// @param ResultFD If the file could be opened successfully, its descriptor
///                 is stored in this location. Otherwise, this is set to -1.
/// @param RealPath If nonnull, extra work is done to determine the real path
///                 of the opened file, and that path is stored in this
///                 location.
/// @returns errc::success if \a Name has been opened, otherwise a
///          platform-specific error_code.
std::error_code openFileForRead(const Twine &Name, int &ResultFD,
                                OpenFlags Flags = OF_None,
                                SmallVectorImpl<char> *RealPath = nullptr);

/// @brief Opens the file with the given name in a read-only mode, returning
/// its open file descriptor.
///
/// The caller is responsible for closing the freeing the file once they are
/// finished with it.
///
/// @param Name The path of the file to open, relative or absolute.
/// @param RealPath If nonnull, extra work is done to determine the real path
///                 of the opened file, and that path is stored in this
///                 location.
/// @returns a platform-specific file descriptor if \a Name has been opened,
///          otherwise an error object.
Expected<file_t>
openNativeFileForRead(const Twine &Name, OpenFlags Flags = OF_None,
                      SmallVectorImpl<char> *RealPath = nullptr);

/// @brief Close the file object.  This should be used instead of ::close for
/// portability. On error, the caller should assume the file is closed, as is
/// the case for Process::SafelyCloseFileDescriptor
///
/// @param F On input, this is the file to close.  On output, the file is
/// set to kInvalidFile.
///
/// @returns An error code if closing the file failed. Typically, an error here
/// means that the filesystem may have failed to perform some buffered writes.
std::error_code closeFile(file_t &F);

std::error_code getUniqueID(const Twine Path, UniqueID &Result);

/// Get disk space usage information.
///
/// Note: Users must be careful about "Time Of Check, Time Of Use" kind of bug.
/// Note: Windows reports results according to the quota allocated to the user.
///
/// @param Path Input path.
/// @returns a space_info structure filled with the capacity, free, and
/// available space on the device \a Path is on. A platform specific error_code
/// is returned on error.
ErrorOr<space_info> disk_space(const Twine &Path);

/// This class represents a memory mapped file. It is based on
/// boost::iostreams::mapped_file.
class mapped_file_region {
public:
  enum mapmode {
    readonly, ///< May only access map via const_data as read only.
    readwrite, ///< May access map via data and modify it. Written to path.
    priv ///< May modify via data, but changes are lost on destruction.
  };

private:
  /// Platform-specific mapping state.
  size_t Size;
  void *Mapping;
#ifdef _WIN32
  sys::fs::file_t FileHandle;
#endif
# 1175 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
  mapmode Mode;

  std::error_code init(sys::fs::file_t FD, uint64_t Offset, mapmode Mode);

public:
  mapped_file_region() = delete;
  mapped_file_region(mapped_file_region&) = delete;
  mapped_file_region &operator =(mapped_file_region&) = delete;

  /// \param fd An open file descriptor to map. Does not take ownership of fd.
  mapped_file_region(sys::fs::file_t fd, mapmode mode, size_t length, uint64_t offset,
                     std::error_code &ec);

  ~mapped_file_region();

  size_t size() const;
  char *data() const;

  /// Get a const view of the data. Modifying this memory has undefined
  /// behavior.
  const char *const_data() const;

  /// \returns The minimum alignment offset must be.
  static int alignment();
};

/// Return the path to the main executable, given the value of argv[0] from
/// program startup and the address of main itself. In extremis, this function
/// may fail and return an empty path.
std::string getMainExecutable(const char *argv0, void *MainExecAddr);

/// @}
/// @name Iterators
/// @{

/// directory_entry - A single entry in a directory.
class directory_entry {
  // FIXME: different platforms make different information available "for free"
  // when traversing a directory. The design of this class wraps most of the
  // information in basic_file_status, so on platforms where we can't populate
  // that whole structure, callers end up paying for a stat().
  // std::filesystem::directory_entry may be a better model.
  std::string Path;
  file_type Type = file_type::type_unknown; // Most platforms can provide this.
  bool FollowSymlinks = true;               // Affects the behavior of status().
  basic_file_status Status;                 // If available.

public:
  explicit directory_entry(const Twine &Path, bool FollowSymlinks = true,
                           file_type Type = file_type::type_unknown,
                           basic_file_status Status = basic_file_status())
      : Path(Path.str()), Type(Type), FollowSymlinks(FollowSymlinks),
        Status(Status) {}

  directory_entry() = default;

  void replace_filename(const Twine &Filename, file_type Type,
                        basic_file_status Status = basic_file_status());

  const std::string &path() const { return Path; }
  // Get basic information about entry file (a subset of fs::status()).
  // On most platforms this is a stat() call.
  // On windows the information was already retrieved from the directory.
  ErrorOr<basic_file_status> status() const;
  // Get the type of this file.
  // On most platforms (Linux/Mac/Windows/BSD), this was already retrieved.
  // On some platforms (e.g. Solaris) this is a stat() call.
  file_type type() const {
    if (Type != file_type::type_unknown)
      return Type;
    auto S = status();
    return S ? S->type() : file_type::type_unknown;
  }

  bool operator==(const directory_entry& RHS) const { return Path == RHS.Path; }
  bool operator!=(const directory_entry& RHS) const { return !(*this == RHS); }
  bool operator< (const directory_entry& RHS) const;
  bool operator<=(const directory_entry& RHS) const;
  bool operator> (const directory_entry& RHS) const;
  bool operator>=(const directory_entry& RHS) const;
};

namespace detail {

  struct DirIterState;

  std::error_code directory_iterator_construct(DirIterState &, StringRef, bool);
  std::error_code directory_iterator_increment(DirIterState &);
  std::error_code directory_iterator_destruct(DirIterState &);

  /// Keeps state for the directory_iterator.
  struct DirIterState {
    ~DirIterState() {
      directory_iterator_destruct(*this);
    }

    intptr_t IterationHandle = 0;
    directory_entry CurrentEntry;
  };

} // end namespace detail

/// directory_iterator - Iterates through the entries in path. There is no
/// operator++ because we need an error_code. If it's really needed we can make
/// it call report_fatal_error on error.
class directory_iterator {
  std::shared_ptr<detail::DirIterState> State;
  bool FollowSymlinks = true;

public:
  explicit directory_iterator(const Twine &path, std::error_code &ec,
                              bool follow_symlinks = true)
      : FollowSymlinks(follow_symlinks) {
    State = std::make_shared<detail::DirIterState>();
    SmallString<128> path_storage;
    ec = detail::directory_iterator_construct(
        *State, path.toStringRef(path_storage), FollowSymlinks);
  }

  explicit directory_iterator(const directory_entry &de, std::error_code &ec,
                              bool follow_symlinks = true)
      : FollowSymlinks(follow_symlinks) {
    State = std::make_shared<detail::DirIterState>();
    ec = detail::directory_iterator_construct(
        *State, de.path(), FollowSymlinks);
  }

  /// Construct end iterator.
  directory_iterator() = default;

  // No operator++ because we need error_code.
  directory_iterator &increment(std::error_code &ec) {
    ec = directory_iterator_increment(*State);
    return *this;
  }

  const directory_entry &operator*() const { return State->CurrentEntry; }
  const directory_entry *operator->() const { return &State->CurrentEntry; }

  bool operator==(const directory_iterator &RHS) const {
    if (State == RHS.State)
      return true;
    if (!RHS.State)
      return State->CurrentEntry == directory_entry();
    if (!State)
      return RHS.State->CurrentEntry == directory_entry();
    return State->CurrentEntry == RHS.State->CurrentEntry;
  }

  bool operator!=(const directory_iterator &RHS) const {
    return !(*this == RHS);
  }
};

namespace detail {

  /// Keeps state for the recursive_directory_iterator.
  struct RecDirIterState {
    std::stack<directory_iterator, std::vector<directory_iterator>> Stack;
    uint16_t Level = 0;
    bool HasNoPushRequest = false;
  };

} // end namespace detail

/// recursive_directory_iterator - Same as directory_iterator except for it
/// recurses down into child directories.
class recursive_directory_iterator {
  std::shared_ptr<detail::RecDirIterState> State;
  bool Follow;

public:
  recursive_directory_iterator() = default;
  explicit recursive_directory_iterator(const Twine &path, std::error_code &ec,
                                        bool follow_symlinks = true)
      : State(std::make_shared<detail::RecDirIterState>()),
        Follow(follow_symlinks) {
    State->Stack.push(directory_iterator(path, ec, Follow));
    if (State->Stack.top() == directory_iterator())
      State.reset();
  }

  // No operator++ because we need error_code.
  recursive_directory_iterator &increment(std::error_code &ec) {
    const directory_iterator end_itr = {};

    if (State->HasNoPushRequest)
      State->HasNoPushRequest = false;
    else {
      file_type type = State->Stack.top()->type();
      if (type == file_type::symlink_file && Follow) {
        // Resolve the symlink: is it a directory to recurse into?
        ErrorOr<basic_file_status> status = State->Stack.top()->status();
        if (status)
          type = status->type();
        // Otherwise broken symlink, and we'll continue.
      }
      if (type == file_type::directory_file) {
        State->Stack.push(directory_iterator(*State->Stack.top(), ec, Follow));
        if (State->Stack.top() != end_itr) {
          ++State->Level;
          return *this;
        }
        State->Stack.pop();
      }
    }

    while (!State->Stack.empty()
           && State->Stack.top().increment(ec) == end_itr) {
      State->Stack.pop();
      --State->Level;
    }

    // Check if we are done. If so, create an end iterator.
    if (State->Stack.empty())
      State.reset();

    return *this;
  }

  const directory_entry &operator*() const { return *State->Stack.top(); }
  const directory_entry *operator->() const { return &*State->Stack.top(); }

  // observers
  /// Gets the current level. Starting path is at level 0.
  int level() const { return State->Level; }

  /// Returns true if no_push has been called for this directory_entry.
  bool no_push_request() const { return State->HasNoPushRequest; }

  // modifiers
  /// Goes up one level if Level > 0.
  void pop() {
    assert(State && "Cannot pop an end iterator!");
    assert(State->Level > 0 && "Cannot pop an iterator with level < 1");

    const directory_iterator end_itr = {};
    std::error_code ec;
    do {
      if (ec)
        report_fatal_error("Error incrementing directory iterator.");
      State->Stack.pop();
      --State->Level;
    } while (!State->Stack.empty()
             && State->Stack.top().increment(ec) == end_itr);

    // Check if we are done. If so, create an end iterator.
    if (State->Stack.empty())
      State.reset();
  }

  /// Does not go down into the current directory_entry.
  void no_push() { State->HasNoPushRequest = true; }

  bool operator==(const recursive_directory_iterator &RHS) const {
    return State == RHS.State;
  }

  bool operator!=(const recursive_directory_iterator &RHS) const {
    return !(*this == RHS);
  }
};

/// @}

} // end namespace fs
} // end namespace sys
} // end namespace llvm

#endif // LLVM_SUPPORT_FILESYSTEM_H
# 1445 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/FileSystem.h"
# 27 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/VirtualFileSystem.h"
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h" 1
//===- VirtualFileSystem.h - Virtual File System Layer ----------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
/// \file
/// Defines the virtual file system interface vfs::FileSystem.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_VIRTUALFILESYSTEM_H
#define LLVM_SUPPORT_VIRTUALFILESYSTEM_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/IntrusiveRefCntPtr.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/None.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Optional.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Twine.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Chrono.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorOr.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/FileSystem.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Path.h"
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h" 1
//===- llvm/Support/Path.h - Path Operating System Concept ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file declares the llvm::sys::path namespace. It is designed after
// TR2/boost filesystem (v3), but modified to remove exception handling and the
// path class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_PATH_H
#define LLVM_SUPPORT_PATH_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Twine.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h" 1
//===-- llvm/Support/DataTypes.h - Define fixed size types ------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// Due to layering constraints (Support depends on llvm-c) this is a thin
// wrapper around the implementation that lives in llvm-c, though most clients
// can/should think of this as being provided by Support for simplicity (not
// many clients are aware of their dependency on llvm-c).
//
//===----------------------------------------------------------------------===//

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/DataTypes.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
#if 0 /* expanded by -frewrite-includes */
#include <system_error>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"

namespace llvm {
namespace sys {
namespace path {

enum class Style { windows, posix, native };

/// @name Lexical Component Iterator
/// @{

/// Path iterator.
///
/// This is an input iterator that iterates over the individual components in
/// \a path. The traversal order is as follows:
/// * The root-name element, if present.
/// * The root-directory element, if present.
/// * Each successive filename element, if present.
/// * Dot, if one or more trailing non-root slash characters are present.
/// Traversing backwards is possible with \a reverse_iterator
///
/// Iteration examples. Each component is separated by ',':
/// @code
///   /          => /
///   /foo       => /,foo
///   foo/       => foo,.
///   /foo/bar   => /,foo,bar
///   ../        => ..,.
///   C:\foo\bar => C:,/,foo,bar
/// @endcode
class const_iterator
    : public iterator_facade_base<const_iterator, std::input_iterator_tag,
                                  const StringRef> {
  StringRef Path;          ///< The entire path.
  StringRef Component;     ///< The current component. Not necessarily in Path.
  size_t    Position = 0;  ///< The iterators current position within Path.
  Style S = Style::native; ///< The path style to use.

  // An end iterator has Position = Path.size() + 1.
  friend const_iterator begin(StringRef path, Style style);
  friend const_iterator end(StringRef path);

public:
  reference operator*() const { return Component; }
  const_iterator &operator++();    // preincrement
  bool operator==(const const_iterator &RHS) const;

  /// Difference in bytes between this and RHS.
  ptrdiff_t operator-(const const_iterator &RHS) const;
};

/// Reverse path iterator.
///
/// This is an input iterator that iterates over the individual components in
/// \a path in reverse order. The traversal order is exactly reversed from that
/// of \a const_iterator
class reverse_iterator
    : public iterator_facade_base<reverse_iterator, std::input_iterator_tag,
                                  const StringRef> {
  StringRef Path;          ///< The entire path.
  StringRef Component;     ///< The current component. Not necessarily in Path.
  size_t    Position = 0;  ///< The iterators current position within Path.
  Style S = Style::native; ///< The path style to use.

  friend reverse_iterator rbegin(StringRef path, Style style);
  friend reverse_iterator rend(StringRef path);

public:
  reference operator*() const { return Component; }
  reverse_iterator &operator++();    // preincrement
  bool operator==(const reverse_iterator &RHS) const;

  /// Difference in bytes between this and RHS.
  ptrdiff_t operator-(const reverse_iterator &RHS) const;
};

/// Get begin iterator over \a path.
/// @param path Input path.
/// @returns Iterator initialized with the first component of \a path.
const_iterator begin(StringRef path, Style style = Style::native);

/// Get end iterator over \a path.
/// @param path Input path.
/// @returns Iterator initialized to the end of \a path.
const_iterator end(StringRef path);

/// Get reverse begin iterator over \a path.
/// @param path Input path.
/// @returns Iterator initialized with the first reverse component of \a path.
reverse_iterator rbegin(StringRef path, Style style = Style::native);

/// Get reverse end iterator over \a path.
/// @param path Input path.
/// @returns Iterator initialized to the reverse end of \a path.
reverse_iterator rend(StringRef path);

/// @}
/// @name Lexical Modifiers
/// @{

/// Remove the last component from \a path unless it is the root dir.
///
/// Similar to the POSIX "dirname" utility.
///
/// @code
///   directory/filename.cpp => directory/
///   directory/             => directory
///   filename.cpp           => <empty>
///   /                      => /
/// @endcode
///
/// @param path A path that is modified to not have a file component.
void remove_filename(SmallVectorImpl<char> &path, Style style = Style::native);

/// Replace the file extension of \a path with \a extension.
///
/// @code
///   ./filename.cpp => ./filename.extension
///   ./filename     => ./filename.extension
///   ./             => ./.extension
/// @endcode
///
/// @param path A path that has its extension replaced with \a extension.
/// @param extension The extension to be added. It may be empty. It may also
///                  optionally start with a '.', if it does not, one will be
///                  prepended.
void replace_extension(SmallVectorImpl<char> &path, const Twine &extension,
                       Style style = Style::native);

/// Replace matching path prefix with another path.
///
/// @code
///   /foo, /old, /new => /foo
///   /old, /old, /new => /new
///   /old, /old/, /new, false => /old
///   /old, /old/, /new, true => /new
///   /old/foo, /old, /new => /new/foo
///   /old/foo, /old/, /new => /new/foo
///   /old/foo, /old/, /new/ => /new/foo
///   /oldfoo, /old, /new => /oldfoo
///   /foo, <empty>, /new => /new/foo
///   /foo, <empty>, new => new/foo
///   /old/foo, /old, <empty>, false => /foo
///   /old/foo, /old, <empty>, true => foo
/// @endcode
///
/// @param Path If \a Path starts with \a OldPrefix modify to instead
///        start with \a NewPrefix.
/// @param OldPrefix The path prefix to strip from \a Path. Any trailing
///        path separator is ignored if strict is true.
/// @param NewPrefix The path prefix to replace \a NewPrefix with.
/// @param style The path separator style
/// @param strict If strict is true, a directory separator following
///        \a OldPrefix will also be stripped. Otherwise, directory
///        separators will only be matched and stripped when present
///        in \a OldPrefix.
/// @result true if \a Path begins with OldPrefix
bool replace_path_prefix(SmallVectorImpl<char> &Path,
                         const StringRef &OldPrefix, const StringRef &NewPrefix,
                         Style style = Style::native, bool strict = false);

/// Append to path.
///
/// @code
///   /foo  + bar/f => /foo/bar/f
///   /foo/ + bar/f => /foo/bar/f
///   foo   + bar/f => foo/bar/f
/// @endcode
///
/// @param path Set to \a path + \a component.
/// @param a The component to be appended to \a path.
void append(SmallVectorImpl<char> &path, const Twine &a,
                                         const Twine &b = "",
                                         const Twine &c = "",
                                         const Twine &d = "");

void append(SmallVectorImpl<char> &path, Style style, const Twine &a,
            const Twine &b = "", const Twine &c = "", const Twine &d = "");

/// Append to path.
///
/// @code
///   /foo  + [bar,f] => /foo/bar/f
///   /foo/ + [bar,f] => /foo/bar/f
///   foo   + [bar,f] => foo/bar/f
/// @endcode
///
/// @param path Set to \a path + [\a begin, \a end).
/// @param begin Start of components to append.
/// @param end One past the end of components to append.
void append(SmallVectorImpl<char> &path, const_iterator begin,
            const_iterator end, Style style = Style::native);

/// @}
/// @name Transforms (or some other better name)
/// @{

/// Convert path to the native form. This is used to give paths to users and
/// operating system calls in the platform's normal way. For example, on Windows
/// all '/' are converted to '\'.
///
/// @param path A path that is transformed to native format.
/// @param result Holds the result of the transformation.
void native(const Twine &path, SmallVectorImpl<char> &result,
            Style style = Style::native);

/// Convert path to the native form in place. This is used to give paths to
/// users and operating system calls in the platform's normal way. For example,
/// on Windows all '/' are converted to '\'.
///
/// @param path A path that is transformed to native format.
void native(SmallVectorImpl<char> &path, Style style = Style::native);

/// Replaces backslashes with slashes if Windows.
///
/// @param path processed path
/// @result The result of replacing backslashes with forward slashes if Windows.
/// On Unix, this function is a no-op because backslashes are valid path
/// chracters.
std::string convert_to_slash(StringRef path, Style style = Style::native);

/// @}
/// @name Lexical Observers
/// @{

/// Get root name.
///
/// @code
///   //net/hello => //net
///   c:/hello    => c: (on Windows, on other platforms nothing)
///   /hello      => <empty>
/// @endcode
///
/// @param path Input path.
/// @result The root name of \a path if it has one, otherwise "".
StringRef root_name(StringRef path, Style style = Style::native);

/// Get root directory.
///
/// @code
///   /goo/hello => /
///   c:/hello   => /
///   d/file.txt => <empty>
/// @endcode
///
/// @param path Input path.
/// @result The root directory of \a path if it has one, otherwise
///               "".
StringRef root_directory(StringRef path, Style style = Style::native);

/// Get root path.
///
/// Equivalent to root_name + root_directory.
///
/// @param path Input path.
/// @result The root path of \a path if it has one, otherwise "".
StringRef root_path(StringRef path, Style style = Style::native);

/// Get relative path.
///
/// @code
///   C:\hello\world => hello\world
///   foo/bar        => foo/bar
///   /foo/bar       => foo/bar
/// @endcode
///
/// @param path Input path.
/// @result The path starting after root_path if one exists, otherwise "".
StringRef relative_path(StringRef path, Style style = Style::native);

/// Get parent path.
///
/// @code
///   /          => <empty>
///   /foo       => /
///   foo/../bar => foo/..
/// @endcode
///
/// @param path Input path.
/// @result The parent path of \a path if one exists, otherwise "".
StringRef parent_path(StringRef path, Style style = Style::native);

/// Get filename.
///
/// @code
///   /foo.txt    => foo.txt
///   .          => .
///   ..         => ..
///   /          => /
/// @endcode
///
/// @param path Input path.
/// @result The filename part of \a path. This is defined as the last component
///         of \a path. Similar to the POSIX "basename" utility.
StringRef filename(StringRef path, Style style = Style::native);

/// Get stem.
///
/// If filename contains a dot but not solely one or two dots, result is the
/// substring of filename ending at (but not including) the last dot. Otherwise
/// it is filename.
///
/// @code
///   /foo/bar.txt => bar
///   /foo/bar     => bar
///   /foo/.txt    => <empty>
///   /foo/.       => .
///   /foo/..      => ..
/// @endcode
///
/// @param path Input path.
/// @result The stem of \a path.
StringRef stem(StringRef path, Style style = Style::native);

/// Get extension.
///
/// If filename contains a dot but not solely one or two dots, result is the
/// substring of filename starting at (and including) the last dot, and ending
/// at the end of \a path. Otherwise "".
///
/// @code
///   /foo/bar.txt => .txt
///   /foo/bar     => <empty>
///   /foo/.txt    => .txt
/// @endcode
///
/// @param path Input path.
/// @result The extension of \a path.
StringRef extension(StringRef path, Style style = Style::native);

/// Check whether the given char is a path separator on the host OS.
///
/// @param value a character
/// @result true if \a value is a path separator character on the host OS
bool is_separator(char value, Style style = Style::native);

/// Return the preferred separator for this platform.
///
/// @result StringRef of the preferred separator, null-terminated.
StringRef get_separator(Style style = Style::native);

/// Get the typical temporary directory for the system, e.g.,
/// "/var/tmp" or "C:/TEMP"
///
/// @param erasedOnReboot Whether to favor a path that is erased on reboot
/// rather than one that potentially persists longer. This parameter will be
/// ignored if the user or system has set the typical environment variable
/// (e.g., TEMP on Windows, TMPDIR on *nix) to specify a temporary directory.
///
/// @param result Holds the resulting path name.
void system_temp_directory(bool erasedOnReboot, SmallVectorImpl<char> &result);

/// Get the user's home directory.
///
/// @param result Holds the resulting path name.
/// @result True if a home directory is set, false otherwise.
bool home_directory(SmallVectorImpl<char> &result);

/// Has root name?
///
/// root_name != ""
///
/// @param path Input path.
/// @result True if the path has a root name, false otherwise.
bool has_root_name(const Twine &path, Style style = Style::native);

/// Has root directory?
///
/// root_directory != ""
///
/// @param path Input path.
/// @result True if the path has a root directory, false otherwise.
bool has_root_directory(const Twine &path, Style style = Style::native);

/// Has root path?
///
/// root_path != ""
///
/// @param path Input path.
/// @result True if the path has a root path, false otherwise.
bool has_root_path(const Twine &path, Style style = Style::native);

/// Has relative path?
///
/// relative_path != ""
///
/// @param path Input path.
/// @result True if the path has a relative path, false otherwise.
bool has_relative_path(const Twine &path, Style style = Style::native);

/// Has parent path?
///
/// parent_path != ""
///
/// @param path Input path.
/// @result True if the path has a parent path, false otherwise.
bool has_parent_path(const Twine &path, Style style = Style::native);

/// Has filename?
///
/// filename != ""
///
/// @param path Input path.
/// @result True if the path has a filename, false otherwise.
bool has_filename(const Twine &path, Style style = Style::native);

/// Has stem?
///
/// stem != ""
///
/// @param path Input path.
/// @result True if the path has a stem, false otherwise.
bool has_stem(const Twine &path, Style style = Style::native);

/// Has extension?
///
/// extension != ""
///
/// @param path Input path.
/// @result True if the path has a extension, false otherwise.
bool has_extension(const Twine &path, Style style = Style::native);

/// Is path absolute?
///
/// @param path Input path.
/// @result True if the path is absolute, false if it is not.
bool is_absolute(const Twine &path, Style style = Style::native);

/// Is path relative?
///
/// @param path Input path.
/// @result True if the path is relative, false if it is not.
bool is_relative(const Twine &path, Style style = Style::native);

/// Remove redundant leading "./" pieces and consecutive separators.
///
/// @param path Input path.
/// @result The cleaned-up \a path.
StringRef remove_leading_dotslash(StringRef path, Style style = Style::native);

/// In-place remove any './' and optionally '../' components from a path.
///
/// @param path processed path
/// @param remove_dot_dot specify if '../' (except for leading "../") should be
/// removed
/// @result True if path was changed
bool remove_dots(SmallVectorImpl<char> &path, bool remove_dot_dot = false,
                 Style style = Style::native);

#if 0 /* disabled by -frewrite-includes */
#if defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 472 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
std::error_code widenPath(const Twine &Path8, SmallVectorImpl<wchar_t> &Path16);
#endif
# 474 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"

} // end namespace path
} // end namespace sys
} // end namespace llvm

#endif
# 480 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Path.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/SourceMgr.h"
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h" 1
//===- SourceMgr.h - Manager for Source Buffers & Diagnostics ---*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file declares the SMDiagnostic and SourceMgr classes.  This
// provides a simple substrate for diagnostics, #include handling, and other low
// level things for simple parsers.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_SOURCEMGR_H
#define LLVM_SUPPORT_SOURCEMGR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/ArrayRef.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/None.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/PointerUnion.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h" 1
//===- llvm/ADT/PointerUnion.h - Discriminated Union of 2 Ptrs --*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the PointerUnion class, which is a discriminated union of
// pointer types.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_POINTERUNION_H
#define LLVM_ADT_POINTERUNION_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMapInfo.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/PointerIntPair.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h" 1
//===- llvm/ADT/PointerIntPair.h - Pair for pointer and int -----*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the PointerIntPair class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_POINTERINTPAIR_H
#define LLVM_ADT_POINTERINTPAIR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/PointerLikeTypeTraits.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/type_traits.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"

namespace llvm {

template <typename T> struct DenseMapInfo;
template <typename PointerT, unsigned IntBits, typename PtrTraits>
struct PointerIntPairInfo;

/// PointerIntPair - This class implements a pair of a pointer and small
/// integer.  It is designed to represent this in the space required by one
/// pointer by bitmangling the integer into the low part of the pointer.  This
/// can only be done for small integers: typically up to 3 bits, but it depends
/// on the number of bits available according to PointerLikeTypeTraits for the
/// type.
///
/// Note that PointerIntPair always puts the IntVal part in the highest bits
/// possible.  For example, PointerIntPair<void*, 1, bool> will put the bit for
/// the bool into bit #2, not bit #0, which allows the low two bits to be used
/// for something else.  For example, this allows:
///   PointerIntPair<PointerIntPair<void*, 1, bool>, 1, bool>
/// ... and the two bools will land in different bits.
template <typename PointerTy, unsigned IntBits, typename IntType = unsigned,
          typename PtrTraits = PointerLikeTypeTraits<PointerTy>,
          typename Info = PointerIntPairInfo<PointerTy, IntBits, PtrTraits>>
class PointerIntPair {
  // Used by MSVC visualizer and generally helpful for debugging/visualizing.
  using InfoTy = Info;
  intptr_t Value = 0;

public:
  constexpr PointerIntPair() = default;

  PointerIntPair(PointerTy PtrVal, IntType IntVal) {
    setPointerAndInt(PtrVal, IntVal);
  }

  explicit PointerIntPair(PointerTy PtrVal) { initWithPointer(PtrVal); }

  PointerTy getPointer() const { return Info::getPointer(Value); }

  IntType getInt() const { return (IntType)Info::getInt(Value); }

  void setPointer(PointerTy PtrVal) LLVM_LVALUE_FUNCTION {
    Value = Info::updatePointer(Value, PtrVal);
  }

  void setInt(IntType IntVal) LLVM_LVALUE_FUNCTION {
    Value = Info::updateInt(Value, static_cast<intptr_t>(IntVal));
  }

  void initWithPointer(PointerTy PtrVal) LLVM_LVALUE_FUNCTION {
    Value = Info::updatePointer(0, PtrVal);
  }

  void setPointerAndInt(PointerTy PtrVal, IntType IntVal) LLVM_LVALUE_FUNCTION {
    Value = Info::updateInt(Info::updatePointer(0, PtrVal),
                            static_cast<intptr_t>(IntVal));
  }

  PointerTy const *getAddrOfPointer() const {
    return const_cast<PointerIntPair *>(this)->getAddrOfPointer();
  }

  PointerTy *getAddrOfPointer() {
    assert(Value == reinterpret_cast<intptr_t>(getPointer()) &&
           "Can only return the address if IntBits is cleared and "
           "PtrTraits doesn't change the pointer");
    return reinterpret_cast<PointerTy *>(&Value);
  }

  void *getOpaqueValue() const { return reinterpret_cast<void *>(Value); }

  void setFromOpaqueValue(void *Val) LLVM_LVALUE_FUNCTION {
    Value = reinterpret_cast<intptr_t>(Val);
  }

  static PointerIntPair getFromOpaqueValue(void *V) {
    PointerIntPair P;
    P.setFromOpaqueValue(V);
    return P;
  }

  // Allow PointerIntPairs to be created from const void * if and only if the
  // pointer type could be created from a const void *.
  static PointerIntPair getFromOpaqueValue(const void *V) {
    (void)PtrTraits::getFromVoidPointer(V);
    return getFromOpaqueValue(const_cast<void *>(V));
  }

  bool operator==(const PointerIntPair &RHS) const {
    return Value == RHS.Value;
  }

  bool operator!=(const PointerIntPair &RHS) const {
    return Value != RHS.Value;
  }

  bool operator<(const PointerIntPair &RHS) const { return Value < RHS.Value; }
  bool operator>(const PointerIntPair &RHS) const { return Value > RHS.Value; }

  bool operator<=(const PointerIntPair &RHS) const {
    return Value <= RHS.Value;
  }

  bool operator>=(const PointerIntPair &RHS) const {
    return Value >= RHS.Value;
  }
};

// Specialize is_trivially_copyable to avoid limitation of llvm::is_trivially_copyable
// when compiled with gcc 4.9.
template <typename PointerTy, unsigned IntBits, typename IntType,
          typename PtrTraits,
          typename Info>
struct is_trivially_copyable<PointerIntPair<PointerTy, IntBits, IntType, PtrTraits, Info>> : std::true_type {
#ifdef HAVE_STD_IS_TRIVIALLY_COPYABLE
  static_assert(std::is_trivially_copyable<PointerIntPair<PointerTy, IntBits, IntType, PtrTraits, Info>>::value,
                "inconsistent behavior between llvm:: and std:: implementation of is_trivially_copyable");
#endif
# 140 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
};


template <typename PointerT, unsigned IntBits, typename PtrTraits>
struct PointerIntPairInfo {
  static_assert(PtrTraits::NumLowBitsAvailable <
                    std::numeric_limits<uintptr_t>::digits,
                "cannot use a pointer type that has all bits free");
  static_assert(IntBits <= PtrTraits::NumLowBitsAvailable,
                "PointerIntPair with integer size too large for pointer");
  enum MaskAndShiftConstants : uintptr_t {
    /// PointerBitMask - The bits that come from the pointer.
    PointerBitMask =
        ~(uintptr_t)(((intptr_t)1 << PtrTraits::NumLowBitsAvailable) - 1),

    /// IntShift - The number of low bits that we reserve for other uses, and
    /// keep zero.
    IntShift = (uintptr_t)PtrTraits::NumLowBitsAvailable - IntBits,

    /// IntMask - This is the unshifted mask for valid bits of the int type.
    IntMask = (uintptr_t)(((intptr_t)1 << IntBits) - 1),

    // ShiftedIntMask - This is the bits for the integer shifted in place.
    ShiftedIntMask = (uintptr_t)(IntMask << IntShift)
  };

  static PointerT getPointer(intptr_t Value) {
    return PtrTraits::getFromVoidPointer(
        reinterpret_cast<void *>(Value & PointerBitMask));
  }

  static intptr_t getInt(intptr_t Value) {
    return (Value >> IntShift) & IntMask;
  }

  static intptr_t updatePointer(intptr_t OrigValue, PointerT Ptr) {
    intptr_t PtrWord =
        reinterpret_cast<intptr_t>(PtrTraits::getAsVoidPointer(Ptr));
    assert((PtrWord & ~PointerBitMask) == 0 &&
           "Pointer is not sufficiently aligned");
    // Preserve all low bits, just update the pointer.
    return PtrWord | (OrigValue & ~PointerBitMask);
  }

  static intptr_t updateInt(intptr_t OrigValue, intptr_t Int) {
    intptr_t IntWord = static_cast<intptr_t>(Int);
    assert((IntWord & ~IntMask) == 0 && "Integer too large for field");

    // Preserve all bits other than the ones we are updating.
    return (OrigValue & ~ShiftedIntMask) | IntWord << IntShift;
  }
};

// Provide specialization of DenseMapInfo for PointerIntPair.
template <typename PointerTy, unsigned IntBits, typename IntType>
struct DenseMapInfo<PointerIntPair<PointerTy, IntBits, IntType>> {
  using Ty = PointerIntPair<PointerTy, IntBits, IntType>;

  static Ty getEmptyKey() {
    uintptr_t Val = static_cast<uintptr_t>(-1);
    Val <<= PointerLikeTypeTraits<Ty>::NumLowBitsAvailable;
    return Ty::getFromOpaqueValue(reinterpret_cast<void *>(Val));
  }

  static Ty getTombstoneKey() {
    uintptr_t Val = static_cast<uintptr_t>(-2);
    Val <<= PointerLikeTypeTraits<PointerTy>::NumLowBitsAvailable;
    return Ty::getFromOpaqueValue(reinterpret_cast<void *>(Val));
  }

  static unsigned getHashValue(Ty V) {
    uintptr_t IV = reinterpret_cast<uintptr_t>(V.getOpaqueValue());
    return unsigned(IV) ^ unsigned(IV >> 9);
  }

  static bool isEqual(const Ty &LHS, const Ty &RHS) { return LHS == RHS; }
};

// Teach SmallPtrSet that PointerIntPair is "basically a pointer".
template <typename PointerTy, unsigned IntBits, typename IntType,
          typename PtrTraits>
struct PointerLikeTypeTraits<
    PointerIntPair<PointerTy, IntBits, IntType, PtrTraits>> {
  static inline void *
  getAsVoidPointer(const PointerIntPair<PointerTy, IntBits, IntType> &P) {
    return P.getOpaqueValue();
  }

  static inline PointerIntPair<PointerTy, IntBits, IntType>
  getFromVoidPointer(void *P) {
    return PointerIntPair<PointerTy, IntBits, IntType>::getFromOpaqueValue(P);
  }

  static inline PointerIntPair<PointerTy, IntBits, IntType>
  getFromVoidPointer(const void *P) {
    return PointerIntPair<PointerTy, IntBits, IntType>::getFromOpaqueValue(P);
  }

  static constexpr int NumLowBitsAvailable =
      PtrTraits::NumLowBitsAvailable - IntBits;
};

} // end namespace llvm

#endif // LLVM_ADT_POINTERINTPAIR_H
# 245 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerIntPair.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/PointerLikeTypeTraits.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"

namespace llvm {

template <typename T> struct PointerUnionTypeSelectorReturn {
  using Return = T;
};

/// Get a type based on whether two types are the same or not.
///
/// For:
///
/// \code
///   using Ret = typename PointerUnionTypeSelector<T1, T2, EQ, NE>::Return;
/// \endcode
///
/// Ret will be EQ type if T1 is same as T2 or NE type otherwise.
template <typename T1, typename T2, typename RET_EQ, typename RET_NE>
struct PointerUnionTypeSelector {
  using Return = typename PointerUnionTypeSelectorReturn<RET_NE>::Return;
};

template <typename T, typename RET_EQ, typename RET_NE>
struct PointerUnionTypeSelector<T, T, RET_EQ, RET_NE> {
  using Return = typename PointerUnionTypeSelectorReturn<RET_EQ>::Return;
};

template <typename T1, typename T2, typename RET_EQ, typename RET_NE>
struct PointerUnionTypeSelectorReturn<
    PointerUnionTypeSelector<T1, T2, RET_EQ, RET_NE>> {
  using Return =
      typename PointerUnionTypeSelector<T1, T2, RET_EQ, RET_NE>::Return;
};

namespace pointer_union_detail {
  /// Determine the number of bits required to store integers with values < n.
  /// This is ceil(log2(n)).
  constexpr int bitsRequired(unsigned n) {
    return n > 1 ? 1 + bitsRequired((n + 1) / 2) : 0;
  }

  template <typename... Ts> constexpr int lowBitsAvailable() {
    return std::min<int>({PointerLikeTypeTraits<Ts>::NumLowBitsAvailable...});
  }

  /// Find the index of a type in a list of types. TypeIndex<T, Us...>::Index
  /// is the index of T in Us, or sizeof...(Us) if T does not appear in the
  /// list.
  template <typename T, typename ...Us> struct TypeIndex;
  template <typename T, typename ...Us> struct TypeIndex<T, T, Us...> {
    static constexpr int Index = 0;
  };
  template <typename T, typename U, typename... Us>
  struct TypeIndex<T, U, Us...> {
    static constexpr int Index = 1 + TypeIndex<T, Us...>::Index;
  };
  template <typename T> struct TypeIndex<T> {
    static constexpr int Index = 0;
  };

  /// Find the first type in a list of types.
  template <typename T, typename...> struct GetFirstType {
    using type = T;
  };

  /// Provide PointerLikeTypeTraits for void* that is used by PointerUnion
  /// for the template arguments.
  template <typename ...PTs> class PointerUnionUIntTraits {
  public:
    static inline void *getAsVoidPointer(void *P) { return P; }
    static inline void *getFromVoidPointer(void *P) { return P; }
    static constexpr int NumLowBitsAvailable = lowBitsAvailable<PTs...>();
  };

  /// Implement assignment in terms of construction.
  template <typename Derived, typename T> struct AssignableFrom {
    Derived &operator=(T t) {
      return static_cast<Derived &>(*this) = Derived(t);
    }
  };

  template <typename Derived, typename ValTy, int I, typename ...Types>
  class PointerUnionMembers;

  template <typename Derived, typename ValTy, int I>
  class PointerUnionMembers<Derived, ValTy, I> {
  protected:
    ValTy Val;
    PointerUnionMembers() = default;
    PointerUnionMembers(ValTy Val) : Val(Val) {}

    friend struct PointerLikeTypeTraits<Derived>;
  };

  template <typename Derived, typename ValTy, int I, typename Type,
            typename ...Types>
  class PointerUnionMembers<Derived, ValTy, I, Type, Types...>
      : public PointerUnionMembers<Derived, ValTy, I + 1, Types...> {
    using Base = PointerUnionMembers<Derived, ValTy, I + 1, Types...>;
  public:
    using Base::Base;
    PointerUnionMembers() = default;
    PointerUnionMembers(Type V)
        : Base(ValTy(const_cast<void *>(
                         PointerLikeTypeTraits<Type>::getAsVoidPointer(V)),
                     I)) {}

    using Base::operator=;
    Derived &operator=(Type V) {
      this->Val = ValTy(
          const_cast<void *>(PointerLikeTypeTraits<Type>::getAsVoidPointer(V)),
          I);
      return static_cast<Derived &>(*this);
    };
  };
}

/// A discriminated union of two or more pointer types, with the discriminator
/// in the low bit of the pointer.
///
/// This implementation is extremely efficient in space due to leveraging the
/// low bits of the pointer, while exposing a natural and type-safe API.
///
/// Common use patterns would be something like this:
///    PointerUnion<int*, float*> P;
///    P = (int*)0;
///    printf("%d %d", P.is<int*>(), P.is<float*>());  // prints "1 0"
///    X = P.get<int*>();     // ok.
///    Y = P.get<float*>();   // runtime assertion failure.
///    Z = P.get<double*>();  // compile time failure.
///    P = (float*)0;
///    Y = P.get<float*>();   // ok.
///    X = P.get<int*>();     // runtime assertion failure.
template <typename... PTs>
class PointerUnion
    : public pointer_union_detail::PointerUnionMembers<
          PointerUnion<PTs...>,
          PointerIntPair<
              void *, pointer_union_detail::bitsRequired(sizeof...(PTs)), int,
              pointer_union_detail::PointerUnionUIntTraits<PTs...>>,
          0, PTs...> {
  // The first type is special because we want to directly cast a pointer to a
  // default-initialized union to a pointer to the first type. But we don't
  // want PointerUnion to be a 'template <typename First, typename ...Rest>'
  // because it's much more convenient to have a name for the whole pack. So
  // split off the first type here.
  using First = typename pointer_union_detail::GetFirstType<PTs...>::type;
  using Base = typename PointerUnion::PointerUnionMembers;

public:
  PointerUnion() = default;

  PointerUnion(std::nullptr_t) : PointerUnion() {}
  using Base::Base;

  /// Test if the pointer held in the union is null, regardless of
  /// which type it is.
  bool isNull() const { return !this->Val.getPointer(); }

  explicit operator bool() const { return !isNull(); }

  /// Test if the Union currently holds the type matching T.
  template <typename T> bool is() const {
    constexpr int Index = pointer_union_detail::TypeIndex<T, PTs...>::Index;
    static_assert(Index < sizeof...(PTs),
                  "PointerUnion::is<T> given type not in the union");
    return this->Val.getInt() == Index;
  }

  /// Returns the value of the specified pointer type.
  ///
  /// If the specified pointer type is incorrect, assert.
  template <typename T> T get() const {
    assert(is<T>() && "Invalid accessor called");
    return PointerLikeTypeTraits<T>::getFromVoidPointer(this->Val.getPointer());
  }

  /// Returns the current pointer if it is of the specified pointer type,
  /// otherwises returns null.
  template <typename T> T dyn_cast() const {
    if (is<T>())
      return get<T>();
    return T();
  }

  /// If the union is set to the first pointer type get an address pointing to
  /// it.
  First const *getAddrOfPtr1() const {
    return const_cast<PointerUnion *>(this)->getAddrOfPtr1();
  }

  /// If the union is set to the first pointer type get an address pointing to
  /// it.
  First *getAddrOfPtr1() {
    assert(is<First>() && "Val is not the first pointer");
    assert(
        PointerLikeTypeTraits<First>::getAsVoidPointer(get<First>()) ==
            this->Val.getPointer() &&
        "Can't get the address because PointerLikeTypeTraits changes the ptr");
    return const_cast<First *>(
        reinterpret_cast<const First *>(this->Val.getAddrOfPointer()));
  }

  /// Assignment from nullptr which just clears the union.
  const PointerUnion &operator=(std::nullptr_t) {
    this->Val.initWithPointer(nullptr);
    return *this;
  }

  /// Assignment from elements of the union.
  using Base::operator=;

  void *getOpaqueValue() const { return this->Val.getOpaqueValue(); }
  static inline PointerUnion getFromOpaqueValue(void *VP) {
    PointerUnion V;
    V.Val = decltype(V.Val)::getFromOpaqueValue(VP);
    return V;
  }
};

template <typename ...PTs>
bool operator==(PointerUnion<PTs...> lhs, PointerUnion<PTs...> rhs) {
  return lhs.getOpaqueValue() == rhs.getOpaqueValue();
}

template <typename ...PTs>
bool operator!=(PointerUnion<PTs...> lhs, PointerUnion<PTs...> rhs) {
  return lhs.getOpaqueValue() != rhs.getOpaqueValue();
}

template <typename ...PTs>
bool operator<(PointerUnion<PTs...> lhs, PointerUnion<PTs...> rhs) {
  return lhs.getOpaqueValue() < rhs.getOpaqueValue();
}

// Teach SmallPtrSet that PointerUnion is "basically a pointer", that has
// # low bits available = min(PT1bits,PT2bits)-1.
template <typename ...PTs>
struct PointerLikeTypeTraits<PointerUnion<PTs...>> {
  static inline void *getAsVoidPointer(const PointerUnion<PTs...> &P) {
    return P.getOpaqueValue();
  }

  static inline PointerUnion<PTs...> getFromVoidPointer(void *P) {
    return PointerUnion<PTs...>::getFromOpaqueValue(P);
  }

  // The number of bits available are the min of the pointer types minus the
  // bits needed for the discriminator.
  static constexpr int NumLowBitsAvailable = PointerLikeTypeTraits<decltype(
      PointerUnion<PTs...>::Val)>::NumLowBitsAvailable;
};

// Teach DenseMap how to use PointerUnions as keys.
template <typename ...PTs> struct DenseMapInfo<PointerUnion<PTs...>> {
  using Union = PointerUnion<PTs...>;
  using FirstInfo =
      DenseMapInfo<typename pointer_union_detail::GetFirstType<PTs...>::type>;

  static inline Union getEmptyKey() { return Union(FirstInfo::getEmptyKey()); }

  static inline Union getTombstoneKey() {
    return Union(FirstInfo::getTombstoneKey());
  }

  static unsigned getHashValue(const Union &UnionVal) {
    intptr_t key = (intptr_t)UnionVal.getOpaqueValue();
    return DenseMapInfo<intptr_t>::getHashValue(key);
  }

  static bool isEqual(const Union &LHS, const Union &RHS) {
    return LHS == RHS;
  }
};

} // end namespace llvm

#endif // LLVM_ADT_POINTERUNION_H
# 300 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/PointerUnion.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Twine.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MemoryBuffer.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h" 1
//===--- MemoryBuffer.h - Memory Buffer Interface ---------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
//  This file defines the MemoryBuffer interface.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_MEMORYBUFFER_H
#define LLVM_SUPPORT_MEMORYBUFFER_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/Types.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Types.h" 1
/*===-- llvm-c/Support.h - C Interface Types declarations ---------*- C -*-===*\
|*                                                                            *|
|* Part of the LLVM Project, under the Apache License v2.0 with LLVM          *|
|* Exceptions.                                                                *|
|* See https://llvm.org/LICENSE.txt for license information.                  *|
|* SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception                    *|
|*                                                                            *|
|*===----------------------------------------------------------------------===*|
|*                                                                            *|
|* This file defines types used by the C interface to LLVM.                   *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_C_TYPES_H
#define LLVM_C_TYPES_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/DataTypes.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Types.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Types.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/ExternC.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Types.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Types.h"

LLVM_C_EXTERN_C_BEGIN

/**
 * @defgroup LLVMCSupportTypes Types and Enumerations
 *
 * @{
 */

typedef int LLVMBool;

/* Opaque types. */

/**
 * LLVM uses a polymorphic type hierarchy which C cannot represent, therefore
 * parameters must be passed as base types. Despite the declared types, most
 * of the functions provided operate only on branches of the type hierarchy.
 * The declared parameter names are descriptive and specify which type is
 * required. Additionally, each type hierarchy is documented along with the
 * functions that operate upon it. For more detail, refer to LLVM's C++ code.
 * If in doubt, refer to Core.cpp, which performs parameter downcasts in the
 * form unwrap<RequiredType>(Param).
 */

/**
 * Used to pass regions of memory through LLVM interfaces.
 *
 * @see llvm::MemoryBuffer
 */
typedef struct LLVMOpaqueMemoryBuffer *LLVMMemoryBufferRef;

/**
 * The top-level container for all LLVM global data. See the LLVMContext class.
 */
typedef struct LLVMOpaqueContext *LLVMContextRef;

/**
 * The top-level container for all other LLVM Intermediate Representation (IR)
 * objects.
 *
 * @see llvm::Module
 */
typedef struct LLVMOpaqueModule *LLVMModuleRef;

/**
 * Each value in the LLVM IR has a type, an LLVMTypeRef.
 *
 * @see llvm::Type
 */
typedef struct LLVMOpaqueType *LLVMTypeRef;

/**
 * Represents an individual value in LLVM IR.
 *
 * This models llvm::Value.
 */
typedef struct LLVMOpaqueValue *LLVMValueRef;

/**
 * Represents a basic block of instructions in LLVM IR.
 *
 * This models llvm::BasicBlock.
 */
typedef struct LLVMOpaqueBasicBlock *LLVMBasicBlockRef;

/**
 * Represents an LLVM Metadata.
 *
 * This models llvm::Metadata.
 */
typedef struct LLVMOpaqueMetadata *LLVMMetadataRef;

/**
 * Represents an LLVM Named Metadata Node.
 *
 * This models llvm::NamedMDNode.
 */
typedef struct LLVMOpaqueNamedMDNode *LLVMNamedMDNodeRef;

/**
 * Represents an entry in a Global Object's metadata attachments.
 *
 * This models std::pair<unsigned, MDNode *>
 */
typedef struct LLVMOpaqueValueMetadataEntry LLVMValueMetadataEntry;

/**
 * Represents an LLVM basic block builder.
 *
 * This models llvm::IRBuilder.
 */
typedef struct LLVMOpaqueBuilder *LLVMBuilderRef;

/**
 * Represents an LLVM debug info builder.
 *
 * This models llvm::DIBuilder.
 */
typedef struct LLVMOpaqueDIBuilder *LLVMDIBuilderRef;

/**
 * Interface used to provide a module to JIT or interpreter.
 * This is now just a synonym for llvm::Module, but we have to keep using the
 * different type to keep binary compatibility.
 */
typedef struct LLVMOpaqueModuleProvider *LLVMModuleProviderRef;

/** @see llvm::PassManagerBase */
typedef struct LLVMOpaquePassManager *LLVMPassManagerRef;

/** @see llvm::PassRegistry */
typedef struct LLVMOpaquePassRegistry *LLVMPassRegistryRef;

/**
 * Used to get the users and usees of a Value.
 *
 * @see llvm::Use */
typedef struct LLVMOpaqueUse *LLVMUseRef;

/**
 * Used to represent an attributes.
 *
 * @see llvm::Attribute
 */
typedef struct LLVMOpaqueAttributeRef *LLVMAttributeRef;

/**
 * @see llvm::DiagnosticInfo
 */
typedef struct LLVMOpaqueDiagnosticInfo *LLVMDiagnosticInfoRef;

/**
 * @see llvm::Comdat
 */
typedef struct LLVMComdat *LLVMComdatRef;

/**
 * @see llvm::Module::ModuleFlagEntry
 */
typedef struct LLVMOpaqueModuleFlagEntry LLVMModuleFlagEntry;

/**
 * @see llvm::JITEventListener
 */
typedef struct LLVMOpaqueJITEventListener *LLVMJITEventListenerRef;

/**
 * @see llvm::object::Binary
 */
typedef struct LLVMOpaqueBinary *LLVMBinaryRef;

/**
 * @}
 */

LLVM_C_EXTERN_C_END

#endif
# 177 "/Users/vsk/src/llvm-project-master/llvm/include/llvm-c/Types.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/ArrayRef.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Twine.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/CBindingWrapping.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/CBindingWrapping.h" 1
//===- llvm/Support/CBindingWrapping.h - C Interface Wrapping ---*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file declares the wrapping macros for the C interface.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_CBINDINGWRAPPING_H
#define LLVM_SUPPORT_CBINDINGWRAPPING_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm-c/Types.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/CBindingWrapping.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/CBindingWrapping.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Casting.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/CBindingWrapping.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/CBindingWrapping.h"

#define DEFINE_SIMPLE_CONVERSION_FUNCTIONS(ty, ref)     \
  inline ty *unwrap(ref P) {                            \
    return reinterpret_cast<ty*>(P);                    \
  }                                                     \
                                                        \
  inline ref wrap(const ty *P) {                        \
    return reinterpret_cast<ref>(const_cast<ty*>(P));   \
  }

#define DEFINE_ISA_CONVERSION_FUNCTIONS(ty, ref)        \
  DEFINE_SIMPLE_CONVERSION_FUNCTIONS(ty, ref)           \
                                                        \
  template<typename T>                                  \
  inline T *unwrap(ref P) {                             \
    return cast<T>(unwrap(P));                          \
  }

#define DEFINE_STDCXX_CONVERSION_FUNCTIONS(ty, ref)     \
  DEFINE_SIMPLE_CONVERSION_FUNCTIONS(ty, ref)           \
                                                        \
  template<typename T>                                  \
  inline T *unwrap(ref P) {                             \
    T *Q = (T*)unwrap(P);                               \
    assert(Q && "Invalid cast!");                       \
    return Q;                                           \
  }

#endif
# 47 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/CBindingWrapping.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorOr.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/FileSystem.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"

namespace llvm {

class MemoryBufferRef;

/// This interface provides simple read-only access to a block of memory, and
/// provides simple methods for reading files and standard input into a memory
/// buffer.  In addition to basic access to the characters in the file, this
/// interface guarantees you can read one character past the end of the file,
/// and that this character will read as '\0'.
///
/// The '\0' guarantee is needed to support an optimization -- it's intended to
/// be more efficient for clients which are reading all the data to stop
/// reading when they encounter a '\0' than to continually check the file
/// position to see if it has reached the end of the file.
class MemoryBuffer {
  const char *BufferStart; // Start of the buffer.
  const char *BufferEnd;   // End of the buffer.

protected:
  MemoryBuffer() = default;

  void init(const char *BufStart, const char *BufEnd,
            bool RequiresNullTerminator);

  static constexpr sys::fs::mapped_file_region::mapmode Mapmode =
      sys::fs::mapped_file_region::readonly;

public:
  MemoryBuffer(const MemoryBuffer &) = delete;
  MemoryBuffer &operator=(const MemoryBuffer &) = delete;
  virtual ~MemoryBuffer();

  const char *getBufferStart() const { return BufferStart; }
  const char *getBufferEnd() const   { return BufferEnd; }
  size_t getBufferSize() const { return BufferEnd-BufferStart; }

  StringRef getBuffer() const {
    return StringRef(BufferStart, getBufferSize());
  }

  /// Return an identifier for this buffer, typically the filename it was read
  /// from.
  virtual StringRef getBufferIdentifier() const { return "Unknown buffer"; }

  /// Open the specified file as a MemoryBuffer, returning a new MemoryBuffer
  /// if successful, otherwise returning null. If FileSize is specified, this
  /// means that the client knows that the file exists and that it has the
  /// specified size.
  ///
  /// \param IsVolatile Set to true to indicate that the contents of the file
  /// can change outside the user's control, e.g. when libclang tries to parse
  /// while the user is editing/updating the file or if the file is on an NFS.
  static ErrorOr<std::unique_ptr<MemoryBuffer>>
  getFile(const Twine &Filename, int64_t FileSize = -1,
          bool RequiresNullTerminator = true, bool IsVolatile = false);

  /// Read all of the specified file into a MemoryBuffer as a stream
  /// (i.e. until EOF reached). This is useful for special files that
  /// look like a regular file but have 0 size (e.g. /proc/cpuinfo on Linux).
  static ErrorOr<std::unique_ptr<MemoryBuffer>>
  getFileAsStream(const Twine &Filename);

  /// Given an already-open file descriptor, map some slice of it into a
  /// MemoryBuffer. The slice is specified by an \p Offset and \p MapSize.
  /// Since this is in the middle of a file, the buffer is not null terminated.
  static ErrorOr<std::unique_ptr<MemoryBuffer>>
  getOpenFileSlice(sys::fs::file_t FD, const Twine &Filename, uint64_t MapSize,
                   int64_t Offset, bool IsVolatile = false);

  /// Given an already-open file descriptor, read the file and return a
  /// MemoryBuffer.
  ///
  /// \param IsVolatile Set to true to indicate that the contents of the file
  /// can change outside the user's control, e.g. when libclang tries to parse
  /// while the user is editing/updating the file or if the file is on an NFS.
  static ErrorOr<std::unique_ptr<MemoryBuffer>>
  getOpenFile(sys::fs::file_t FD, const Twine &Filename, uint64_t FileSize,
              bool RequiresNullTerminator = true, bool IsVolatile = false);

  /// Open the specified memory range as a MemoryBuffer. Note that InputData
  /// must be null terminated if RequiresNullTerminator is true.
  static std::unique_ptr<MemoryBuffer>
  getMemBuffer(StringRef InputData, StringRef BufferName = "",
               bool RequiresNullTerminator = true);

  static std::unique_ptr<MemoryBuffer>
  getMemBuffer(MemoryBufferRef Ref, bool RequiresNullTerminator = true);

  /// Open the specified memory range as a MemoryBuffer, copying the contents
  /// and taking ownership of it. InputData does not have to be null terminated.
  static std::unique_ptr<MemoryBuffer>
  getMemBufferCopy(StringRef InputData, const Twine &BufferName = "");

  /// Read all of stdin into a file buffer, and return it.
  static ErrorOr<std::unique_ptr<MemoryBuffer>> getSTDIN();

  /// Open the specified file as a MemoryBuffer, or open stdin if the Filename
  /// is "-".
  static ErrorOr<std::unique_ptr<MemoryBuffer>>
  getFileOrSTDIN(const Twine &Filename, int64_t FileSize = -1,
                 bool RequiresNullTerminator = true);

  /// Map a subrange of the specified file as a MemoryBuffer.
  static ErrorOr<std::unique_ptr<MemoryBuffer>>
  getFileSlice(const Twine &Filename, uint64_t MapSize, uint64_t Offset,
               bool IsVolatile = false);

  //===--------------------------------------------------------------------===//
  // Provided for performance analysis.
  //===--------------------------------------------------------------------===//

  /// The kind of memory backing used to support the MemoryBuffer.
  enum BufferKind {
    MemoryBuffer_Malloc,
    MemoryBuffer_MMap
  };

  /// Return information on the memory mechanism used to support the
  /// MemoryBuffer.
  virtual BufferKind getBufferKind() const = 0;

  MemoryBufferRef getMemBufferRef() const;
};

/// This class is an extension of MemoryBuffer, which allows copy-on-write
/// access to the underlying contents.  It only supports creation methods that
/// are guaranteed to produce a writable buffer.  For example, mapping a file
/// read-only is not supported.
class WritableMemoryBuffer : public MemoryBuffer {
protected:
  WritableMemoryBuffer() = default;

  static constexpr sys::fs::mapped_file_region::mapmode Mapmode =
      sys::fs::mapped_file_region::priv;

public:
  using MemoryBuffer::getBuffer;
  using MemoryBuffer::getBufferEnd;
  using MemoryBuffer::getBufferStart;

  // const_cast is well-defined here, because the underlying buffer is
  // guaranteed to have been initialized with a mutable buffer.
  char *getBufferStart() {
    return const_cast<char *>(MemoryBuffer::getBufferStart());
  }
  char *getBufferEnd() {
    return const_cast<char *>(MemoryBuffer::getBufferEnd());
  }
  MutableArrayRef<char> getBuffer() {
    return {getBufferStart(), getBufferEnd()};
  }

  static ErrorOr<std::unique_ptr<WritableMemoryBuffer>>
  getFile(const Twine &Filename, int64_t FileSize = -1,
          bool IsVolatile = false);

  /// Map a subrange of the specified file as a WritableMemoryBuffer.
  static ErrorOr<std::unique_ptr<WritableMemoryBuffer>>
  getFileSlice(const Twine &Filename, uint64_t MapSize, uint64_t Offset,
               bool IsVolatile = false);

  /// Allocate a new MemoryBuffer of the specified size that is not initialized.
  /// Note that the caller should initialize the memory allocated by this
  /// method. The memory is owned by the MemoryBuffer object.
  static std::unique_ptr<WritableMemoryBuffer>
  getNewUninitMemBuffer(size_t Size, const Twine &BufferName = "");

  /// Allocate a new zero-initialized MemoryBuffer of the specified size. Note
  /// that the caller need not initialize the memory allocated by this method.
  /// The memory is owned by the MemoryBuffer object.
  static std::unique_ptr<WritableMemoryBuffer>
  getNewMemBuffer(size_t Size, const Twine &BufferName = "");

private:
  // Hide these base class factory function so one can't write
  //   WritableMemoryBuffer::getXXX()
  // and be surprised that he got a read-only Buffer.
  using MemoryBuffer::getFileAsStream;
  using MemoryBuffer::getFileOrSTDIN;
  using MemoryBuffer::getMemBuffer;
  using MemoryBuffer::getMemBufferCopy;
  using MemoryBuffer::getOpenFile;
  using MemoryBuffer::getOpenFileSlice;
  using MemoryBuffer::getSTDIN;
};

/// This class is an extension of MemoryBuffer, which allows write access to
/// the underlying contents and committing those changes to the original source.
/// It only supports creation methods that are guaranteed to produce a writable
/// buffer.  For example, mapping a file read-only is not supported.
class WriteThroughMemoryBuffer : public MemoryBuffer {
protected:
  WriteThroughMemoryBuffer() = default;

  static constexpr sys::fs::mapped_file_region::mapmode Mapmode =
      sys::fs::mapped_file_region::readwrite;

public:
  using MemoryBuffer::getBuffer;
  using MemoryBuffer::getBufferEnd;
  using MemoryBuffer::getBufferStart;

  // const_cast is well-defined here, because the underlying buffer is
  // guaranteed to have been initialized with a mutable buffer.
  char *getBufferStart() {
    return const_cast<char *>(MemoryBuffer::getBufferStart());
  }
  char *getBufferEnd() {
    return const_cast<char *>(MemoryBuffer::getBufferEnd());
  }
  MutableArrayRef<char> getBuffer() {
    return {getBufferStart(), getBufferEnd()};
  }

  static ErrorOr<std::unique_ptr<WriteThroughMemoryBuffer>>
  getFile(const Twine &Filename, int64_t FileSize = -1);

  /// Map a subrange of the specified file as a ReadWriteMemoryBuffer.
  static ErrorOr<std::unique_ptr<WriteThroughMemoryBuffer>>
  getFileSlice(const Twine &Filename, uint64_t MapSize, uint64_t Offset);

private:
  // Hide these base class factory function so one can't write
  //   WritableMemoryBuffer::getXXX()
  // and be surprised that he got a read-only Buffer.
  using MemoryBuffer::getFileAsStream;
  using MemoryBuffer::getFileOrSTDIN;
  using MemoryBuffer::getMemBuffer;
  using MemoryBuffer::getMemBufferCopy;
  using MemoryBuffer::getOpenFile;
  using MemoryBuffer::getOpenFileSlice;
  using MemoryBuffer::getSTDIN;
};

class MemoryBufferRef {
  StringRef Buffer;
  StringRef Identifier;

public:
  MemoryBufferRef() = default;
  MemoryBufferRef(const MemoryBuffer& Buffer)
      : Buffer(Buffer.getBuffer()), Identifier(Buffer.getBufferIdentifier()) {}
  MemoryBufferRef(StringRef Buffer, StringRef Identifier)
      : Buffer(Buffer), Identifier(Identifier) {}

  StringRef getBuffer() const { return Buffer; }

  StringRef getBufferIdentifier() const { return Identifier; }

  const char *getBufferStart() const { return Buffer.begin(); }
  const char *getBufferEnd() const { return Buffer.end(); }
  size_t getBufferSize() const { return Buffer.size(); }
};

// Create wrappers for C Binding types (see CBindingWrapping.h).
DEFINE_SIMPLE_CONVERSION_FUNCTIONS(MemoryBuffer, LLVMMemoryBufferRef)

} // end namespace llvm

#endif // LLVM_SUPPORT_MEMORYBUFFER_H
# 287 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/MemoryBuffer.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/SMLoc.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SMLoc.h" 1
//===- SMLoc.h - Source location for use with diagnostics -------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file declares the SMLoc class.  This class encapsulates a location in
// source code for use in diagnostics.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_SMLOC_H
#define LLVM_SUPPORT_SMLOC_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/None.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SMLoc.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SMLoc.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SMLoc.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SMLoc.h" 2

namespace llvm {

/// Represents a location in source code.
class SMLoc {
  const char *Ptr = nullptr;

public:
  SMLoc() = default;

  bool isValid() const { return Ptr != nullptr; }

  bool operator==(const SMLoc &RHS) const { return RHS.Ptr == Ptr; }
  bool operator!=(const SMLoc &RHS) const { return RHS.Ptr != Ptr; }

  const char *getPointer() const { return Ptr; }

  static SMLoc getFromPointer(const char *Ptr) {
    SMLoc L;
    L.Ptr = Ptr;
    return L;
  }
};

/// Represents a range in source code.
///
/// SMRange is implemented using a half-open range, as is the convention in C++.
/// In the string "abc", the range [1,3) represents the substring "bc", and the
/// range [2,2) represents an empty range between the characters "b" and "c".
class SMRange {
public:
  SMLoc Start, End;

  SMRange() = default;
  SMRange(NoneType) {}
  SMRange(SMLoc St, SMLoc En) : Start(St), End(En) {
    assert(Start.isValid() == End.isValid() &&
           "Start and End should either both be valid or both be invalid!");
  }

  bool isValid() const { return Start.isValid(); }
};

} // end namespace llvm

#endif // LLVM_SUPPORT_SMLOC_H
# 65 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SMLoc.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"

namespace llvm {

class raw_ostream;
class SMDiagnostic;
class SMFixIt;

/// This owns the files read by a parser, handles include stacks,
/// and handles diagnostic wrangling.
class SourceMgr {
public:
  enum DiagKind {
    DK_Error,
    DK_Warning,
    DK_Remark,
    DK_Note,
  };

  /// Clients that want to handle their own diagnostics in a custom way can
  /// register a function pointer+context as a diagnostic handler.
  /// It gets called each time PrintMessage is invoked.
  using DiagHandlerTy = void (*)(const SMDiagnostic &, void *Context);

private:
  struct SrcBuffer {
    /// The memory buffer for the file.
    std::unique_ptr<MemoryBuffer> Buffer;

    /// Helper type for OffsetCache below: since we're storing many offsets
    /// into relatively small files (often smaller than 2^8 or 2^16 bytes),
    /// we select the offset vector element type dynamically based on the
    /// size of Buffer.
    using VariableSizeOffsets = PointerUnion<std::vector<uint8_t> *,
                                             std::vector<uint16_t> *,
                                             std::vector<uint32_t> *,
                                             std::vector<uint64_t> *>;

    /// Vector of offsets into Buffer at which there are line-endings
    /// (lazily populated). Once populated, the '\n' that marks the end of
    /// line number N from [1..] is at Buffer[OffsetCache[N-1]]. Since
    /// these offsets are in sorted (ascending) order, they can be
    /// binary-searched for the first one after any given offset (eg. an
    /// offset corresponding to a particular SMLoc).
    mutable VariableSizeOffsets OffsetCache;

    /// Populate \c OffsetCache and look up a given \p Ptr in it, assuming
    /// it points somewhere into \c Buffer. The static type parameter \p T
    /// must be an unsigned integer type from uint{8,16,32,64}_t large
    /// enough to store offsets inside \c Buffer.
    template<typename T>
    unsigned getLineNumber(const char *Ptr) const;

    /// This is the location of the parent include, or null if at the top level.
    SMLoc IncludeLoc;

    SrcBuffer() = default;
    SrcBuffer(SrcBuffer &&);
    SrcBuffer(const SrcBuffer &) = delete;
    SrcBuffer &operator=(const SrcBuffer &) = delete;
    ~SrcBuffer();
  };

  /// This is all of the buffers that we are reading from.
  std::vector<SrcBuffer> Buffers;

  // This is the list of directories we should search for include files in.
  std::vector<std::string> IncludeDirectories;

  DiagHandlerTy DiagHandler = nullptr;
  void *DiagContext = nullptr;

  bool isValidBufferID(unsigned i) const { return i && i <= Buffers.size(); }

public:
  SourceMgr() = default;
  SourceMgr(const SourceMgr &) = delete;
  SourceMgr &operator=(const SourceMgr &) = delete;
  SourceMgr(SourceMgr &&) = default;
  SourceMgr &operator=(SourceMgr &&) = default;
  ~SourceMgr() = default;

  void setIncludeDirs(const std::vector<std::string> &Dirs) {
    IncludeDirectories = Dirs;
  }

  /// Specify a diagnostic handler to be invoked every time PrintMessage is
  /// called. \p Ctx is passed into the handler when it is invoked.
  void setDiagHandler(DiagHandlerTy DH, void *Ctx = nullptr) {
    DiagHandler = DH;
    DiagContext = Ctx;
  }

  DiagHandlerTy getDiagHandler() const { return DiagHandler; }
  void *getDiagContext() const { return DiagContext; }

  const SrcBuffer &getBufferInfo(unsigned i) const {
    assert(isValidBufferID(i));
    return Buffers[i - 1];
  }

  const MemoryBuffer *getMemoryBuffer(unsigned i) const {
    assert(isValidBufferID(i));
    return Buffers[i - 1].Buffer.get();
  }

  unsigned getNumBuffers() const {
    return Buffers.size();
  }

  unsigned getMainFileID() const {
    assert(getNumBuffers());
    return 1;
  }

  SMLoc getParentIncludeLoc(unsigned i) const {
    assert(isValidBufferID(i));
    return Buffers[i - 1].IncludeLoc;
  }

  /// Add a new source buffer to this source manager. This takes ownership of
  /// the memory buffer.
  unsigned AddNewSourceBuffer(std::unique_ptr<MemoryBuffer> F,
                              SMLoc IncludeLoc) {
    SrcBuffer NB;
    NB.Buffer = std::move(F);
    NB.IncludeLoc = IncludeLoc;
    Buffers.push_back(std::move(NB));
    return Buffers.size();
  }

  /// Search for a file with the specified name in the current directory or in
  /// one of the IncludeDirs.
  ///
  /// If no file is found, this returns 0, otherwise it returns the buffer ID
  /// of the stacked file. The full path to the included file can be found in
  /// \p IncludedFile.
  unsigned AddIncludeFile(const std::string &Filename, SMLoc IncludeLoc,
                          std::string &IncludedFile);

  /// Return the ID of the buffer containing the specified location.
  ///
  /// 0 is returned if the buffer is not found.
  unsigned FindBufferContainingLoc(SMLoc Loc) const;

  /// Find the line number for the specified location in the specified file.
  /// This is not a fast method.
  unsigned FindLineNumber(SMLoc Loc, unsigned BufferID = 0) const {
    return getLineAndColumn(Loc, BufferID).first;
  }

  /// Find the line and column number for the specified location in the
  /// specified file. This is not a fast method.
  std::pair<unsigned, unsigned> getLineAndColumn(SMLoc Loc,
                                                 unsigned BufferID = 0) const;

  /// Emit a message about the specified location with the specified string.
  ///
  /// \param ShowColors Display colored messages if output is a terminal and
  /// the default error handler is used.
  void PrintMessage(raw_ostream &OS, SMLoc Loc, DiagKind Kind,
                    const Twine &Msg,
                    ArrayRef<SMRange> Ranges = None,
                    ArrayRef<SMFixIt> FixIts = None,
                    bool ShowColors = true) const;

  /// Emits a diagnostic to llvm::errs().
  void PrintMessage(SMLoc Loc, DiagKind Kind, const Twine &Msg,
                    ArrayRef<SMRange> Ranges = None,
                    ArrayRef<SMFixIt> FixIts = None,
                    bool ShowColors = true) const;

  /// Emits a manually-constructed diagnostic to the given output stream.
  ///
  /// \param ShowColors Display colored messages if output is a terminal and
  /// the default error handler is used.
  void PrintMessage(raw_ostream &OS, const SMDiagnostic &Diagnostic,
                    bool ShowColors = true) const;

  /// Return an SMDiagnostic at the specified location with the specified
  /// string.
  ///
  /// \param Msg If non-null, the kind of message (e.g., "error") which is
  /// prefixed to the message.
  SMDiagnostic GetMessage(SMLoc Loc, DiagKind Kind, const Twine &Msg,
                          ArrayRef<SMRange> Ranges = None,
                          ArrayRef<SMFixIt> FixIts = None) const;

  /// Prints the names of included files and the line of the file they were
  /// included from. A diagnostic handler can use this before printing its
  /// custom formatted message.
  ///
  /// \param IncludeLoc The location of the include.
  /// \param OS the raw_ostream to print on.
  void PrintIncludeStack(SMLoc IncludeLoc, raw_ostream &OS) const;
};

/// Represents a single fixit, a replacement of one range of text with another.
class SMFixIt {
  SMRange Range;

  std::string Text;

public:
  // FIXME: Twine.str() is not very efficient.
  SMFixIt(SMLoc Loc, const Twine &Insertion)
    : Range(Loc, Loc), Text(Insertion.str()) {
    assert(Loc.isValid());
  }

  // FIXME: Twine.str() is not very efficient.
  SMFixIt(SMRange R, const Twine &Replacement)
    : Range(R), Text(Replacement.str()) {
    assert(R.isValid());
  }

  StringRef getText() const { return Text; }
  SMRange getRange() const { return Range; }

  bool operator<(const SMFixIt &Other) const {
    if (Range.Start.getPointer() != Other.Range.Start.getPointer())
      return Range.Start.getPointer() < Other.Range.Start.getPointer();
    if (Range.End.getPointer() != Other.Range.End.getPointer())
      return Range.End.getPointer() < Other.Range.End.getPointer();
    return Text < Other.Text;
  }
};

/// Instances of this class encapsulate one diagnostic report, allowing
/// printing to a raw_ostream as a caret diagnostic.
class SMDiagnostic {
  const SourceMgr *SM = nullptr;
  SMLoc Loc;
  std::string Filename;
  int LineNo = 0;
  int ColumnNo = 0;
  SourceMgr::DiagKind Kind = SourceMgr::DK_Error;
  std::string Message, LineContents;
  std::vector<std::pair<unsigned, unsigned>> Ranges;
  SmallVector<SMFixIt, 4> FixIts;

public:
  // Null diagnostic.
  SMDiagnostic() = default;
  // Diagnostic with no location (e.g. file not found, command line arg error).
  SMDiagnostic(StringRef filename, SourceMgr::DiagKind Knd, StringRef Msg)
    : Filename(filename), LineNo(-1), ColumnNo(-1), Kind(Knd), Message(Msg) {}

  // Diagnostic with a location.
  SMDiagnostic(const SourceMgr &sm, SMLoc L, StringRef FN,
               int Line, int Col, SourceMgr::DiagKind Kind,
               StringRef Msg, StringRef LineStr,
               ArrayRef<std::pair<unsigned,unsigned>> Ranges,
               ArrayRef<SMFixIt> FixIts = None);

  const SourceMgr *getSourceMgr() const { return SM; }
  SMLoc getLoc() const { return Loc; }
  StringRef getFilename() const { return Filename; }
  int getLineNo() const { return LineNo; }
  int getColumnNo() const { return ColumnNo; }
  SourceMgr::DiagKind getKind() const { return Kind; }
  StringRef getMessage() const { return Message; }
  StringRef getLineContents() const { return LineContents; }
  ArrayRef<std::pair<unsigned, unsigned>> getRanges() const { return Ranges; }

  void addFixIt(const SMFixIt &Hint) {
    FixIts.push_back(Hint);
  }

  ArrayRef<SMFixIt> getFixIts() const {
    return FixIts;
  }

  void print(const char *ProgName, raw_ostream &S, bool ShowColors = true,
             bool ShowKindLabel = true) const;
};

} // end namespace llvm

#endif // LLVM_SUPPORT_SOURCEMGR_H
# 311 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/SourceMgr.h"
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <ctime>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <stack>
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <system_error>
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 36 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 37 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"

namespace llvm {

class MemoryBuffer;

namespace vfs {

/// The result of a \p status operation.
class Status {
  std::string Name;
  llvm::sys::fs::UniqueID UID;
  llvm::sys::TimePoint<> MTime;
  uint32_t User;
  uint32_t Group;
  uint64_t Size;
  llvm::sys::fs::file_type Type = llvm::sys::fs::file_type::status_error;
  llvm::sys::fs::perms Perms;

public:
  // FIXME: remove when files support multiple names
  bool IsVFSMapped = false;

  Status() = default;
  Status(const llvm::sys::fs::file_status &Status);
  Status(const Twine &Name, llvm::sys::fs::UniqueID UID,
         llvm::sys::TimePoint<> MTime, uint32_t User, uint32_t Group,
         uint64_t Size, llvm::sys::fs::file_type Type,
         llvm::sys::fs::perms Perms);

  /// Get a copy of a Status with a different name.
  static Status copyWithNewName(const Status &In, const Twine &NewName);
  static Status copyWithNewName(const llvm::sys::fs::file_status &In,
                                const Twine &NewName);

  /// Returns the name that should be used for this file or directory.
  StringRef getName() const { return Name; }

  /// @name Status interface from llvm::sys::fs
  /// @{
  llvm::sys::fs::file_type getType() const { return Type; }
  llvm::sys::fs::perms getPermissions() const { return Perms; }
  llvm::sys::TimePoint<> getLastModificationTime() const { return MTime; }
  llvm::sys::fs::UniqueID getUniqueID() const { return UID; }
  uint32_t getUser() const { return User; }
  uint32_t getGroup() const { return Group; }
  uint64_t getSize() const { return Size; }
  /// @}
  /// @name Status queries
  /// These are static queries in llvm::sys::fs.
  /// @{
  bool equivalent(const Status &Other) const;
  bool isDirectory() const;
  bool isRegularFile() const;
  bool isOther() const;
  bool isSymlink() const;
  bool isStatusKnown() const;
  bool exists() const;
  /// @}
};

/// Represents an open file.
class File {
public:
  /// Destroy the file after closing it (if open).
  /// Sub-classes should generally call close() inside their destructors.  We
  /// cannot do that from the base class, since close is virtual.
  virtual ~File();

  /// Get the status of the file.
  virtual llvm::ErrorOr<Status> status() = 0;

  /// Get the name of the file
  virtual llvm::ErrorOr<std::string> getName() {
    if (auto Status = status())
      return Status->getName().str();
    else
      return Status.getError();
  }

  /// Get the contents of the file as a \p MemoryBuffer.
  virtual llvm::ErrorOr<std::unique_ptr<llvm::MemoryBuffer>>
  getBuffer(const Twine &Name, int64_t FileSize = -1,
            bool RequiresNullTerminator = true, bool IsVolatile = false) = 0;

  /// Closes the file.
  virtual std::error_code close() = 0;
};

/// A member of a directory, yielded by a directory_iterator.
/// Only information available on most platforms is included.
class directory_entry {
  std::string Path;
  llvm::sys::fs::file_type Type = llvm::sys::fs::file_type::type_unknown;

public:
  directory_entry() = default;
  directory_entry(std::string Path, llvm::sys::fs::file_type Type)
      : Path(std::move(Path)), Type(Type) {}

  llvm::StringRef path() const { return Path; }
  llvm::sys::fs::file_type type() const { return Type; }
};

namespace detail {

/// An interface for virtual file systems to provide an iterator over the
/// (non-recursive) contents of a directory.
struct DirIterImpl {
  virtual ~DirIterImpl();

  /// Sets \c CurrentEntry to the next entry in the directory on success,
  /// to directory_entry() at end,  or returns a system-defined \c error_code.
  virtual std::error_code increment() = 0;

  directory_entry CurrentEntry;
};

} // namespace detail

/// An input iterator over the entries in a virtual path, similar to
/// llvm::sys::fs::directory_iterator.
class directory_iterator {
  std::shared_ptr<detail::DirIterImpl> Impl; // Input iterator semantics on copy

public:
  directory_iterator(std::shared_ptr<detail::DirIterImpl> I)
      : Impl(std::move(I)) {
    assert(Impl.get() != nullptr && "requires non-null implementation");
    if (Impl->CurrentEntry.path().empty())
      Impl.reset(); // Normalize the end iterator to Impl == nullptr.
  }

  /// Construct an 'end' iterator.
  directory_iterator() = default;

  /// Equivalent to operator++, with an error code.
  directory_iterator &increment(std::error_code &EC) {
    assert(Impl && "attempting to increment past end");
    EC = Impl->increment();
    if (Impl->CurrentEntry.path().empty())
      Impl.reset(); // Normalize the end iterator to Impl == nullptr.
    return *this;
  }

  const directory_entry &operator*() const { return Impl->CurrentEntry; }
  const directory_entry *operator->() const { return &Impl->CurrentEntry; }

  bool operator==(const directory_iterator &RHS) const {
    if (Impl && RHS.Impl)
      return Impl->CurrentEntry.path() == RHS.Impl->CurrentEntry.path();
    return !Impl && !RHS.Impl;
  }
  bool operator!=(const directory_iterator &RHS) const {
    return !(*this == RHS);
  }
};

class FileSystem;

namespace detail {

/// Keeps state for the recursive_directory_iterator.
struct RecDirIterState {
  std::stack<directory_iterator, std::vector<directory_iterator>> Stack;
  bool HasNoPushRequest = false;
};

} // end namespace detail

/// An input iterator over the recursive contents of a virtual path,
/// similar to llvm::sys::fs::recursive_directory_iterator.
class recursive_directory_iterator {
  FileSystem *FS;
  std::shared_ptr<detail::RecDirIterState>
      State; // Input iterator semantics on copy.

public:
  recursive_directory_iterator(FileSystem &FS, const Twine &Path,
                               std::error_code &EC);

  /// Construct an 'end' iterator.
  recursive_directory_iterator() = default;

  /// Equivalent to operator++, with an error code.
  recursive_directory_iterator &increment(std::error_code &EC);

  const directory_entry &operator*() const { return *State->Stack.top(); }
  const directory_entry *operator->() const { return &*State->Stack.top(); }

  bool operator==(const recursive_directory_iterator &Other) const {
    return State == Other.State; // identity
  }
  bool operator!=(const recursive_directory_iterator &RHS) const {
    return !(*this == RHS);
  }

  /// Gets the current level. Starting path is at level 0.
  int level() const {
    assert(!State->Stack.empty() &&
           "Cannot get level without any iteration state");
    return State->Stack.size() - 1;
  }

  void no_push() { State->HasNoPushRequest = true; }
};

/// The virtual file system interface.
class FileSystem : public llvm::ThreadSafeRefCountedBase<FileSystem> {
public:
  virtual ~FileSystem();

  /// Get the status of the entry at \p Path, if one exists.
  virtual llvm::ErrorOr<Status> status(const Twine &Path) = 0;

  /// Get a \p File object for the file at \p Path, if one exists.
  virtual llvm::ErrorOr<std::unique_ptr<File>>
  openFileForRead(const Twine &Path) = 0;

  /// This is a convenience method that opens a file, gets its content and then
  /// closes the file.
  llvm::ErrorOr<std::unique_ptr<llvm::MemoryBuffer>>
  getBufferForFile(const Twine &Name, int64_t FileSize = -1,
                   bool RequiresNullTerminator = true, bool IsVolatile = false);

  /// Get a directory_iterator for \p Dir.
  /// \note The 'end' iterator is directory_iterator().
  virtual directory_iterator dir_begin(const Twine &Dir,
                                       std::error_code &EC) = 0;

  /// Set the working directory. This will affect all following operations on
  /// this file system and may propagate down for nested file systems.
  virtual std::error_code setCurrentWorkingDirectory(const Twine &Path) = 0;

  /// Get the working directory of this file system.
  virtual llvm::ErrorOr<std::string> getCurrentWorkingDirectory() const = 0;

  /// Gets real path of \p Path e.g. collapse all . and .. patterns, resolve
  /// symlinks. For real file system, this uses `llvm::sys::fs::real_path`.
  /// This returns errc::operation_not_permitted if not implemented by subclass.
  virtual std::error_code getRealPath(const Twine &Path,
                                      SmallVectorImpl<char> &Output) const;

  /// Check whether a file exists. Provided for convenience.
  bool exists(const Twine &Path);

  /// Is the file mounted on a local filesystem?
  virtual std::error_code isLocal(const Twine &Path, bool &Result);

  /// Make \a Path an absolute path.
  ///
  /// Makes \a Path absolute using the current directory if it is not already.
  /// An empty \a Path will result in the current directory.
  ///
  /// /absolute/path   => /absolute/path
  /// relative/../path => <current-directory>/relative/../path
  ///
  /// \param Path A path that is modified to be an absolute path.
  /// \returns success if \a path has been made absolute, otherwise a
  ///          platform-specific error_code.
  virtual std::error_code makeAbsolute(SmallVectorImpl<char> &Path) const;
};

/// Gets an \p vfs::FileSystem for the 'real' file system, as seen by
/// the operating system.
/// The working directory is linked to the process's working directory.
/// (This is usually thread-hostile).
IntrusiveRefCntPtr<FileSystem> getRealFileSystem();

/// Create an \p vfs::FileSystem for the 'real' file system, as seen by
/// the operating system.
/// It has its own working directory, independent of (but initially equal to)
/// that of the process.
std::unique_ptr<FileSystem> createPhysicalFileSystem();

/// A file system that allows overlaying one \p AbstractFileSystem on top
/// of another.
///
/// Consists of a stack of >=1 \p FileSystem objects, which are treated as being
/// one merged file system. When there is a directory that exists in more than
/// one file system, the \p OverlayFileSystem contains a directory containing
/// the union of their contents.  The attributes (permissions, etc.) of the
/// top-most (most recently added) directory are used.  When there is a file
/// that exists in more than one file system, the file in the top-most file
/// system overrides the other(s).
class OverlayFileSystem : public FileSystem {
  using FileSystemList = SmallVector<IntrusiveRefCntPtr<FileSystem>, 1>;

  /// The stack of file systems, implemented as a list in order of
  /// their addition.
  FileSystemList FSList;

public:
  OverlayFileSystem(IntrusiveRefCntPtr<FileSystem> Base);

  /// Pushes a file system on top of the stack.
  void pushOverlay(IntrusiveRefCntPtr<FileSystem> FS);

  llvm::ErrorOr<Status> status(const Twine &Path) override;
  llvm::ErrorOr<std::unique_ptr<File>>
  openFileForRead(const Twine &Path) override;
  directory_iterator dir_begin(const Twine &Dir, std::error_code &EC) override;
  llvm::ErrorOr<std::string> getCurrentWorkingDirectory() const override;
  std::error_code setCurrentWorkingDirectory(const Twine &Path) override;
  std::error_code isLocal(const Twine &Path, bool &Result) override;
  std::error_code getRealPath(const Twine &Path,
                              SmallVectorImpl<char> &Output) const override;

  using iterator = FileSystemList::reverse_iterator;
  using const_iterator = FileSystemList::const_reverse_iterator;
  using reverse_iterator = FileSystemList::iterator;
  using const_reverse_iterator = FileSystemList::const_iterator;

  /// Get an iterator pointing to the most recently added file system.
  iterator overlays_begin() { return FSList.rbegin(); }
  const_iterator overlays_begin() const { return FSList.rbegin(); }

  /// Get an iterator pointing one-past the least recently added file system.
  iterator overlays_end() { return FSList.rend(); }
  const_iterator overlays_end() const { return FSList.rend(); }

  /// Get an iterator pointing to the least recently added file system.
  reverse_iterator overlays_rbegin() { return FSList.begin(); }
  const_reverse_iterator overlays_rbegin() const { return FSList.begin(); }

  /// Get an iterator pointing one-past the most recently added file system.
  reverse_iterator overlays_rend() { return FSList.end(); }
  const_reverse_iterator overlays_rend() const { return FSList.end(); }
};

/// By default, this delegates all calls to the underlying file system. This
/// is useful when derived file systems want to override some calls and still
/// proxy other calls.
class ProxyFileSystem : public FileSystem {
public:
  explicit ProxyFileSystem(IntrusiveRefCntPtr<FileSystem> FS)
      : FS(std::move(FS)) {}

  llvm::ErrorOr<Status> status(const Twine &Path) override {
    return FS->status(Path);
  }
  llvm::ErrorOr<std::unique_ptr<File>>
  openFileForRead(const Twine &Path) override {
    return FS->openFileForRead(Path);
  }
  directory_iterator dir_begin(const Twine &Dir, std::error_code &EC) override {
    return FS->dir_begin(Dir, EC);
  }
  llvm::ErrorOr<std::string> getCurrentWorkingDirectory() const override {
    return FS->getCurrentWorkingDirectory();
  }
  std::error_code setCurrentWorkingDirectory(const Twine &Path) override {
    return FS->setCurrentWorkingDirectory(Path);
  }
  std::error_code getRealPath(const Twine &Path,
                              SmallVectorImpl<char> &Output) const override {
    return FS->getRealPath(Path, Output);
  }
  std::error_code isLocal(const Twine &Path, bool &Result) override {
    return FS->isLocal(Path, Result);
  }

protected:
  FileSystem &getUnderlyingFS() { return *FS; }

private:
  IntrusiveRefCntPtr<FileSystem> FS;

  virtual void anchor();
};

namespace detail {

class InMemoryDirectory;
class InMemoryFile;

} // namespace detail

/// An in-memory file system.
class InMemoryFileSystem : public FileSystem {
  std::unique_ptr<detail::InMemoryDirectory> Root;
  std::string WorkingDirectory;
  bool UseNormalizedPaths = true;

  /// If HardLinkTarget is non-null, a hardlink is created to the To path which
  /// must be a file. If it is null then it adds the file as the public addFile.
  bool addFile(const Twine &Path, time_t ModificationTime,
               std::unique_ptr<llvm::MemoryBuffer> Buffer,
               Optional<uint32_t> User, Optional<uint32_t> Group,
               Optional<llvm::sys::fs::file_type> Type,
               Optional<llvm::sys::fs::perms> Perms,
               const detail::InMemoryFile *HardLinkTarget);

public:
  explicit InMemoryFileSystem(bool UseNormalizedPaths = true);
  ~InMemoryFileSystem() override;

  /// Add a file containing a buffer or a directory to the VFS with a
  /// path. The VFS owns the buffer.  If present, User, Group, Type
  /// and Perms apply to the newly-created file or directory.
  /// \return true if the file or directory was successfully added,
  /// false if the file or directory already exists in the file system with
  /// different contents.
  bool addFile(const Twine &Path, time_t ModificationTime,
               std::unique_ptr<llvm::MemoryBuffer> Buffer,
               Optional<uint32_t> User = None, Optional<uint32_t> Group = None,
               Optional<llvm::sys::fs::file_type> Type = None,
               Optional<llvm::sys::fs::perms> Perms = None);

  /// Add a hard link to a file.
  /// Here hard links are not intended to be fully equivalent to the classical
  /// filesystem. Both the hard link and the file share the same buffer and
  /// status (and thus have the same UniqueID). Because of this there is no way
  /// to distinguish between the link and the file after the link has been
  /// added.
  ///
  /// The To path must be an existing file or a hardlink. The From file must not
  /// have been added before. The To Path must not be a directory. The From Node
  /// is added as a hard link which points to the resolved file of To Node.
  /// \return true if the above condition is satisfied and hardlink was
  /// successfully created, false otherwise.
  bool addHardLink(const Twine &From, const Twine &To);

  /// Add a buffer to the VFS with a path. The VFS does not own the buffer.
  /// If present, User, Group, Type and Perms apply to the newly-created file
  /// or directory.
  /// \return true if the file or directory was successfully added,
  /// false if the file or directory already exists in the file system with
  /// different contents.
  bool addFileNoOwn(const Twine &Path, time_t ModificationTime,
                    llvm::MemoryBuffer *Buffer, Optional<uint32_t> User = None,
                    Optional<uint32_t> Group = None,
                    Optional<llvm::sys::fs::file_type> Type = None,
                    Optional<llvm::sys::fs::perms> Perms = None);

  std::string toString() const;

  /// Return true if this file system normalizes . and .. in paths.
  bool useNormalizedPaths() const { return UseNormalizedPaths; }

  llvm::ErrorOr<Status> status(const Twine &Path) override;
  llvm::ErrorOr<std::unique_ptr<File>>
  openFileForRead(const Twine &Path) override;
  directory_iterator dir_begin(const Twine &Dir, std::error_code &EC) override;

  llvm::ErrorOr<std::string> getCurrentWorkingDirectory() const override {
    return WorkingDirectory;
  }
  /// Canonicalizes \p Path by combining with the current working
  /// directory and normalizing the path (e.g. remove dots). If the current
  /// working directory is not set, this returns errc::operation_not_permitted.
  ///
  /// This doesn't resolve symlinks as they are not supported in in-memory file
  /// system.
  std::error_code getRealPath(const Twine &Path,
                              SmallVectorImpl<char> &Output) const override;
  std::error_code isLocal(const Twine &Path, bool &Result) override;
  std::error_code setCurrentWorkingDirectory(const Twine &Path) override;
};

/// Get a globally unique ID for a virtual file or directory.
llvm::sys::fs::UniqueID getNextVirtualUniqueID();

/// Gets a \p FileSystem for a virtual file system described in YAML
/// format.
IntrusiveRefCntPtr<FileSystem>
getVFSFromYAML(std::unique_ptr<llvm::MemoryBuffer> Buffer,
               llvm::SourceMgr::DiagHandlerTy DiagHandler,
               StringRef YAMLFilePath, void *DiagContext = nullptr,
               IntrusiveRefCntPtr<FileSystem> ExternalFS = getRealFileSystem());

struct YAMLVFSEntry {
  template <typename T1, typename T2>
  YAMLVFSEntry(T1 &&VPath, T2 &&RPath)
      : VPath(std::forward<T1>(VPath)), RPath(std::forward<T2>(RPath)) {}
  std::string VPath;
  std::string RPath;
};

class VFSFromYamlDirIterImpl;
class RedirectingFileSystemParser;

/// A virtual file system parsed from a YAML file.
///
/// Currently, this class allows creating virtual directories and mapping
/// virtual file paths to existing external files, available in \c ExternalFS.
///
/// The basic structure of the parsed file is:
/// \verbatim
/// {
///   'version': <version number>,
///   <optional configuration>
///   'roots': [
///              <directory entries>
///            ]
/// }
/// \endverbatim
///
/// All configuration options are optional.
///   'case-sensitive': <boolean, default=(true for Posix, false for Windows)>
///   'use-external-names': <boolean, default=true>
///   'overlay-relative': <boolean, default=false>
///   'fallthrough': <boolean, default=true>
///
/// Virtual directories are represented as
/// \verbatim
/// {
///   'type': 'directory',
///   'name': <string>,
///   'contents': [ <file or directory entries> ]
/// }
/// \endverbatim
///
/// The default attributes for virtual directories are:
/// \verbatim
/// MTime = now() when created
/// Perms = 0777
/// User = Group = 0
/// Size = 0
/// UniqueID = unspecified unique value
/// \endverbatim
///
/// Re-mapped files are represented as
/// \verbatim
/// {
///   'type': 'file',
///   'name': <string>,
///   'use-external-name': <boolean> # Optional
///   'external-contents': <path to external file>
/// }
/// \endverbatim
///
/// and inherit their attributes from the external contents.
///
/// In both cases, the 'name' field may contain multiple path components (e.g.
/// /path/to/file). However, any directory that contains more than one child
/// must be uniquely represented by a directory entry.
class RedirectingFileSystem : public vfs::FileSystem {
public:
  enum EntryKind { EK_Directory, EK_File };

  /// A single file or directory in the VFS.
  class Entry {
    EntryKind Kind;
    std::string Name;

  public:
    Entry(EntryKind K, StringRef Name) : Kind(K), Name(Name) {}
    virtual ~Entry() = default;

    StringRef getName() const { return Name; }
    EntryKind getKind() const { return Kind; }
  };

  class RedirectingDirectoryEntry : public Entry {
    std::vector<std::unique_ptr<Entry>> Contents;
    Status S;

  public:
    RedirectingDirectoryEntry(StringRef Name,
                              std::vector<std::unique_ptr<Entry>> Contents,
                              Status S)
        : Entry(EK_Directory, Name), Contents(std::move(Contents)),
          S(std::move(S)) {}
    RedirectingDirectoryEntry(StringRef Name, Status S)
        : Entry(EK_Directory, Name), S(std::move(S)) {}

    Status getStatus() { return S; }

    void addContent(std::unique_ptr<Entry> Content) {
      Contents.push_back(std::move(Content));
    }

    Entry *getLastContent() const { return Contents.back().get(); }

    using iterator = decltype(Contents)::iterator;

    iterator contents_begin() { return Contents.begin(); }
    iterator contents_end() { return Contents.end(); }

    static bool classof(const Entry *E) { return E->getKind() == EK_Directory; }
  };

  class RedirectingFileEntry : public Entry {
  public:
    enum NameKind { NK_NotSet, NK_External, NK_Virtual };

  private:
    std::string ExternalContentsPath;
    NameKind UseName;

  public:
    RedirectingFileEntry(StringRef Name, StringRef ExternalContentsPath,
                         NameKind UseName)
        : Entry(EK_File, Name), ExternalContentsPath(ExternalContentsPath),
          UseName(UseName) {}

    StringRef getExternalContentsPath() const { return ExternalContentsPath; }

    /// whether to use the external path as the name for this file.
    bool useExternalName(bool GlobalUseExternalName) const {
      return UseName == NK_NotSet ? GlobalUseExternalName
                                  : (UseName == NK_External);
    }

    NameKind getUseName() const { return UseName; }

    static bool classof(const Entry *E) { return E->getKind() == EK_File; }
  };

private:
  friend class VFSFromYamlDirIterImpl;
  friend class RedirectingFileSystemParser;

  bool shouldUseExternalFS() const {
    return ExternalFSValidWD && IsFallthrough;
  }

  // In a RedirectingFileSystem, keys can be specified in Posix or Windows
  // style (or even a mixture of both), so this comparison helper allows
  // slashes (representing a root) to match backslashes (and vice versa).  Note
  // that, other than the root, patch components should not contain slashes or
  // backslashes.
  bool pathComponentMatches(llvm::StringRef lhs, llvm::StringRef rhs) const {
    if ((CaseSensitive ? lhs.equals(rhs) : lhs.equals_lower(rhs)))
      return true;
    return (lhs == "/" && rhs == "\\") || (lhs == "\\" && rhs == "/");
  }

  /// The root(s) of the virtual file system.
  std::vector<std::unique_ptr<Entry>> Roots;

  /// The current working directory of the file system.
  std::string WorkingDirectory;

  /// Whether the current working directory is valid for the external FS.
  bool ExternalFSValidWD = false;

  /// The file system to use for external references.
  IntrusiveRefCntPtr<FileSystem> ExternalFS;

  /// If IsRelativeOverlay is set, this represents the directory
  /// path that should be prefixed to each 'external-contents' entry
  /// when reading from YAML files.
  std::string ExternalContentsPrefixDir;

  /// @name Configuration
  /// @{

  /// Whether to perform case-sensitive comparisons.
  ///
  /// Currently, case-insensitive matching only works correctly with ASCII.
  bool CaseSensitive =
#ifdef _WIN32
      false;
#else
# 692 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
      true;
#endif
# 694 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"

  /// IsRelativeOverlay marks whether a ExternalContentsPrefixDir path must
  /// be prefixed in every 'external-contents' when reading from YAML files.
  bool IsRelativeOverlay = false;

  /// Whether to use to use the value of 'external-contents' for the
  /// names of files.  This global value is overridable on a per-file basis.
  bool UseExternalNames = true;

  /// Whether to attempt a file lookup in external file system after it wasn't
  /// found in VFS.
  bool IsFallthrough = true;
  /// @}

  RedirectingFileSystem(IntrusiveRefCntPtr<FileSystem> ExternalFS);

  /// Looks up the path <tt>[Start, End)</tt> in \p From, possibly
  /// recursing into the contents of \p From if it is a directory.
  ErrorOr<Entry *> lookupPath(llvm::sys::path::const_iterator Start,
                              llvm::sys::path::const_iterator End,
                              Entry *From) const;

  /// Get the status of a given an \c Entry.
  ErrorOr<Status> status(const Twine &Path, Entry *E);

public:
  /// Looks up \p Path in \c Roots.
  ErrorOr<Entry *> lookupPath(const Twine &Path) const;

  /// Parses \p Buffer, which is expected to be in YAML format and
  /// returns a virtual file system representing its contents.
  static RedirectingFileSystem *
  create(std::unique_ptr<MemoryBuffer> Buffer,
         SourceMgr::DiagHandlerTy DiagHandler, StringRef YAMLFilePath,
         void *DiagContext, IntrusiveRefCntPtr<FileSystem> ExternalFS);

  ErrorOr<Status> status(const Twine &Path) override;
  ErrorOr<std::unique_ptr<File>> openFileForRead(const Twine &Path) override;

  std::error_code getRealPath(const Twine &Path,
                              SmallVectorImpl<char> &Output) const override;

  llvm::ErrorOr<std::string> getCurrentWorkingDirectory() const override;

  std::error_code setCurrentWorkingDirectory(const Twine &Path) override;

  std::error_code isLocal(const Twine &Path, bool &Result) override;

  std::error_code makeAbsolute(SmallVectorImpl<char> &Path) const override;

  directory_iterator dir_begin(const Twine &Dir, std::error_code &EC) override;

  void setExternalContentsPrefixDir(StringRef PrefixDir);

  StringRef getExternalContentsPrefixDir() const;

  void dump(raw_ostream &OS) const;
  void dumpEntry(raw_ostream &OS, Entry *E, int NumSpaces = 0) const;
#if 0 /* disabled by -frewrite-includes */
#if !defined(NDEBUG) || defined(LLVM_ENABLE_DUMP)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 753 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
  LLVM_DUMP_METHOD void dump() const;
#endif
# 755 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
};

/// Collect all pairs of <virtual path, real path> entries from the
/// \p YAMLFilePath. This is used by the module dependency collector to forward
/// the entries into the reproducer output VFS YAML file.
void collectVFSFromYAML(
    std::unique_ptr<llvm::MemoryBuffer> Buffer,
    llvm::SourceMgr::DiagHandlerTy DiagHandler, StringRef YAMLFilePath,
    SmallVectorImpl<YAMLVFSEntry> &CollectedEntries,
    void *DiagContext = nullptr,
    IntrusiveRefCntPtr<FileSystem> ExternalFS = getRealFileSystem());

class YAMLVFSWriter {
  std::vector<YAMLVFSEntry> Mappings;
  Optional<bool> IsCaseSensitive;
  Optional<bool> IsOverlayRelative;
  Optional<bool> UseExternalNames;
  std::string OverlayDir;

public:
  YAMLVFSWriter() = default;

  void addFileMapping(StringRef VirtualPath, StringRef RealPath);

  void setCaseSensitivity(bool CaseSensitive) {
    IsCaseSensitive = CaseSensitive;
  }

  void setUseExternalNames(bool UseExtNames) { UseExternalNames = UseExtNames; }

  void setOverlayDir(StringRef OverlayDirectory) {
    IsOverlayRelative = true;
    OverlayDir.assign(OverlayDirectory.str());
  }

  const std::vector<YAMLVFSEntry> &getMappings() const { return Mappings; }

  void write(llvm::raw_ostream &OS);
};

} // namespace vfs
} // namespace llvm

#endif // LLVM_SUPPORT_VIRTUALFILESYSTEM_H
# 799 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/VirtualFileSystem.h"
# 28 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <ctime>
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 29 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <map>
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 30 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 31 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 32 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"

namespace llvm {

class MemoryBuffer;

} // end namespace llvm

namespace clang {

class FileSystemStatCache;

/// Cached information about one directory (either on disk or in
/// the virtual file system).
class DirectoryEntry {
  friend class FileManager;

  // FIXME: We should not be storing a directory entry name here.
  StringRef Name; // Name of the directory.

public:
  StringRef getName() const { return Name; }
};

/// A reference to a \c DirectoryEntry  that includes the name of the directory
/// as it was accessed by the FileManager's client.
class DirectoryEntryRef {
public:
  const DirectoryEntry &getDirEntry() const { return *Entry->getValue(); }

  StringRef getName() const { return Entry->getKey(); }

private:
  friend class FileManager;

  DirectoryEntryRef(
      llvm::StringMapEntry<llvm::ErrorOr<DirectoryEntry &>> *Entry)
      : Entry(Entry) {}

  const llvm::StringMapEntry<llvm::ErrorOr<DirectoryEntry &>> *Entry;
};

/// Cached information about one file (either on disk
/// or in the virtual file system).
///
/// If the 'File' member is valid, then this FileEntry has an open file
/// descriptor for the file.
class FileEntry {
  friend class FileManager;

  StringRef Name;             // Name of the file.
  std::string RealPathName;   // Real path to the file; could be empty.
  off_t Size;                 // File size in bytes.
  time_t ModTime;             // Modification time of file.
  const DirectoryEntry *Dir;  // Directory file lives in.
  llvm::sys::fs::UniqueID UniqueID;
  unsigned UID;               // A unique (small) ID for the file.
  bool IsNamedPipe;
  bool IsValid;               // Is this \c FileEntry initialized and valid?

  /// The open file, if it is owned by the \p FileEntry.
  mutable std::unique_ptr<llvm::vfs::File> File;

public:
  FileEntry()
      : UniqueID(0, 0), IsNamedPipe(false), IsValid(false)
  {}

  FileEntry(const FileEntry &) = delete;
  FileEntry &operator=(const FileEntry &) = delete;

  StringRef getName() const { return Name; }
  StringRef tryGetRealPathName() const { return RealPathName; }
  bool isValid() const { return IsValid; }
  off_t getSize() const { return Size; }
  unsigned getUID() const { return UID; }
  const llvm::sys::fs::UniqueID &getUniqueID() const { return UniqueID; }
  time_t getModificationTime() const { return ModTime; }

  /// Return the directory the file lives in.
  const DirectoryEntry *getDir() const { return Dir; }

  bool operator<(const FileEntry &RHS) const { return UniqueID < RHS.UniqueID; }

  /// Check whether the file is a named pipe (and thus can't be opened by
  /// the native FileManager methods).
  bool isNamedPipe() const { return IsNamedPipe; }

  void closeFile() const {
    File.reset(); // rely on destructor to close File
  }

  // Only for use in tests to see if deferred opens are happening, rather than
  // relying on RealPathName being empty.
  bool isOpenForTests() const { return File != nullptr; }
};

/// A reference to a \c FileEntry that includes the name of the file as it was
/// accessed by the FileManager's client.
class FileEntryRef {
public:
  FileEntryRef() = delete;
  FileEntryRef(StringRef Name, const FileEntry &Entry)
      : Name(Name), Entry(&Entry) {}

  const StringRef getName() const { return Name; }

  bool isValid() const { return Entry->isValid(); }

  const FileEntry &getFileEntry() const { return *Entry; }

  off_t getSize() const { return Entry->getSize(); }

  unsigned getUID() const { return Entry->getUID(); }

  const llvm::sys::fs::UniqueID &getUniqueID() const {
    return Entry->getUniqueID();
  }

  time_t getModificationTime() const { return Entry->getModificationTime(); }

  friend bool operator==(const FileEntryRef &LHS, const FileEntryRef &RHS) {
    return LHS.Entry == RHS.Entry && LHS.Name == RHS.Name;
  }
  friend bool operator!=(const FileEntryRef &LHS, const FileEntryRef &RHS) {
    return !(LHS == RHS);
  }

private:
  StringRef Name;
  const FileEntry *Entry;
};

/// Implements support for file system lookup, file system caching,
/// and directory search management.
///
/// This also handles more advanced properties, such as uniquing files based
/// on "inode", so that a file with two names (e.g. symlinked) will be treated
/// as a single file.
///
class FileManager : public RefCountedBase<FileManager> {
  IntrusiveRefCntPtr<llvm::vfs::FileSystem> FS;
  FileSystemOptions FileSystemOpts;

  /// Cache for existing real directories.
  std::map<llvm::sys::fs::UniqueID, DirectoryEntry> UniqueRealDirs;

  /// Cache for existing real files.
  std::map<llvm::sys::fs::UniqueID, FileEntry> UniqueRealFiles;

  /// The virtual directories that we have allocated.
  ///
  /// For each virtual file (e.g. foo/bar/baz.cpp), we add all of its parent
  /// directories (foo/ and foo/bar/) here.
  SmallVector<std::unique_ptr<DirectoryEntry>, 4> VirtualDirectoryEntries;
  /// The virtual files that we have allocated.
  SmallVector<std::unique_ptr<FileEntry>, 4> VirtualFileEntries;

  /// A set of files that bypass the maps and uniquing.  They can have
  /// conflicting filenames.
  SmallVector<std::unique_ptr<FileEntry>, 0> BypassFileEntries;

  /// A cache that maps paths to directory entries (either real or
  /// virtual) we have looked up, or an error that occurred when we looked up
  /// the directory.
  ///
  /// The actual Entries for real directories/files are
  /// owned by UniqueRealDirs/UniqueRealFiles above, while the Entries
  /// for virtual directories/files are owned by
  /// VirtualDirectoryEntries/VirtualFileEntries above.
  ///
  llvm::StringMap<llvm::ErrorOr<DirectoryEntry &>, llvm::BumpPtrAllocator>
  SeenDirEntries;

  /// A reference to the file entry that is associated with a particular
  /// filename, or a reference to another filename that should be looked up
  /// instead of the accessed filename.
  ///
  /// The reference to another filename is specifically useful for Redirecting
  /// VFSs that use external names. In that case, the \c FileEntryRef returned
  /// by the \c FileManager will have the external name, and not the name that
  /// was used to lookup the file.
  using SeenFileEntryOrRedirect =
      llvm::PointerUnion<FileEntry *, const StringRef *>;

  /// A cache that maps paths to file entries (either real or
  /// virtual) we have looked up, or an error that occurred when we looked up
  /// the file.
  ///
  /// \see SeenDirEntries
  llvm::StringMap<llvm::ErrorOr<SeenFileEntryOrRedirect>,
                  llvm::BumpPtrAllocator>
      SeenFileEntries;

  /// The canonical names of files and directories .
  llvm::DenseMap<const void *, llvm::StringRef> CanonicalNames;

  /// Storage for canonical names that we have computed.
  llvm::BumpPtrAllocator CanonicalNameStorage;

  /// Each FileEntry we create is assigned a unique ID #.
  ///
  unsigned NextFileUID;

  // Caching.
  std::unique_ptr<FileSystemStatCache> StatCache;

  std::error_code getStatValue(StringRef Path, llvm::vfs::Status &Status,
                               bool isFile,
                               std::unique_ptr<llvm::vfs::File> *F);

  /// Add all ancestors of the given path (pointing to either a file
  /// or a directory) as virtual directories.
  void addAncestorsAsVirtualDirs(StringRef Path);

  /// Fills the RealPathName in file entry.
  void fillRealPathName(FileEntry *UFE, llvm::StringRef FileName);

public:
  /// Construct a file manager, optionally with a custom VFS.
  ///
  /// \param FS if non-null, the VFS to use.  Otherwise uses
  /// llvm::vfs::getRealFileSystem().
  FileManager(const FileSystemOptions &FileSystemOpts,
              IntrusiveRefCntPtr<llvm::vfs::FileSystem> FS = nullptr);
  ~FileManager();

  /// Installs the provided FileSystemStatCache object within
  /// the FileManager.
  ///
  /// Ownership of this object is transferred to the FileManager.
  ///
  /// \param statCache the new stat cache to install. Ownership of this
  /// object is transferred to the FileManager.
  void setStatCache(std::unique_ptr<FileSystemStatCache> statCache);

  /// Removes the FileSystemStatCache object from the manager.
  void clearStatCache();

  /// Returns the number of unique real file entries cached by the file manager.
  size_t getNumUniqueRealFiles() const { return UniqueRealFiles.size(); }

  /// Lookup, cache, and verify the specified directory (real or
  /// virtual).
  ///
  /// This returns a \c std::error_code if there was an error reading the
  /// directory. On success, returns the reference to the directory entry
  /// together with the exact path that was used to access a file by a
  /// particular call to getDirectoryRef.
  ///
  /// \param CacheFailure If true and the file does not exist, we'll cache
  /// the failure to find this file.
  llvm::Expected<DirectoryEntryRef> getDirectoryRef(StringRef DirName,
                                                    bool CacheFailure = true);

  /// Get a \c DirectoryEntryRef if it exists, without doing anything on error.
  llvm::Optional<DirectoryEntryRef>
  getOptionalDirectoryRef(StringRef DirName, bool CacheFailure = true) {
    return llvm::expectedToOptional(getDirectoryRef(DirName, CacheFailure));
  }

  /// Lookup, cache, and verify the specified directory (real or
  /// virtual).
  ///
  /// This function is deprecated and will be removed at some point in the
  /// future, new clients should use
  ///  \c getDirectoryRef.
  ///
  /// This returns a \c std::error_code if there was an error reading the
  /// directory. If there is no error, the DirectoryEntry is guaranteed to be
  /// non-NULL.
  ///
  /// \param CacheFailure If true and the file does not exist, we'll cache
  /// the failure to find this file.
  llvm::ErrorOr<const DirectoryEntry *>
  getDirectory(StringRef DirName, bool CacheFailure = true);

  /// Lookup, cache, and verify the specified file (real or
  /// virtual).
  ///
  /// This function is deprecated and will be removed at some point in the
  /// future, new clients should use
  ///  \c getFileRef.
  ///
  /// This returns a \c std::error_code if there was an error loading the file.
  /// If there is no error, the FileEntry is guaranteed to be non-NULL.
  ///
  /// \param OpenFile if true and the file exists, it will be opened.
  ///
  /// \param CacheFailure If true and the file does not exist, we'll cache
  /// the failure to find this file.
  llvm::ErrorOr<const FileEntry *>
  getFile(StringRef Filename, bool OpenFile = false, bool CacheFailure = true);

  /// Lookup, cache, and verify the specified file (real or virtual). Return the
  /// reference to the file entry together with the exact path that was used to
  /// access a file by a particular call to getFileRef. If the underlying VFS is
  /// a redirecting VFS that uses external file names, the returned FileEntryRef
  /// will use the external name instead of the filename that was passed to this
  /// method.
  ///
  /// This returns a \c std::error_code if there was an error loading the file,
  /// or a \c FileEntryRef otherwise.
  ///
  /// \param OpenFile if true and the file exists, it will be opened.
  ///
  /// \param CacheFailure If true and the file does not exist, we'll cache
  /// the failure to find this file.
  llvm::Expected<FileEntryRef> getFileRef(StringRef Filename,
                                          bool OpenFile = false,
                                          bool CacheFailure = true);

  /// Get a FileEntryRef if it exists, without doing anything on error.
  llvm::Optional<FileEntryRef> getOptionalFileRef(StringRef Filename,
                                                  bool OpenFile = false,
                                                  bool CacheFailure = true) {
    return llvm::expectedToOptional(
        getFileRef(Filename, OpenFile, CacheFailure));
  }

  /// Returns the current file system options
  FileSystemOptions &getFileSystemOpts() { return FileSystemOpts; }
  const FileSystemOptions &getFileSystemOpts() const { return FileSystemOpts; }

  llvm::vfs::FileSystem &getVirtualFileSystem() const { return *FS; }

  void setVirtualFileSystem(IntrusiveRefCntPtr<llvm::vfs::FileSystem> FS) {
    this->FS = std::move(FS);
  }

  /// Retrieve a file entry for a "virtual" file that acts as
  /// if there were a file with the given name on disk.
  ///
  /// The file itself is not accessed.
  const FileEntry *getVirtualFile(StringRef Filename, off_t Size,
                                  time_t ModificationTime);

  /// Retrieve a FileEntry that bypasses VFE, which is expected to be a virtual
  /// file entry, to access the real file.  The returned FileEntry will have
  /// the same filename as FE but a different identity and its own stat.
  ///
  /// This should be used only for rare error recovery paths because it
  /// bypasses all mapping and uniquing, blindly creating a new FileEntry.
  /// There is no attempt to deduplicate these; if you bypass the same file
  /// twice, you get two new file entries.
  llvm::Optional<FileEntryRef> getBypassFile(FileEntryRef VFE);

  /// Open the specified file as a MemoryBuffer, returning a new
  /// MemoryBuffer if successful, otherwise returning null.
  llvm::ErrorOr<std::unique_ptr<llvm::MemoryBuffer>>
  getBufferForFile(const FileEntry *Entry, bool isVolatile = false);
  llvm::ErrorOr<std::unique_ptr<llvm::MemoryBuffer>>
  getBufferForFile(StringRef Filename, bool isVolatile = false) {
    return getBufferForFileImpl(Filename, /*FileSize=*/-1, isVolatile);
  }

private:
  llvm::ErrorOr<std::unique_ptr<llvm::MemoryBuffer>>
  getBufferForFileImpl(StringRef Filename, int64_t FileSize, bool isVolatile);

public:
  /// Get the 'stat' information for the given \p Path.
  ///
  /// If the path is relative, it will be resolved against the WorkingDir of the
  /// FileManager's FileSystemOptions.
  ///
  /// \returns a \c std::error_code describing an error, if there was one
  std::error_code getNoncachedStatValue(StringRef Path,
                                        llvm::vfs::Status &Result);

  /// If path is not absolute and FileSystemOptions set the working
  /// directory, the path is modified to be relative to the given
  /// working directory.
  /// \returns true if \c path changed.
  bool FixupRelativePath(SmallVectorImpl<char> &path) const;

  /// Makes \c Path absolute taking into account FileSystemOptions and the
  /// working directory option.
  /// \returns true if \c Path changed to absolute.
  bool makeAbsolutePath(SmallVectorImpl<char> &Path) const;

  /// Produce an array mapping from the unique IDs assigned to each
  /// file to the corresponding FileEntry pointer.
  void GetUniqueIDMapping(
                    SmallVectorImpl<const FileEntry *> &UIDToFiles) const;

  /// Retrieve the canonical name for a given directory.
  ///
  /// This is a very expensive operation, despite its results being cached,
  /// and should only be used when the physical layout of the file system is
  /// required, which is (almost) never.
  StringRef getCanonicalName(const DirectoryEntry *Dir);

  /// Retrieve the canonical name for a given file.
  ///
  /// This is a very expensive operation, despite its results being cached,
  /// and should only be used when the physical layout of the file system is
  /// required, which is (almost) never.
  StringRef getCanonicalName(const FileEntry *File);

  void PrintStats() const;
};

} // end namespace clang

#endif // LLVM_CLANG_BASIC_FILEMANAGER_H
# 437 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/FileManager.h"
# 39 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/SourceLocation.h"
#endif /* expanded by -frewrite-includes */
# 39 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 40 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/ArrayRef.h"
#endif /* expanded by -frewrite-includes */
# 40 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 41 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/BitVector.h"
#endif /* expanded by -frewrite-includes */
# 41 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h" 1
//===- llvm/ADT/BitVector.h - Bit vectors -----------------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file implements the BitVector class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_BITVECTOR_H
#define LLVM_ADT_BITVECTOR_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/ArrayRef.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMapInfo.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/iterator_range.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MathExtras.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <climits>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 27 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"

namespace llvm {

/// ForwardIterator for the bits that are set.
/// Iterators get invalidated when resize / reserve is called.
template <typename BitVectorT> class const_set_bits_iterator_impl {
  const BitVectorT &Parent;
  int Current = 0;

  void advance() {
    assert(Current != -1 && "Trying to advance past end.");
    Current = Parent.find_next(Current);
  }

public:
  const_set_bits_iterator_impl(const BitVectorT &Parent, int Current)
      : Parent(Parent), Current(Current) {}
  explicit const_set_bits_iterator_impl(const BitVectorT &Parent)
      : const_set_bits_iterator_impl(Parent, Parent.find_first()) {}
  const_set_bits_iterator_impl(const const_set_bits_iterator_impl &) = default;

  const_set_bits_iterator_impl operator++(int) {
    auto Prev = *this;
    advance();
    return Prev;
  }

  const_set_bits_iterator_impl &operator++() {
    advance();
    return *this;
  }

  unsigned operator*() const { return Current; }

  bool operator==(const const_set_bits_iterator_impl &Other) const {
    assert(&Parent == &Other.Parent &&
           "Comparing iterators from different BitVectors");
    return Current == Other.Current;
  }

  bool operator!=(const const_set_bits_iterator_impl &Other) const {
    assert(&Parent == &Other.Parent &&
           "Comparing iterators from different BitVectors");
    return Current != Other.Current;
  }
};

class BitVector {
  typedef uintptr_t BitWord;

  enum { BITWORD_SIZE = (unsigned)sizeof(BitWord) * CHAR_BIT };

  static_assert(BITWORD_SIZE == 64 || BITWORD_SIZE == 32,
                "Unsupported word size");

  MutableArrayRef<BitWord> Bits; // Actual bits.
  unsigned Size;                 // Size of bitvector in bits.

public:
  typedef unsigned size_type;
  // Encapsulation of a single bit.
  class reference {
    friend class BitVector;

    BitWord *WordRef;
    unsigned BitPos;

  public:
    reference(BitVector &b, unsigned Idx) {
      WordRef = &b.Bits[Idx / BITWORD_SIZE];
      BitPos = Idx % BITWORD_SIZE;
    }

    reference() = delete;
    reference(const reference&) = default;

    reference &operator=(reference t) {
      *this = bool(t);
      return *this;
    }

    reference& operator=(bool t) {
      if (t)
        *WordRef |= BitWord(1) << BitPos;
      else
        *WordRef &= ~(BitWord(1) << BitPos);
      return *this;
    }

    operator bool() const {
      return ((*WordRef) & (BitWord(1) << BitPos)) != 0;
    }
  };

  typedef const_set_bits_iterator_impl<BitVector> const_set_bits_iterator;
  typedef const_set_bits_iterator set_iterator;

  const_set_bits_iterator set_bits_begin() const {
    return const_set_bits_iterator(*this);
  }
  const_set_bits_iterator set_bits_end() const {
    return const_set_bits_iterator(*this, -1);
  }
  iterator_range<const_set_bits_iterator> set_bits() const {
    return make_range(set_bits_begin(), set_bits_end());
  }

  /// BitVector default ctor - Creates an empty bitvector.
  BitVector() : Size(0) {}

  /// BitVector ctor - Creates a bitvector of specified number of bits. All
  /// bits are initialized to the specified value.
  explicit BitVector(unsigned s, bool t = false) : Size(s) {
    size_t Capacity = NumBitWords(s);
    Bits = allocate(Capacity);
    init_words(Bits, t);
    if (t)
      clear_unused_bits();
  }

  /// BitVector copy ctor.
  BitVector(const BitVector &RHS) : Size(RHS.size()) {
    if (Size == 0) {
      Bits = MutableArrayRef<BitWord>();
      return;
    }

    size_t Capacity = NumBitWords(RHS.size());
    Bits = allocate(Capacity);
    std::memcpy(Bits.data(), RHS.Bits.data(), Capacity * sizeof(BitWord));
  }

  BitVector(BitVector &&RHS) : Bits(RHS.Bits), Size(RHS.Size) {
    RHS.Bits = MutableArrayRef<BitWord>();
    RHS.Size = 0;
  }

  ~BitVector() { std::free(Bits.data()); }

  /// empty - Tests whether there are no bits in this bitvector.
  bool empty() const { return Size == 0; }

  /// size - Returns the number of bits in this bitvector.
  size_type size() const { return Size; }

  /// count - Returns the number of bits which are set.
  size_type count() const {
    unsigned NumBits = 0;
    for (unsigned i = 0; i < NumBitWords(size()); ++i)
      NumBits += countPopulation(Bits[i]);
    return NumBits;
  }

  /// any - Returns true if any bit is set.
  bool any() const {
    for (unsigned i = 0; i < NumBitWords(size()); ++i)
      if (Bits[i] != 0)
        return true;
    return false;
  }

  /// all - Returns true if all bits are set.
  bool all() const {
    for (unsigned i = 0; i < Size / BITWORD_SIZE; ++i)
      if (Bits[i] != ~BitWord(0))
        return false;

    // If bits remain check that they are ones. The unused bits are always zero.
    if (unsigned Remainder = Size % BITWORD_SIZE)
      return Bits[Size / BITWORD_SIZE] == (BitWord(1) << Remainder) - 1;

    return true;
  }

  /// none - Returns true if none of the bits are set.
  bool none() const {
    return !any();
  }

  /// find_first_in - Returns the index of the first set bit in the range
  /// [Begin, End).  Returns -1 if all bits in the range are unset.
  int find_first_in(unsigned Begin, unsigned End) const {
    assert(Begin <= End && End <= Size);
    if (Begin == End)
      return -1;

    unsigned FirstWord = Begin / BITWORD_SIZE;
    unsigned LastWord = (End - 1) / BITWORD_SIZE;

    // Check subsequent words.
    for (unsigned i = FirstWord; i <= LastWord; ++i) {
      BitWord Copy = Bits[i];

      if (i == FirstWord) {
        unsigned FirstBit = Begin % BITWORD_SIZE;
        Copy &= maskTrailingZeros<BitWord>(FirstBit);
      }

      if (i == LastWord) {
        unsigned LastBit = (End - 1) % BITWORD_SIZE;
        Copy &= maskTrailingOnes<BitWord>(LastBit + 1);
      }
      if (Copy != 0)
        return i * BITWORD_SIZE + countTrailingZeros(Copy);
    }
    return -1;
  }

  /// find_last_in - Returns the index of the last set bit in the range
  /// [Begin, End).  Returns -1 if all bits in the range are unset.
  int find_last_in(unsigned Begin, unsigned End) const {
    assert(Begin <= End && End <= Size);
    if (Begin == End)
      return -1;

    unsigned LastWord = (End - 1) / BITWORD_SIZE;
    unsigned FirstWord = Begin / BITWORD_SIZE;

    for (unsigned i = LastWord + 1; i >= FirstWord + 1; --i) {
      unsigned CurrentWord = i - 1;

      BitWord Copy = Bits[CurrentWord];
      if (CurrentWord == LastWord) {
        unsigned LastBit = (End - 1) % BITWORD_SIZE;
        Copy &= maskTrailingOnes<BitWord>(LastBit + 1);
      }

      if (CurrentWord == FirstWord) {
        unsigned FirstBit = Begin % BITWORD_SIZE;
        Copy &= maskTrailingZeros<BitWord>(FirstBit);
      }

      if (Copy != 0)
        return (CurrentWord + 1) * BITWORD_SIZE - countLeadingZeros(Copy) - 1;
    }

    return -1;
  }

  /// find_first_unset_in - Returns the index of the first unset bit in the
  /// range [Begin, End).  Returns -1 if all bits in the range are set.
  int find_first_unset_in(unsigned Begin, unsigned End) const {
    assert(Begin <= End && End <= Size);
    if (Begin == End)
      return -1;

    unsigned FirstWord = Begin / BITWORD_SIZE;
    unsigned LastWord = (End - 1) / BITWORD_SIZE;

    // Check subsequent words.
    for (unsigned i = FirstWord; i <= LastWord; ++i) {
      BitWord Copy = Bits[i];

      if (i == FirstWord) {
        unsigned FirstBit = Begin % BITWORD_SIZE;
        Copy |= maskTrailingOnes<BitWord>(FirstBit);
      }

      if (i == LastWord) {
        unsigned LastBit = (End - 1) % BITWORD_SIZE;
        Copy |= maskTrailingZeros<BitWord>(LastBit + 1);
      }
      if (Copy != ~BitWord(0)) {
        unsigned Result = i * BITWORD_SIZE + countTrailingOnes(Copy);
        return Result < size() ? Result : -1;
      }
    }
    return -1;
  }

  /// find_last_unset_in - Returns the index of the last unset bit in the
  /// range [Begin, End).  Returns -1 if all bits in the range are set.
  int find_last_unset_in(unsigned Begin, unsigned End) const {
    assert(Begin <= End && End <= Size);
    if (Begin == End)
      return -1;

    unsigned LastWord = (End - 1) / BITWORD_SIZE;
    unsigned FirstWord = Begin / BITWORD_SIZE;

    for (unsigned i = LastWord + 1; i >= FirstWord + 1; --i) {
      unsigned CurrentWord = i - 1;

      BitWord Copy = Bits[CurrentWord];
      if (CurrentWord == LastWord) {
        unsigned LastBit = (End - 1) % BITWORD_SIZE;
        Copy |= maskTrailingZeros<BitWord>(LastBit + 1);
      }

      if (CurrentWord == FirstWord) {
        unsigned FirstBit = Begin % BITWORD_SIZE;
        Copy |= maskTrailingOnes<BitWord>(FirstBit);
      }

      if (Copy != ~BitWord(0)) {
        unsigned Result =
            (CurrentWord + 1) * BITWORD_SIZE - countLeadingOnes(Copy) - 1;
        return Result < Size ? Result : -1;
      }
    }
    return -1;
  }

  /// find_first - Returns the index of the first set bit, -1 if none
  /// of the bits are set.
  int find_first() const { return find_first_in(0, Size); }

  /// find_last - Returns the index of the last set bit, -1 if none of the bits
  /// are set.
  int find_last() const { return find_last_in(0, Size); }

  /// find_next - Returns the index of the next set bit following the
  /// "Prev" bit. Returns -1 if the next set bit is not found.
  int find_next(unsigned Prev) const { return find_first_in(Prev + 1, Size); }

  /// find_prev - Returns the index of the first set bit that precedes the
  /// the bit at \p PriorTo.  Returns -1 if all previous bits are unset.
  int find_prev(unsigned PriorTo) const { return find_last_in(0, PriorTo); }

  /// find_first_unset - Returns the index of the first unset bit, -1 if all
  /// of the bits are set.
  int find_first_unset() const { return find_first_unset_in(0, Size); }

  /// find_next_unset - Returns the index of the next unset bit following the
  /// "Prev" bit.  Returns -1 if all remaining bits are set.
  int find_next_unset(unsigned Prev) const {
    return find_first_unset_in(Prev + 1, Size);
  }

  /// find_last_unset - Returns the index of the last unset bit, -1 if all of
  /// the bits are set.
  int find_last_unset() const { return find_last_unset_in(0, Size); }

  /// find_prev_unset - Returns the index of the first unset bit that precedes
  /// the bit at \p PriorTo.  Returns -1 if all previous bits are set.
  int find_prev_unset(unsigned PriorTo) {
    return find_last_unset_in(0, PriorTo);
  }

  /// clear - Removes all bits from the bitvector. Does not change capacity.
  void clear() {
    Size = 0;
  }

  /// resize - Grow or shrink the bitvector.
  void resize(unsigned N, bool t = false) {
    if (N > getBitCapacity()) {
      unsigned OldCapacity = Bits.size();
      grow(N);
      init_words(Bits.drop_front(OldCapacity), t);
    }

    // Set any old unused bits that are now included in the BitVector. This
    // may set bits that are not included in the new vector, but we will clear
    // them back out below.
    if (N > Size)
      set_unused_bits(t);

    // Update the size, and clear out any bits that are now unused
    unsigned OldSize = Size;
    Size = N;
    if (t || N < OldSize)
      clear_unused_bits();
  }

  void reserve(unsigned N) {
    if (N > getBitCapacity())
      grow(N);
  }

  // Set, reset, flip
  BitVector &set() {
    init_words(Bits, true);
    clear_unused_bits();
    return *this;
  }

  BitVector &set(unsigned Idx) {
    assert(Bits.data() && "Bits never allocated");
    Bits[Idx / BITWORD_SIZE] |= BitWord(1) << (Idx % BITWORD_SIZE);
    return *this;
  }

  /// set - Efficiently set a range of bits in [I, E)
  BitVector &set(unsigned I, unsigned E) {
    assert(I <= E && "Attempted to set backwards range!");
    assert(E <= size() && "Attempted to set out-of-bounds range!");

    if (I == E) return *this;

    if (I / BITWORD_SIZE == E / BITWORD_SIZE) {
      BitWord EMask = BitWord(1) << (E % BITWORD_SIZE);
      BitWord IMask = BitWord(1) << (I % BITWORD_SIZE);
      BitWord Mask = EMask - IMask;
      Bits[I / BITWORD_SIZE] |= Mask;
      return *this;
    }

    BitWord PrefixMask = ~BitWord(0) << (I % BITWORD_SIZE);
    Bits[I / BITWORD_SIZE] |= PrefixMask;
    I = alignTo(I, BITWORD_SIZE);

    for (; I + BITWORD_SIZE <= E; I += BITWORD_SIZE)
      Bits[I / BITWORD_SIZE] = ~BitWord(0);

    BitWord PostfixMask = (BitWord(1) << (E % BITWORD_SIZE)) - 1;
    if (I < E)
      Bits[I / BITWORD_SIZE] |= PostfixMask;

    return *this;
  }

  BitVector &reset() {
    init_words(Bits, false);
    return *this;
  }

  BitVector &reset(unsigned Idx) {
    Bits[Idx / BITWORD_SIZE] &= ~(BitWord(1) << (Idx % BITWORD_SIZE));
    return *this;
  }

  /// reset - Efficiently reset a range of bits in [I, E)
  BitVector &reset(unsigned I, unsigned E) {
    assert(I <= E && "Attempted to reset backwards range!");
    assert(E <= size() && "Attempted to reset out-of-bounds range!");

    if (I == E) return *this;

    if (I / BITWORD_SIZE == E / BITWORD_SIZE) {
      BitWord EMask = BitWord(1) << (E % BITWORD_SIZE);
      BitWord IMask = BitWord(1) << (I % BITWORD_SIZE);
      BitWord Mask = EMask - IMask;
      Bits[I / BITWORD_SIZE] &= ~Mask;
      return *this;
    }

    BitWord PrefixMask = ~BitWord(0) << (I % BITWORD_SIZE);
    Bits[I / BITWORD_SIZE] &= ~PrefixMask;
    I = alignTo(I, BITWORD_SIZE);

    for (; I + BITWORD_SIZE <= E; I += BITWORD_SIZE)
      Bits[I / BITWORD_SIZE] = BitWord(0);

    BitWord PostfixMask = (BitWord(1) << (E % BITWORD_SIZE)) - 1;
    if (I < E)
      Bits[I / BITWORD_SIZE] &= ~PostfixMask;

    return *this;
  }

  BitVector &flip() {
    for (unsigned i = 0; i < NumBitWords(size()); ++i)
      Bits[i] = ~Bits[i];
    clear_unused_bits();
    return *this;
  }

  BitVector &flip(unsigned Idx) {
    Bits[Idx / BITWORD_SIZE] ^= BitWord(1) << (Idx % BITWORD_SIZE);
    return *this;
  }

  // Indexing.
  reference operator[](unsigned Idx) {
    assert (Idx < Size && "Out-of-bounds Bit access.");
    return reference(*this, Idx);
  }

  bool operator[](unsigned Idx) const {
    assert (Idx < Size && "Out-of-bounds Bit access.");
    BitWord Mask = BitWord(1) << (Idx % BITWORD_SIZE);
    return (Bits[Idx / BITWORD_SIZE] & Mask) != 0;
  }

  bool test(unsigned Idx) const {
    return (*this)[Idx];
  }

  // Push single bit to end of vector.
  void push_back(bool Val) {
    unsigned OldSize = Size;
    unsigned NewSize = Size + 1;

    // Resize, which will insert zeros.
    // If we already fit then the unused bits will be already zero.
    if (NewSize > getBitCapacity())
      resize(NewSize, false);
    else
      Size = NewSize;

    // If true, set single bit.
    if (Val)
      set(OldSize);
  }

  /// Test if any common bits are set.
  bool anyCommon(const BitVector &RHS) const {
    unsigned ThisWords = NumBitWords(size());
    unsigned RHSWords  = NumBitWords(RHS.size());
    for (unsigned i = 0, e = std::min(ThisWords, RHSWords); i != e; ++i)
      if (Bits[i] & RHS.Bits[i])
        return true;
    return false;
  }

  // Comparison operators.
  bool operator==(const BitVector &RHS) const {
    unsigned ThisWords = NumBitWords(size());
    unsigned RHSWords  = NumBitWords(RHS.size());
    unsigned i;
    for (i = 0; i != std::min(ThisWords, RHSWords); ++i)
      if (Bits[i] != RHS.Bits[i])
        return false;

    // Verify that any extra words are all zeros.
    if (i != ThisWords) {
      for (; i != ThisWords; ++i)
        if (Bits[i])
          return false;
    } else if (i != RHSWords) {
      for (; i != RHSWords; ++i)
        if (RHS.Bits[i])
          return false;
    }
    return true;
  }

  bool operator!=(const BitVector &RHS) const {
    return !(*this == RHS);
  }

  /// Intersection, union, disjoint union.
  BitVector &operator&=(const BitVector &RHS) {
    unsigned ThisWords = NumBitWords(size());
    unsigned RHSWords  = NumBitWords(RHS.size());
    unsigned i;
    for (i = 0; i != std::min(ThisWords, RHSWords); ++i)
      Bits[i] &= RHS.Bits[i];

    // Any bits that are just in this bitvector become zero, because they aren't
    // in the RHS bit vector.  Any words only in RHS are ignored because they
    // are already zero in the LHS.
    for (; i != ThisWords; ++i)
      Bits[i] = 0;

    return *this;
  }

  /// reset - Reset bits that are set in RHS. Same as *this &= ~RHS.
  BitVector &reset(const BitVector &RHS) {
    unsigned ThisWords = NumBitWords(size());
    unsigned RHSWords  = NumBitWords(RHS.size());
    unsigned i;
    for (i = 0; i != std::min(ThisWords, RHSWords); ++i)
      Bits[i] &= ~RHS.Bits[i];
    return *this;
  }

  /// test - Check if (This - RHS) is zero.
  /// This is the same as reset(RHS) and any().
  bool test(const BitVector &RHS) const {
    unsigned ThisWords = NumBitWords(size());
    unsigned RHSWords  = NumBitWords(RHS.size());
    unsigned i;
    for (i = 0; i != std::min(ThisWords, RHSWords); ++i)
      if ((Bits[i] & ~RHS.Bits[i]) != 0)
        return true;

    for (; i != ThisWords ; ++i)
      if (Bits[i] != 0)
        return true;

    return false;
  }

  BitVector &operator|=(const BitVector &RHS) {
    if (size() < RHS.size())
      resize(RHS.size());
    for (size_t i = 0, e = NumBitWords(RHS.size()); i != e; ++i)
      Bits[i] |= RHS.Bits[i];
    return *this;
  }

  BitVector &operator^=(const BitVector &RHS) {
    if (size() < RHS.size())
      resize(RHS.size());
    for (size_t i = 0, e = NumBitWords(RHS.size()); i != e; ++i)
      Bits[i] ^= RHS.Bits[i];
    return *this;
  }

  BitVector &operator>>=(unsigned N) {
    assert(N <= Size);
    if (LLVM_UNLIKELY(empty() || N == 0))
      return *this;

    unsigned NumWords = NumBitWords(Size);
    assert(NumWords >= 1);

    wordShr(N / BITWORD_SIZE);

    unsigned BitDistance = N % BITWORD_SIZE;
    if (BitDistance == 0)
      return *this;

    // When the shift size is not a multiple of the word size, then we have
    // a tricky situation where each word in succession needs to extract some
    // of the bits from the next word and or them into this word while
    // shifting this word to make room for the new bits.  This has to be done
    // for every word in the array.

    // Since we're shifting each word right, some bits will fall off the end
    // of each word to the right, and empty space will be created on the left.
    // The final word in the array will lose bits permanently, so starting at
    // the beginning, work forwards shifting each word to the right, and
    // OR'ing in the bits from the end of the next word to the beginning of
    // the current word.

    // Example:
    //   Starting with {0xAABBCCDD, 0xEEFF0011, 0x22334455} and shifting right
    //   by 4 bits.
    // Step 1: Word[0] >>= 4           ; 0x0ABBCCDD
    // Step 2: Word[0] |= 0x10000000   ; 0x1ABBCCDD
    // Step 3: Word[1] >>= 4           ; 0x0EEFF001
    // Step 4: Word[1] |= 0x50000000   ; 0x5EEFF001
    // Step 5: Word[2] >>= 4           ; 0x02334455
    // Result: { 0x1ABBCCDD, 0x5EEFF001, 0x02334455 }
    const BitWord Mask = maskTrailingOnes<BitWord>(BitDistance);
    const unsigned LSH = BITWORD_SIZE - BitDistance;

    for (unsigned I = 0; I < NumWords - 1; ++I) {
      Bits[I] >>= BitDistance;
      Bits[I] |= (Bits[I + 1] & Mask) << LSH;
    }

    Bits[NumWords - 1] >>= BitDistance;

    return *this;
  }

  BitVector &operator<<=(unsigned N) {
    assert(N <= Size);
    if (LLVM_UNLIKELY(empty() || N == 0))
      return *this;

    unsigned NumWords = NumBitWords(Size);
    assert(NumWords >= 1);

    wordShl(N / BITWORD_SIZE);

    unsigned BitDistance = N % BITWORD_SIZE;
    if (BitDistance == 0)
      return *this;

    // When the shift size is not a multiple of the word size, then we have
    // a tricky situation where each word in succession needs to extract some
    // of the bits from the previous word and or them into this word while
    // shifting this word to make room for the new bits.  This has to be done
    // for every word in the array.  This is similar to the algorithm outlined
    // in operator>>=, but backwards.

    // Since we're shifting each word left, some bits will fall off the end
    // of each word to the left, and empty space will be created on the right.
    // The first word in the array will lose bits permanently, so starting at
    // the end, work backwards shifting each word to the left, and OR'ing
    // in the bits from the end of the next word to the beginning of the
    // current word.

    // Example:
    //   Starting with {0xAABBCCDD, 0xEEFF0011, 0x22334455} and shifting left
    //   by 4 bits.
    // Step 1: Word[2] <<= 4           ; 0x23344550
    // Step 2: Word[2] |= 0x0000000E   ; 0x2334455E
    // Step 3: Word[1] <<= 4           ; 0xEFF00110
    // Step 4: Word[1] |= 0x0000000A   ; 0xEFF0011A
    // Step 5: Word[0] <<= 4           ; 0xABBCCDD0
    // Result: { 0xABBCCDD0, 0xEFF0011A, 0x2334455E }
    const BitWord Mask = maskLeadingOnes<BitWord>(BitDistance);
    const unsigned RSH = BITWORD_SIZE - BitDistance;

    for (int I = NumWords - 1; I > 0; --I) {
      Bits[I] <<= BitDistance;
      Bits[I] |= (Bits[I - 1] & Mask) >> RSH;
    }
    Bits[0] <<= BitDistance;
    clear_unused_bits();

    return *this;
  }

  // Assignment operator.
  const BitVector &operator=(const BitVector &RHS) {
    if (this == &RHS) return *this;

    Size = RHS.size();

    // Handle tombstone when the BitVector is a key of a DenseHash.
    if (RHS.isInvalid()) {
      std::free(Bits.data());
      Bits = None;
      return *this;
    }

    unsigned RHSWords = NumBitWords(Size);
    if (Size <= getBitCapacity()) {
      if (Size)
        std::memcpy(Bits.data(), RHS.Bits.data(), RHSWords * sizeof(BitWord));
      clear_unused_bits();
      return *this;
    }

    // Grow the bitvector to have enough elements.
    unsigned NewCapacity = RHSWords;
    assert(NewCapacity > 0 && "negative capacity?");
    auto NewBits = allocate(NewCapacity);
    std::memcpy(NewBits.data(), RHS.Bits.data(), NewCapacity * sizeof(BitWord));

    // Destroy the old bits.
    std::free(Bits.data());
    Bits = NewBits;

    return *this;
  }

  const BitVector &operator=(BitVector &&RHS) {
    if (this == &RHS) return *this;

    std::free(Bits.data());
    Bits = RHS.Bits;
    Size = RHS.Size;

    RHS.Bits = MutableArrayRef<BitWord>();
    RHS.Size = 0;

    return *this;
  }

  void swap(BitVector &RHS) {
    std::swap(Bits, RHS.Bits);
    std::swap(Size, RHS.Size);
  }

  void invalid() {
    assert(!Size && Bits.empty());
    Size = (unsigned)-1;
  }
  bool isInvalid() const { return Size == (unsigned)-1; }

  ArrayRef<BitWord> getData() const { return Bits; }

  //===--------------------------------------------------------------------===//
  // Portable bit mask operations.
  //===--------------------------------------------------------------------===//
  //
  // These methods all operate on arrays of uint32_t, each holding 32 bits. The
  // fixed word size makes it easier to work with literal bit vector constants
  // in portable code.
  //
  // The LSB in each word is the lowest numbered bit.  The size of a portable
  // bit mask is always a whole multiple of 32 bits.  If no bit mask size is
  // given, the bit mask is assumed to cover the entire BitVector.

  /// setBitsInMask - Add '1' bits from Mask to this vector. Don't resize.
  /// This computes "*this |= Mask".
  void setBitsInMask(const uint32_t *Mask, unsigned MaskWords = ~0u) {
    applyMask<true, false>(Mask, MaskWords);
  }

  /// clearBitsInMask - Clear any bits in this vector that are set in Mask.
  /// Don't resize. This computes "*this &= ~Mask".
  void clearBitsInMask(const uint32_t *Mask, unsigned MaskWords = ~0u) {
    applyMask<false, false>(Mask, MaskWords);
  }

  /// setBitsNotInMask - Add a bit to this vector for every '0' bit in Mask.
  /// Don't resize.  This computes "*this |= ~Mask".
  void setBitsNotInMask(const uint32_t *Mask, unsigned MaskWords = ~0u) {
    applyMask<true, true>(Mask, MaskWords);
  }

  /// clearBitsNotInMask - Clear a bit in this vector for every '0' bit in Mask.
  /// Don't resize.  This computes "*this &= Mask".
  void clearBitsNotInMask(const uint32_t *Mask, unsigned MaskWords = ~0u) {
    applyMask<false, true>(Mask, MaskWords);
  }

private:
  /// Perform a logical left shift of \p Count words by moving everything
  /// \p Count words to the right in memory.
  ///
  /// While confusing, words are stored from least significant at Bits[0] to
  /// most significant at Bits[NumWords-1].  A logical shift left, however,
  /// moves the current least significant bit to a higher logical index, and
  /// fills the previous least significant bits with 0.  Thus, we actually
  /// need to move the bytes of the memory to the right, not to the left.
  /// Example:
  ///   Words = [0xBBBBAAAA, 0xDDDDFFFF, 0x00000000, 0xDDDD0000]
  /// represents a BitVector where 0xBBBBAAAA contain the least significant
  /// bits.  So if we want to shift the BitVector left by 2 words, we need to
  /// turn this into 0x00000000 0x00000000 0xBBBBAAAA 0xDDDDFFFF by using a
  /// memmove which moves right, not left.
  void wordShl(uint32_t Count) {
    if (Count == 0)
      return;

    uint32_t NumWords = NumBitWords(Size);

    auto Src = Bits.take_front(NumWords).drop_back(Count);
    auto Dest = Bits.take_front(NumWords).drop_front(Count);

    // Since we always move Word-sized chunks of data with src and dest both
    // aligned to a word-boundary, we don't need to worry about endianness
    // here.
    std::memmove(Dest.begin(), Src.begin(), Dest.size() * sizeof(BitWord));
    std::memset(Bits.data(), 0, Count * sizeof(BitWord));
    clear_unused_bits();
  }

  /// Perform a logical right shift of \p Count words by moving those
  /// words to the left in memory.  See wordShl for more information.
  ///
  void wordShr(uint32_t Count) {
    if (Count == 0)
      return;

    uint32_t NumWords = NumBitWords(Size);

    auto Src = Bits.take_front(NumWords).drop_front(Count);
    auto Dest = Bits.take_front(NumWords).drop_back(Count);
    assert(Dest.size() == Src.size());

    std::memmove(Dest.begin(), Src.begin(), Dest.size() * sizeof(BitWord));
    std::memset(Dest.end(), 0, Count * sizeof(BitWord));
  }

  MutableArrayRef<BitWord> allocate(size_t NumWords) {
    BitWord *RawBits = static_cast<BitWord *>(
        safe_malloc(NumWords * sizeof(BitWord)));
    return MutableArrayRef<BitWord>(RawBits, NumWords);
  }

  int next_unset_in_word(int WordIndex, BitWord Word) const {
    unsigned Result = WordIndex * BITWORD_SIZE + countTrailingOnes(Word);
    return Result < size() ? Result : -1;
  }

  unsigned NumBitWords(unsigned S) const {
    return (S + BITWORD_SIZE-1) / BITWORD_SIZE;
  }

  // Set the unused bits in the high words.
  void set_unused_bits(bool t = true) {
    //  Set high words first.
    unsigned UsedWords = NumBitWords(Size);
    if (Bits.size() > UsedWords)
      init_words(Bits.drop_front(UsedWords), t);

    //  Then set any stray high bits of the last used word.
    unsigned ExtraBits = Size % BITWORD_SIZE;
    if (ExtraBits) {
      BitWord ExtraBitMask = ~BitWord(0) << ExtraBits;
      if (t)
        Bits[UsedWords-1] |= ExtraBitMask;
      else
        Bits[UsedWords-1] &= ~ExtraBitMask;
    }
  }

  // Clear the unused bits in the high words.
  void clear_unused_bits() {
    set_unused_bits(false);
  }

  void grow(unsigned NewSize) {
    size_t NewCapacity = std::max<size_t>(NumBitWords(NewSize), Bits.size() * 2);
    assert(NewCapacity > 0 && "realloc-ing zero space");
    BitWord *NewBits = static_cast<BitWord *>(
        safe_realloc(Bits.data(), NewCapacity * sizeof(BitWord)));
    Bits = MutableArrayRef<BitWord>(NewBits, NewCapacity);
    clear_unused_bits();
  }

  void init_words(MutableArrayRef<BitWord> B, bool t) {
    if (B.size() > 0)
      memset(B.data(), 0 - (int)t, B.size() * sizeof(BitWord));
  }

  template<bool AddBits, bool InvertMask>
  void applyMask(const uint32_t *Mask, unsigned MaskWords) {
    static_assert(BITWORD_SIZE % 32 == 0, "Unsupported BitWord size.");
    MaskWords = std::min(MaskWords, (size() + 31) / 32);
    const unsigned Scale = BITWORD_SIZE / 32;
    unsigned i;
    for (i = 0; MaskWords >= Scale; ++i, MaskWords -= Scale) {
      BitWord BW = Bits[i];
      // This inner loop should unroll completely when BITWORD_SIZE > 32.
      for (unsigned b = 0; b != BITWORD_SIZE; b += 32) {
        uint32_t M = *Mask++;
        if (InvertMask) M = ~M;
        if (AddBits) BW |=   BitWord(M) << b;
        else         BW &= ~(BitWord(M) << b);
      }
      Bits[i] = BW;
    }
    for (unsigned b = 0; MaskWords; b += 32, --MaskWords) {
      uint32_t M = *Mask++;
      if (InvertMask) M = ~M;
      if (AddBits) Bits[i] |=   BitWord(M) << b;
      else         Bits[i] &= ~(BitWord(M) << b);
    }
    if (AddBits)
      clear_unused_bits();
  }

public:
  /// Return the size (in bytes) of the bit vector.
  size_t getMemorySize() const { return Bits.size() * sizeof(BitWord); }
  size_t getBitCapacity() const { return Bits.size() * BITWORD_SIZE; }
};

inline size_t capacity_in_bytes(const BitVector &X) {
  return X.getMemorySize();
}

template <> struct DenseMapInfo<BitVector> {
  static inline BitVector getEmptyKey() { return BitVector(); }
  static inline BitVector getTombstoneKey() {
    BitVector V;
    V.invalid();
    return V;
  }
  static unsigned getHashValue(const BitVector &V) {
    return DenseMapInfo<std::pair<unsigned, ArrayRef<uintptr_t>>>::getHashValue(
        std::make_pair(V.size(), V.getData()));
  }
  static bool isEqual(const BitVector &LHS, const BitVector &RHS) {
    if (LHS.isInvalid() || RHS.isInvalid())
      return LHS.isInvalid() == RHS.isInvalid();
    return LHS == RHS;
  }
};
} // end namespace llvm

namespace std {
  /// Implement std::swap in terms of BitVector swap.
  inline void
  swap(llvm::BitVector &LHS, llvm::BitVector &RHS) {
    LHS.swap(RHS);
  }
} // end namespace std

#endif // LLVM_ADT_BITVECTOR_H
# 980 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/BitVector.h"
# 42 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMap.h"
#endif /* expanded by -frewrite-includes */
# 42 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 43 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseSet.h"
#endif /* expanded by -frewrite-includes */
# 43 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h" 1
//===- llvm/ADT/DenseSet.h - Dense probed hash table ------------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the DenseSet and SmallDenseSet classes.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_ADT_DENSESET_H
#define LLVM_ADT_DENSESET_H

#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMap.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMapInfo.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MathExtras.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/type_traits.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 25 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"

namespace llvm {

namespace detail {

struct DenseSetEmpty {};

// Use the empty base class trick so we can create a DenseMap where the buckets
// contain only a single item.
template <typename KeyT> class DenseSetPair : public DenseSetEmpty {
  KeyT key;

public:
  KeyT &getFirst() { return key; }
  const KeyT &getFirst() const { return key; }
  DenseSetEmpty &getSecond() { return *this; }
  const DenseSetEmpty &getSecond() const { return *this; }
};

/// Base class for DenseSet and DenseSmallSet.
///
/// MapTy should be either
///
///   DenseMap<ValueT, detail::DenseSetEmpty, ValueInfoT,
///            detail::DenseSetPair<ValueT>>
///
/// or the equivalent SmallDenseMap type.  ValueInfoT must implement the
/// DenseMapInfo "concept".
template <typename ValueT, typename MapTy, typename ValueInfoT>
class DenseSetImpl {
  static_assert(sizeof(typename MapTy::value_type) == sizeof(ValueT),
                "DenseMap buckets unexpectedly large!");
  MapTy TheMap;

  template <typename T>
  using const_arg_type_t = typename const_pointer_or_const_ref<T>::type;

public:
  using key_type = ValueT;
  using value_type = ValueT;
  using size_type = unsigned;

  explicit DenseSetImpl(unsigned InitialReserve = 0) : TheMap(InitialReserve) {}

  DenseSetImpl(std::initializer_list<ValueT> Elems)
      : DenseSetImpl(PowerOf2Ceil(Elems.size())) {
    insert(Elems.begin(), Elems.end());
  }

  bool empty() const { return TheMap.empty(); }
  size_type size() const { return TheMap.size(); }
  size_t getMemorySize() const { return TheMap.getMemorySize(); }

  /// Grow the DenseSet so that it has at least Size buckets. Will not shrink
  /// the Size of the set.
  void resize(size_t Size) { TheMap.resize(Size); }

  /// Grow the DenseSet so that it can contain at least \p NumEntries items
  /// before resizing again.
  void reserve(size_t Size) { TheMap.reserve(Size); }

  void clear() {
    TheMap.clear();
  }

  /// Return 1 if the specified key is in the set, 0 otherwise.
  size_type count(const_arg_type_t<ValueT> V) const {
    return TheMap.count(V);
  }

  bool erase(const ValueT &V) {
    return TheMap.erase(V);
  }

  void swap(DenseSetImpl &RHS) { TheMap.swap(RHS.TheMap); }

  // Iterators.

  class ConstIterator;

  class Iterator {
    typename MapTy::iterator I;
    friend class DenseSetImpl;
    friend class ConstIterator;

  public:
    using difference_type = typename MapTy::iterator::difference_type;
    using value_type = ValueT;
    using pointer = value_type *;
    using reference = value_type &;
    using iterator_category = std::forward_iterator_tag;

    Iterator() = default;
    Iterator(const typename MapTy::iterator &i) : I(i) {}

    ValueT &operator*() { return I->getFirst(); }
    const ValueT &operator*() const { return I->getFirst(); }
    ValueT *operator->() { return &I->getFirst(); }
    const ValueT *operator->() const { return &I->getFirst(); }

    Iterator& operator++() { ++I; return *this; }
    Iterator operator++(int) { auto T = *this; ++I; return T; }
    bool operator==(const ConstIterator& X) const { return I == X.I; }
    bool operator!=(const ConstIterator& X) const { return I != X.I; }
  };

  class ConstIterator {
    typename MapTy::const_iterator I;
    friend class DenseSetImpl;
    friend class Iterator;

  public:
    using difference_type = typename MapTy::const_iterator::difference_type;
    using value_type = ValueT;
    using pointer = const value_type *;
    using reference = const value_type &;
    using iterator_category = std::forward_iterator_tag;

    ConstIterator() = default;
    ConstIterator(const Iterator &B) : I(B.I) {}
    ConstIterator(const typename MapTy::const_iterator &i) : I(i) {}

    const ValueT &operator*() const { return I->getFirst(); }
    const ValueT *operator->() const { return &I->getFirst(); }

    ConstIterator& operator++() { ++I; return *this; }
    ConstIterator operator++(int) { auto T = *this; ++I; return T; }
    bool operator==(const ConstIterator& X) const { return I == X.I; }
    bool operator!=(const ConstIterator& X) const { return I != X.I; }
  };

  using iterator = Iterator;
  using const_iterator = ConstIterator;

  iterator begin() { return Iterator(TheMap.begin()); }
  iterator end() { return Iterator(TheMap.end()); }

  const_iterator begin() const { return ConstIterator(TheMap.begin()); }
  const_iterator end() const { return ConstIterator(TheMap.end()); }

  iterator find(const_arg_type_t<ValueT> V) { return Iterator(TheMap.find(V)); }
  const_iterator find(const_arg_type_t<ValueT> V) const {
    return ConstIterator(TheMap.find(V));
  }

  /// Alternative version of find() which allows a different, and possibly less
  /// expensive, key type.
  /// The DenseMapInfo is responsible for supplying methods
  /// getHashValue(LookupKeyT) and isEqual(LookupKeyT, KeyT) for each key type
  /// used.
  template <class LookupKeyT>
  iterator find_as(const LookupKeyT &Val) {
    return Iterator(TheMap.find_as(Val));
  }
  template <class LookupKeyT>
  const_iterator find_as(const LookupKeyT &Val) const {
    return ConstIterator(TheMap.find_as(Val));
  }

  void erase(Iterator I) { return TheMap.erase(I.I); }
  void erase(ConstIterator CI) { return TheMap.erase(CI.I); }

  std::pair<iterator, bool> insert(const ValueT &V) {
    detail::DenseSetEmpty Empty;
    return TheMap.try_emplace(V, Empty);
  }

  std::pair<iterator, bool> insert(ValueT &&V) {
    detail::DenseSetEmpty Empty;
    return TheMap.try_emplace(std::move(V), Empty);
  }

  /// Alternative version of insert that uses a different (and possibly less
  /// expensive) key type.
  template <typename LookupKeyT>
  std::pair<iterator, bool> insert_as(const ValueT &V,
                                      const LookupKeyT &LookupKey) {
    return TheMap.insert_as({V, detail::DenseSetEmpty()}, LookupKey);
  }
  template <typename LookupKeyT>
  std::pair<iterator, bool> insert_as(ValueT &&V, const LookupKeyT &LookupKey) {
    return TheMap.insert_as({std::move(V), detail::DenseSetEmpty()}, LookupKey);
  }

  // Range insertion of values.
  template<typename InputIt>
  void insert(InputIt I, InputIt E) {
    for (; I != E; ++I)
      insert(*I);
  }
};

/// Equality comparison for DenseSet.
///
/// Iterates over elements of LHS confirming that each element is also a member
/// of RHS, and that RHS contains no additional values.
/// Equivalent to N calls to RHS.count. Amortized complexity is linear, worst
/// case is O(N^2) (if every hash collides).
template <typename ValueT, typename MapTy, typename ValueInfoT>
bool operator==(const DenseSetImpl<ValueT, MapTy, ValueInfoT> &LHS,
                const DenseSetImpl<ValueT, MapTy, ValueInfoT> &RHS) {
  if (LHS.size() != RHS.size())
    return false;

  for (auto &E : LHS)
    if (!RHS.count(E))
      return false;

  return true;
}

/// Inequality comparison for DenseSet.
///
/// Equivalent to !(LHS == RHS). See operator== for performance notes.
template <typename ValueT, typename MapTy, typename ValueInfoT>
bool operator!=(const DenseSetImpl<ValueT, MapTy, ValueInfoT> &LHS,
                const DenseSetImpl<ValueT, MapTy, ValueInfoT> &RHS) {
  return !(LHS == RHS);
}

} // end namespace detail

/// Implements a dense probed hash-table based set.
template <typename ValueT, typename ValueInfoT = DenseMapInfo<ValueT>>
class DenseSet : public detail::DenseSetImpl<
                     ValueT, DenseMap<ValueT, detail::DenseSetEmpty, ValueInfoT,
                                      detail::DenseSetPair<ValueT>>,
                     ValueInfoT> {
  using BaseT =
      detail::DenseSetImpl<ValueT,
                           DenseMap<ValueT, detail::DenseSetEmpty, ValueInfoT,
                                    detail::DenseSetPair<ValueT>>,
                           ValueInfoT>;

public:
  using BaseT::BaseT;
};

/// Implements a dense probed hash-table based set with some number of buckets
/// stored inline.
template <typename ValueT, unsigned InlineBuckets = 4,
          typename ValueInfoT = DenseMapInfo<ValueT>>
class SmallDenseSet
    : public detail::DenseSetImpl<
          ValueT, SmallDenseMap<ValueT, detail::DenseSetEmpty, InlineBuckets,
                                ValueInfoT, detail::DenseSetPair<ValueT>>,
          ValueInfoT> {
  using BaseT = detail::DenseSetImpl<
      ValueT, SmallDenseMap<ValueT, detail::DenseSetEmpty, InlineBuckets,
                            ValueInfoT, detail::DenseSetPair<ValueT>>,
      ValueInfoT>;

public:
  using BaseT::BaseT;
};

} // end namespace llvm

#endif // LLVM_ADT_DENSESET_H
# 284 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/ADT/DenseSet.h"
# 44 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/IntrusiveRefCntPtr.h"
#endif /* expanded by -frewrite-includes */
# 44 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 45 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/PointerIntPair.h"
#endif /* expanded by -frewrite-includes */
# 45 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 46 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 46 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 47 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 47 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 48 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Allocator.h"
#endif /* expanded by -frewrite-includes */
# 48 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 49 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 49 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 50 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MemoryBuffer.h"
#endif /* expanded by -frewrite-includes */
# 50 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 51 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 51 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 52 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 52 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 53 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <map>
#endif /* expanded by -frewrite-includes */
# 53 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 54 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 54 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 55 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 55 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 56 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 56 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 57 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 57 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 58 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"

namespace clang {

class ASTReader;
class ASTWriter;
class LineTableInfo;
class SourceManager;

/// Public enums and private classes that are part of the
/// SourceManager implementation.
namespace SrcMgr {

  /// Indicates whether a file or directory holds normal user code,
  /// system code, or system code which is implicitly 'extern "C"' in C++ mode.
  ///
  /// Entire directories can be tagged with this (this is maintained by
  /// DirectoryLookup and friends) as can specific FileInfos when a \#pragma
  /// system_header is seen or in various other cases.
  ///
  enum CharacteristicKind {
    C_User, C_System, C_ExternCSystem, C_User_ModuleMap, C_System_ModuleMap
  };

  /// Determine whether a file / directory characteristic is for system code.
  inline bool isSystem(CharacteristicKind CK) {
    return CK != C_User && CK != C_User_ModuleMap;
  }

  /// Determine whether a file characteristic is for a module map.
  inline bool isModuleMap(CharacteristicKind CK) {
    return CK == C_User_ModuleMap || CK == C_System_ModuleMap;
  }

  /// One instance of this struct is kept for every file loaded or used.
  ///
  /// This object owns the MemoryBuffer object.
  class alignas(8) ContentCache {
    enum CCFlags {
      /// Whether the buffer is invalid.
      InvalidFlag = 0x01,

      /// Whether the buffer should not be freed on destruction.
      DoNotFreeFlag = 0x02
    };

    /// The actual buffer containing the characters from the input
    /// file.
    ///
    /// This is owned by the ContentCache object.  The bits indicate
    /// whether the buffer is invalid.
    mutable llvm::PointerIntPair<const llvm::MemoryBuffer *, 2> Buffer;

  public:
    /// Reference to the file entry representing this ContentCache.
    ///
    /// This reference does not own the FileEntry object.
    ///
    /// It is possible for this to be NULL if the ContentCache encapsulates
    /// an imaginary text buffer.
    const FileEntry *OrigEntry;

    /// References the file which the contents were actually loaded from.
    ///
    /// Can be different from 'Entry' if we overridden the contents of one file
    /// with the contents of another file.
    const FileEntry *ContentsEntry;

    /// A bump pointer allocated array of offsets for each source line.
    ///
    /// This is lazily computed.  This is owned by the SourceManager
    /// BumpPointerAllocator object.
    unsigned *SourceLineCache = nullptr;

    /// The number of lines in this ContentCache.
    ///
    /// This is only valid if SourceLineCache is non-null.
    unsigned NumLines = 0;

    /// Indicates whether the buffer itself was provided to override
    /// the actual file contents.
    ///
    /// When true, the original entry may be a virtual file that does not
    /// exist.
    unsigned BufferOverridden : 1;

    /// True if this content cache was initially created for a source file
    /// considered to be volatile (likely to change between stat and open).
    unsigned IsFileVolatile : 1;

    /// True if this file may be transient, that is, if it might not
    /// exist at some later point in time when this content entry is used,
    /// after serialization and deserialization.
    unsigned IsTransient : 1;

    ContentCache(const FileEntry *Ent = nullptr) : ContentCache(Ent, Ent) {}

    ContentCache(const FileEntry *Ent, const FileEntry *contentEnt)
        : Buffer(nullptr, false), OrigEntry(Ent), ContentsEntry(contentEnt),
          BufferOverridden(false), IsFileVolatile(false), IsTransient(false) {}

    /// The copy ctor does not allow copies where source object has either
    /// a non-NULL Buffer or SourceLineCache.  Ownership of allocated memory
    /// is not transferred, so this is a logical error.
    ContentCache(const ContentCache &RHS)
        : Buffer(nullptr, false), BufferOverridden(false),
          IsFileVolatile(false), IsTransient(false) {
      OrigEntry = RHS.OrigEntry;
      ContentsEntry = RHS.ContentsEntry;

      assert(RHS.Buffer.getPointer() == nullptr &&
             RHS.SourceLineCache == nullptr &&
             "Passed ContentCache object cannot own a buffer.");

      NumLines = RHS.NumLines;
    }

    ContentCache &operator=(const ContentCache& RHS) = delete;

    ~ContentCache();

    /// Returns the memory buffer for the associated content.
    ///
    /// \param Diag Object through which diagnostics will be emitted if the
    ///   buffer cannot be retrieved.
    ///
    /// \param Loc If specified, is the location that invalid file diagnostics
    ///   will be emitted at.
    ///
    /// \param Invalid If non-NULL, will be set \c true if an error occurred.
    const llvm::MemoryBuffer *getBuffer(DiagnosticsEngine &Diag,
                                        FileManager &FM,
                                        SourceLocation Loc = SourceLocation(),
                                        bool *Invalid = nullptr) const;

    /// Returns the size of the content encapsulated by this
    /// ContentCache.
    ///
    /// This can be the size of the source file or the size of an
    /// arbitrary scratch buffer.  If the ContentCache encapsulates a source
    /// file this size is retrieved from the file's FileEntry.
    unsigned getSize() const;

    /// Returns the number of bytes actually mapped for this
    /// ContentCache.
    ///
    /// This can be 0 if the MemBuffer was not actually expanded.
    unsigned getSizeBytesMapped() const;

    /// Returns the kind of memory used to back the memory buffer for
    /// this content cache.  This is used for performance analysis.
    llvm::MemoryBuffer::BufferKind getMemoryBufferKind() const;

    /// Get the underlying buffer, returning NULL if the buffer is not
    /// yet available.
    const llvm::MemoryBuffer *getRawBuffer() const {
      return Buffer.getPointer();
    }

    /// Replace the existing buffer (which will be deleted)
    /// with the given buffer.
    void replaceBuffer(const llvm::MemoryBuffer *B, bool DoNotFree = false);

    /// Determine whether the buffer itself is invalid.
    bool isBufferInvalid() const {
      return Buffer.getInt() & InvalidFlag;
    }

    /// Determine whether the buffer should be freed.
    bool shouldFreeBuffer() const {
      return (Buffer.getInt() & DoNotFreeFlag) == 0;
    }

    // If BufStr has an invalid BOM, returns the BOM name; otherwise, returns
    // nullptr
    static const char *getInvalidBOM(StringRef BufStr);
  };

  // Assert that the \c ContentCache objects will always be 8-byte aligned so
  // that we can pack 3 bits of integer into pointers to such objects.
  static_assert(alignof(ContentCache) >= 8,
                "ContentCache must be 8-byte aligned.");

  /// Information about a FileID, basically just the logical file
  /// that it represents and include stack information.
  ///
  /// Each FileInfo has include stack information, indicating where it came
  /// from. This information encodes the \#include chain that a token was
  /// expanded from. The main include file has an invalid IncludeLoc.
  ///
  /// FileInfos contain a "ContentCache *", with the contents of the file.
  ///
  class FileInfo {
    friend class clang::SourceManager;
    friend class clang::ASTWriter;
    friend class clang::ASTReader;

    /// The location of the \#include that brought in this file.
    ///
    /// This is an invalid SLOC for the main file (top of the \#include chain).
    unsigned IncludeLoc;  // Really a SourceLocation

    /// Number of FileIDs (files and macros) that were created during
    /// preprocessing of this \#include, including this SLocEntry.
    ///
    /// Zero means the preprocessor didn't provide such info for this SLocEntry.
    unsigned NumCreatedFIDs : 31;

    /// Whether this FileInfo has any \#line directives.
    unsigned HasLineDirectives : 1;

    /// The content cache and the characteristic of the file.
    llvm::PointerIntPair<const ContentCache*, 3, CharacteristicKind>
        ContentAndKind;

    /// The filename that is used to access the file entry represented by the
    /// content cache.
    StringRef Filename;

  public:
    /// Return a FileInfo object.
    static FileInfo get(SourceLocation IL, const ContentCache *Con,
                        CharacteristicKind FileCharacter, StringRef Filename) {
      FileInfo X;
      X.IncludeLoc = IL.getRawEncoding();
      X.NumCreatedFIDs = 0;
      X.HasLineDirectives = false;
      X.ContentAndKind.setPointer(Con);
      X.ContentAndKind.setInt(FileCharacter);
      X.Filename = Filename;
      return X;
    }

    SourceLocation getIncludeLoc() const {
      return SourceLocation::getFromRawEncoding(IncludeLoc);
    }

    const ContentCache *getContentCache() const {
      return ContentAndKind.getPointer();
    }

    /// Return whether this is a system header or not.
    CharacteristicKind getFileCharacteristic() const {
      return ContentAndKind.getInt();
    }

    /// Return true if this FileID has \#line directives in it.
    bool hasLineDirectives() const { return HasLineDirectives; }

    /// Set the flag that indicates that this FileID has
    /// line table entries associated with it.
    void setHasLineDirectives() {
      HasLineDirectives = true;
    }

    /// Returns the name of the file that was used when the file was loaded from
    /// the underlying file system.
    StringRef getName() const { return Filename; }
  };

  /// Each ExpansionInfo encodes the expansion location - where
  /// the token was ultimately expanded, and the SpellingLoc - where the actual
  /// character data for the token came from.
  class ExpansionInfo {
    // Really these are all SourceLocations.

    /// Where the spelling for the token can be found.
    unsigned SpellingLoc;

    /// In a macro expansion, ExpansionLocStart and ExpansionLocEnd
    /// indicate the start and end of the expansion. In object-like macros,
    /// they will be the same. In a function-like macro expansion, the start
    /// will be the identifier and the end will be the ')'. Finally, in
    /// macro-argument instantiations, the end will be 'SourceLocation()', an
    /// invalid location.
    unsigned ExpansionLocStart, ExpansionLocEnd;

    /// Whether the expansion range is a token range.
    bool ExpansionIsTokenRange;

  public:
    SourceLocation getSpellingLoc() const {
      SourceLocation SpellLoc = SourceLocation::getFromRawEncoding(SpellingLoc);
      return SpellLoc.isInvalid() ? getExpansionLocStart() : SpellLoc;
    }

    SourceLocation getExpansionLocStart() const {
      return SourceLocation::getFromRawEncoding(ExpansionLocStart);
    }

    SourceLocation getExpansionLocEnd() const {
      SourceLocation EndLoc =
        SourceLocation::getFromRawEncoding(ExpansionLocEnd);
      return EndLoc.isInvalid() ? getExpansionLocStart() : EndLoc;
    }

    bool isExpansionTokenRange() const {
      return ExpansionIsTokenRange;
    }

    CharSourceRange getExpansionLocRange() const {
      return CharSourceRange(
          SourceRange(getExpansionLocStart(), getExpansionLocEnd()),
          isExpansionTokenRange());
    }

    bool isMacroArgExpansion() const {
      // Note that this needs to return false for default constructed objects.
      return getExpansionLocStart().isValid() &&
        SourceLocation::getFromRawEncoding(ExpansionLocEnd).isInvalid();
    }

    bool isMacroBodyExpansion() const {
      return getExpansionLocStart().isValid() &&
        SourceLocation::getFromRawEncoding(ExpansionLocEnd).isValid();
    }

    bool isFunctionMacroExpansion() const {
      return getExpansionLocStart().isValid() &&
          getExpansionLocStart() != getExpansionLocEnd();
    }

    /// Return a ExpansionInfo for an expansion.
    ///
    /// Start and End specify the expansion range (where the macro is
    /// expanded), and SpellingLoc specifies the spelling location (where
    /// the characters from the token come from). All three can refer to
    /// normal File SLocs or expansion locations.
    static ExpansionInfo create(SourceLocation SpellingLoc,
                                SourceLocation Start, SourceLocation End,
                                bool ExpansionIsTokenRange = true) {
      ExpansionInfo X;
      X.SpellingLoc = SpellingLoc.getRawEncoding();
      X.ExpansionLocStart = Start.getRawEncoding();
      X.ExpansionLocEnd = End.getRawEncoding();
      X.ExpansionIsTokenRange = ExpansionIsTokenRange;
      return X;
    }

    /// Return a special ExpansionInfo for the expansion of
    /// a macro argument into a function-like macro's body.
    ///
    /// ExpansionLoc specifies the expansion location (where the macro is
    /// expanded). This doesn't need to be a range because a macro is always
    /// expanded at a macro parameter reference, and macro parameters are
    /// always exactly one token. SpellingLoc specifies the spelling location
    /// (where the characters from the token come from). ExpansionLoc and
    /// SpellingLoc can both refer to normal File SLocs or expansion locations.
    ///
    /// Given the code:
    /// \code
    ///   #define F(x) f(x)
    ///   F(42);
    /// \endcode
    ///
    /// When expanding '\c F(42)', the '\c x' would call this with an
    /// SpellingLoc pointing at '\c 42' and an ExpansionLoc pointing at its
    /// location in the definition of '\c F'.
    static ExpansionInfo createForMacroArg(SourceLocation SpellingLoc,
                                           SourceLocation ExpansionLoc) {
      // We store an intentionally invalid source location for the end of the
      // expansion range to mark that this is a macro argument location rather
      // than a normal one.
      return create(SpellingLoc, ExpansionLoc, SourceLocation());
    }

    /// Return a special ExpansionInfo representing a token that ends
    /// prematurely. This is used to model a '>>' token that has been split
    /// into '>' tokens and similar cases. Unlike for the other forms of
    /// expansion, the expansion range in this case is a character range, not
    /// a token range.
    static ExpansionInfo createForTokenSplit(SourceLocation SpellingLoc,
                                             SourceLocation Start,
                                             SourceLocation End) {
      return create(SpellingLoc, Start, End, false);
    }
  };

  /// This is a discriminated union of FileInfo and ExpansionInfo.
  ///
  /// SourceManager keeps an array of these objects, and they are uniquely
  /// identified by the FileID datatype.
  class SLocEntry {
    unsigned Offset : 31;
    unsigned IsExpansion : 1;
    union {
      FileInfo File;
      ExpansionInfo Expansion;
    };

  public:
    SLocEntry() : Offset(), IsExpansion(), File() {}

    unsigned getOffset() const { return Offset; }

    bool isExpansion() const { return IsExpansion; }
    bool isFile() const { return !isExpansion(); }

    const FileInfo &getFile() const {
      assert(isFile() && "Not a file SLocEntry!");
      return File;
    }

    const ExpansionInfo &getExpansion() const {
      assert(isExpansion() && "Not a macro expansion SLocEntry!");
      return Expansion;
    }

    static SLocEntry get(unsigned Offset, const FileInfo &FI) {
      assert(!(Offset & (1u << 31)) && "Offset is too large");
      SLocEntry E;
      E.Offset = Offset;
      E.IsExpansion = false;
      E.File = FI;
      return E;
    }

    static SLocEntry get(unsigned Offset, const ExpansionInfo &Expansion) {
      assert(!(Offset & (1u << 31)) && "Offset is too large");
      SLocEntry E;
      E.Offset = Offset;
      E.IsExpansion = true;
      E.Expansion = Expansion;
      return E;
    }
  };

} // namespace SrcMgr

/// External source of source location entries.
class ExternalSLocEntrySource {
public:
  virtual ~ExternalSLocEntrySource();

  /// Read the source location entry with index ID, which will always be
  /// less than -1.
  ///
  /// \returns true if an error occurred that prevented the source-location
  /// entry from being loaded.
  virtual bool ReadSLocEntry(int ID) = 0;

  /// Retrieve the module import location and name for the given ID, if
  /// in fact it was loaded from a module (rather than, say, a precompiled
  /// header).
  virtual std::pair<SourceLocation, StringRef> getModuleImportLoc(int ID) = 0;
};

/// Holds the cache used by isBeforeInTranslationUnit.
///
/// The cache structure is complex enough to be worth breaking out of
/// SourceManager.
class InBeforeInTUCacheEntry {
  /// The FileID's of the cached query.
  ///
  /// If these match up with a subsequent query, the result can be reused.
  FileID LQueryFID, RQueryFID;

  /// True if LQueryFID was created before RQueryFID.
  ///
  /// This is used to compare macro expansion locations.
  bool IsLQFIDBeforeRQFID;

  /// The file found in common between the two \#include traces, i.e.,
  /// the nearest common ancestor of the \#include tree.
  FileID CommonFID;

  /// The offset of the previous query in CommonFID.
  ///
  /// Usually, this represents the location of the \#include for QueryFID, but
  /// if LQueryFID is a parent of RQueryFID (or vice versa) then these can be a
  /// random token in the parent.
  unsigned LCommonOffset, RCommonOffset;

public:
  /// Return true if the currently cached values match up with
  /// the specified LHS/RHS query.
  ///
  /// If not, we can't use the cache.
  bool isCacheValid(FileID LHS, FileID RHS) const {
    return LQueryFID == LHS && RQueryFID == RHS;
  }

  /// If the cache is valid, compute the result given the
  /// specified offsets in the LHS/RHS FileID's.
  bool getCachedResult(unsigned LOffset, unsigned ROffset) const {
    // If one of the query files is the common file, use the offset.  Otherwise,
    // use the #include loc in the common file.
    if (LQueryFID != CommonFID) LOffset = LCommonOffset;
    if (RQueryFID != CommonFID) ROffset = RCommonOffset;

    // It is common for multiple macro expansions to be "included" from the same
    // location (expansion location), in which case use the order of the FileIDs
    // to determine which came first. This will also take care the case where
    // one of the locations points at the inclusion/expansion point of the other
    // in which case its FileID will come before the other.
    if (LOffset == ROffset)
      return IsLQFIDBeforeRQFID;

    return LOffset < ROffset;
  }

  /// Set up a new query.
  void setQueryFIDs(FileID LHS, FileID RHS, bool isLFIDBeforeRFID) {
    assert(LHS != RHS);
    LQueryFID = LHS;
    RQueryFID = RHS;
    IsLQFIDBeforeRQFID = isLFIDBeforeRFID;
  }

  void clear() {
    LQueryFID = RQueryFID = FileID();
    IsLQFIDBeforeRQFID = false;
  }

  void setCommonLoc(FileID commonFID, unsigned lCommonOffset,
                    unsigned rCommonOffset) {
    CommonFID = commonFID;
    LCommonOffset = lCommonOffset;
    RCommonOffset = rCommonOffset;
  }
};

/// The stack used when building modules on demand, which is used
/// to provide a link between the source managers of the different compiler
/// instances.
using ModuleBuildStack = ArrayRef<std::pair<std::string, FullSourceLoc>>;

/// This class handles loading and caching of source files into memory.
///
/// This object owns the MemoryBuffer objects for all of the loaded
/// files and assigns unique FileID's for each unique \#include chain.
///
/// The SourceManager can be queried for information about SourceLocation
/// objects, turning them into either spelling or expansion locations. Spelling
/// locations represent where the bytes corresponding to a token came from and
/// expansion locations represent where the location is in the user's view. In
/// the case of a macro expansion, for example, the spelling location indicates
/// where the expanded token came from and the expansion location specifies
/// where it was expanded.
class SourceManager : public RefCountedBase<SourceManager> {
  /// DiagnosticsEngine object.
  DiagnosticsEngine &Diag;

  FileManager &FileMgr;

  mutable llvm::BumpPtrAllocator ContentCacheAlloc;

  /// Memoized information about all of the files tracked by this
  /// SourceManager.
  ///
  /// This map allows us to merge ContentCache entries based
  /// on their FileEntry*.  All ContentCache objects will thus have unique,
  /// non-null, FileEntry pointers.
  llvm::DenseMap<const FileEntry*, SrcMgr::ContentCache*> FileInfos;

  /// True if the ContentCache for files that are overridden by other
  /// files, should report the original file name. Defaults to true.
  bool OverridenFilesKeepOriginalName = true;

  /// True if non-system source files should be treated as volatile
  /// (likely to change while trying to use them). Defaults to false.
  bool UserFilesAreVolatile;

  /// True if all files read during this compilation should be treated
  /// as transient (may not be present in later compilations using a module
  /// file created from this compilation). Defaults to false.
  bool FilesAreTransient = false;

  struct OverriddenFilesInfoTy {
    /// Files that have been overridden with the contents from another
    /// file.
    llvm::DenseMap<const FileEntry *, const FileEntry *> OverriddenFiles;

    /// Files that were overridden with a memory buffer.
    llvm::DenseSet<const FileEntry *> OverriddenFilesWithBuffer;
  };

  /// Lazily create the object keeping overridden files info, since
  /// it is uncommonly used.
  std::unique_ptr<OverriddenFilesInfoTy> OverriddenFilesInfo;

  OverriddenFilesInfoTy &getOverriddenFilesInfo() {
    if (!OverriddenFilesInfo)
      OverriddenFilesInfo.reset(new OverriddenFilesInfoTy);
    return *OverriddenFilesInfo;
  }

  /// Information about various memory buffers that we have read in.
  ///
  /// All FileEntry* within the stored ContentCache objects are NULL,
  /// as they do not refer to a file.
  std::vector<SrcMgr::ContentCache*> MemBufferInfos;

  /// The table of SLocEntries that are local to this module.
  ///
  /// Positive FileIDs are indexes into this table. Entry 0 indicates an invalid
  /// expansion.
  SmallVector<SrcMgr::SLocEntry, 0> LocalSLocEntryTable;

  /// The table of SLocEntries that are loaded from other modules.
  ///
  /// Negative FileIDs are indexes into this table. To get from ID to an index,
  /// use (-ID - 2).
  mutable SmallVector<SrcMgr::SLocEntry, 0> LoadedSLocEntryTable;

  /// The starting offset of the next local SLocEntry.
  ///
  /// This is LocalSLocEntryTable.back().Offset + the size of that entry.
  unsigned NextLocalOffset;

  /// The starting offset of the latest batch of loaded SLocEntries.
  ///
  /// This is LoadedSLocEntryTable.back().Offset, except that that entry might
  /// not have been loaded, so that value would be unknown.
  unsigned CurrentLoadedOffset;

  /// The highest possible offset is 2^31-1, so CurrentLoadedOffset
  /// starts at 2^31.
  static const unsigned MaxLoadedOffset = 1U << 31U;

  /// A bitmap that indicates whether the entries of LoadedSLocEntryTable
  /// have already been loaded from the external source.
  ///
  /// Same indexing as LoadedSLocEntryTable.
  llvm::BitVector SLocEntryLoaded;

  /// An external source for source location entries.
  ExternalSLocEntrySource *ExternalSLocEntries = nullptr;

  /// A one-entry cache to speed up getFileID.
  ///
  /// LastFileIDLookup records the last FileID looked up or created, because it
  /// is very common to look up many tokens from the same file.
  mutable FileID LastFileIDLookup;

  /// Holds information for \#line directives.
  ///
  /// This is referenced by indices from SLocEntryTable.
  std::unique_ptr<LineTableInfo> LineTable;

  /// These ivars serve as a cache used in the getLineNumber
  /// method which is used to speedup getLineNumber calls to nearby locations.
  mutable FileID LastLineNoFileIDQuery;
  mutable SrcMgr::ContentCache *LastLineNoContentCache;
  mutable unsigned LastLineNoFilePos;
  mutable unsigned LastLineNoResult;

  /// The file ID for the main source file of the translation unit.
  FileID MainFileID;

  /// The file ID for the precompiled preamble there is one.
  FileID PreambleFileID;

  // Statistics for -print-stats.
  mutable unsigned NumLinearScans = 0;
  mutable unsigned NumBinaryProbes = 0;

  /// Associates a FileID with its "included/expanded in" decomposed
  /// location.
  ///
  /// Used to cache results from and speed-up \c getDecomposedIncludedLoc
  /// function.
  mutable llvm::DenseMap<FileID, std::pair<FileID, unsigned>> IncludedLocMap;

  /// The key value into the IsBeforeInTUCache table.
  using IsBeforeInTUCacheKey = std::pair<FileID, FileID>;

  /// The IsBeforeInTranslationUnitCache is a mapping from FileID pairs
  /// to cache results.
  using InBeforeInTUCache =
      llvm::DenseMap<IsBeforeInTUCacheKey, InBeforeInTUCacheEntry>;

  /// Cache results for the isBeforeInTranslationUnit method.
  mutable InBeforeInTUCache IBTUCache;
  mutable InBeforeInTUCacheEntry IBTUCacheOverflow;

  /// Return the cache entry for comparing the given file IDs
  /// for isBeforeInTranslationUnit.
  InBeforeInTUCacheEntry &getInBeforeInTUCache(FileID LFID, FileID RFID) const;

  // Cache for the "fake" buffer used for error-recovery purposes.
  mutable std::unique_ptr<llvm::MemoryBuffer> FakeBufferForRecovery;

  mutable std::unique_ptr<SrcMgr::ContentCache> FakeContentCacheForRecovery;

  /// Lazily computed map of macro argument chunks to their expanded
  /// source location.
  using MacroArgsMap = std::map<unsigned, SourceLocation>;

  mutable llvm::DenseMap<FileID, std::unique_ptr<MacroArgsMap>>
      MacroArgsCacheMap;

  /// The stack of modules being built, which is used to detect
  /// cycles in the module dependency graph as modules are being built, as
  /// well as to describe why we're rebuilding a particular module.
  ///
  /// There is no way to set this value from the command line. If we ever need
  /// to do so (e.g., if on-demand module construction moves out-of-process),
  /// we can add a cc1-level option to do so.
  SmallVector<std::pair<std::string, FullSourceLoc>, 2> StoredModuleBuildStack;

public:
  SourceManager(DiagnosticsEngine &Diag, FileManager &FileMgr,
                bool UserFilesAreVolatile = false);
  explicit SourceManager(const SourceManager &) = delete;
  SourceManager &operator=(const SourceManager &) = delete;
  ~SourceManager();

  void clearIDTables();

  /// Initialize this source manager suitably to replay the compilation
  /// described by \p Old. Requires that \p Old outlive \p *this.
  void initializeForReplay(const SourceManager &Old);

  DiagnosticsEngine &getDiagnostics() const { return Diag; }

  FileManager &getFileManager() const { return FileMgr; }

  /// Set true if the SourceManager should report the original file name
  /// for contents of files that were overridden by other files. Defaults to
  /// true.
  void setOverridenFilesKeepOriginalName(bool value) {
    OverridenFilesKeepOriginalName = value;
  }

  /// True if non-system source files should be treated as volatile
  /// (likely to change while trying to use them).
  bool userFilesAreVolatile() const { return UserFilesAreVolatile; }

  /// Retrieve the module build stack.
  ModuleBuildStack getModuleBuildStack() const {
    return StoredModuleBuildStack;
  }

  /// Set the module build stack.
  void setModuleBuildStack(ModuleBuildStack stack) {
    StoredModuleBuildStack.clear();
    StoredModuleBuildStack.append(stack.begin(), stack.end());
  }

  /// Push an entry to the module build stack.
  void pushModuleBuildStack(StringRef moduleName, FullSourceLoc importLoc) {
    StoredModuleBuildStack.push_back(std::make_pair(moduleName.str(),importLoc));
  }

  //===--------------------------------------------------------------------===//
  // MainFileID creation and querying methods.
  //===--------------------------------------------------------------------===//

  /// Returns the FileID of the main source file.
  FileID getMainFileID() const { return MainFileID; }

  /// Set the file ID for the main source file.
  void setMainFileID(FileID FID) {
    MainFileID = FID;
  }

  /// Set the file ID for the precompiled preamble.
  void setPreambleFileID(FileID Preamble) {
    assert(PreambleFileID.isInvalid() && "PreambleFileID already set!");
    PreambleFileID = Preamble;
  }

  /// Get the file ID for the precompiled preamble if there is one.
  FileID getPreambleFileID() const { return PreambleFileID; }

  //===--------------------------------------------------------------------===//
  // Methods to create new FileID's and macro expansions.
  //===--------------------------------------------------------------------===//

  /// Create a new FileID that represents the specified file
  /// being \#included from the specified IncludePosition.
  ///
  /// This translates NULL into standard input.
  FileID createFileID(const FileEntry *SourceFile, SourceLocation IncludePos,
                      SrcMgr::CharacteristicKind FileCharacter,
                      int LoadedID = 0, unsigned LoadedOffset = 0) {
    assert(SourceFile && "Null source file!");
    const SrcMgr::ContentCache *IR =
        getOrCreateContentCache(SourceFile, isSystem(FileCharacter));
    assert(IR && "getOrCreateContentCache() cannot return NULL");
    return createFileID(IR, SourceFile->getName(), IncludePos, FileCharacter,
                        LoadedID, LoadedOffset);
  }

  FileID createFileID(FileEntryRef SourceFile, SourceLocation IncludePos,
                      SrcMgr::CharacteristicKind FileCharacter,
                      int LoadedID = 0, unsigned LoadedOffset = 0) {
    const SrcMgr::ContentCache *IR = getOrCreateContentCache(
        &SourceFile.getFileEntry(), isSystem(FileCharacter));
    assert(IR && "getOrCreateContentCache() cannot return NULL");
    return createFileID(IR, SourceFile.getName(), IncludePos, FileCharacter,
                        LoadedID, LoadedOffset);
  }

  /// Create a new FileID that represents the specified memory buffer.
  ///
  /// This does no caching of the buffer and takes ownership of the
  /// MemoryBuffer, so only pass a MemoryBuffer to this once.
  FileID createFileID(std::unique_ptr<llvm::MemoryBuffer> Buffer,
                      SrcMgr::CharacteristicKind FileCharacter = SrcMgr::C_User,
                      int LoadedID = 0, unsigned LoadedOffset = 0,
                      SourceLocation IncludeLoc = SourceLocation()) {
    StringRef Name = Buffer->getBufferIdentifier();
    return createFileID(
        createMemBufferContentCache(Buffer.release(), /*DoNotFree*/ false),
        Name, IncludeLoc, FileCharacter, LoadedID, LoadedOffset);
  }

  enum UnownedTag { Unowned };

  /// Create a new FileID that represents the specified memory buffer.
  ///
  /// This does not take ownership of the MemoryBuffer. The memory buffer must
  /// outlive the SourceManager.
  FileID createFileID(UnownedTag, const llvm::MemoryBuffer *Buffer,
                      SrcMgr::CharacteristicKind FileCharacter = SrcMgr::C_User,
                      int LoadedID = 0, unsigned LoadedOffset = 0,
                      SourceLocation IncludeLoc = SourceLocation()) {
    return createFileID(createMemBufferContentCache(Buffer, /*DoNotFree*/ true),
                        Buffer->getBufferIdentifier(), IncludeLoc,
                        FileCharacter, LoadedID, LoadedOffset);
  }

  /// Get the FileID for \p SourceFile if it exists. Otherwise, create a
  /// new FileID for the \p SourceFile.
  FileID getOrCreateFileID(const FileEntry *SourceFile,
                           SrcMgr::CharacteristicKind FileCharacter) {
    FileID ID = translateFile(SourceFile);
    return ID.isValid() ? ID : createFileID(SourceFile, SourceLocation(),
                                            FileCharacter);
  }

  /// Return a new SourceLocation that encodes the
  /// fact that a token from SpellingLoc should actually be referenced from
  /// ExpansionLoc, and that it represents the expansion of a macro argument
  /// into the function-like macro body.
  SourceLocation createMacroArgExpansionLoc(SourceLocation Loc,
                                            SourceLocation ExpansionLoc,
                                            unsigned TokLength);

  /// Return a new SourceLocation that encodes the fact
  /// that a token from SpellingLoc should actually be referenced from
  /// ExpansionLoc.
  SourceLocation createExpansionLoc(SourceLocation Loc,
                                    SourceLocation ExpansionLocStart,
                                    SourceLocation ExpansionLocEnd,
                                    unsigned TokLength,
                                    bool ExpansionIsTokenRange = true,
                                    int LoadedID = 0,
                                    unsigned LoadedOffset = 0);

  /// Return a new SourceLocation that encodes that the token starting
  /// at \p TokenStart ends prematurely at \p TokenEnd.
  SourceLocation createTokenSplitLoc(SourceLocation SpellingLoc,
                                     SourceLocation TokenStart,
                                     SourceLocation TokenEnd);

  /// Retrieve the memory buffer associated with the given file.
  ///
  /// \param Invalid If non-NULL, will be set \c true if an error
  /// occurs while retrieving the memory buffer.
  const llvm::MemoryBuffer *getMemoryBufferForFile(const FileEntry *File,
                                                   bool *Invalid = nullptr);

  /// Override the contents of the given source file by providing an
  /// already-allocated buffer.
  ///
  /// \param SourceFile the source file whose contents will be overridden.
  ///
  /// \param Buffer the memory buffer whose contents will be used as the
  /// data in the given source file.
  ///
  /// \param DoNotFree If true, then the buffer will not be freed when the
  /// source manager is destroyed.
  void overrideFileContents(const FileEntry *SourceFile,
                            llvm::MemoryBuffer *Buffer, bool DoNotFree);
  void overrideFileContents(const FileEntry *SourceFile,
                            std::unique_ptr<llvm::MemoryBuffer> Buffer) {
    overrideFileContents(SourceFile, Buffer.release(), /*DoNotFree*/ false);
  }

  /// Override the given source file with another one.
  ///
  /// \param SourceFile the source file which will be overridden.
  ///
  /// \param NewFile the file whose contents will be used as the
  /// data instead of the contents of the given source file.
  void overrideFileContents(const FileEntry *SourceFile,
                            const FileEntry *NewFile);

  /// Returns true if the file contents have been overridden.
  bool isFileOverridden(const FileEntry *File) const {
    if (OverriddenFilesInfo) {
      if (OverriddenFilesInfo->OverriddenFilesWithBuffer.count(File))
        return true;
      if (OverriddenFilesInfo->OverriddenFiles.find(File) !=
          OverriddenFilesInfo->OverriddenFiles.end())
        return true;
    }
    return false;
  }

  /// Bypass the overridden contents of a file.  This creates a new FileEntry
  /// and initializes the content cache for it.  Returns nullptr if there is no
  /// such file in the filesystem.
  ///
  /// This should be called before parsing has begun.
  const FileEntry *bypassFileContentsOverride(const FileEntry &File);

  /// Specify that a file is transient.
  void setFileIsTransient(const FileEntry *SourceFile);

  /// Specify that all files that are read during this compilation are
  /// transient.
  void setAllFilesAreTransient(bool Transient) {
    FilesAreTransient = Transient;
  }

  //===--------------------------------------------------------------------===//
  // FileID manipulation methods.
  //===--------------------------------------------------------------------===//

  /// Return the buffer for the specified FileID.
  ///
  /// If there is an error opening this buffer the first time, this
  /// manufactures a temporary buffer and returns a non-empty error string.
  const llvm::MemoryBuffer *getBuffer(FileID FID, SourceLocation Loc,
                                      bool *Invalid = nullptr) const {
    bool MyInvalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &MyInvalid);
    if (MyInvalid || !Entry.isFile()) {
      if (Invalid)
        *Invalid = true;

      return getFakeBufferForRecovery();
    }

    return Entry.getFile().getContentCache()->getBuffer(Diag, getFileManager(),
                                                        Loc, Invalid);
  }

  const llvm::MemoryBuffer *getBuffer(FileID FID,
                                      bool *Invalid = nullptr) const {
    bool MyInvalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &MyInvalid);
    if (MyInvalid || !Entry.isFile()) {
      if (Invalid)
        *Invalid = true;

      return getFakeBufferForRecovery();
    }

    return Entry.getFile().getContentCache()->getBuffer(
        Diag, getFileManager(), SourceLocation(), Invalid);
  }

  /// Returns the FileEntry record for the provided FileID.
  const FileEntry *getFileEntryForID(FileID FID) const {
    bool MyInvalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &MyInvalid);
    if (MyInvalid || !Entry.isFile())
      return nullptr;

    const SrcMgr::ContentCache *Content = Entry.getFile().getContentCache();
    if (!Content)
      return nullptr;
    return Content->OrigEntry;
  }

  /// Returns the FileEntryRef for the provided FileID.
  Optional<FileEntryRef> getFileEntryRefForID(FileID FID) const {
    bool Invalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
    if (Invalid || !Entry.isFile())
      return None;

    const SrcMgr::ContentCache *Content = Entry.getFile().getContentCache();
    if (!Content || !Content->OrigEntry)
      return None;
    return FileEntryRef(Entry.getFile().getName(), *Content->OrigEntry);
  }

  /// Returns the FileEntry record for the provided SLocEntry.
  const FileEntry *getFileEntryForSLocEntry(const SrcMgr::SLocEntry &sloc) const
  {
    const SrcMgr::ContentCache *Content = sloc.getFile().getContentCache();
    if (!Content)
      return nullptr;
    return Content->OrigEntry;
  }

  /// Return a StringRef to the source buffer data for the
  /// specified FileID.
  ///
  /// \param FID The file ID whose contents will be returned.
  /// \param Invalid If non-NULL, will be set true if an error occurred.
  StringRef getBufferData(FileID FID, bool *Invalid = nullptr) const;

  /// Get the number of FileIDs (files and macros) that were created
  /// during preprocessing of \p FID, including it.
  unsigned getNumCreatedFIDsForFileID(FileID FID) const {
    bool Invalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
    if (Invalid || !Entry.isFile())
      return 0;

    return Entry.getFile().NumCreatedFIDs;
  }

  /// Set the number of FileIDs (files and macros) that were created
  /// during preprocessing of \p FID, including it.
  void setNumCreatedFIDsForFileID(FileID FID, unsigned NumFIDs,
                                  bool Force = false) const {
    bool Invalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
    if (Invalid || !Entry.isFile())
      return;

    assert((Force || Entry.getFile().NumCreatedFIDs == 0) && "Already set!");
    const_cast<SrcMgr::FileInfo &>(Entry.getFile()).NumCreatedFIDs = NumFIDs;
  }

  //===--------------------------------------------------------------------===//
  // SourceLocation manipulation methods.
  //===--------------------------------------------------------------------===//

  /// Return the FileID for a SourceLocation.
  ///
  /// This is a very hot method that is used for all SourceManager queries
  /// that start with a SourceLocation object.  It is responsible for finding
  /// the entry in SLocEntryTable which contains the specified location.
  ///
  FileID getFileID(SourceLocation SpellingLoc) const {
    unsigned SLocOffset = SpellingLoc.getOffset();

    // If our one-entry cache covers this offset, just return it.
    if (isOffsetInFileID(LastFileIDLookup, SLocOffset))
      return LastFileIDLookup;

    return getFileIDSlow(SLocOffset);
  }

  /// Return the filename of the file containing a SourceLocation.
  StringRef getFilename(SourceLocation SpellingLoc) const {
    if (const FileEntry *F = getFileEntryForID(getFileID(SpellingLoc)))
      return F->getName();
    return StringRef();
  }

  /// Return the source location corresponding to the first byte of
  /// the specified file.
  SourceLocation getLocForStartOfFile(FileID FID) const {
    bool Invalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
    if (Invalid || !Entry.isFile())
      return SourceLocation();

    unsigned FileOffset = Entry.getOffset();
    return SourceLocation::getFileLoc(FileOffset);
  }

  /// Return the source location corresponding to the last byte of the
  /// specified file.
  SourceLocation getLocForEndOfFile(FileID FID) const {
    bool Invalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
    if (Invalid || !Entry.isFile())
      return SourceLocation();

    unsigned FileOffset = Entry.getOffset();
    return SourceLocation::getFileLoc(FileOffset + getFileIDSize(FID));
  }

  /// Returns the include location if \p FID is a \#include'd file
  /// otherwise it returns an invalid location.
  SourceLocation getIncludeLoc(FileID FID) const {
    bool Invalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
    if (Invalid || !Entry.isFile())
      return SourceLocation();

    return Entry.getFile().getIncludeLoc();
  }

  // Returns the import location if the given source location is
  // located within a module, or an invalid location if the source location
  // is within the current translation unit.
  std::pair<SourceLocation, StringRef>
  getModuleImportLoc(SourceLocation Loc) const {
    FileID FID = getFileID(Loc);

    // Positive file IDs are in the current translation unit, and -1 is a
    // placeholder.
    if (FID.ID >= -1)
      return std::make_pair(SourceLocation(), "");

    return ExternalSLocEntries->getModuleImportLoc(FID.ID);
  }

  /// Given a SourceLocation object \p Loc, return the expansion
  /// location referenced by the ID.
  SourceLocation getExpansionLoc(SourceLocation Loc) const {
    // Handle the non-mapped case inline, defer to out of line code to handle
    // expansions.
    if (Loc.isFileID()) return Loc;
    return getExpansionLocSlowCase(Loc);
  }

  /// Given \p Loc, if it is a macro location return the expansion
  /// location or the spelling location, depending on if it comes from a
  /// macro argument or not.
  SourceLocation getFileLoc(SourceLocation Loc) const {
    if (Loc.isFileID()) return Loc;
    return getFileLocSlowCase(Loc);
  }

  /// Return the start/end of the expansion information for an
  /// expansion location.
  ///
  /// \pre \p Loc is required to be an expansion location.
  CharSourceRange getImmediateExpansionRange(SourceLocation Loc) const;

  /// Given a SourceLocation object, return the range of
  /// tokens covered by the expansion in the ultimate file.
  CharSourceRange getExpansionRange(SourceLocation Loc) const;

  /// Given a SourceRange object, return the range of
  /// tokens or characters covered by the expansion in the ultimate file.
  CharSourceRange getExpansionRange(SourceRange Range) const {
    SourceLocation Begin = getExpansionRange(Range.getBegin()).getBegin();
    CharSourceRange End = getExpansionRange(Range.getEnd());
    return CharSourceRange(SourceRange(Begin, End.getEnd()),
                           End.isTokenRange());
  }

  /// Given a CharSourceRange object, return the range of
  /// tokens or characters covered by the expansion in the ultimate file.
  CharSourceRange getExpansionRange(CharSourceRange Range) const {
    CharSourceRange Expansion = getExpansionRange(Range.getAsRange());
    if (Expansion.getEnd() == Range.getEnd())
      Expansion.setTokenRange(Range.isTokenRange());
    return Expansion;
  }

  /// Given a SourceLocation object, return the spelling
  /// location referenced by the ID.
  ///
  /// This is the place where the characters that make up the lexed token
  /// can be found.
  SourceLocation getSpellingLoc(SourceLocation Loc) const {
    // Handle the non-mapped case inline, defer to out of line code to handle
    // expansions.
    if (Loc.isFileID()) return Loc;
    return getSpellingLocSlowCase(Loc);
  }

  /// Given a SourceLocation object, return the spelling location
  /// referenced by the ID.
  ///
  /// This is the first level down towards the place where the characters
  /// that make up the lexed token can be found.  This should not generally
  /// be used by clients.
  SourceLocation getImmediateSpellingLoc(SourceLocation Loc) const;

  /// Form a SourceLocation from a FileID and Offset pair.
  SourceLocation getComposedLoc(FileID FID, unsigned Offset) const {
    bool Invalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
    if (Invalid)
      return SourceLocation();

    unsigned GlobalOffset = Entry.getOffset() + Offset;
    return Entry.isFile() ? SourceLocation::getFileLoc(GlobalOffset)
                          : SourceLocation::getMacroLoc(GlobalOffset);
  }

  /// Decompose the specified location into a raw FileID + Offset pair.
  ///
  /// The first element is the FileID, the second is the offset from the
  /// start of the buffer of the location.
  std::pair<FileID, unsigned> getDecomposedLoc(SourceLocation Loc) const {
    FileID FID = getFileID(Loc);
    bool Invalid = false;
    const SrcMgr::SLocEntry &E = getSLocEntry(FID, &Invalid);
    if (Invalid)
      return std::make_pair(FileID(), 0);
    return std::make_pair(FID, Loc.getOffset()-E.getOffset());
  }

  /// Decompose the specified location into a raw FileID + Offset pair.
  ///
  /// If the location is an expansion record, walk through it until we find
  /// the final location expanded.
  std::pair<FileID, unsigned>
  getDecomposedExpansionLoc(SourceLocation Loc) const {
    FileID FID = getFileID(Loc);
    bool Invalid = false;
    const SrcMgr::SLocEntry *E = &getSLocEntry(FID, &Invalid);
    if (Invalid)
      return std::make_pair(FileID(), 0);

    unsigned Offset = Loc.getOffset()-E->getOffset();
    if (Loc.isFileID())
      return std::make_pair(FID, Offset);

    return getDecomposedExpansionLocSlowCase(E);
  }

  /// Decompose the specified location into a raw FileID + Offset pair.
  ///
  /// If the location is an expansion record, walk through it until we find
  /// its spelling record.
  std::pair<FileID, unsigned>
  getDecomposedSpellingLoc(SourceLocation Loc) const {
    FileID FID = getFileID(Loc);
    bool Invalid = false;
    const SrcMgr::SLocEntry *E = &getSLocEntry(FID, &Invalid);
    if (Invalid)
      return std::make_pair(FileID(), 0);

    unsigned Offset = Loc.getOffset()-E->getOffset();
    if (Loc.isFileID())
      return std::make_pair(FID, Offset);
    return getDecomposedSpellingLocSlowCase(E, Offset);
  }

  /// Returns the "included/expanded in" decomposed location of the given
  /// FileID.
  std::pair<FileID, unsigned> getDecomposedIncludedLoc(FileID FID) const;

  /// Returns the offset from the start of the file that the
  /// specified SourceLocation represents.
  ///
  /// This is not very meaningful for a macro ID.
  unsigned getFileOffset(SourceLocation SpellingLoc) const {
    return getDecomposedLoc(SpellingLoc).second;
  }

  /// Tests whether the given source location represents a macro
  /// argument's expansion into the function-like macro definition.
  ///
  /// \param StartLoc If non-null and function returns true, it is set to the
  /// start location of the macro argument expansion.
  ///
  /// Such source locations only appear inside of the expansion
  /// locations representing where a particular function-like macro was
  /// expanded.
  bool isMacroArgExpansion(SourceLocation Loc,
                           SourceLocation *StartLoc = nullptr) const;

  /// Tests whether the given source location represents the expansion of
  /// a macro body.
  ///
  /// This is equivalent to testing whether the location is part of a macro
  /// expansion but not the expansion of an argument to a function-like macro.
  bool isMacroBodyExpansion(SourceLocation Loc) const;

  /// Returns true if the given MacroID location points at the beginning
  /// of the immediate macro expansion.
  ///
  /// \param MacroBegin If non-null and function returns true, it is set to the
  /// begin location of the immediate macro expansion.
  bool isAtStartOfImmediateMacroExpansion(SourceLocation Loc,
                                    SourceLocation *MacroBegin = nullptr) const;

  /// Returns true if the given MacroID location points at the character
  /// end of the immediate macro expansion.
  ///
  /// \param MacroEnd If non-null and function returns true, it is set to the
  /// character end location of the immediate macro expansion.
  bool
  isAtEndOfImmediateMacroExpansion(SourceLocation Loc,
                                   SourceLocation *MacroEnd = nullptr) const;

  /// Returns true if \p Loc is inside the [\p Start, +\p Length)
  /// chunk of the source location address space.
  ///
  /// If it's true and \p RelativeOffset is non-null, it will be set to the
  /// relative offset of \p Loc inside the chunk.
  bool isInSLocAddrSpace(SourceLocation Loc,
                         SourceLocation Start, unsigned Length,
                         unsigned *RelativeOffset = nullptr) const {
    assert(((Start.getOffset() < NextLocalOffset &&
               Start.getOffset()+Length <= NextLocalOffset) ||
            (Start.getOffset() >= CurrentLoadedOffset &&
                Start.getOffset()+Length < MaxLoadedOffset)) &&
           "Chunk is not valid SLoc address space");
    unsigned LocOffs = Loc.getOffset();
    unsigned BeginOffs = Start.getOffset();
    unsigned EndOffs = BeginOffs + Length;
    if (LocOffs >= BeginOffs && LocOffs < EndOffs) {
      if (RelativeOffset)
        *RelativeOffset = LocOffs - BeginOffs;
      return true;
    }

    return false;
  }

  /// Return true if both \p LHS and \p RHS are in the local source
  /// location address space or the loaded one.
  ///
  /// If it's true and \p RelativeOffset is non-null, it will be set to the
  /// offset of \p RHS relative to \p LHS.
  bool isInSameSLocAddrSpace(SourceLocation LHS, SourceLocation RHS,
                             int *RelativeOffset) const {
    unsigned LHSOffs = LHS.getOffset(), RHSOffs = RHS.getOffset();
    bool LHSLoaded = LHSOffs >= CurrentLoadedOffset;
    bool RHSLoaded = RHSOffs >= CurrentLoadedOffset;

    if (LHSLoaded == RHSLoaded) {
      if (RelativeOffset)
        *RelativeOffset = RHSOffs - LHSOffs;
      return true;
    }

    return false;
  }

  //===--------------------------------------------------------------------===//
  // Queries about the code at a SourceLocation.
  //===--------------------------------------------------------------------===//

  /// Return a pointer to the start of the specified location
  /// in the appropriate spelling MemoryBuffer.
  ///
  /// \param Invalid If non-NULL, will be set \c true if an error occurs.
  const char *getCharacterData(SourceLocation SL,
                               bool *Invalid = nullptr) const;

  /// Return the column # for the specified file position.
  ///
  /// This is significantly cheaper to compute than the line number.  This
  /// returns zero if the column number isn't known.  This may only be called
  /// on a file sloc, so you must choose a spelling or expansion location
  /// before calling this method.
  unsigned getColumnNumber(FileID FID, unsigned FilePos,
                           bool *Invalid = nullptr) const;
  unsigned getSpellingColumnNumber(SourceLocation Loc,
                                   bool *Invalid = nullptr) const;
  unsigned getExpansionColumnNumber(SourceLocation Loc,
                                    bool *Invalid = nullptr) const;
  unsigned getPresumedColumnNumber(SourceLocation Loc,
                                   bool *Invalid = nullptr) const;

  /// Given a SourceLocation, return the spelling line number
  /// for the position indicated.
  ///
  /// This requires building and caching a table of line offsets for the
  /// MemoryBuffer, so this is not cheap: use only when about to emit a
  /// diagnostic.
  unsigned getLineNumber(FileID FID, unsigned FilePos, bool *Invalid = nullptr) const;
  unsigned getSpellingLineNumber(SourceLocation Loc, bool *Invalid = nullptr) const;
  unsigned getExpansionLineNumber(SourceLocation Loc, bool *Invalid = nullptr) const;
  unsigned getPresumedLineNumber(SourceLocation Loc, bool *Invalid = nullptr) const;

  /// Return the filename or buffer identifier of the buffer the
  /// location is in.
  ///
  /// Note that this name does not respect \#line directives.  Use
  /// getPresumedLoc for normal clients.
  StringRef getBufferName(SourceLocation Loc, bool *Invalid = nullptr) const;

  /// Return the file characteristic of the specified source
  /// location, indicating whether this is a normal file, a system
  /// header, or an "implicit extern C" system header.
  ///
  /// This state can be modified with flags on GNU linemarker directives like:
  /// \code
  ///   # 4 "foo.h" 3
  /// \endcode
  /// which changes all source locations in the current file after that to be
  /// considered to be from a system header.
  SrcMgr::CharacteristicKind getFileCharacteristic(SourceLocation Loc) const;

  /// Returns the "presumed" location of a SourceLocation specifies.
  ///
  /// A "presumed location" can be modified by \#line or GNU line marker
  /// directives.  This provides a view on the data that a user should see
  /// in diagnostics, for example.
  ///
  /// Note that a presumed location is always given as the expansion point of
  /// an expansion location, not at the spelling location.
  ///
  /// \returns The presumed location of the specified SourceLocation. If the
  /// presumed location cannot be calculated (e.g., because \p Loc is invalid
  /// or the file containing \p Loc has changed on disk), returns an invalid
  /// presumed location.
  PresumedLoc getPresumedLoc(SourceLocation Loc,
                             bool UseLineDirectives = true) const;

  /// Returns whether the PresumedLoc for a given SourceLocation is
  /// in the main file.
  ///
  /// This computes the "presumed" location for a SourceLocation, then checks
  /// whether it came from a file other than the main file. This is different
  /// from isWrittenInMainFile() because it takes line marker directives into
  /// account.
  bool isInMainFile(SourceLocation Loc) const;

  /// Returns true if the spelling locations for both SourceLocations
  /// are part of the same file buffer.
  ///
  /// This check ignores line marker directives.
  bool isWrittenInSameFile(SourceLocation Loc1, SourceLocation Loc2) const {
    return getFileID(Loc1) == getFileID(Loc2);
  }

  /// Returns true if the spelling location for the given location
  /// is in the main file buffer.
  ///
  /// This check ignores line marker directives.
  bool isWrittenInMainFile(SourceLocation Loc) const {
    return getFileID(Loc) == getMainFileID();
  }

  /// Returns whether \p Loc is located in a <built-in> file.
  bool isWrittenInBuiltinFile(SourceLocation Loc) const {
    StringRef Filename(getPresumedLoc(Loc).getFilename());
    return Filename.equals("<built-in>");
  }

  /// Returns whether \p Loc is located in a <command line> file.
  bool isWrittenInCommandLineFile(SourceLocation Loc) const {
    StringRef Filename(getPresumedLoc(Loc).getFilename());
    return Filename.equals("<command line>");
  }

  /// Returns whether \p Loc is located in a <scratch space> file.
  bool isWrittenInScratchSpace(SourceLocation Loc) const {
    StringRef Filename(getPresumedLoc(Loc).getFilename());
    return Filename.equals("<scratch space>");
  }

  /// Returns if a SourceLocation is in a system header.
  bool isInSystemHeader(SourceLocation Loc) const {
    return isSystem(getFileCharacteristic(Loc));
  }

  /// Returns if a SourceLocation is in an "extern C" system header.
  bool isInExternCSystemHeader(SourceLocation Loc) const {
    return getFileCharacteristic(Loc) == SrcMgr::C_ExternCSystem;
  }

  /// Returns whether \p Loc is expanded from a macro in a system header.
  bool isInSystemMacro(SourceLocation loc) const {
    if (!loc.isMacroID())
      return false;

    // This happens when the macro is the result of a paste, in that case
    // its spelling is the scratch memory, so we take the parent context.
    // There can be several level of token pasting.
    if (isWrittenInScratchSpace(getSpellingLoc(loc))) {
      do {
        loc = getImmediateMacroCallerLoc(loc);
      } while (isWrittenInScratchSpace(getSpellingLoc(loc)));
      return isInSystemMacro(loc);
    }

    return isInSystemHeader(getSpellingLoc(loc));
  }

  /// The size of the SLocEntry that \p FID represents.
  unsigned getFileIDSize(FileID FID) const;

  /// Given a specific FileID, returns true if \p Loc is inside that
  /// FileID chunk and sets relative offset (offset of \p Loc from beginning
  /// of FileID) to \p relativeOffset.
  bool isInFileID(SourceLocation Loc, FileID FID,
                  unsigned *RelativeOffset = nullptr) const {
    unsigned Offs = Loc.getOffset();
    if (isOffsetInFileID(FID, Offs)) {
      if (RelativeOffset)
        *RelativeOffset = Offs - getSLocEntry(FID).getOffset();
      return true;
    }

    return false;
  }

  //===--------------------------------------------------------------------===//
  // Line Table Manipulation Routines
  //===--------------------------------------------------------------------===//

  /// Return the uniqued ID for the specified filename.
  unsigned getLineTableFilenameID(StringRef Str);

  /// Add a line note to the line table for the FileID and offset
  /// specified by Loc.
  ///
  /// If FilenameID is -1, it is considered to be unspecified.
  void AddLineNote(SourceLocation Loc, unsigned LineNo, int FilenameID,
                   bool IsFileEntry, bool IsFileExit,
                   SrcMgr::CharacteristicKind FileKind);

  /// Determine if the source manager has a line table.
  bool hasLineTable() const { return LineTable != nullptr; }

  /// Retrieve the stored line table.
  LineTableInfo &getLineTable();

  //===--------------------------------------------------------------------===//
  // Queries for performance analysis.
  //===--------------------------------------------------------------------===//

  /// Return the total amount of physical memory allocated by the
  /// ContentCache allocator.
  size_t getContentCacheSize() const {
    return ContentCacheAlloc.getTotalMemory();
  }

  struct MemoryBufferSizes {
    const size_t malloc_bytes;
    const size_t mmap_bytes;

    MemoryBufferSizes(size_t malloc_bytes, size_t mmap_bytes)
      : malloc_bytes(malloc_bytes), mmap_bytes(mmap_bytes) {}
  };

  /// Return the amount of memory used by memory buffers, breaking down
  /// by heap-backed versus mmap'ed memory.
  MemoryBufferSizes getMemoryBufferSizes() const;

  /// Return the amount of memory used for various side tables and
  /// data structures in the SourceManager.
  size_t getDataStructureSizes() const;

  //===--------------------------------------------------------------------===//
  // Other miscellaneous methods.
  //===--------------------------------------------------------------------===//

  /// Get the source location for the given file:line:col triplet.
  ///
  /// If the source file is included multiple times, the source location will
  /// be based upon the first inclusion.
  SourceLocation translateFileLineCol(const FileEntry *SourceFile,
                                      unsigned Line, unsigned Col) const;

  /// Get the FileID for the given file.
  ///
  /// If the source file is included multiple times, the FileID will be the
  /// first inclusion.
  FileID translateFile(const FileEntry *SourceFile) const;

  /// Get the source location in \p FID for the given line:col.
  /// Returns null location if \p FID is not a file SLocEntry.
  SourceLocation translateLineCol(FileID FID,
                                  unsigned Line, unsigned Col) const;

  /// If \p Loc points inside a function macro argument, the returned
  /// location will be the macro location in which the argument was expanded.
  /// If a macro argument is used multiple times, the expanded location will
  /// be at the first expansion of the argument.
  /// e.g.
  ///   MY_MACRO(foo);
  ///             ^
  /// Passing a file location pointing at 'foo', will yield a macro location
  /// where 'foo' was expanded into.
  SourceLocation getMacroArgExpandedLocation(SourceLocation Loc) const;

  /// Determines the order of 2 source locations in the translation unit.
  ///
  /// \returns true if LHS source location comes before RHS, false otherwise.
  bool isBeforeInTranslationUnit(SourceLocation LHS, SourceLocation RHS) const;

  /// Determines whether the two decomposed source location is in the
  ///        same translation unit. As a byproduct, it also calculates the order
  ///        of the source locations in case they are in the same TU.
  ///
  /// \returns Pair of bools the first component is true if the two locations
  ///          are in the same TU. The second bool is true if the first is true
  ///          and \p LOffs is before \p ROffs.
  std::pair<bool, bool>
  isInTheSameTranslationUnit(std::pair<FileID, unsigned> &LOffs,
                             std::pair<FileID, unsigned> &ROffs) const;

  /// Determines the order of 2 source locations in the "source location
  /// address space".
  bool isBeforeInSLocAddrSpace(SourceLocation LHS, SourceLocation RHS) const {
    return isBeforeInSLocAddrSpace(LHS, RHS.getOffset());
  }

  /// Determines the order of a source location and a source location
  /// offset in the "source location address space".
  ///
  /// Note that we always consider source locations loaded from
  bool isBeforeInSLocAddrSpace(SourceLocation LHS, unsigned RHS) const {
    unsigned LHSOffset = LHS.getOffset();
    bool LHSLoaded = LHSOffset >= CurrentLoadedOffset;
    bool RHSLoaded = RHS >= CurrentLoadedOffset;
    if (LHSLoaded == RHSLoaded)
      return LHSOffset < RHS;

    return LHSLoaded;
  }

  /// Return true if the Point is within Start and End.
  bool isPointWithin(SourceLocation Location, SourceLocation Start,
                     SourceLocation End) const {
    return Location == Start || Location == End ||
           (isBeforeInTranslationUnit(Start, Location) &&
            isBeforeInTranslationUnit(Location, End));
  }

  // Iterators over FileInfos.
  using fileinfo_iterator =
      llvm::DenseMap<const FileEntry*, SrcMgr::ContentCache*>::const_iterator;

  fileinfo_iterator fileinfo_begin() const { return FileInfos.begin(); }
  fileinfo_iterator fileinfo_end() const { return FileInfos.end(); }
  bool hasFileInfo(const FileEntry *File) const {
    return FileInfos.find(File) != FileInfos.end();
  }

  /// Print statistics to stderr.
  void PrintStats() const;

  void dump() const;

  /// Get the number of local SLocEntries we have.
  unsigned local_sloc_entry_size() const { return LocalSLocEntryTable.size(); }

  /// Get a local SLocEntry. This is exposed for indexing.
  const SrcMgr::SLocEntry &getLocalSLocEntry(unsigned Index,
                                             bool *Invalid = nullptr) const {
    assert(Index < LocalSLocEntryTable.size() && "Invalid index");
    return LocalSLocEntryTable[Index];
  }

  /// Get the number of loaded SLocEntries we have.
  unsigned loaded_sloc_entry_size() const { return LoadedSLocEntryTable.size();}

  /// Get a loaded SLocEntry. This is exposed for indexing.
  const SrcMgr::SLocEntry &getLoadedSLocEntry(unsigned Index,
                                              bool *Invalid = nullptr) const {
    assert(Index < LoadedSLocEntryTable.size() && "Invalid index");
    if (SLocEntryLoaded[Index])
      return LoadedSLocEntryTable[Index];
    return loadSLocEntry(Index, Invalid);
  }

  const SrcMgr::SLocEntry &getSLocEntry(FileID FID,
                                        bool *Invalid = nullptr) const {
    if (FID.ID == 0 || FID.ID == -1) {
      if (Invalid) *Invalid = true;
      return LocalSLocEntryTable[0];
    }
    return getSLocEntryByID(FID.ID, Invalid);
  }

  unsigned getNextLocalOffset() const { return NextLocalOffset; }

  void setExternalSLocEntrySource(ExternalSLocEntrySource *Source) {
    assert(LoadedSLocEntryTable.empty() &&
           "Invalidating existing loaded entries");
    ExternalSLocEntries = Source;
  }

  /// Allocate a number of loaded SLocEntries, which will be actually
  /// loaded on demand from the external source.
  ///
  /// NumSLocEntries will be allocated, which occupy a total of TotalSize space
  /// in the global source view. The lowest ID and the base offset of the
  /// entries will be returned.
  std::pair<int, unsigned>
  AllocateLoadedSLocEntries(unsigned NumSLocEntries, unsigned TotalSize);

  /// Returns true if \p Loc came from a PCH/Module.
  bool isLoadedSourceLocation(SourceLocation Loc) const {
    return Loc.getOffset() >= CurrentLoadedOffset;
  }

  /// Returns true if \p Loc did not come from a PCH/Module.
  bool isLocalSourceLocation(SourceLocation Loc) const {
    return Loc.getOffset() < NextLocalOffset;
  }

  /// Returns true if \p FID came from a PCH/Module.
  bool isLoadedFileID(FileID FID) const {
    assert(FID.ID != -1 && "Using FileID sentinel value");
    return FID.ID < 0;
  }

  /// Returns true if \p FID did not come from a PCH/Module.
  bool isLocalFileID(FileID FID) const {
    return !isLoadedFileID(FID);
  }

  /// Gets the location of the immediate macro caller, one level up the stack
  /// toward the initial macro typed into the source.
  SourceLocation getImmediateMacroCallerLoc(SourceLocation Loc) const {
    if (!Loc.isMacroID()) return Loc;

    // When we have the location of (part of) an expanded parameter, its
    // spelling location points to the argument as expanded in the macro call,
    // and therefore is used to locate the macro caller.
    if (isMacroArgExpansion(Loc))
      return getImmediateSpellingLoc(Loc);

    // Otherwise, the caller of the macro is located where this macro is
    // expanded (while the spelling is part of the macro definition).
    return getImmediateExpansionRange(Loc).getBegin();
  }

  /// \return Location of the top-level macro caller.
  SourceLocation getTopMacroCallerLoc(SourceLocation Loc) const;

private:
  friend class ASTReader;
  friend class ASTWriter;

  llvm::MemoryBuffer *getFakeBufferForRecovery() const;
  const SrcMgr::ContentCache *getFakeContentCacheForRecovery() const;

  const SrcMgr::SLocEntry &loadSLocEntry(unsigned Index, bool *Invalid) const;

  /// Get the entry with the given unwrapped FileID.
  const SrcMgr::SLocEntry &getSLocEntryByID(int ID,
                                            bool *Invalid = nullptr) const {
    assert(ID != -1 && "Using FileID sentinel value");
    if (ID < 0)
      return getLoadedSLocEntryByID(ID, Invalid);
    return getLocalSLocEntry(static_cast<unsigned>(ID), Invalid);
  }

  const SrcMgr::SLocEntry &
  getLoadedSLocEntryByID(int ID, bool *Invalid = nullptr) const {
    return getLoadedSLocEntry(static_cast<unsigned>(-ID - 2), Invalid);
  }

  /// Implements the common elements of storing an expansion info struct into
  /// the SLocEntry table and producing a source location that refers to it.
  SourceLocation createExpansionLocImpl(const SrcMgr::ExpansionInfo &Expansion,
                                        unsigned TokLength,
                                        int LoadedID = 0,
                                        unsigned LoadedOffset = 0);

  /// Return true if the specified FileID contains the
  /// specified SourceLocation offset.  This is a very hot method.
  inline bool isOffsetInFileID(FileID FID, unsigned SLocOffset) const {
    const SrcMgr::SLocEntry &Entry = getSLocEntry(FID);
    // If the entry is after the offset, it can't contain it.
    if (SLocOffset < Entry.getOffset()) return false;

    // If this is the very last entry then it does.
    if (FID.ID == -2)
      return true;

    // If it is the last local entry, then it does if the location is local.
    if (FID.ID+1 == static_cast<int>(LocalSLocEntryTable.size()))
      return SLocOffset < NextLocalOffset;

    // Otherwise, the entry after it has to not include it. This works for both
    // local and loaded entries.
    return SLocOffset < getSLocEntryByID(FID.ID+1).getOffset();
  }

  /// Returns the previous in-order FileID or an invalid FileID if there
  /// is no previous one.
  FileID getPreviousFileID(FileID FID) const;

  /// Returns the next in-order FileID or an invalid FileID if there is
  /// no next one.
  FileID getNextFileID(FileID FID) const;

  /// Create a new fileID for the specified ContentCache and
  /// include position.
  ///
  /// This works regardless of whether the ContentCache corresponds to a
  /// file or some other input source.
  FileID createFileID(const SrcMgr::ContentCache *File, StringRef Filename,
                      SourceLocation IncludePos,
                      SrcMgr::CharacteristicKind DirCharacter, int LoadedID,
                      unsigned LoadedOffset);

  const SrcMgr::ContentCache *
    getOrCreateContentCache(const FileEntry *SourceFile,
                            bool isSystemFile = false);

  /// Create a new ContentCache for the specified  memory buffer.
  const SrcMgr::ContentCache *
  createMemBufferContentCache(const llvm::MemoryBuffer *Buf, bool DoNotFree);

  FileID getFileIDSlow(unsigned SLocOffset) const;
  FileID getFileIDLocal(unsigned SLocOffset) const;
  FileID getFileIDLoaded(unsigned SLocOffset) const;

  SourceLocation getExpansionLocSlowCase(SourceLocation Loc) const;
  SourceLocation getSpellingLocSlowCase(SourceLocation Loc) const;
  SourceLocation getFileLocSlowCase(SourceLocation Loc) const;

  std::pair<FileID, unsigned>
  getDecomposedExpansionLocSlowCase(const SrcMgr::SLocEntry *E) const;
  std::pair<FileID, unsigned>
  getDecomposedSpellingLocSlowCase(const SrcMgr::SLocEntry *E,
                                   unsigned Offset) const;
  void computeMacroArgsCache(MacroArgsMap &MacroArgsCache, FileID FID) const;
  void associateFileChunkWithMacroArgExp(MacroArgsMap &MacroArgsCache,
                                         FileID FID,
                                         SourceLocation SpellLoc,
                                         SourceLocation ExpansionLoc,
                                         unsigned ExpansionLength) const;
};

/// Comparison function object.
template<typename T>
class BeforeThanCompare;

/// Compare two source locations.
template<>
class BeforeThanCompare<SourceLocation> {
  SourceManager &SM;

public:
  explicit BeforeThanCompare(SourceManager &SM) : SM(SM) {}

  bool operator()(SourceLocation LHS, SourceLocation RHS) const {
    return SM.isBeforeInTranslationUnit(LHS, RHS);
  }
};

/// Compare two non-overlapping source ranges.
template<>
class BeforeThanCompare<SourceRange> {
  SourceManager &SM;

public:
  explicit BeforeThanCompare(SourceManager &SM) : SM(SM) {}

  bool operator()(SourceRange LHS, SourceRange RHS) const {
    return SM.isBeforeInTranslationUnit(LHS.getBegin(), RHS.getBegin());
  }
};

/// SourceManager and necessary depdencies (e.g. VFS, FileManager) for a single
/// in-memorty file.
class SourceManagerForFile {
public:
  /// Creates SourceManager and necessary depdencies (e.g. VFS, FileManager).
  /// The main file in the SourceManager will be \p FileName with \p Content.
  SourceManagerForFile(StringRef FileName, StringRef Content);

  SourceManager &get() {
    assert(SourceMgr);
    return *SourceMgr;
  }

private:
  // The order of these fields are important - they should be in the same order
  // as they are created in `createSourceManagerForFile` so that they can be
  // deleted in the reverse order as they are created.
  std::unique_ptr<FileManager> FileMgr;
  std::unique_ptr<DiagnosticsEngine> Diagnostics;
  std::unique_ptr<SourceManager> SourceMgr;
};

} // namespace clang

#endif // LLVM_CLANG_BASIC_SOURCEMANAGER_H
# 1917 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManager.h"
# 14 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp" 2
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/Diagnostic.h"
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 15 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/FileManager.h"
#endif /* expanded by -frewrite-includes */
# 15 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 16 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/LLVM.h"
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 17 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/SourceLocation.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 18 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/SourceManagerInternals.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 1 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h" 1
//===- SourceManagerInternals.h - SourceManager Internals -------*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
/// \file
/// Defines implementation details of the clang::SourceManager class.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_CLANG_BASIC_SOURCEMANAGERINTERNALS_H
#define LLVM_CLANG_BASIC_SOURCEMANAGERINTERNALS_H

#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/SourceLocation.h"
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
#if 0 /* expanded by -frewrite-includes */
#include "clang/Basic/SourceManager.h"
#endif /* expanded by -frewrite-includes */
# 18 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringMap.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Allocator.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 23 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <map>
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 25 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"

namespace clang {

//===----------------------------------------------------------------------===//
// Line Table Implementation
//===----------------------------------------------------------------------===//

struct LineEntry {
  /// The offset in this file that the line entry occurs at.
  unsigned FileOffset;

  /// The presumed line number of this line entry: \#line 4.
  unsigned LineNo;

  /// The ID of the filename identified by this line entry:
  /// \#line 4 "foo.c".  This is -1 if not specified.
  int FilenameID;

  /// Set the 0 if no flags, 1 if a system header,
  SrcMgr::CharacteristicKind FileKind;

  /// The offset of the virtual include stack location,
  /// which is manipulated by GNU linemarker directives.
  ///
  /// If this is 0 then there is no virtual \#includer.
  unsigned IncludeOffset;

  static LineEntry get(unsigned Offs, unsigned Line, int Filename,
                       SrcMgr::CharacteristicKind FileKind,
                       unsigned IncludeOffset) {
    LineEntry E;
    E.FileOffset = Offs;
    E.LineNo = Line;
    E.FilenameID = Filename;
    E.FileKind = FileKind;
    E.IncludeOffset = IncludeOffset;
    return E;
  }
};

// needed for FindNearestLineEntry (upper_bound of LineEntry)
inline bool operator<(const LineEntry &lhs, const LineEntry &rhs) {
  // FIXME: should check the other field?
  return lhs.FileOffset < rhs.FileOffset;
}

inline bool operator<(const LineEntry &E, unsigned Offset) {
  return E.FileOffset < Offset;
}

inline bool operator<(unsigned Offset, const LineEntry &E) {
  return Offset < E.FileOffset;
}

/// Used to hold and unique data used to represent \#line information.
class LineTableInfo {
  /// Map used to assign unique IDs to filenames in \#line directives.
  ///
  /// This allows us to unique the filenames that
  /// frequently reoccur and reference them with indices.  FilenameIDs holds
  /// the mapping from string -> ID, and FilenamesByID holds the mapping of ID
  /// to string.
  llvm::StringMap<unsigned, llvm::BumpPtrAllocator> FilenameIDs;
  std::vector<llvm::StringMapEntry<unsigned>*> FilenamesByID;

  /// Map from FileIDs to a list of line entries (sorted by the offset
  /// at which they occur in the file).
  std::map<FileID, std::vector<LineEntry>> LineEntries;

public:
  void clear() {
    FilenameIDs.clear();
    FilenamesByID.clear();
    LineEntries.clear();
  }

  unsigned getLineTableFilenameID(StringRef Str);

  StringRef getFilename(unsigned ID) const {
    assert(ID < FilenamesByID.size() && "Invalid FilenameID");
    return FilenamesByID[ID]->getKey();
  }

  unsigned getNumFilenames() const { return FilenamesByID.size(); }

  void AddLineNote(FileID FID, unsigned Offset,
                   unsigned LineNo, int FilenameID,
                   unsigned EntryExit, SrcMgr::CharacteristicKind FileKind);


  /// Find the line entry nearest to FID that is before it.
  ///
  /// If there is no line entry before \p Offset in \p FID, returns null.
  const LineEntry *FindNearestLineEntry(FileID FID, unsigned Offset);

  // Low-level access
  using iterator = std::map<FileID, std::vector<LineEntry>>::iterator;

  iterator begin() { return LineEntries.begin(); }
  iterator end() { return LineEntries.end(); }

  /// Add a new line entry that has already been encoded into
  /// the internal representation of the line table.
  void AddEntry(FileID FID, const std::vector<LineEntry> &Entries);
};

} // namespace clang

#endif // LLVM_CLANG_BASIC_SOURCEMANAGERINTERNALS_H
# 134 "/Users/vsk/src/llvm-project-master/clang/include/clang/Basic/SourceManagerInternals.h"
# 19 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/DenseMap.h"
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 20 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/Optional.h"
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 21 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/None.h"
#endif /* expanded by -frewrite-includes */
# 21 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 22 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/STLExtras.h"
#endif /* expanded by -frewrite-includes */
# 22 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 23 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/SmallVector.h"
#endif /* expanded by -frewrite-includes */
# 23 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 24 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringSwitch.h"
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 25 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/ADT/StringRef.h"
#endif /* expanded by -frewrite-includes */
# 25 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 26 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Allocator.h"
#endif /* expanded by -frewrite-includes */
# 26 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 27 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Capacity.h"
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 1 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Capacity.h" 1
//===--- Capacity.h - Generic computation of ADT memory use -----*- C++ -*-===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//
//
// This file defines the capacity function that computes the amount of
// memory used by an ADT.
//
//===----------------------------------------------------------------------===//

#ifndef LLVM_SUPPORT_CAPACITY_H
#define LLVM_SUPPORT_CAPACITY_H

#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 17 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Capacity.h"
# 18 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Capacity.h"

namespace llvm {

template <typename T>
static inline size_t capacity_in_bytes(const T &x) {
  // This default definition of capacity should work for things like std::vector
  // and friends.  More specialized versions will work for others.
  return x.capacity() * sizeof(typename T::value_type);
}

} // end namespace llvm

#endif
# 31 "/Users/vsk/src/llvm-project-master/llvm/include/llvm/Support/Capacity.h"

# 28 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp" 2
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Compiler.h"
#endif /* expanded by -frewrite-includes */
# 28 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 29 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/ErrorHandling.h"
#endif /* expanded by -frewrite-includes */
# 29 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 30 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/FileSystem.h"
#endif /* expanded by -frewrite-includes */
# 30 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 31 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MathExtras.h"
#endif /* expanded by -frewrite-includes */
# 31 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 32 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/MemoryBuffer.h"
#endif /* expanded by -frewrite-includes */
# 32 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 33 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/Path.h"
#endif /* expanded by -frewrite-includes */
# 33 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 34 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include "llvm/Support/raw_ostream.h"
#endif /* expanded by -frewrite-includes */
# 34 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 35 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 35 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 36 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 36 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 1 3
// -*- C++ -*-
//===-------------------------- cassert -----------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

/*
    cassert synopsis

Macros:

    assert

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#include <assert.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 1 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)assert.h	8.2 (Berkeley) 1/21/94
 * $FreeBSD: src/include/assert.h,v 1.4 2002/03/23 17:24:53 imp Exp $
 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 43 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 44 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3 4
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3 4
# 45 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 2 3 4
#endif /* __cplusplus */
# 46 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

/*
 * Unlike other ANSI header files, <assert.h> may usefully be included
 * multiple times, with and without NDEBUG defined.
 */

#undef assert
#undef __assert

#ifdef NDEBUG
#define	assert(e)	((void)0)
#else
# 58 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef __GNUC__

__BEGIN_DECLS
#ifndef __cplusplus
void abort(void) __dead2;
#endif /* !__cplusplus */
# 65 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
int  printf(const char * __restrict, ...);
__END_DECLS

#define assert(e)  \
    ((void) ((e) ? ((void)0) : __assert (#e, __FILE__, __LINE__)))
#define __assert(e, file, line) \
    ((void)printf ("%s:%u: failed assertion `%s'\n", file, line, e), abort())

#else /* __GNUC__ */
# 74 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

__BEGIN_DECLS
void __assert_rtn(const char *, const char *, int, const char *) __dead2 __disable_tail_calls;
#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 78 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
void __eprintf(const char *, const char *, unsigned, const char *) __dead2;
#endif
# 80 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
__END_DECLS

#if 0 /* disabled by -frewrite-includes */
#if defined(__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__) && ((__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) < 1070)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 83 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define __assert(e, file, line) \
    __eprintf ("%s:%u: failed assertion `%s'\n", file, line, e)
#else
# 86 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
/* 8462256: modified __assert_rtn() replaces deprecated __eprintf() */
#define __assert(e, file, line) \
    __assert_rtn ((const char *)-1L, file, line, e)
#endif
# 90 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#if 0 /* disabled by -frewrite-includes */
#if __DARWIN_UNIX03
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 92 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define	assert(e) \
    (__builtin_expect(!(e), 0) ? __assert_rtn(__func__, __FILE__, __LINE__, #e) : (void)0)
#else /* !__DARWIN_UNIX03 */
# 95 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define assert(e)  \
    (__builtin_expect(!(e), 0) ? __assert (#e, __FILE__, __LINE__) : (void)0)
#endif /* __DARWIN_UNIX03 */
# 98 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* __GNUC__ */
# 100 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* NDEBUG */
# 101 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#ifndef _ASSERT_H_
#define _ASSERT_H_

#ifndef __cplusplus
#if 0 /* disabled by -frewrite-includes */
#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 107 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#define static_assert _Static_assert
#endif /* __STDC_VERSION__ */
# 109 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
#endif /* !__cplusplus */
# 110 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4

#endif /* _ASSERT_H_ */
# 112 "/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/assert.h" 3 4
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 2 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 24 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
#endif
# 25 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/cassert" 3
# 37 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp" 2
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 37 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 38 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 38 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 39 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 39 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 40 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 40 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 41 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 41 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 42 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
#if 0 /* expanded by -frewrite-includes */
#include <vector>
#endif /* expanded by -frewrite-includes */
# 42 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 43 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"

using namespace clang;
using namespace SrcMgr;
using llvm::MemoryBuffer;

//===----------------------------------------------------------------------===//
// SourceManager Helper Classes
//===----------------------------------------------------------------------===//

ContentCache::~ContentCache() {
  if (shouldFreeBuffer())
    delete Buffer.getPointer();
}

/// getSizeBytesMapped - Returns the number of bytes actually mapped for this
/// ContentCache. This can be 0 if the MemBuffer was not actually expanded.
unsigned ContentCache::getSizeBytesMapped() const {
  return Buffer.getPointer() ? Buffer.getPointer()->getBufferSize() : 0;
}

/// Returns the kind of memory used to back the memory buffer for
/// this content cache.  This is used for performance analysis.
llvm::MemoryBuffer::BufferKind ContentCache::getMemoryBufferKind() const {
  assert(Buffer.getPointer());

  // Should be unreachable, but keep for sanity.
  if (!Buffer.getPointer())
    return llvm::MemoryBuffer::MemoryBuffer_Malloc;

  const llvm::MemoryBuffer *buf = Buffer.getPointer();
  return buf->getBufferKind();
}

/// getSize - Returns the size of the content encapsulated by this ContentCache.
///  This can be the size of the source file or the size of an arbitrary
///  scratch buffer.  If the ContentCache encapsulates a source file, that
///  file is not lazily brought in from disk to satisfy this query.
unsigned ContentCache::getSize() const {
  return Buffer.getPointer() ? (unsigned) Buffer.getPointer()->getBufferSize()
                             : (unsigned) ContentsEntry->getSize();
}

void ContentCache::replaceBuffer(const llvm::MemoryBuffer *B, bool DoNotFree) {
  if (B && B == Buffer.getPointer()) {
    assert(0 && "Replacing with the same buffer");
    Buffer.setInt(DoNotFree? DoNotFreeFlag : 0);
    return;
  }

  if (shouldFreeBuffer())
    delete Buffer.getPointer();
  Buffer.setPointer(B);
  Buffer.setInt((B && DoNotFree) ? DoNotFreeFlag : 0);
}

const char *ContentCache::getInvalidBOM(StringRef BufStr) {
  // If the buffer is valid, check to see if it has a UTF Byte Order Mark
  // (BOM).  We only support UTF-8 with and without a BOM right now.  See
  // http://en.wikipedia.org/wiki/Byte_order_mark for more information.
  const char *InvalidBOM =
      llvm::StringSwitch<const char *>(BufStr)
          .StartsWith(llvm::StringLiteral::withInnerNUL("\x00\x00\xFE\xFF"),
                      "UTF-32 (BE)")
          .StartsWith(llvm::StringLiteral::withInnerNUL("\xFF\xFE\x00\x00"),
                      "UTF-32 (LE)")
          .StartsWith("\xFE\xFF", "UTF-16 (BE)")
          .StartsWith("\xFF\xFE", "UTF-16 (LE)")
          .StartsWith("\x2B\x2F\x76", "UTF-7")
          .StartsWith("\xF7\x64\x4C", "UTF-1")
          .StartsWith("\xDD\x73\x66\x73", "UTF-EBCDIC")
          .StartsWith("\x0E\xFE\xFF", "SCSU")
          .StartsWith("\xFB\xEE\x28", "BOCU-1")
          .StartsWith("\x84\x31\x95\x33", "GB-18030")
          .Default(nullptr);

  return InvalidBOM;
}

const llvm::MemoryBuffer *ContentCache::getBuffer(DiagnosticsEngine &Diag,
                                                  FileManager &FM,
                                                  SourceLocation Loc,
                                                  bool *Invalid) const {
  // Lazily create the Buffer for ContentCaches that wrap files.  If we already
  // computed it, just return what we have.
  if (Buffer.getPointer() || !ContentsEntry) {
    if (Invalid)
      *Invalid = isBufferInvalid();

    return Buffer.getPointer();
  }

  // Check that the file's size fits in an 'unsigned' (with room for a
  // past-the-end value). This is deeply regrettable, but various parts of
  // Clang (including elsewhere in this file!) use 'unsigned' to represent file
  // offsets, line numbers, string literal lengths, and so on, and fail
  // miserably on large source files.
  if ((uint64_t)ContentsEntry->getSize() >=
      std::numeric_limits<unsigned>::max()) {
    // We can't make a memory buffer of the required size, so just make a small
    // one. We should never hit a situation where we've already parsed to a
    // later offset of the file, so it shouldn't matter that the buffer is
    // smaller than the file.
    Buffer.setPointer(
        llvm::MemoryBuffer::getMemBuffer("", ContentsEntry->getName())
            .release());
    if (Diag.isDiagnosticInFlight())
      Diag.SetDelayedDiagnostic(diag::err_file_too_large,
                                ContentsEntry->getName());
    else
      Diag.Report(Loc, diag::err_file_too_large)
        << ContentsEntry->getName();

    Buffer.setInt(Buffer.getInt() | InvalidFlag);
    if (Invalid) *Invalid = true;
    return Buffer.getPointer();
  }

  auto BufferOrError = FM.getBufferForFile(ContentsEntry, IsFileVolatile);

  // If we were unable to open the file, then we are in an inconsistent
  // situation where the content cache referenced a file which no longer
  // exists. Most likely, we were using a stat cache with an invalid entry but
  // the file could also have been removed during processing. Since we can't
  // really deal with this situation, just create an empty buffer.
  //
  // FIXME: This is definitely not ideal, but our immediate clients can't
  // currently handle returning a null entry here. Ideally we should detect
  // that we are in an inconsistent situation and error out as quickly as
  // possible.
  if (!BufferOrError) {
    StringRef FillStr("<<<MISSING SOURCE FILE>>>\n");
    auto BackupBuffer = llvm::WritableMemoryBuffer::getNewUninitMemBuffer(
        ContentsEntry->getSize(), "<invalid>");
    char *Ptr = BackupBuffer->getBufferStart();
    for (unsigned i = 0, e = ContentsEntry->getSize(); i != e; ++i)
      Ptr[i] = FillStr[i % FillStr.size()];
    Buffer.setPointer(BackupBuffer.release());

    if (Diag.isDiagnosticInFlight())
      Diag.SetDelayedDiagnostic(diag::err_cannot_open_file,
                                ContentsEntry->getName(),
                                BufferOrError.getError().message());
    else
      Diag.Report(Loc, diag::err_cannot_open_file)
          << ContentsEntry->getName() << BufferOrError.getError().message();

    Buffer.setInt(Buffer.getInt() | InvalidFlag);

    if (Invalid) *Invalid = true;
    return Buffer.getPointer();
  }

  Buffer.setPointer(BufferOrError->release());

  // Check that the file's size is the same as in the file entry (which may
  // have come from a stat cache).
  if (getRawBuffer()->getBufferSize() != (size_t)ContentsEntry->getSize()) {
    if (Diag.isDiagnosticInFlight())
      Diag.SetDelayedDiagnostic(diag::err_file_modified,
                                ContentsEntry->getName());
    else
      Diag.Report(Loc, diag::err_file_modified)
        << ContentsEntry->getName();

    Buffer.setInt(Buffer.getInt() | InvalidFlag);
    if (Invalid) *Invalid = true;
    return Buffer.getPointer();
  }

  // If the buffer is valid, check to see if it has a UTF Byte Order Mark
  // (BOM).  We only support UTF-8 with and without a BOM right now.  See
  // http://en.wikipedia.org/wiki/Byte_order_mark for more information.
  StringRef BufStr = Buffer.getPointer()->getBuffer();
  const char *InvalidBOM = getInvalidBOM(BufStr);

  if (InvalidBOM) {
    Diag.Report(Loc, diag::err_unsupported_bom)
      << InvalidBOM << ContentsEntry->getName();
    Buffer.setInt(Buffer.getInt() | InvalidFlag);
  }

  if (Invalid)
    *Invalid = isBufferInvalid();

  return Buffer.getPointer();
}

unsigned LineTableInfo::getLineTableFilenameID(StringRef Name) {
  auto IterBool = FilenameIDs.try_emplace(Name, FilenamesByID.size());
  if (IterBool.second)
    FilenamesByID.push_back(&*IterBool.first);
  return IterBool.first->second;
}

/// Add a line note to the line table that indicates that there is a \#line or
/// GNU line marker at the specified FID/Offset location which changes the
/// presumed location to LineNo/FilenameID. If EntryExit is 0, then this doesn't
/// change the presumed \#include stack.  If it is 1, this is a file entry, if
/// it is 2 then this is a file exit. FileKind specifies whether this is a
/// system header or extern C system header.
void LineTableInfo::AddLineNote(FileID FID, unsigned Offset, unsigned LineNo,
                                int FilenameID, unsigned EntryExit,
                                SrcMgr::CharacteristicKind FileKind) {
  std::vector<LineEntry> &Entries = LineEntries[FID];

  // An unspecified FilenameID means use the last filename if available, or the
  // main source file otherwise.
  if (FilenameID == -1 && !Entries.empty())
    FilenameID = Entries.back().FilenameID;

  assert((Entries.empty() || Entries.back().FileOffset < Offset) &&
         "Adding line entries out of order!");

  unsigned IncludeOffset = 0;
  if (EntryExit == 0) {  // No #include stack change.
    IncludeOffset = Entries.empty() ? 0 : Entries.back().IncludeOffset;
  } else if (EntryExit == 1) {
    IncludeOffset = Offset-1;
  } else if (EntryExit == 2) {
    assert(!Entries.empty() && Entries.back().IncludeOffset &&
       "PPDirectives should have caught case when popping empty include stack");

    // Get the include loc of the last entries' include loc as our include loc.
    IncludeOffset = 0;
    if (const LineEntry *PrevEntry =
          FindNearestLineEntry(FID, Entries.back().IncludeOffset))
      IncludeOffset = PrevEntry->IncludeOffset;
  }

  Entries.push_back(LineEntry::get(Offset, LineNo, FilenameID, FileKind,
                                   IncludeOffset));
}

/// FindNearestLineEntry - Find the line entry nearest to FID that is before
/// it.  If there is no line entry before Offset in FID, return null.
const LineEntry *LineTableInfo::FindNearestLineEntry(FileID FID,
                                                     unsigned Offset) {
  const std::vector<LineEntry> &Entries = LineEntries[FID];
  assert(!Entries.empty() && "No #line entries for this FID after all!");

  // It is very common for the query to be after the last #line, check this
  // first.
  if (Entries.back().FileOffset <= Offset)
    return &Entries.back();

  // Do a binary search to find the maximal element that is still before Offset.
  std::vector<LineEntry>::const_iterator I = llvm::upper_bound(Entries, Offset);
  if (I == Entries.begin())
    return nullptr;
  return &*--I;
}

/// Add a new line entry that has already been encoded into
/// the internal representation of the line table.
void LineTableInfo::AddEntry(FileID FID,
                             const std::vector<LineEntry> &Entries) {
  LineEntries[FID] = Entries;
}

/// getLineTableFilenameID - Return the uniqued ID for the specified filename.
unsigned SourceManager::getLineTableFilenameID(StringRef Name) {
  return getLineTable().getLineTableFilenameID(Name);
}

/// AddLineNote - Add a line note to the line table for the FileID and offset
/// specified by Loc.  If FilenameID is -1, it is considered to be
/// unspecified.
void SourceManager::AddLineNote(SourceLocation Loc, unsigned LineNo,
                                int FilenameID, bool IsFileEntry,
                                bool IsFileExit,
                                SrcMgr::CharacteristicKind FileKind) {
  std::pair<FileID, unsigned> LocInfo = getDecomposedExpansionLoc(Loc);

  bool Invalid = false;
  const SLocEntry &Entry = getSLocEntry(LocInfo.first, &Invalid);
  if (!Entry.isFile() || Invalid)
    return;

  const SrcMgr::FileInfo &FileInfo = Entry.getFile();

  // Remember that this file has #line directives now if it doesn't already.
  const_cast<SrcMgr::FileInfo&>(FileInfo).setHasLineDirectives();

  (void) getLineTable();

  unsigned EntryExit = 0;
  if (IsFileEntry)
    EntryExit = 1;
  else if (IsFileExit)
    EntryExit = 2;

  LineTable->AddLineNote(LocInfo.first, LocInfo.second, LineNo, FilenameID,
                         EntryExit, FileKind);
}

LineTableInfo &SourceManager::getLineTable() {
  if (!LineTable)
    LineTable.reset(new LineTableInfo());
  return *LineTable;
}

//===----------------------------------------------------------------------===//
// Private 'Create' methods.
//===----------------------------------------------------------------------===//

SourceManager::SourceManager(DiagnosticsEngine &Diag, FileManager &FileMgr,
                             bool UserFilesAreVolatile)
  : Diag(Diag), FileMgr(FileMgr), UserFilesAreVolatile(UserFilesAreVolatile) {
  clearIDTables();
  Diag.setSourceManager(this);
}

SourceManager::~SourceManager() {
  // Delete FileEntry objects corresponding to content caches.  Since the actual
  // content cache objects are bump pointer allocated, we just have to run the
  // dtors, but we call the deallocate method for completeness.
  for (unsigned i = 0, e = MemBufferInfos.size(); i != e; ++i) {
    if (MemBufferInfos[i]) {
      MemBufferInfos[i]->~ContentCache();
      ContentCacheAlloc.Deallocate(MemBufferInfos[i]);
    }
  }
  for (llvm::DenseMap<const FileEntry*, SrcMgr::ContentCache*>::iterator
       I = FileInfos.begin(), E = FileInfos.end(); I != E; ++I) {
    if (I->second) {
      I->second->~ContentCache();
      ContentCacheAlloc.Deallocate(I->second);
    }
  }
}

void SourceManager::clearIDTables() {
  MainFileID = FileID();
  LocalSLocEntryTable.clear();
  LoadedSLocEntryTable.clear();
  SLocEntryLoaded.clear();
  LastLineNoFileIDQuery = FileID();
  LastLineNoContentCache = nullptr;
  LastFileIDLookup = FileID();

  if (LineTable)
    LineTable->clear();

  // Use up FileID #0 as an invalid expansion.
  NextLocalOffset = 0;
  CurrentLoadedOffset = MaxLoadedOffset;
  createExpansionLoc(SourceLocation(), SourceLocation(), SourceLocation(), 1);
}

void SourceManager::initializeForReplay(const SourceManager &Old) {
  assert(MainFileID.isInvalid() && "expected uninitialized SourceManager");

  auto CloneContentCache = [&](const ContentCache *Cache) -> ContentCache * {
    auto *Clone = new (ContentCacheAlloc.Allocate<ContentCache>()) ContentCache;
    Clone->OrigEntry = Cache->OrigEntry;
    Clone->ContentsEntry = Cache->ContentsEntry;
    Clone->BufferOverridden = Cache->BufferOverridden;
    Clone->IsFileVolatile = Cache->IsFileVolatile;
    Clone->IsTransient = Cache->IsTransient;
    Clone->replaceBuffer(Cache->getRawBuffer(), /*DoNotFree*/true);
    return Clone;
  };

  // Ensure all SLocEntries are loaded from the external source.
  for (unsigned I = 0, N = Old.LoadedSLocEntryTable.size(); I != N; ++I)
    if (!Old.SLocEntryLoaded[I])
      Old.loadSLocEntry(I, nullptr);

  // Inherit any content cache data from the old source manager.
  for (auto &FileInfo : Old.FileInfos) {
    SrcMgr::ContentCache *&Slot = FileInfos[FileInfo.first];
    if (Slot)
      continue;
    Slot = CloneContentCache(FileInfo.second);
  }
}

/// getOrCreateContentCache - Create or return a cached ContentCache for the
/// specified file.
const ContentCache *
SourceManager::getOrCreateContentCache(const FileEntry *FileEnt,
                                       bool isSystemFile) {
  assert(FileEnt && "Didn't specify a file entry to use?");

  // Do we already have information about this file?
  ContentCache *&Entry = FileInfos[FileEnt];
  if (Entry) return Entry;

  // Nope, create a new Cache entry.
  Entry = ContentCacheAlloc.Allocate<ContentCache>();

  if (OverriddenFilesInfo) {
    // If the file contents are overridden with contents from another file,
    // pass that file to ContentCache.
    llvm::DenseMap<const FileEntry *, const FileEntry *>::iterator
        overI = OverriddenFilesInfo->OverriddenFiles.find(FileEnt);
    if (overI == OverriddenFilesInfo->OverriddenFiles.end())
      new (Entry) ContentCache(FileEnt);
    else
      new (Entry) ContentCache(OverridenFilesKeepOriginalName ? FileEnt
                                                              : overI->second,
                               overI->second);
  } else {
    new (Entry) ContentCache(FileEnt);
  }

  Entry->IsFileVolatile = UserFilesAreVolatile && !isSystemFile;
  Entry->IsTransient = FilesAreTransient;

  return Entry;
}

/// Create a new ContentCache for the specified memory buffer.
/// This does no caching.
const ContentCache *
SourceManager::createMemBufferContentCache(const llvm::MemoryBuffer *Buffer,
                                           bool DoNotFree) {
  // Add a new ContentCache to the MemBufferInfos list and return it.
  ContentCache *Entry = ContentCacheAlloc.Allocate<ContentCache>();
  new (Entry) ContentCache();
  MemBufferInfos.push_back(Entry);
  Entry->replaceBuffer(Buffer, DoNotFree);
  return Entry;
}

const SrcMgr::SLocEntry &SourceManager::loadSLocEntry(unsigned Index,
                                                      bool *Invalid) const {
  assert(!SLocEntryLoaded[Index]);
  if (ExternalSLocEntries->ReadSLocEntry(-(static_cast<int>(Index) + 2))) {
    if (Invalid)
      *Invalid = true;
    // If the file of the SLocEntry changed we could still have loaded it.
    if (!SLocEntryLoaded[Index]) {
      // Try to recover; create a SLocEntry so the rest of clang can handle it.
      LoadedSLocEntryTable[Index] = SLocEntry::get(
          0, FileInfo::get(SourceLocation(), getFakeContentCacheForRecovery(),
                           SrcMgr::C_User, ""));
    }
  }

  return LoadedSLocEntryTable[Index];
}

std::pair<int, unsigned>
SourceManager::AllocateLoadedSLocEntries(unsigned NumSLocEntries,
                                         unsigned TotalSize) {
  assert(ExternalSLocEntries && "Don't have an external sloc source");
  // Make sure we're not about to run out of source locations.
  if (CurrentLoadedOffset - TotalSize < NextLocalOffset)
    return std::make_pair(0, 0);
  LoadedSLocEntryTable.resize(LoadedSLocEntryTable.size() + NumSLocEntries);
  SLocEntryLoaded.resize(LoadedSLocEntryTable.size());
  CurrentLoadedOffset -= TotalSize;
  int ID = LoadedSLocEntryTable.size();
  return std::make_pair(-ID - 1, CurrentLoadedOffset);
}

/// As part of recovering from missing or changed content, produce a
/// fake, non-empty buffer.
llvm::MemoryBuffer *SourceManager::getFakeBufferForRecovery() const {
  if (!FakeBufferForRecovery)
    FakeBufferForRecovery =
        llvm::MemoryBuffer::getMemBuffer("<<<INVALID BUFFER>>");

  return FakeBufferForRecovery.get();
}

/// As part of recovering from missing or changed content, produce a
/// fake content cache.
const SrcMgr::ContentCache *
SourceManager::getFakeContentCacheForRecovery() const {
  if (!FakeContentCacheForRecovery) {
    FakeContentCacheForRecovery = std::make_unique<SrcMgr::ContentCache>();
    FakeContentCacheForRecovery->replaceBuffer(getFakeBufferForRecovery(),
                                               /*DoNotFree=*/true);
  }
  return FakeContentCacheForRecovery.get();
}

/// Returns the previous in-order FileID or an invalid FileID if there
/// is no previous one.
FileID SourceManager::getPreviousFileID(FileID FID) const {
  if (FID.isInvalid())
    return FileID();

  int ID = FID.ID;
  if (ID == -1)
    return FileID();

  if (ID > 0) {
    if (ID-1 == 0)
      return FileID();
  } else if (unsigned(-(ID-1) - 2) >= LoadedSLocEntryTable.size()) {
    return FileID();
  }

  return FileID::get(ID-1);
}

/// Returns the next in-order FileID or an invalid FileID if there is
/// no next one.
FileID SourceManager::getNextFileID(FileID FID) const {
  if (FID.isInvalid())
    return FileID();

  int ID = FID.ID;
  if (ID > 0) {
    if (unsigned(ID+1) >= local_sloc_entry_size())
      return FileID();
  } else if (ID+1 >= -1) {
    return FileID();
  }

  return FileID::get(ID+1);
}

//===----------------------------------------------------------------------===//
// Methods to create new FileID's and macro expansions.
//===----------------------------------------------------------------------===//

/// createFileID - Create a new FileID for the specified ContentCache and
/// include position.  This works regardless of whether the ContentCache
/// corresponds to a file or some other input source.
FileID SourceManager::createFileID(const ContentCache *File, StringRef Filename,
                                   SourceLocation IncludePos,
                                   SrcMgr::CharacteristicKind FileCharacter,
                                   int LoadedID, unsigned LoadedOffset) {
  if (LoadedID < 0) {
    assert(LoadedID != -1 && "Loading sentinel FileID");
    unsigned Index = unsigned(-LoadedID) - 2;
    assert(Index < LoadedSLocEntryTable.size() && "FileID out of range");
    assert(!SLocEntryLoaded[Index] && "FileID already loaded");
    LoadedSLocEntryTable[Index] = SLocEntry::get(
        LoadedOffset, FileInfo::get(IncludePos, File, FileCharacter, Filename));
    SLocEntryLoaded[Index] = true;
    return FileID::get(LoadedID);
  }
  unsigned FileSize = File->getSize();
  if (!(NextLocalOffset + FileSize + 1 > NextLocalOffset &&
        NextLocalOffset + FileSize + 1 <= CurrentLoadedOffset)) {
    Diag.Report(IncludePos, diag::err_include_too_large);
    return FileID();
  }
  LocalSLocEntryTable.push_back(
      SLocEntry::get(NextLocalOffset,
                     FileInfo::get(IncludePos, File, FileCharacter, Filename)));
  // We do a +1 here because we want a SourceLocation that means "the end of the
  // file", e.g. for the "no newline at the end of the file" diagnostic.
  NextLocalOffset += FileSize + 1;

  // Set LastFileIDLookup to the newly created file.  The next getFileID call is
  // almost guaranteed to be from that file.
  FileID FID = FileID::get(LocalSLocEntryTable.size()-1);
  return LastFileIDLookup = FID;
}

SourceLocation
SourceManager::createMacroArgExpansionLoc(SourceLocation SpellingLoc,
                                          SourceLocation ExpansionLoc,
                                          unsigned TokLength) {
  ExpansionInfo Info = ExpansionInfo::createForMacroArg(SpellingLoc,
                                                        ExpansionLoc);
  return createExpansionLocImpl(Info, TokLength);
}

SourceLocation
SourceManager::createExpansionLoc(SourceLocation SpellingLoc,
                                  SourceLocation ExpansionLocStart,
                                  SourceLocation ExpansionLocEnd,
                                  unsigned TokLength,
                                  bool ExpansionIsTokenRange,
                                  int LoadedID,
                                  unsigned LoadedOffset) {
  ExpansionInfo Info = ExpansionInfo::create(
      SpellingLoc, ExpansionLocStart, ExpansionLocEnd, ExpansionIsTokenRange);
  return createExpansionLocImpl(Info, TokLength, LoadedID, LoadedOffset);
}

SourceLocation SourceManager::createTokenSplitLoc(SourceLocation Spelling,
                                                  SourceLocation TokenStart,
                                                  SourceLocation TokenEnd) {
  assert(getFileID(TokenStart) == getFileID(TokenEnd) &&
         "token spans multiple files");
  return createExpansionLocImpl(
      ExpansionInfo::createForTokenSplit(Spelling, TokenStart, TokenEnd),
      TokenEnd.getOffset() - TokenStart.getOffset());
}

SourceLocation
SourceManager::createExpansionLocImpl(const ExpansionInfo &Info,
                                      unsigned TokLength,
                                      int LoadedID,
                                      unsigned LoadedOffset) {
  if (LoadedID < 0) {
    assert(LoadedID != -1 && "Loading sentinel FileID");
    unsigned Index = unsigned(-LoadedID) - 2;
    assert(Index < LoadedSLocEntryTable.size() && "FileID out of range");
    assert(!SLocEntryLoaded[Index] && "FileID already loaded");
    LoadedSLocEntryTable[Index] = SLocEntry::get(LoadedOffset, Info);
    SLocEntryLoaded[Index] = true;
    return SourceLocation::getMacroLoc(LoadedOffset);
  }
  LocalSLocEntryTable.push_back(SLocEntry::get(NextLocalOffset, Info));
  assert(NextLocalOffset + TokLength + 1 > NextLocalOffset &&
         NextLocalOffset + TokLength + 1 <= CurrentLoadedOffset &&
         "Ran out of source locations!");
  // See createFileID for that +1.
  NextLocalOffset += TokLength + 1;
  return SourceLocation::getMacroLoc(NextLocalOffset - (TokLength + 1));
}

const llvm::MemoryBuffer *
SourceManager::getMemoryBufferForFile(const FileEntry *File, bool *Invalid) {
  const SrcMgr::ContentCache *IR = getOrCreateContentCache(File);
  assert(IR && "getOrCreateContentCache() cannot return NULL");
  return IR->getBuffer(Diag, getFileManager(), SourceLocation(), Invalid);
}

void SourceManager::overrideFileContents(const FileEntry *SourceFile,
                                         llvm::MemoryBuffer *Buffer,
                                         bool DoNotFree) {
  const SrcMgr::ContentCache *IR = getOrCreateContentCache(SourceFile);
  assert(IR && "getOrCreateContentCache() cannot return NULL");

  const_cast<SrcMgr::ContentCache *>(IR)->replaceBuffer(Buffer, DoNotFree);
  const_cast<SrcMgr::ContentCache *>(IR)->BufferOverridden = true;

  getOverriddenFilesInfo().OverriddenFilesWithBuffer.insert(SourceFile);
}

void SourceManager::overrideFileContents(const FileEntry *SourceFile,
                                         const FileEntry *NewFile) {
  assert(SourceFile->getSize() == NewFile->getSize() &&
         "Different sizes, use the FileManager to create a virtual file with "
         "the correct size");
  assert(FileInfos.count(SourceFile) == 0 &&
         "This function should be called at the initialization stage, before "
         "any parsing occurs.");
  getOverriddenFilesInfo().OverriddenFiles[SourceFile] = NewFile;
}

const FileEntry *
SourceManager::bypassFileContentsOverride(const FileEntry &File) {
  assert(isFileOverridden(&File));
  llvm::Optional<FileEntryRef> BypassFile =
      FileMgr.getBypassFile(FileEntryRef(File.getName(), File));

  // If the file can't be found in the FS, give up.
  if (!BypassFile)
    return nullptr;

  const FileEntry *FE = &BypassFile->getFileEntry();
  (void)getOrCreateContentCache(FE);
  return FE;
}

void SourceManager::setFileIsTransient(const FileEntry *File) {
  const SrcMgr::ContentCache *CC = getOrCreateContentCache(File);
  const_cast<SrcMgr::ContentCache *>(CC)->IsTransient = true;
}

StringRef SourceManager::getBufferData(FileID FID, bool *Invalid) const {
  bool MyInvalid = false;
  const SLocEntry &SLoc = getSLocEntry(FID, &MyInvalid);
  if (!SLoc.isFile() || MyInvalid) {
    if (Invalid)
      *Invalid = true;
    return "<<<<<INVALID SOURCE LOCATION>>>>>";
  }

  const llvm::MemoryBuffer *Buf = SLoc.getFile().getContentCache()->getBuffer(
      Diag, getFileManager(), SourceLocation(), &MyInvalid);
  if (Invalid)
    *Invalid = MyInvalid;

  if (MyInvalid)
    return "<<<<<INVALID SOURCE LOCATION>>>>>";

  return Buf->getBuffer();
}

//===----------------------------------------------------------------------===//
// SourceLocation manipulation methods.
//===----------------------------------------------------------------------===//

/// Return the FileID for a SourceLocation.
///
/// This is the cache-miss path of getFileID. Not as hot as that function, but
/// still very important. It is responsible for finding the entry in the
/// SLocEntry tables that contains the specified location.
FileID SourceManager::getFileIDSlow(unsigned SLocOffset) const {
  if (!SLocOffset)
    return FileID::get(0);

  // Now it is time to search for the correct file. See where the SLocOffset
  // sits in the global view and consult local or loaded buffers for it.
  if (SLocOffset < NextLocalOffset)
    return getFileIDLocal(SLocOffset);
  return getFileIDLoaded(SLocOffset);
}

/// Return the FileID for a SourceLocation with a low offset.
///
/// This function knows that the SourceLocation is in a local buffer, not a
/// loaded one.
FileID SourceManager::getFileIDLocal(unsigned SLocOffset) const {
  assert(SLocOffset < NextLocalOffset && "Bad function choice");

  // After the first and second level caches, I see two common sorts of
  // behavior: 1) a lot of searched FileID's are "near" the cached file
  // location or are "near" the cached expansion location. 2) others are just
  // completely random and may be a very long way away.
  //
  // To handle this, we do a linear search for up to 8 steps to catch #1 quickly
  // then we fall back to a less cache efficient, but more scalable, binary
  // search to find the location.

  // See if this is near the file point - worst case we start scanning from the
  // most newly created FileID.
  const SrcMgr::SLocEntry *I;

  if (LastFileIDLookup.ID < 0 ||
      LocalSLocEntryTable[LastFileIDLookup.ID].getOffset() < SLocOffset) {
    // Neither loc prunes our search.
    I = LocalSLocEntryTable.end();
  } else {
    // Perhaps it is near the file point.
    I = LocalSLocEntryTable.begin()+LastFileIDLookup.ID;
  }

  // Find the FileID that contains this.  "I" is an iterator that points to a
  // FileID whose offset is known to be larger than SLocOffset.
  unsigned NumProbes = 0;
  while (true) {
    --I;
    if (I->getOffset() <= SLocOffset) {
      FileID Res = FileID::get(int(I - LocalSLocEntryTable.begin()));

      // If this isn't an expansion, remember it.  We have good locality across
      // FileID lookups.
      if (!I->isExpansion())
        LastFileIDLookup = Res;
      NumLinearScans += NumProbes+1;
      return Res;
    }
    if (++NumProbes == 8)
      break;
  }

  // Convert "I" back into an index.  We know that it is an entry whose index is
  // larger than the offset we are looking for.
  unsigned GreaterIndex = I - LocalSLocEntryTable.begin();
  // LessIndex - This is the lower bound of the range that we're searching.
  // We know that the offset corresponding to the FileID is is less than
  // SLocOffset.
  unsigned LessIndex = 0;
  NumProbes = 0;
  while (true) {
    bool Invalid = false;
    unsigned MiddleIndex = (GreaterIndex-LessIndex)/2+LessIndex;
    unsigned MidOffset = getLocalSLocEntry(MiddleIndex, &Invalid).getOffset();
    if (Invalid)
      return FileID::get(0);

    ++NumProbes;

    // If the offset of the midpoint is too large, chop the high side of the
    // range to the midpoint.
    if (MidOffset > SLocOffset) {
      GreaterIndex = MiddleIndex;
      continue;
    }

    // If the middle index contains the value, succeed and return.
    // FIXME: This could be made faster by using a function that's aware of
    // being in the local area.
    if (isOffsetInFileID(FileID::get(MiddleIndex), SLocOffset)) {
      FileID Res = FileID::get(MiddleIndex);

      // If this isn't a macro expansion, remember it.  We have good locality
      // across FileID lookups.
      if (!LocalSLocEntryTable[MiddleIndex].isExpansion())
        LastFileIDLookup = Res;
      NumBinaryProbes += NumProbes;
      return Res;
    }

    // Otherwise, move the low-side up to the middle index.
    LessIndex = MiddleIndex;
  }
}

/// Return the FileID for a SourceLocation with a high offset.
///
/// This function knows that the SourceLocation is in a loaded buffer, not a
/// local one.
FileID SourceManager::getFileIDLoaded(unsigned SLocOffset) const {
  // Sanity checking, otherwise a bug may lead to hanging in release build.
  if (SLocOffset < CurrentLoadedOffset) {
    assert(0 && "Invalid SLocOffset or bad function choice");
    return FileID();
  }

  // Essentially the same as the local case, but the loaded array is sorted
  // in the other direction.

  // First do a linear scan from the last lookup position, if possible.
  unsigned I;
  int LastID = LastFileIDLookup.ID;
  if (LastID >= 0 || getLoadedSLocEntryByID(LastID).getOffset() < SLocOffset)
    I = 0;
  else
    I = (-LastID - 2) + 1;

  unsigned NumProbes;
  for (NumProbes = 0; NumProbes < 8; ++NumProbes, ++I) {
    // Make sure the entry is loaded!
    const SrcMgr::SLocEntry &E = getLoadedSLocEntry(I);
    if (E.getOffset() <= SLocOffset) {
      FileID Res = FileID::get(-int(I) - 2);

      if (!E.isExpansion())
        LastFileIDLookup = Res;
      NumLinearScans += NumProbes + 1;
      return Res;
    }
  }

  // Linear scan failed. Do the binary search. Note the reverse sorting of the
  // table: GreaterIndex is the one where the offset is greater, which is
  // actually a lower index!
  unsigned GreaterIndex = I;
  unsigned LessIndex = LoadedSLocEntryTable.size();
  NumProbes = 0;
  while (true) {
    ++NumProbes;
    unsigned MiddleIndex = (LessIndex - GreaterIndex) / 2 + GreaterIndex;
    const SrcMgr::SLocEntry &E = getLoadedSLocEntry(MiddleIndex);
    if (E.getOffset() == 0)
      return FileID(); // invalid entry.

    ++NumProbes;

    if (E.getOffset() > SLocOffset) {
      // Sanity checking, otherwise a bug may lead to hanging in release build.
      if (GreaterIndex == MiddleIndex) {
        assert(0 && "binary search missed the entry");
        return FileID();
      }
      GreaterIndex = MiddleIndex;
      continue;
    }

    if (isOffsetInFileID(FileID::get(-int(MiddleIndex) - 2), SLocOffset)) {
      FileID Res = FileID::get(-int(MiddleIndex) - 2);
      if (!E.isExpansion())
        LastFileIDLookup = Res;
      NumBinaryProbes += NumProbes;
      return Res;
    }

    // Sanity checking, otherwise a bug may lead to hanging in release build.
    if (LessIndex == MiddleIndex) {
      assert(0 && "binary search missed the entry");
      return FileID();
    }
    LessIndex = MiddleIndex;
  }
}

SourceLocation SourceManager::
getExpansionLocSlowCase(SourceLocation Loc) const {
  do {
    // Note: If Loc indicates an offset into a token that came from a macro
    // expansion (e.g. the 5th character of the token) we do not want to add
    // this offset when going to the expansion location.  The expansion
    // location is the macro invocation, which the offset has nothing to do
    // with.  This is unlike when we get the spelling loc, because the offset
    // directly correspond to the token whose spelling we're inspecting.
    Loc = getSLocEntry(getFileID(Loc)).getExpansion().getExpansionLocStart();
  } while (!Loc.isFileID());

  return Loc;
}

SourceLocation SourceManager::getSpellingLocSlowCase(SourceLocation Loc) const {
  do {
    std::pair<FileID, unsigned> LocInfo = getDecomposedLoc(Loc);
    Loc = getSLocEntry(LocInfo.first).getExpansion().getSpellingLoc();
    Loc = Loc.getLocWithOffset(LocInfo.second);
  } while (!Loc.isFileID());
  return Loc;
}

SourceLocation SourceManager::getFileLocSlowCase(SourceLocation Loc) const {
  do {
    if (isMacroArgExpansion(Loc))
      Loc = getImmediateSpellingLoc(Loc);
    else
      Loc = getImmediateExpansionRange(Loc).getBegin();
  } while (!Loc.isFileID());
  return Loc;
}


std::pair<FileID, unsigned>
SourceManager::getDecomposedExpansionLocSlowCase(
                                             const SrcMgr::SLocEntry *E) const {
  // If this is an expansion record, walk through all the expansion points.
  FileID FID;
  SourceLocation Loc;
  unsigned Offset;
  do {
    Loc = E->getExpansion().getExpansionLocStart();

    FID = getFileID(Loc);
    E = &getSLocEntry(FID);
    Offset = Loc.getOffset()-E->getOffset();
  } while (!Loc.isFileID());

  return std::make_pair(FID, Offset);
}

std::pair<FileID, unsigned>
SourceManager::getDecomposedSpellingLocSlowCase(const SrcMgr::SLocEntry *E,
                                                unsigned Offset) const {
  // If this is an expansion record, walk through all the expansion points.
  FileID FID;
  SourceLocation Loc;
  do {
    Loc = E->getExpansion().getSpellingLoc();
    Loc = Loc.getLocWithOffset(Offset);

    FID = getFileID(Loc);
    E = &getSLocEntry(FID);
    Offset = Loc.getOffset()-E->getOffset();
  } while (!Loc.isFileID());

  return std::make_pair(FID, Offset);
}

/// getImmediateSpellingLoc - Given a SourceLocation object, return the
/// spelling location referenced by the ID.  This is the first level down
/// towards the place where the characters that make up the lexed token can be
/// found.  This should not generally be used by clients.
SourceLocation SourceManager::getImmediateSpellingLoc(SourceLocation Loc) const{
  if (Loc.isFileID()) return Loc;
  std::pair<FileID, unsigned> LocInfo = getDecomposedLoc(Loc);
  Loc = getSLocEntry(LocInfo.first).getExpansion().getSpellingLoc();
  return Loc.getLocWithOffset(LocInfo.second);
}

/// getImmediateExpansionRange - Loc is required to be an expansion location.
/// Return the start/end of the expansion information.
CharSourceRange
SourceManager::getImmediateExpansionRange(SourceLocation Loc) const {
  assert(Loc.isMacroID() && "Not a macro expansion loc!");
  const ExpansionInfo &Expansion = getSLocEntry(getFileID(Loc)).getExpansion();
  return Expansion.getExpansionLocRange();
}

SourceLocation SourceManager::getTopMacroCallerLoc(SourceLocation Loc) const {
  while (isMacroArgExpansion(Loc))
    Loc = getImmediateSpellingLoc(Loc);
  return Loc;
}

/// getExpansionRange - Given a SourceLocation object, return the range of
/// tokens covered by the expansion in the ultimate file.
CharSourceRange SourceManager::getExpansionRange(SourceLocation Loc) const {
  if (Loc.isFileID())
    return CharSourceRange(SourceRange(Loc, Loc), true);

  CharSourceRange Res = getImmediateExpansionRange(Loc);

  // Fully resolve the start and end locations to their ultimate expansion
  // points.
  while (!Res.getBegin().isFileID())
    Res.setBegin(getImmediateExpansionRange(Res.getBegin()).getBegin());
  while (!Res.getEnd().isFileID()) {
    CharSourceRange EndRange = getImmediateExpansionRange(Res.getEnd());
    Res.setEnd(EndRange.getEnd());
    Res.setTokenRange(EndRange.isTokenRange());
  }
  return Res;
}

bool SourceManager::isMacroArgExpansion(SourceLocation Loc,
                                        SourceLocation *StartLoc) const {
  if (!Loc.isMacroID()) return false;

  FileID FID = getFileID(Loc);
  const SrcMgr::ExpansionInfo &Expansion = getSLocEntry(FID).getExpansion();
  if (!Expansion.isMacroArgExpansion()) return false;

  if (StartLoc)
    *StartLoc = Expansion.getExpansionLocStart();
  return true;
}

bool SourceManager::isMacroBodyExpansion(SourceLocation Loc) const {
  if (!Loc.isMacroID()) return false;

  FileID FID = getFileID(Loc);
  const SrcMgr::ExpansionInfo &Expansion = getSLocEntry(FID).getExpansion();
  return Expansion.isMacroBodyExpansion();
}

bool SourceManager::isAtStartOfImmediateMacroExpansion(SourceLocation Loc,
                                             SourceLocation *MacroBegin) const {
  assert(Loc.isValid() && Loc.isMacroID() && "Expected a valid macro loc");

  std::pair<FileID, unsigned> DecompLoc = getDecomposedLoc(Loc);
  if (DecompLoc.second > 0)
    return false; // Does not point at the start of expansion range.

  bool Invalid = false;
  const SrcMgr::ExpansionInfo &ExpInfo =
      getSLocEntry(DecompLoc.first, &Invalid).getExpansion();
  if (Invalid)
    return false;
  SourceLocation ExpLoc = ExpInfo.getExpansionLocStart();

  if (ExpInfo.isMacroArgExpansion()) {
    // For macro argument expansions, check if the previous FileID is part of
    // the same argument expansion, in which case this Loc is not at the
    // beginning of the expansion.
    FileID PrevFID = getPreviousFileID(DecompLoc.first);
    if (!PrevFID.isInvalid()) {
      const SrcMgr::SLocEntry &PrevEntry = getSLocEntry(PrevFID, &Invalid);
      if (Invalid)
        return false;
      if (PrevEntry.isExpansion() &&
          PrevEntry.getExpansion().getExpansionLocStart() == ExpLoc)
        return false;
    }
  }

  if (MacroBegin)
    *MacroBegin = ExpLoc;
  return true;
}

bool SourceManager::isAtEndOfImmediateMacroExpansion(SourceLocation Loc,
                                               SourceLocation *MacroEnd) const {
  assert(Loc.isValid() && Loc.isMacroID() && "Expected a valid macro loc");

  FileID FID = getFileID(Loc);
  SourceLocation NextLoc = Loc.getLocWithOffset(1);
  if (isInFileID(NextLoc, FID))
    return false; // Does not point at the end of expansion range.

  bool Invalid = false;
  const SrcMgr::ExpansionInfo &ExpInfo =
      getSLocEntry(FID, &Invalid).getExpansion();
  if (Invalid)
    return false;

  if (ExpInfo.isMacroArgExpansion()) {
    // For macro argument expansions, check if the next FileID is part of the
    // same argument expansion, in which case this Loc is not at the end of the
    // expansion.
    FileID NextFID = getNextFileID(FID);
    if (!NextFID.isInvalid()) {
      const SrcMgr::SLocEntry &NextEntry = getSLocEntry(NextFID, &Invalid);
      if (Invalid)
        return false;
      if (NextEntry.isExpansion() &&
          NextEntry.getExpansion().getExpansionLocStart() ==
              ExpInfo.getExpansionLocStart())
        return false;
    }
  }

  if (MacroEnd)
    *MacroEnd = ExpInfo.getExpansionLocEnd();
  return true;
}

//===----------------------------------------------------------------------===//
// Queries about the code at a SourceLocation.
//===----------------------------------------------------------------------===//

/// getCharacterData - Return a pointer to the start of the specified location
/// in the appropriate MemoryBuffer.
const char *SourceManager::getCharacterData(SourceLocation SL,
                                            bool *Invalid) const {
  // Note that this is a hot function in the getSpelling() path, which is
  // heavily used by -E mode.
  std::pair<FileID, unsigned> LocInfo = getDecomposedSpellingLoc(SL);

  // Note that calling 'getBuffer()' may lazily page in a source file.
  bool CharDataInvalid = false;
  const SLocEntry &Entry = getSLocEntry(LocInfo.first, &CharDataInvalid);
  if (CharDataInvalid || !Entry.isFile()) {
    if (Invalid)
      *Invalid = true;

    return "<<<<INVALID BUFFER>>>>";
  }
  const llvm::MemoryBuffer *Buffer =
      Entry.getFile().getContentCache()->getBuffer(
          Diag, getFileManager(), SourceLocation(), &CharDataInvalid);
  if (Invalid)
    *Invalid = CharDataInvalid;
  return Buffer->getBufferStart() + (CharDataInvalid? 0 : LocInfo.second);
}

/// getColumnNumber - Return the column # for the specified file position.
/// this is significantly cheaper to compute than the line number.
unsigned SourceManager::getColumnNumber(FileID FID, unsigned FilePos,
                                        bool *Invalid) const {
  bool MyInvalid = false;
  const llvm::MemoryBuffer *MemBuf = getBuffer(FID, &MyInvalid);
  if (Invalid)
    *Invalid = MyInvalid;

  if (MyInvalid)
    return 1;

  // It is okay to request a position just past the end of the buffer.
  if (FilePos > MemBuf->getBufferSize()) {
    if (Invalid)
      *Invalid = true;
    return 1;
  }

  const char *Buf = MemBuf->getBufferStart();
  // See if we just calculated the line number for this FilePos and can use
  // that to lookup the start of the line instead of searching for it.
  if (LastLineNoFileIDQuery == FID &&
      LastLineNoContentCache->SourceLineCache != nullptr &&
      LastLineNoResult < LastLineNoContentCache->NumLines) {
    unsigned *SourceLineCache = LastLineNoContentCache->SourceLineCache;
    unsigned LineStart = SourceLineCache[LastLineNoResult - 1];
    unsigned LineEnd = SourceLineCache[LastLineNoResult];
    if (FilePos >= LineStart && FilePos < LineEnd) {
      // LineEnd is the LineStart of the next line.
      // A line ends with separator LF or CR+LF on Windows.
      // FilePos might point to the last separator,
      // but we need a column number at most 1 + the last column.
      if (FilePos + 1 == LineEnd && FilePos > LineStart) {
        if (Buf[FilePos - 1] == '\r' || Buf[FilePos - 1] == '\n')
          --FilePos;
      }
      return FilePos - LineStart + 1;
    }
  }

  unsigned LineStart = FilePos;
  while (LineStart && Buf[LineStart-1] != '\n' && Buf[LineStart-1] != '\r')
    --LineStart;
  return FilePos-LineStart+1;
}

// isInvalid - Return the result of calling loc.isInvalid(), and
// if Invalid is not null, set its value to same.
template<typename LocType>
static bool isInvalid(LocType Loc, bool *Invalid) {
  bool MyInvalid = Loc.isInvalid();
  if (Invalid)
    *Invalid = MyInvalid;
  return MyInvalid;
}

unsigned SourceManager::getSpellingColumnNumber(SourceLocation Loc,
                                                bool *Invalid) const {
  if (isInvalid(Loc, Invalid)) return 0;
  std::pair<FileID, unsigned> LocInfo = getDecomposedSpellingLoc(Loc);
  return getColumnNumber(LocInfo.first, LocInfo.second, Invalid);
}

unsigned SourceManager::getExpansionColumnNumber(SourceLocation Loc,
                                                 bool *Invalid) const {
  if (isInvalid(Loc, Invalid)) return 0;
  std::pair<FileID, unsigned> LocInfo = getDecomposedExpansionLoc(Loc);
  return getColumnNumber(LocInfo.first, LocInfo.second, Invalid);
}

unsigned SourceManager::getPresumedColumnNumber(SourceLocation Loc,
                                                bool *Invalid) const {
  PresumedLoc PLoc = getPresumedLoc(Loc);
  if (isInvalid(PLoc, Invalid)) return 0;
  return PLoc.getColumn();
}

#ifdef __SSE2__
#if 0 /* expanded by -frewrite-includes */
#include <emmintrin.h>
#endif /* expanded by -frewrite-includes */
# 1230 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 1 3
/*===---- emmintrin.h - SSE2 intrinsics ------------------------------------===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __EMMINTRIN_H
#define __EMMINTRIN_H

#if 0 /* expanded by -frewrite-includes */
#include <xmmintrin.h>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 1 3
/*===---- xmmintrin.h - SSE intrinsics -------------------------------------===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __XMMINTRIN_H
#define __XMMINTRIN_H

#if 0 /* expanded by -frewrite-includes */
#include <mmintrin.h>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mmintrin.h" 1 3
/*===---- mmintrin.h - MMX intrinsics --------------------------------------===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __MMINTRIN_H
#define __MMINTRIN_H

typedef long long __m64 __attribute__((__vector_size__(8), __aligned__(8)));

typedef long long __v1di __attribute__((__vector_size__(8)));
typedef int __v2si __attribute__((__vector_size__(8)));
typedef short __v4hi __attribute__((__vector_size__(8)));
typedef char __v8qi __attribute__((__vector_size__(8)));

/* Define the default attributes for the functions in this file. */
#define __DEFAULT_FN_ATTRS __attribute__((__always_inline__, __nodebug__, __target__("mmx"), __min_vector_width__(64)))

/// Clears the MMX state by setting the state of the x87 stack registers
///    to empty.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> EMMS </c> instruction.
///
static __inline__ void  __attribute__((__always_inline__, __nodebug__, __target__("mmx")))
_mm_empty(void)
{
    __builtin_ia32_emms();
}

/// Constructs a 64-bit integer vector, setting the lower 32 bits to the
///    value of the 32-bit integer parameter and setting the upper 32 bits to 0.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVD </c> instruction.
///
/// \param __i
///    A 32-bit integer value.
/// \returns A 64-bit integer vector. The lower 32 bits contain the value of the
///    parameter. The upper 32 bits are set to 0.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_cvtsi32_si64(int __i)
{
    return (__m64)__builtin_ia32_vec_init_v2si(__i, 0);
}

/// Returns the lower 32 bits of a 64-bit integer vector as a 32-bit
///    signed integer.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVD </c> instruction.
///
/// \param __m
///    A 64-bit integer vector.
/// \returns A 32-bit signed integer value containing the lower 32 bits of the
///    parameter.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvtsi64_si32(__m64 __m)
{
    return __builtin_ia32_vec_ext_v2si((__v2si)__m, 0);
}

/// Casts a 64-bit signed integer value into a 64-bit integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVQ </c> instruction.
///
/// \param __i
///    A 64-bit signed integer.
/// \returns A 64-bit integer vector containing the same bitwise pattern as the
///    parameter.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_cvtsi64_m64(long long __i)
{
    return (__m64)__i;
}

/// Casts a 64-bit integer vector into a 64-bit signed integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVQ </c> instruction.
///
/// \param __m
///    A 64-bit integer vector.
/// \returns A 64-bit signed integer containing the same bitwise pattern as the
///    parameter.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvtm64_si64(__m64 __m)
{
    return (long long)__m;
}

/// Converts 16-bit signed integers from both 64-bit integer vector
///    parameters of [4 x i16] into 8-bit signed integer values, and constructs
///    a 64-bit integer vector of [8 x i8] as the result. Positive values
///    greater than 0x7F are saturated to 0x7F. Negative values less than 0x80
///    are saturated to 0x80.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PACKSSWB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16]. Each 16-bit element is treated as a
///    16-bit signed integer and is converted to an 8-bit signed integer with
///    saturation. Positive values greater than 0x7F are saturated to 0x7F.
///    Negative values less than 0x80 are saturated to 0x80. The converted
///    [4 x i8] values are written to the lower 32 bits of the result.
/// \param __m2
///    A 64-bit integer vector of [4 x i16]. Each 16-bit element is treated as a
///    16-bit signed integer and is converted to an 8-bit signed integer with
///    saturation. Positive values greater than 0x7F are saturated to 0x7F.
///    Negative values less than 0x80 are saturated to 0x80. The converted
///    [4 x i8] values are written to the upper 32 bits of the result.
/// \returns A 64-bit integer vector of [8 x i8] containing the converted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_packs_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_packsswb((__v4hi)__m1, (__v4hi)__m2);
}

/// Converts 32-bit signed integers from both 64-bit integer vector
///    parameters of [2 x i32] into 16-bit signed integer values, and constructs
///    a 64-bit integer vector of [4 x i16] as the result. Positive values
///    greater than 0x7FFF are saturated to 0x7FFF. Negative values less than
///    0x8000 are saturated to 0x8000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PACKSSDW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [2 x i32]. Each 32-bit element is treated as a
///    32-bit signed integer and is converted to a 16-bit signed integer with
///    saturation. Positive values greater than 0x7FFF are saturated to 0x7FFF.
///    Negative values less than 0x8000 are saturated to 0x8000. The converted
///    [2 x i16] values are written to the lower 32 bits of the result.
/// \param __m2
///    A 64-bit integer vector of [2 x i32]. Each 32-bit element is treated as a
///    32-bit signed integer and is converted to a 16-bit signed integer with
///    saturation. Positive values greater than 0x7FFF are saturated to 0x7FFF.
///    Negative values less than 0x8000 are saturated to 0x8000. The converted
///    [2 x i16] values are written to the upper 32 bits of the result.
/// \returns A 64-bit integer vector of [4 x i16] containing the converted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_packs_pi32(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_packssdw((__v2si)__m1, (__v2si)__m2);
}

/// Converts 16-bit signed integers from both 64-bit integer vector
///    parameters of [4 x i16] into 8-bit unsigned integer values, and
///    constructs a 64-bit integer vector of [8 x i8] as the result. Values
///    greater than 0xFF are saturated to 0xFF. Values less than 0 are saturated
///    to 0.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PACKUSWB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16]. Each 16-bit element is treated as a
///    16-bit signed integer and is converted to an 8-bit unsigned integer with
///    saturation. Values greater than 0xFF are saturated to 0xFF. Values less
///    than 0 are saturated to 0. The converted [4 x i8] values are written to
///    the lower 32 bits of the result.
/// \param __m2
///    A 64-bit integer vector of [4 x i16]. Each 16-bit element is treated as a
///    16-bit signed integer and is converted to an 8-bit unsigned integer with
///    saturation. Values greater than 0xFF are saturated to 0xFF. Values less
///    than 0 are saturated to 0. The converted [4 x i8] values are written to
///    the upper 32 bits of the result.
/// \returns A 64-bit integer vector of [8 x i8] containing the converted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_packs_pu16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_packuswb((__v4hi)__m1, (__v4hi)__m2);
}

/// Unpacks the upper 32 bits from two 64-bit integer vectors of [8 x i8]
///    and interleaves them into a 64-bit integer vector of [8 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PUNPCKHBW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8]. \n
///    Bits [39:32] are written to bits [7:0] of the result. \n
///    Bits [47:40] are written to bits [23:16] of the result. \n
///    Bits [55:48] are written to bits [39:32] of the result. \n
///    Bits [63:56] are written to bits [55:48] of the result.
/// \param __m2
///    A 64-bit integer vector of [8 x i8].
///    Bits [39:32] are written to bits [15:8] of the result. \n
///    Bits [47:40] are written to bits [31:24] of the result. \n
///    Bits [55:48] are written to bits [47:40] of the result. \n
///    Bits [63:56] are written to bits [63:56] of the result.
/// \returns A 64-bit integer vector of [8 x i8] containing the interleaved
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_unpackhi_pi8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_punpckhbw((__v8qi)__m1, (__v8qi)__m2);
}

/// Unpacks the upper 32 bits from two 64-bit integer vectors of
///    [4 x i16] and interleaves them into a 64-bit integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PUNPCKHWD </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
///    Bits [47:32] are written to bits [15:0] of the result. \n
///    Bits [63:48] are written to bits [47:32] of the result.
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
///    Bits [47:32] are written to bits [31:16] of the result. \n
///    Bits [63:48] are written to bits [63:48] of the result.
/// \returns A 64-bit integer vector of [4 x i16] containing the interleaved
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_unpackhi_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_punpckhwd((__v4hi)__m1, (__v4hi)__m2);
}

/// Unpacks the upper 32 bits from two 64-bit integer vectors of
///    [2 x i32] and interleaves them into a 64-bit integer vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PUNPCKHDQ </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [2 x i32]. The upper 32 bits are written to
///    the lower 32 bits of the result.
/// \param __m2
///    A 64-bit integer vector of [2 x i32]. The upper 32 bits are written to
///    the upper 32 bits of the result.
/// \returns A 64-bit integer vector of [2 x i32] containing the interleaved
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_unpackhi_pi32(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_punpckhdq((__v2si)__m1, (__v2si)__m2);
}

/// Unpacks the lower 32 bits from two 64-bit integer vectors of [8 x i8]
///    and interleaves them into a 64-bit integer vector of [8 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PUNPCKLBW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8].
///    Bits [7:0] are written to bits [7:0] of the result. \n
///    Bits [15:8] are written to bits [23:16] of the result. \n
///    Bits [23:16] are written to bits [39:32] of the result. \n
///    Bits [31:24] are written to bits [55:48] of the result.
/// \param __m2
///    A 64-bit integer vector of [8 x i8].
///    Bits [7:0] are written to bits [15:8] of the result. \n
///    Bits [15:8] are written to bits [31:24] of the result. \n
///    Bits [23:16] are written to bits [47:40] of the result. \n
///    Bits [31:24] are written to bits [63:56] of the result.
/// \returns A 64-bit integer vector of [8 x i8] containing the interleaved
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_unpacklo_pi8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_punpcklbw((__v8qi)__m1, (__v8qi)__m2);
}

/// Unpacks the lower 32 bits from two 64-bit integer vectors of
///    [4 x i16] and interleaves them into a 64-bit integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PUNPCKLWD </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
///    Bits [15:0] are written to bits [15:0] of the result. \n
///    Bits [31:16] are written to bits [47:32] of the result.
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
///    Bits [15:0] are written to bits [31:16] of the result. \n
///    Bits [31:16] are written to bits [63:48] of the result.
/// \returns A 64-bit integer vector of [4 x i16] containing the interleaved
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_unpacklo_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_punpcklwd((__v4hi)__m1, (__v4hi)__m2);
}

/// Unpacks the lower 32 bits from two 64-bit integer vectors of
///    [2 x i32] and interleaves them into a 64-bit integer vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PUNPCKLDQ </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [2 x i32]. The lower 32 bits are written to
///    the lower 32 bits of the result.
/// \param __m2
///    A 64-bit integer vector of [2 x i32]. The lower 32 bits are written to
///    the upper 32 bits of the result.
/// \returns A 64-bit integer vector of [2 x i32] containing the interleaved
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_unpacklo_pi32(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_punpckldq((__v2si)__m1, (__v2si)__m2);
}

/// Adds each 8-bit integer element of the first 64-bit integer vector
///    of [8 x i8] to the corresponding 8-bit integer element of the second
///    64-bit integer vector of [8 x i8]. The lower 8 bits of the results are
///    packed into a 64-bit integer vector of [8 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8].
/// \param __m2
///    A 64-bit integer vector of [8 x i8].
/// \returns A 64-bit integer vector of [8 x i8] containing the sums of both
///    parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_add_pi8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_paddb((__v8qi)__m1, (__v8qi)__m2);
}

/// Adds each 16-bit integer element of the first 64-bit integer vector
///    of [4 x i16] to the corresponding 16-bit integer element of the second
///    64-bit integer vector of [4 x i16]. The lower 16 bits of the results are
///    packed into a 64-bit integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
/// \returns A 64-bit integer vector of [4 x i16] containing the sums of both
///    parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_add_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_paddw((__v4hi)__m1, (__v4hi)__m2);
}

/// Adds each 32-bit integer element of the first 64-bit integer vector
///    of [2 x i32] to the corresponding 32-bit integer element of the second
///    64-bit integer vector of [2 x i32]. The lower 32 bits of the results are
///    packed into a 64-bit integer vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDD </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [2 x i32].
/// \param __m2
///    A 64-bit integer vector of [2 x i32].
/// \returns A 64-bit integer vector of [2 x i32] containing the sums of both
///    parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_add_pi32(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_paddd((__v2si)__m1, (__v2si)__m2);
}

/// Adds each 8-bit signed integer element of the first 64-bit integer
///    vector of [8 x i8] to the corresponding 8-bit signed integer element of
///    the second 64-bit integer vector of [8 x i8]. Positive sums greater than
///    0x7F are saturated to 0x7F. Negative sums less than 0x80 are saturated to
///    0x80. The results are packed into a 64-bit integer vector of [8 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDSB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8].
/// \param __m2
///    A 64-bit integer vector of [8 x i8].
/// \returns A 64-bit integer vector of [8 x i8] containing the saturated sums
///    of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_adds_pi8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_paddsb((__v8qi)__m1, (__v8qi)__m2);
}

/// Adds each 16-bit signed integer element of the first 64-bit integer
///    vector of [4 x i16] to the corresponding 16-bit signed integer element of
///    the second 64-bit integer vector of [4 x i16]. Positive sums greater than
///    0x7FFF are saturated to 0x7FFF. Negative sums less than 0x8000 are
///    saturated to 0x8000. The results are packed into a 64-bit integer vector
///    of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDSW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
/// \returns A 64-bit integer vector of [4 x i16] containing the saturated sums
///    of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_adds_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_paddsw((__v4hi)__m1, (__v4hi)__m2);
}

/// Adds each 8-bit unsigned integer element of the first 64-bit integer
///    vector of [8 x i8] to the corresponding 8-bit unsigned integer element of
///    the second 64-bit integer vector of [8 x i8]. Sums greater than 0xFF are
///    saturated to 0xFF. The results are packed into a 64-bit integer vector of
///    [8 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDUSB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8].
/// \param __m2
///    A 64-bit integer vector of [8 x i8].
/// \returns A 64-bit integer vector of [8 x i8] containing the saturated
///    unsigned sums of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_adds_pu8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_paddusb((__v8qi)__m1, (__v8qi)__m2);
}

/// Adds each 16-bit unsigned integer element of the first 64-bit integer
///    vector of [4 x i16] to the corresponding 16-bit unsigned integer element
///    of the second 64-bit integer vector of [4 x i16]. Sums greater than
///    0xFFFF are saturated to 0xFFFF. The results are packed into a 64-bit
///    integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDUSW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
/// \returns A 64-bit integer vector of [4 x i16] containing the saturated
///    unsigned sums of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_adds_pu16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_paddusw((__v4hi)__m1, (__v4hi)__m2);
}

/// Subtracts each 8-bit integer element of the second 64-bit integer
///    vector of [8 x i8] from the corresponding 8-bit integer element of the
///    first 64-bit integer vector of [8 x i8]. The lower 8 bits of the results
///    are packed into a 64-bit integer vector of [8 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8] containing the minuends.
/// \param __m2
///    A 64-bit integer vector of [8 x i8] containing the subtrahends.
/// \returns A 64-bit integer vector of [8 x i8] containing the differences of
///    both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_sub_pi8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_psubb((__v8qi)__m1, (__v8qi)__m2);
}

/// Subtracts each 16-bit integer element of the second 64-bit integer
///    vector of [4 x i16] from the corresponding 16-bit integer element of the
///    first 64-bit integer vector of [4 x i16]. The lower 16 bits of the
///    results are packed into a 64-bit integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16] containing the minuends.
/// \param __m2
///    A 64-bit integer vector of [4 x i16] containing the subtrahends.
/// \returns A 64-bit integer vector of [4 x i16] containing the differences of
///    both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_sub_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_psubw((__v4hi)__m1, (__v4hi)__m2);
}

/// Subtracts each 32-bit integer element of the second 64-bit integer
///    vector of [2 x i32] from the corresponding 32-bit integer element of the
///    first 64-bit integer vector of [2 x i32]. The lower 32 bits of the
///    results are packed into a 64-bit integer vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBD </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [2 x i32] containing the minuends.
/// \param __m2
///    A 64-bit integer vector of [2 x i32] containing the subtrahends.
/// \returns A 64-bit integer vector of [2 x i32] containing the differences of
///    both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_sub_pi32(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_psubd((__v2si)__m1, (__v2si)__m2);
}

/// Subtracts each 8-bit signed integer element of the second 64-bit
///    integer vector of [8 x i8] from the corresponding 8-bit signed integer
///    element of the first 64-bit integer vector of [8 x i8]. Positive results
///    greater than 0x7F are saturated to 0x7F. Negative results less than 0x80
///    are saturated to 0x80. The results are packed into a 64-bit integer
///    vector of [8 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBSB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8] containing the minuends.
/// \param __m2
///    A 64-bit integer vector of [8 x i8] containing the subtrahends.
/// \returns A 64-bit integer vector of [8 x i8] containing the saturated
///    differences of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_subs_pi8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_psubsb((__v8qi)__m1, (__v8qi)__m2);
}

/// Subtracts each 16-bit signed integer element of the second 64-bit
///    integer vector of [4 x i16] from the corresponding 16-bit signed integer
///    element of the first 64-bit integer vector of [4 x i16]. Positive results
///    greater than 0x7FFF are saturated to 0x7FFF. Negative results less than
///    0x8000 are saturated to 0x8000. The results are packed into a 64-bit
///    integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBSW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16] containing the minuends.
/// \param __m2
///    A 64-bit integer vector of [4 x i16] containing the subtrahends.
/// \returns A 64-bit integer vector of [4 x i16] containing the saturated
///    differences of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_subs_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_psubsw((__v4hi)__m1, (__v4hi)__m2);
}

/// Subtracts each 8-bit unsigned integer element of the second 64-bit
///    integer vector of [8 x i8] from the corresponding 8-bit unsigned integer
///    element of the first 64-bit integer vector of [8 x i8].
///
///    If an element of the first vector is less than the corresponding element
///    of the second vector, the result is saturated to 0. The results are
///    packed into a 64-bit integer vector of [8 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBUSB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8] containing the minuends.
/// \param __m2
///    A 64-bit integer vector of [8 x i8] containing the subtrahends.
/// \returns A 64-bit integer vector of [8 x i8] containing the saturated
///    differences of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_subs_pu8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_psubusb((__v8qi)__m1, (__v8qi)__m2);
}

/// Subtracts each 16-bit unsigned integer element of the second 64-bit
///    integer vector of [4 x i16] from the corresponding 16-bit unsigned
///    integer element of the first 64-bit integer vector of [4 x i16].
///
///    If an element of the first vector is less than the corresponding element
///    of the second vector, the result is saturated to 0. The results are
///    packed into a 64-bit integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBUSW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16] containing the minuends.
/// \param __m2
///    A 64-bit integer vector of [4 x i16] containing the subtrahends.
/// \returns A 64-bit integer vector of [4 x i16] containing the saturated
///    differences of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_subs_pu16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_psubusw((__v4hi)__m1, (__v4hi)__m2);
}

/// Multiplies each 16-bit signed integer element of the first 64-bit
///    integer vector of [4 x i16] by the corresponding 16-bit signed integer
///    element of the second 64-bit integer vector of [4 x i16] and get four
///    32-bit products. Adds adjacent pairs of products to get two 32-bit sums.
///    The lower 32 bits of these two sums are packed into a 64-bit integer
///    vector of [2 x i32].
///
///    For example, bits [15:0] of both parameters are multiplied, bits [31:16]
///    of both parameters are multiplied, and the sum of both results is written
///    to bits [31:0] of the result.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMADDWD </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
/// \returns A 64-bit integer vector of [2 x i32] containing the sums of
///    products of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_madd_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pmaddwd((__v4hi)__m1, (__v4hi)__m2);
}

/// Multiplies each 16-bit signed integer element of the first 64-bit
///    integer vector of [4 x i16] by the corresponding 16-bit signed integer
///    element of the second 64-bit integer vector of [4 x i16]. Packs the upper
///    16 bits of the 32-bit products into a 64-bit integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMULHW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
/// \returns A 64-bit integer vector of [4 x i16] containing the upper 16 bits
///    of the products of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_mulhi_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pmulhw((__v4hi)__m1, (__v4hi)__m2);
}

/// Multiplies each 16-bit signed integer element of the first 64-bit
///    integer vector of [4 x i16] by the corresponding 16-bit signed integer
///    element of the second 64-bit integer vector of [4 x i16]. Packs the lower
///    16 bits of the 32-bit products into a 64-bit integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMULLW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
/// \returns A 64-bit integer vector of [4 x i16] containing the lower 16 bits
///    of the products of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_mullo_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pmullw((__v4hi)__m1, (__v4hi)__m2);
}

/// Left-shifts each 16-bit signed integer element of the first
///    parameter, which is a 64-bit integer vector of [4 x i16], by the number
///    of bits specified by the second parameter, which is a 64-bit integer. The
///    lower 16 bits of the results are packed into a 64-bit integer vector of
///    [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSLLW </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [4 x i16].
/// \param __count
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \returns A 64-bit integer vector of [4 x i16] containing the left-shifted
///    values. If \a __count is greater or equal to 16, the result is set to all
///    0.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_sll_pi16(__m64 __m, __m64 __count)
{
    return (__m64)__builtin_ia32_psllw((__v4hi)__m, __count);
}

/// Left-shifts each 16-bit signed integer element of a 64-bit integer
///    vector of [4 x i16] by the number of bits specified by a 32-bit integer.
///    The lower 16 bits of the results are packed into a 64-bit integer vector
///    of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSLLW </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [4 x i16].
/// \param __count
///    A 32-bit integer value.
/// \returns A 64-bit integer vector of [4 x i16] containing the left-shifted
///    values. If \a __count is greater or equal to 16, the result is set to all
///    0.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_slli_pi16(__m64 __m, int __count)
{
    return (__m64)__builtin_ia32_psllwi((__v4hi)__m, __count);
}

/// Left-shifts each 32-bit signed integer element of the first
///    parameter, which is a 64-bit integer vector of [2 x i32], by the number
///    of bits specified by the second parameter, which is a 64-bit integer. The
///    lower 32 bits of the results are packed into a 64-bit integer vector of
///    [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSLLD </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [2 x i32].
/// \param __count
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \returns A 64-bit integer vector of [2 x i32] containing the left-shifted
///    values. If \a __count is greater or equal to 32, the result is set to all
///    0.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_sll_pi32(__m64 __m, __m64 __count)
{
    return (__m64)__builtin_ia32_pslld((__v2si)__m, __count);
}

/// Left-shifts each 32-bit signed integer element of a 64-bit integer
///    vector of [2 x i32] by the number of bits specified by a 32-bit integer.
///    The lower 32 bits of the results are packed into a 64-bit integer vector
///    of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSLLD </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [2 x i32].
/// \param __count
///    A 32-bit integer value.
/// \returns A 64-bit integer vector of [2 x i32] containing the left-shifted
///    values. If \a __count is greater or equal to 32, the result is set to all
///    0.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_slli_pi32(__m64 __m, int __count)
{
    return (__m64)__builtin_ia32_pslldi((__v2si)__m, __count);
}

/// Left-shifts the first 64-bit integer parameter by the number of bits
///    specified by the second 64-bit integer parameter. The lower 64 bits of
///    result are returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSLLQ </c> instruction.
///
/// \param __m
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \param __count
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \returns A 64-bit integer vector containing the left-shifted value. If
///     \a __count is greater or equal to 64, the result is set to 0.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_sll_si64(__m64 __m, __m64 __count)
{
    return (__m64)__builtin_ia32_psllq((__v1di)__m, __count);
}

/// Left-shifts the first parameter, which is a 64-bit integer, by the
///    number of bits specified by the second parameter, which is a 32-bit
///    integer. The lower 64 bits of result are returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSLLQ </c> instruction.
///
/// \param __m
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \param __count
///    A 32-bit integer value.
/// \returns A 64-bit integer vector containing the left-shifted value. If
///     \a __count is greater or equal to 64, the result is set to 0.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_slli_si64(__m64 __m, int __count)
{
    return (__m64)__builtin_ia32_psllqi((__v1di)__m, __count);
}

/// Right-shifts each 16-bit integer element of the first parameter,
///    which is a 64-bit integer vector of [4 x i16], by the number of bits
///    specified by the second parameter, which is a 64-bit integer.
///
///    High-order bits are filled with the sign bit of the initial value of each
///    16-bit element. The 16-bit results are packed into a 64-bit integer
///    vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRAW </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [4 x i16].
/// \param __count
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \returns A 64-bit integer vector of [4 x i16] containing the right-shifted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_sra_pi16(__m64 __m, __m64 __count)
{
    return (__m64)__builtin_ia32_psraw((__v4hi)__m, __count);
}

/// Right-shifts each 16-bit integer element of a 64-bit integer vector
///    of [4 x i16] by the number of bits specified by a 32-bit integer.
///
///    High-order bits are filled with the sign bit of the initial value of each
///    16-bit element. The 16-bit results are packed into a 64-bit integer
///    vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRAW </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [4 x i16].
/// \param __count
///    A 32-bit integer value.
/// \returns A 64-bit integer vector of [4 x i16] containing the right-shifted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_srai_pi16(__m64 __m, int __count)
{
    return (__m64)__builtin_ia32_psrawi((__v4hi)__m, __count);
}

/// Right-shifts each 32-bit integer element of the first parameter,
///    which is a 64-bit integer vector of [2 x i32], by the number of bits
///    specified by the second parameter, which is a 64-bit integer.
///
///    High-order bits are filled with the sign bit of the initial value of each
///    32-bit element. The 32-bit results are packed into a 64-bit integer
///    vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRAD </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [2 x i32].
/// \param __count
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \returns A 64-bit integer vector of [2 x i32] containing the right-shifted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_sra_pi32(__m64 __m, __m64 __count)
{
    return (__m64)__builtin_ia32_psrad((__v2si)__m, __count);
}

/// Right-shifts each 32-bit integer element of a 64-bit integer vector
///    of [2 x i32] by the number of bits specified by a 32-bit integer.
///
///    High-order bits are filled with the sign bit of the initial value of each
///    32-bit element. The 32-bit results are packed into a 64-bit integer
///    vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRAD </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [2 x i32].
/// \param __count
///    A 32-bit integer value.
/// \returns A 64-bit integer vector of [2 x i32] containing the right-shifted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_srai_pi32(__m64 __m, int __count)
{
    return (__m64)__builtin_ia32_psradi((__v2si)__m, __count);
}

/// Right-shifts each 16-bit integer element of the first parameter,
///    which is a 64-bit integer vector of [4 x i16], by the number of bits
///    specified by the second parameter, which is a 64-bit integer.
///
///    High-order bits are cleared. The 16-bit results are packed into a 64-bit
///    integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRLW </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [4 x i16].
/// \param __count
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \returns A 64-bit integer vector of [4 x i16] containing the right-shifted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_srl_pi16(__m64 __m, __m64 __count)
{
    return (__m64)__builtin_ia32_psrlw((__v4hi)__m, __count);
}

/// Right-shifts each 16-bit integer element of a 64-bit integer vector
///    of [4 x i16] by the number of bits specified by a 32-bit integer.
///
///    High-order bits are cleared. The 16-bit results are packed into a 64-bit
///    integer vector of [4 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRLW </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [4 x i16].
/// \param __count
///    A 32-bit integer value.
/// \returns A 64-bit integer vector of [4 x i16] containing the right-shifted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_srli_pi16(__m64 __m, int __count)
{
    return (__m64)__builtin_ia32_psrlwi((__v4hi)__m, __count);
}

/// Right-shifts each 32-bit integer element of the first parameter,
///    which is a 64-bit integer vector of [2 x i32], by the number of bits
///    specified by the second parameter, which is a 64-bit integer.
///
///    High-order bits are cleared. The 32-bit results are packed into a 64-bit
///    integer vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRLD </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [2 x i32].
/// \param __count
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \returns A 64-bit integer vector of [2 x i32] containing the right-shifted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_srl_pi32(__m64 __m, __m64 __count)
{
    return (__m64)__builtin_ia32_psrld((__v2si)__m, __count);
}

/// Right-shifts each 32-bit integer element of a 64-bit integer vector
///    of [2 x i32] by the number of bits specified by a 32-bit integer.
///
///    High-order bits are cleared. The 32-bit results are packed into a 64-bit
///    integer vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRLD </c> instruction.
///
/// \param __m
///    A 64-bit integer vector of [2 x i32].
/// \param __count
///    A 32-bit integer value.
/// \returns A 64-bit integer vector of [2 x i32] containing the right-shifted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_srli_pi32(__m64 __m, int __count)
{
    return (__m64)__builtin_ia32_psrldi((__v2si)__m, __count);
}

/// Right-shifts the first 64-bit integer parameter by the number of bits
///    specified by the second 64-bit integer parameter.
///
///    High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRLQ </c> instruction.
///
/// \param __m
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \param __count
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \returns A 64-bit integer vector containing the right-shifted value.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_srl_si64(__m64 __m, __m64 __count)
{
    return (__m64)__builtin_ia32_psrlq((__v1di)__m, __count);
}

/// Right-shifts the first parameter, which is a 64-bit integer, by the
///    number of bits specified by the second parameter, which is a 32-bit
///    integer.
///
///    High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSRLQ </c> instruction.
///
/// \param __m
///    A 64-bit integer vector interpreted as a single 64-bit integer.
/// \param __count
///    A 32-bit integer value.
/// \returns A 64-bit integer vector containing the right-shifted value.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_srli_si64(__m64 __m, int __count)
{
    return (__m64)__builtin_ia32_psrlqi((__v1di)__m, __count);
}

/// Performs a bitwise AND of two 64-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PAND </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector.
/// \param __m2
///    A 64-bit integer vector.
/// \returns A 64-bit integer vector containing the bitwise AND of both
///    parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_and_si64(__m64 __m1, __m64 __m2)
{
    return __builtin_ia32_pand((__v1di)__m1, (__v1di)__m2);
}

/// Performs a bitwise NOT of the first 64-bit integer vector, and then
///    performs a bitwise AND of the intermediate result and the second 64-bit
///    integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PANDN </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector. The one's complement of this parameter is used
///    in the bitwise AND.
/// \param __m2
///    A 64-bit integer vector.
/// \returns A 64-bit integer vector containing the bitwise AND of the second
///    parameter and the one's complement of the first parameter.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_andnot_si64(__m64 __m1, __m64 __m2)
{
    return __builtin_ia32_pandn((__v1di)__m1, (__v1di)__m2);
}

/// Performs a bitwise OR of two 64-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> POR </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector.
/// \param __m2
///    A 64-bit integer vector.
/// \returns A 64-bit integer vector containing the bitwise OR of both
///    parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_or_si64(__m64 __m1, __m64 __m2)
{
    return __builtin_ia32_por((__v1di)__m1, (__v1di)__m2);
}

/// Performs a bitwise exclusive OR of two 64-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PXOR </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector.
/// \param __m2
///    A 64-bit integer vector.
/// \returns A 64-bit integer vector containing the bitwise exclusive OR of both
///    parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_xor_si64(__m64 __m1, __m64 __m2)
{
    return __builtin_ia32_pxor((__v1di)__m1, (__v1di)__m2);
}

/// Compares the 8-bit integer elements of two 64-bit integer vectors of
///    [8 x i8] to determine if the element of the first vector is equal to the
///    corresponding element of the second vector.
///
///    The comparison yields 0 for false, 0xFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PCMPEQB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8].
/// \param __m2
///    A 64-bit integer vector of [8 x i8].
/// \returns A 64-bit integer vector of [8 x i8] containing the comparison
///    results.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_cmpeq_pi8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pcmpeqb((__v8qi)__m1, (__v8qi)__m2);
}

/// Compares the 16-bit integer elements of two 64-bit integer vectors of
///    [4 x i16] to determine if the element of the first vector is equal to the
///    corresponding element of the second vector.
///
///    The comparison yields 0 for false, 0xFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PCMPEQW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
/// \returns A 64-bit integer vector of [4 x i16] containing the comparison
///    results.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_cmpeq_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pcmpeqw((__v4hi)__m1, (__v4hi)__m2);
}

/// Compares the 32-bit integer elements of two 64-bit integer vectors of
///    [2 x i32] to determine if the element of the first vector is equal to the
///    corresponding element of the second vector.
///
///    The comparison yields 0 for false, 0xFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PCMPEQD </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [2 x i32].
/// \param __m2
///    A 64-bit integer vector of [2 x i32].
/// \returns A 64-bit integer vector of [2 x i32] containing the comparison
///    results.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_cmpeq_pi32(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pcmpeqd((__v2si)__m1, (__v2si)__m2);
}

/// Compares the 8-bit integer elements of two 64-bit integer vectors of
///    [8 x i8] to determine if the element of the first vector is greater than
///    the corresponding element of the second vector.
///
///    The comparison yields 0 for false, 0xFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PCMPGTB </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [8 x i8].
/// \param __m2
///    A 64-bit integer vector of [8 x i8].
/// \returns A 64-bit integer vector of [8 x i8] containing the comparison
///    results.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_cmpgt_pi8(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pcmpgtb((__v8qi)__m1, (__v8qi)__m2);
}

/// Compares the 16-bit integer elements of two 64-bit integer vectors of
///    [4 x i16] to determine if the element of the first vector is greater than
///    the corresponding element of the second vector.
///
///    The comparison yields 0 for false, 0xFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PCMPGTW </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [4 x i16].
/// \param __m2
///    A 64-bit integer vector of [4 x i16].
/// \returns A 64-bit integer vector of [4 x i16] containing the comparison
///    results.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_cmpgt_pi16(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pcmpgtw((__v4hi)__m1, (__v4hi)__m2);
}

/// Compares the 32-bit integer elements of two 64-bit integer vectors of
///    [2 x i32] to determine if the element of the first vector is greater than
///    the corresponding element of the second vector.
///
///    The comparison yields 0 for false, 0xFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PCMPGTD </c> instruction.
///
/// \param __m1
///    A 64-bit integer vector of [2 x i32].
/// \param __m2
///    A 64-bit integer vector of [2 x i32].
/// \returns A 64-bit integer vector of [2 x i32] containing the comparison
///    results.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_cmpgt_pi32(__m64 __m1, __m64 __m2)
{
    return (__m64)__builtin_ia32_pcmpgtd((__v2si)__m1, (__v2si)__m2);
}

/// Constructs a 64-bit integer vector initialized to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PXOR </c> instruction.
///
/// \returns An initialized 64-bit integer vector with all elements set to zero.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_setzero_si64(void)
{
    return __extension__ (__m64){ 0LL };
}

/// Constructs a 64-bit integer vector initialized with the specified
///    32-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i1
///    A 32-bit integer value used to initialize the upper 32 bits of the
///    result.
/// \param __i0
///    A 32-bit integer value used to initialize the lower 32 bits of the
///    result.
/// \returns An initialized 64-bit integer vector.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_set_pi32(int __i1, int __i0)
{
    return (__m64)__builtin_ia32_vec_init_v2si(__i0, __i1);
}

/// Constructs a 64-bit integer vector initialized with the specified
///    16-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __s3
///    A 16-bit integer value used to initialize bits [63:48] of the result.
/// \param __s2
///    A 16-bit integer value used to initialize bits [47:32] of the result.
/// \param __s1
///    A 16-bit integer value used to initialize bits [31:16] of the result.
/// \param __s0
///    A 16-bit integer value used to initialize bits [15:0] of the result.
/// \returns An initialized 64-bit integer vector.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_set_pi16(short __s3, short __s2, short __s1, short __s0)
{
    return (__m64)__builtin_ia32_vec_init_v4hi(__s0, __s1, __s2, __s3);
}

/// Constructs a 64-bit integer vector initialized with the specified
///    8-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b7
///    An 8-bit integer value used to initialize bits [63:56] of the result.
/// \param __b6
///    An 8-bit integer value used to initialize bits [55:48] of the result.
/// \param __b5
///    An 8-bit integer value used to initialize bits [47:40] of the result.
/// \param __b4
///    An 8-bit integer value used to initialize bits [39:32] of the result.
/// \param __b3
///    An 8-bit integer value used to initialize bits [31:24] of the result.
/// \param __b2
///    An 8-bit integer value used to initialize bits [23:16] of the result.
/// \param __b1
///    An 8-bit integer value used to initialize bits [15:8] of the result.
/// \param __b0
///    An 8-bit integer value used to initialize bits [7:0] of the result.
/// \returns An initialized 64-bit integer vector.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_set_pi8(char __b7, char __b6, char __b5, char __b4, char __b3, char __b2,
            char __b1, char __b0)
{
    return (__m64)__builtin_ia32_vec_init_v8qi(__b0, __b1, __b2, __b3,
                                               __b4, __b5, __b6, __b7);
}

/// Constructs a 64-bit integer vector of [2 x i32], with each of the
///    32-bit integer vector elements set to the specified 32-bit integer
///    value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i
///    A 32-bit integer value used to initialize each vector element of the
///    result.
/// \returns An initialized 64-bit integer vector of [2 x i32].
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_set1_pi32(int __i)
{
    return _mm_set_pi32(__i, __i);
}

/// Constructs a 64-bit integer vector of [4 x i16], with each of the
///    16-bit integer vector elements set to the specified 16-bit integer
///    value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __w
///    A 16-bit integer value used to initialize each vector element of the
///    result.
/// \returns An initialized 64-bit integer vector of [4 x i16].
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_set1_pi16(short __w)
{
    return _mm_set_pi16(__w, __w, __w, __w);
}

/// Constructs a 64-bit integer vector of [8 x i8], with each of the
///    8-bit integer vector elements set to the specified 8-bit integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b
///    An 8-bit integer value used to initialize each vector element of the
///    result.
/// \returns An initialized 64-bit integer vector of [8 x i8].
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_set1_pi8(char __b)
{
    return _mm_set_pi8(__b, __b, __b, __b, __b, __b, __b, __b);
}

/// Constructs a 64-bit integer vector, initialized in reverse order with
///    the specified 32-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i0
///    A 32-bit integer value used to initialize the lower 32 bits of the
///    result.
/// \param __i1
///    A 32-bit integer value used to initialize the upper 32 bits of the
///    result.
/// \returns An initialized 64-bit integer vector.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_setr_pi32(int __i0, int __i1)
{
    return _mm_set_pi32(__i1, __i0);
}

/// Constructs a 64-bit integer vector, initialized in reverse order with
///    the specified 16-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __w0
///    A 16-bit integer value used to initialize bits [15:0] of the result.
/// \param __w1
///    A 16-bit integer value used to initialize bits [31:16] of the result.
/// \param __w2
///    A 16-bit integer value used to initialize bits [47:32] of the result.
/// \param __w3
///    A 16-bit integer value used to initialize bits [63:48] of the result.
/// \returns An initialized 64-bit integer vector.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_setr_pi16(short __w0, short __w1, short __w2, short __w3)
{
    return _mm_set_pi16(__w3, __w2, __w1, __w0);
}

/// Constructs a 64-bit integer vector, initialized in reverse order with
///    the specified 8-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b0
///    An 8-bit integer value used to initialize bits [7:0] of the result.
/// \param __b1
///    An 8-bit integer value used to initialize bits [15:8] of the result.
/// \param __b2
///    An 8-bit integer value used to initialize bits [23:16] of the result.
/// \param __b3
///    An 8-bit integer value used to initialize bits [31:24] of the result.
/// \param __b4
///    An 8-bit integer value used to initialize bits [39:32] of the result.
/// \param __b5
///    An 8-bit integer value used to initialize bits [47:40] of the result.
/// \param __b6
///    An 8-bit integer value used to initialize bits [55:48] of the result.
/// \param __b7
///    An 8-bit integer value used to initialize bits [63:56] of the result.
/// \returns An initialized 64-bit integer vector.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_setr_pi8(char __b0, char __b1, char __b2, char __b3, char __b4, char __b5,
             char __b6, char __b7)
{
    return _mm_set_pi8(__b7, __b6, __b5, __b4, __b3, __b2, __b1, __b0);
}

#undef __DEFAULT_FN_ATTRS

/* Aliases for compatibility. */
#define _m_empty _mm_empty
#define _m_from_int _mm_cvtsi32_si64
#define _m_from_int64 _mm_cvtsi64_m64
#define _m_to_int _mm_cvtsi64_si32
#define _m_to_int64 _mm_cvtm64_si64
#define _m_packsswb _mm_packs_pi16
#define _m_packssdw _mm_packs_pi32
#define _m_packuswb _mm_packs_pu16
#define _m_punpckhbw _mm_unpackhi_pi8
#define _m_punpckhwd _mm_unpackhi_pi16
#define _m_punpckhdq _mm_unpackhi_pi32
#define _m_punpcklbw _mm_unpacklo_pi8
#define _m_punpcklwd _mm_unpacklo_pi16
#define _m_punpckldq _mm_unpacklo_pi32
#define _m_paddb _mm_add_pi8
#define _m_paddw _mm_add_pi16
#define _m_paddd _mm_add_pi32
#define _m_paddsb _mm_adds_pi8
#define _m_paddsw _mm_adds_pi16
#define _m_paddusb _mm_adds_pu8
#define _m_paddusw _mm_adds_pu16
#define _m_psubb _mm_sub_pi8
#define _m_psubw _mm_sub_pi16
#define _m_psubd _mm_sub_pi32
#define _m_psubsb _mm_subs_pi8
#define _m_psubsw _mm_subs_pi16
#define _m_psubusb _mm_subs_pu8
#define _m_psubusw _mm_subs_pu16
#define _m_pmaddwd _mm_madd_pi16
#define _m_pmulhw _mm_mulhi_pi16
#define _m_pmullw _mm_mullo_pi16
#define _m_psllw _mm_sll_pi16
#define _m_psllwi _mm_slli_pi16
#define _m_pslld _mm_sll_pi32
#define _m_pslldi _mm_slli_pi32
#define _m_psllq _mm_sll_si64
#define _m_psllqi _mm_slli_si64
#define _m_psraw _mm_sra_pi16
#define _m_psrawi _mm_srai_pi16
#define _m_psrad _mm_sra_pi32
#define _m_psradi _mm_srai_pi32
#define _m_psrlw _mm_srl_pi16
#define _m_psrlwi _mm_srli_pi16
#define _m_psrld _mm_srl_pi32
#define _m_psrldi _mm_srli_pi32
#define _m_psrlq _mm_srl_si64
#define _m_psrlqi _mm_srli_si64
#define _m_pand _mm_and_si64
#define _m_pandn _mm_andnot_si64
#define _m_por _mm_or_si64
#define _m_pxor _mm_xor_si64
#define _m_pcmpeqb _mm_cmpeq_pi8
#define _m_pcmpeqw _mm_cmpeq_pi16
#define _m_pcmpeqd _mm_cmpeq_pi32
#define _m_pcmpgtb _mm_cmpgt_pi8
#define _m_pcmpgtw _mm_cmpgt_pi16
#define _m_pcmpgtd _mm_cmpgt_pi32

#endif /* __MMINTRIN_H */
# 1558 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mmintrin.h" 3

# 14 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 2 3

typedef int __v4si __attribute__((__vector_size__(16)));
typedef float __v4sf __attribute__((__vector_size__(16)));
typedef float __m128 __attribute__((__vector_size__(16), __aligned__(16)));

typedef float __m128_u __attribute__((__vector_size__(16), __aligned__(1)));

/* Unsigned types */
typedef unsigned int __v4su __attribute__((__vector_size__(16)));

/* This header should only be included in a hosted environment as it depends on
 * a standard library to provide allocation routines. */
#if 0 /* disabled by -frewrite-includes */
#if __STDC_HOSTED__
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
#if 0 /* expanded by -frewrite-includes */
#include <mm_malloc.h>
#endif /* expanded by -frewrite-includes */
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 1 3
/*===---- mm_malloc.h - Allocating and Freeing Aligned Memory Blocks -------===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __MM_MALLOC_H
#define __MM_MALLOC_H

#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 1 3
// -*- C++ -*-
//===--------------------------- stdlib.h ---------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#if 0 /* disabled by -frewrite-includes */
#if defined(__need_malloc_and_calloc) || defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 11 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#endif
# 15 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(_LIBCPP_STDLIB_INCLUDE_NEXT)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#undef _LIBCPP_STDLIB_INCLUDE_NEXT
#endif
# 19 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 20 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if 0
#elif !defined(_LIBCPP_STDLIB_H)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 23 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#define _LIBCPP_STDLIB_H

/*
    stdlib.h synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 91 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 92 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 94 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 95 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#endif
# 96 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#if 0 /* expanded by -frewrite-includes */
#include_next <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 97 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 98 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#ifdef __cplusplus
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 100 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 101 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
#endif  // __cplusplus
# 102 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3

#endif  // _LIBCPP_STDLIB_H
# 104 "/Users/vsk/src/builds/llvm-project-master-RA/bin/../include/c++/v1/stdlib.h" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 2 3

#ifdef _WIN32
#if 0 /* expanded by -frewrite-includes */
#include <malloc.h>
#endif /* expanded by -frewrite-includes */
# 16 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
# 17 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
#else
# 18 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
#ifndef __cplusplus
extern int posix_memalign(void **__memptr, size_t __alignment, size_t __size);
#else
# 21 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
// Some systems (e.g. those with GNU libc) declare posix_memalign with an
// exception specifier. Via an "egregious workaround" in
// Sema::CheckEquivalentExceptionSpec, Clang accepts the following as a valid
// redeclaration of glibc's declaration.
extern "C" int posix_memalign(void **__memptr, size_t __alignment, size_t __size);
#endif
# 27 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
#endif
# 28 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3

#if 0 /* disabled by -frewrite-includes */
#if !(defined(_WIN32) && defined(_mm_malloc))
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 30 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
static __inline__ void *__attribute__((__always_inline__, __nodebug__,
                                       __malloc__))
_mm_malloc(size_t __size, size_t __align)
{
  if (__align == 1) {
    return malloc(__size);
  }

  if (!(__align & (__align - 1)) && __align < sizeof(void *))
    __align = sizeof(void *);

  void *__mallocedMemory;
#if 0 /* disabled by -frewrite-includes */
#if defined(__MINGW32__)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 43 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
  __mallocedMemory = __mingw_aligned_malloc(__size, __align);
#if 0 /* disabled by -frewrite-includes */
#if 0
#elif defined(_WIN32)
#endif
#endif /* disabled by -frewrite-includes */
#elif 0 /* evaluated by -frewrite-includes */
# 45 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
  __mallocedMemory = _aligned_malloc(__size, __align);
#else
# 47 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
  if (posix_memalign(&__mallocedMemory, __align, __size))
    return 0;
#endif
# 50 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3

  return __mallocedMemory;
}

static __inline__ void __attribute__((__always_inline__, __nodebug__))
_mm_free(void *__p)
{
  free(__p);
}
#endif
# 60 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3

#endif /* __MM_MALLOC_H */
# 62 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/mm_malloc.h" 3
# 28 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 2 3
#endif
# 29 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/* Define the default attributes for the functions in this file. */
#define __DEFAULT_FN_ATTRS __attribute__((__always_inline__, __nodebug__, __target__("sse"), __min_vector_width__(128)))
#define __DEFAULT_FN_ATTRS_MMX __attribute__((__always_inline__, __nodebug__, __target__("mmx,sse"), __min_vector_width__(64)))

/// Adds the 32-bit float values in the low-order bits of the operands.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VADDSS / ADDSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the source operands.
///    The lower 32 bits of this operand are used in the calculation.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the source operands.
///    The lower 32 bits of this operand are used in the calculation.
/// \returns A 128-bit vector of [4 x float] whose lower 32 bits contain the sum
///    of the lower 32 bits of both operands. The upper 96 bits are copied from
///    the upper 96 bits of the first source operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_add_ss(__m128 __a, __m128 __b)
{
  __a[0] += __b[0];
  return __a;
}

/// Adds two 128-bit vectors of [4 x float], and returns the results of
///    the addition.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VADDPS / ADDPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the source operands.
/// \returns A 128-bit vector of [4 x float] containing the sums of both
///    operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_add_ps(__m128 __a, __m128 __b)
{
  return (__m128)((__v4sf)__a + (__v4sf)__b);
}

/// Subtracts the 32-bit float value in the low-order bits of the second
///    operand from the corresponding value in the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSUBSS / SUBSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing the minuend. The lower 32 bits
///    of this operand are used in the calculation.
/// \param __b
///    A 128-bit vector of [4 x float] containing the subtrahend. The lower 32
///    bits of this operand are used in the calculation.
/// \returns A 128-bit vector of [4 x float] whose lower 32 bits contain the
///    difference of the lower 32 bits of both operands. The upper 96 bits are
///    copied from the upper 96 bits of the first source operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_sub_ss(__m128 __a, __m128 __b)
{
  __a[0] -= __b[0];
  return __a;
}

/// Subtracts each of the values of the second operand from the first
///    operand, both of which are 128-bit vectors of [4 x float] and returns
///    the results of the subtraction.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSUBPS / SUBPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing the minuend.
/// \param __b
///    A 128-bit vector of [4 x float] containing the subtrahend.
/// \returns A 128-bit vector of [4 x float] containing the differences between
///    both operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_sub_ps(__m128 __a, __m128 __b)
{
  return (__m128)((__v4sf)__a - (__v4sf)__b);
}

/// Multiplies two 32-bit float values in the low-order bits of the
///    operands.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMULSS / MULSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the source operands.
///    The lower 32 bits of this operand are used in the calculation.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the source operands.
///    The lower 32 bits of this operand are used in the calculation.
/// \returns A 128-bit vector of [4 x float] containing the product of the lower
///    32 bits of both operands. The upper 96 bits are copied from the upper 96
///    bits of the first source operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_mul_ss(__m128 __a, __m128 __b)
{
  __a[0] *= __b[0];
  return __a;
}

/// Multiplies two 128-bit vectors of [4 x float] and returns the
///    results of the multiplication.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMULPS / MULPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the source operands.
/// \returns A 128-bit vector of [4 x float] containing the products of both
///    operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_mul_ps(__m128 __a, __m128 __b)
{
  return (__m128)((__v4sf)__a * (__v4sf)__b);
}

/// Divides the value in the low-order 32 bits of the first operand by
///    the corresponding value in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VDIVSS / DIVSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing the dividend. The lower 32
///    bits of this operand are used in the calculation.
/// \param __b
///    A 128-bit vector of [4 x float] containing the divisor. The lower 32 bits
///    of this operand are used in the calculation.
/// \returns A 128-bit vector of [4 x float] containing the quotients of the
///    lower 32 bits of both operands. The upper 96 bits are copied from the
///    upper 96 bits of the first source operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_div_ss(__m128 __a, __m128 __b)
{
  __a[0] /= __b[0];
  return __a;
}

/// Divides two 128-bit vectors of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VDIVPS / DIVPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing the dividend.
/// \param __b
///    A 128-bit vector of [4 x float] containing the divisor.
/// \returns A 128-bit vector of [4 x float] containing the quotients of both
///    operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_div_ps(__m128 __a, __m128 __b)
{
  return (__m128)((__v4sf)__a / (__v4sf)__b);
}

/// Calculates the square root of the value stored in the low-order bits
///    of a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSQRTSS / SQRTSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the calculation.
/// \returns A 128-bit vector of [4 x float] containing the square root of the
///    value in the low-order bits of the operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_sqrt_ss(__m128 __a)
{
  return (__m128)__builtin_ia32_sqrtss((__v4sf)__a);
}

/// Calculates the square roots of the values stored in a 128-bit vector
///    of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSQRTPS / SQRTPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the square roots of the
///    values in the operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_sqrt_ps(__m128 __a)
{
  return __builtin_ia32_sqrtps((__v4sf)__a);
}

/// Calculates the approximate reciprocal of the value stored in the
///    low-order bits of a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VRCPSS / RCPSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the calculation.
/// \returns A 128-bit vector of [4 x float] containing the approximate
///    reciprocal of the value in the low-order bits of the operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_rcp_ss(__m128 __a)
{
  return (__m128)__builtin_ia32_rcpss((__v4sf)__a);
}

/// Calculates the approximate reciprocals of the values stored in a
///    128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VRCPPS / RCPPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the approximate
///    reciprocals of the values in the operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_rcp_ps(__m128 __a)
{
  return (__m128)__builtin_ia32_rcpps((__v4sf)__a);
}

/// Calculates the approximate reciprocal of the square root of the value
///    stored in the low-order bits of a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VRSQRTSS / RSQRTSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the calculation.
/// \returns A 128-bit vector of [4 x float] containing the approximate
///    reciprocal of the square root of the value in the low-order bits of the
///    operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_rsqrt_ss(__m128 __a)
{
  return __builtin_ia32_rsqrtss((__v4sf)__a);
}

/// Calculates the approximate reciprocals of the square roots of the
///    values stored in a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VRSQRTPS / RSQRTPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the approximate
///    reciprocals of the square roots of the values in the operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_rsqrt_ps(__m128 __a)
{
  return __builtin_ia32_rsqrtps((__v4sf)__a);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands and returns the lesser value in the low-order bits of the
///    vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMINSS / MINSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] whose lower 32 bits contain the
///    minimum value between both operands. The upper 96 bits are copied from
///    the upper 96 bits of the first source operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_min_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_minss((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 128-bit vectors of [4 x float] and returns the lesser
///    of each pair of values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMINPS / MINPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands.
/// \returns A 128-bit vector of [4 x float] containing the minimum values
///    between both operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_min_ps(__m128 __a, __m128 __b)
{
  return __builtin_ia32_minps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands and returns the greater value in the low-order bits of a 128-bit
///    vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMAXSS / MAXSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] whose lower 32 bits contain the
///    maximum value between both operands. The upper 96 bits are copied from
///    the upper 96 bits of the first source operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_max_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_maxss((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 128-bit vectors of [4 x float] and returns the greater
///    of each pair of values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMAXPS / MAXPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands.
/// \returns A 128-bit vector of [4 x float] containing the maximum values
///    between both operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_max_ps(__m128 __a, __m128 __b)
{
  return __builtin_ia32_maxps((__v4sf)__a, (__v4sf)__b);
}

/// Performs a bitwise AND of two 128-bit vectors of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VANDPS / ANDPS </c> instructions.
///
/// \param __a
///    A 128-bit vector containing one of the source operands.
/// \param __b
///    A 128-bit vector containing one of the source operands.
/// \returns A 128-bit vector of [4 x float] containing the bitwise AND of the
///    values between both operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_and_ps(__m128 __a, __m128 __b)
{
  return (__m128)((__v4su)__a & (__v4su)__b);
}

/// Performs a bitwise AND of two 128-bit vectors of [4 x float], using
///    the one's complement of the values contained in the first source
///    operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VANDNPS / ANDNPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing the first source operand. The
///    one's complement of this value is used in the bitwise AND.
/// \param __b
///    A 128-bit vector of [4 x float] containing the second source operand.
/// \returns A 128-bit vector of [4 x float] containing the bitwise AND of the
///    one's complement of the first operand and the values in the second
///    operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_andnot_ps(__m128 __a, __m128 __b)
{
  return (__m128)(~(__v4su)__a & (__v4su)__b);
}

/// Performs a bitwise OR of two 128-bit vectors of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VORPS / ORPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the source operands.
/// \returns A 128-bit vector of [4 x float] containing the bitwise OR of the
///    values between both operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_or_ps(__m128 __a, __m128 __b)
{
  return (__m128)((__v4su)__a | (__v4su)__b);
}

/// Performs a bitwise exclusive OR of two 128-bit vectors of
///    [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VXORPS / XORPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the source operands.
/// \returns A 128-bit vector of [4 x float] containing the bitwise exclusive OR
///    of the values between both operands.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_xor_ps(__m128 __a, __m128 __b)
{
  return (__m128)((__v4su)__a ^ (__v4su)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands for equality and returns the result of the comparison in the
///    low-order bits of a vector [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPEQSS / CMPEQSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpeq_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpeqss((__v4sf)__a, (__v4sf)__b);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] for equality.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPEQPS / CMPEQPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpeq_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpeqps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is less than the
///    corresponding value in the second operand and returns the result of the
///    comparison in the low-order bits of a vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTSS / CMPLTSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmplt_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpltss((__v4sf)__a, (__v4sf)__b);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are less than those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTPS / CMPLTPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmplt_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpltps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is less than or
///    equal to the corresponding value in the second operand and returns the
///    result of the comparison in the low-order bits of a vector of
///    [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLESS / CMPLESS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmple_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpless((__v4sf)__a, (__v4sf)__b);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are less than or equal to those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLEPS / CMPLEPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmple_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpleps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is greater than
///    the corresponding value in the second operand and returns the result of
///    the comparison in the low-order bits of a vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTSS / CMPLTSS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpgt_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_shufflevector((__v4sf)__a,
                                         (__v4sf)__builtin_ia32_cmpltss((__v4sf)__b, (__v4sf)__a),
                                         4, 1, 2, 3);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are greater than those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTPS / CMPLTPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpgt_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpltps((__v4sf)__b, (__v4sf)__a);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is greater than
///    or equal to the corresponding value in the second operand and returns
///    the result of the comparison in the low-order bits of a vector of
///    [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLESS / CMPLESS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpge_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_shufflevector((__v4sf)__a,
                                         (__v4sf)__builtin_ia32_cmpless((__v4sf)__b, (__v4sf)__a),
                                         4, 1, 2, 3);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are greater than or equal to those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLEPS / CMPLEPS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpge_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpleps((__v4sf)__b, (__v4sf)__a);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands for inequality and returns the result of the comparison in the
///    low-order bits of a vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNEQSS / CMPNEQSS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpneq_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpneqss((__v4sf)__a, (__v4sf)__b);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] for inequality.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNEQPS / CMPNEQPS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpneq_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpneqps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is not less than
///    the corresponding value in the second operand and returns the result of
///    the comparison in the low-order bits of a vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTSS / CMPNLTSS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpnlt_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpnltss((__v4sf)__a, (__v4sf)__b);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are not less than those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTPS / CMPNLTPS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpnlt_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpnltps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is not less than
///    or equal to the corresponding value in the second operand and returns
///    the result of the comparison in the low-order bits of a vector of
///    [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLESS / CMPNLESS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpnle_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpnless((__v4sf)__a, (__v4sf)__b);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are not less than or equal to those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLEPS / CMPNLEPS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpnle_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpnleps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is not greater
///    than the corresponding value in the second operand and returns the
///    result of the comparison in the low-order bits of a vector of
///    [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTSS / CMPNLTSS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpngt_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_shufflevector((__v4sf)__a,
                                         (__v4sf)__builtin_ia32_cmpnltss((__v4sf)__b, (__v4sf)__a),
                                         4, 1, 2, 3);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are not greater than those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTPS / CMPNLTPS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpngt_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpnltps((__v4sf)__b, (__v4sf)__a);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is not greater
///    than or equal to the corresponding value in the second operand and
///    returns the result of the comparison in the low-order bits of a vector
///    of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLESS / CMPNLESS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpnge_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_shufflevector((__v4sf)__a,
                                         (__v4sf)__builtin_ia32_cmpnless((__v4sf)__b, (__v4sf)__a),
                                         4, 1, 2, 3);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are not greater than or equal to those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLEPS / CMPNLEPS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpnge_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpnleps((__v4sf)__b, (__v4sf)__a);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is ordered with
///    respect to the corresponding value in the second operand and returns the
///    result of the comparison in the low-order bits of a vector of
///    [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPORDSS / CMPORDSS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpord_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpordss((__v4sf)__a, (__v4sf)__b);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are ordered with respect to those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPORDPS / CMPORDPS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpord_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpordps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the value in the first operand is unordered
///    with respect to the corresponding value in the second operand and
///    returns the result of the comparison in the low-order bits of a vector
///    of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPUNORDSS / CMPUNORDSS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float] containing one of the operands. The lower
///    32 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [4 x float] containing the comparison results
///    in the low-order bits.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpunord_ss(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpunordss((__v4sf)__a, (__v4sf)__b);
}

/// Compares each of the corresponding 32-bit float values of the
///    128-bit vectors of [4 x float] to determine if the values in the first
///    operand are unordered with respect to those in the second operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPUNORDPS / CMPUNORDPS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x float] containing the comparison results.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cmpunord_ps(__m128 __a, __m128 __b)
{
  return (__m128)__builtin_ia32_cmpunordps((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands for equality and returns the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISS / COMISS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the
///    two lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comieq_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_comieq((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the first operand is less than the second
///    operand and returns the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISS / COMISS </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///     lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comilt_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_comilt((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the first operand is less than or equal to the
///    second operand and returns the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISS / COMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///     lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comile_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_comile((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the first operand is greater than the second
///    operand and returns the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISS / COMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the
///     two lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comigt_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_comigt((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the first operand is greater than or equal to
///    the second operand and returns the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISS / COMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///    lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comige_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_comige((__v4sf)__a, (__v4sf)__b);
}

/// Compares two 32-bit float values in the low-order bits of both
///    operands to determine if the first operand is not equal to the second
///    operand and returns the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 1 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISS / COMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the
///     two lower 32-bit values is NaN, 1 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comineq_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_comineq((__v4sf)__a, (__v4sf)__b);
}

/// Performs an unordered comparison of two 32-bit float values using
///    the low-order bits of both operands to determine equality and returns
///    the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISS / UCOMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///     lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomieq_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_ucomieq((__v4sf)__a, (__v4sf)__b);
}

/// Performs an unordered comparison of two 32-bit float values using
///    the low-order bits of both operands to determine if the first operand is
///    less than the second operand and returns the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISS / UCOMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///    lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomilt_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_ucomilt((__v4sf)__a, (__v4sf)__b);
}

/// Performs an unordered comparison of two 32-bit float values using
///    the low-order bits of both operands to determine if the first operand is
///    less than or equal to the second operand and returns the result of the
///    comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISS / UCOMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///     lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomile_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_ucomile((__v4sf)__a, (__v4sf)__b);
}

/// Performs an unordered comparison of two 32-bit float values using
///    the low-order bits of both operands to determine if the first operand is
///    greater than the second operand and returns the result of the
///    comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISS / UCOMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///     lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomigt_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_ucomigt((__v4sf)__a, (__v4sf)__b);
}

/// Performs an unordered comparison of two 32-bit float values using
///    the low-order bits of both operands to determine if the first operand is
///    greater than or equal to the second operand and returns the result of
///    the comparison.
///
///    If either of the two lower 32-bit values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISS / UCOMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///     lower 32-bit values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomige_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_ucomige((__v4sf)__a, (__v4sf)__b);
}

/// Performs an unordered comparison of two 32-bit float values using
///    the low-order bits of both operands to determine inequality and returns
///    the result of the comparison.
///
///    If either of the two lower 32-bit values is NaN, 1 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISS / UCOMISS </c> instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the comparison.
/// \returns An integer containing the comparison results. If either of the two
///    lower 32-bit values is NaN, 1 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomineq_ss(__m128 __a, __m128 __b)
{
  return __builtin_ia32_ucomineq((__v4sf)__a, (__v4sf)__b);
}

/// Converts a float value contained in the lower 32 bits of a vector of
///    [4 x float] into a 32-bit integer.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSS2SI / CVTSS2SI </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the conversion.
/// \returns A 32-bit integer containing the converted value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvtss_si32(__m128 __a)
{
  return __builtin_ia32_cvtss2si((__v4sf)__a);
}

/// Converts a float value contained in the lower 32 bits of a vector of
///    [4 x float] into a 32-bit integer.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSS2SI / CVTSS2SI </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the conversion.
/// \returns A 32-bit integer containing the converted value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvt_ss2si(__m128 __a)
{
  return _mm_cvtss_si32(__a);
}

#ifdef __x86_64__

/// Converts a float value contained in the lower 32 bits of a vector of
///    [4 x float] into a 64-bit integer.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSS2SI / CVTSS2SI </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the conversion.
/// \returns A 64-bit integer containing the converted value.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvtss_si64(__m128 __a)
{
  return __builtin_ia32_cvtss2si64((__v4sf)__a);
}

#endif
# 1346 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/// Converts two low-order float values in a 128-bit vector of
///    [4 x float] into a 64-bit vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPS2PI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 64-bit integer vector containing the converted values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvtps_pi32(__m128 __a)
{
  return (__m64)__builtin_ia32_cvtps2pi((__v4sf)__a);
}

/// Converts two low-order float values in a 128-bit vector of
///    [4 x float] into a 64-bit vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPS2PI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 64-bit integer vector containing the converted values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvt_ps2pi(__m128 __a)
{
  return _mm_cvtps_pi32(__a);
}

/// Converts a float value contained in the lower 32 bits of a vector of
///    [4 x float] into a 32-bit integer, truncating the result when it is
///    inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTSS2SI / CVTTSS2SI </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the conversion.
/// \returns A 32-bit integer containing the converted value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvttss_si32(__m128 __a)
{
  return __builtin_ia32_cvttss2si((__v4sf)__a);
}

/// Converts a float value contained in the lower 32 bits of a vector of
///    [4 x float] into a 32-bit integer, truncating the result when it is
///    inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTSS2SI / CVTTSS2SI </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the conversion.
/// \returns A 32-bit integer containing the converted value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvtt_ss2si(__m128 __a)
{
  return _mm_cvttss_si32(__a);
}

#ifdef __x86_64__
/// Converts a float value contained in the lower 32 bits of a vector of
///    [4 x float] into a 64-bit integer, truncating the result when it is
///    inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTSS2SI / CVTTSS2SI </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the conversion.
/// \returns A 64-bit integer containing the converted value.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvttss_si64(__m128 __a)
{
  return __builtin_ia32_cvttss2si64((__v4sf)__a);
}
#endif
# 1437 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/// Converts two low-order float values in a 128-bit vector of
///    [4 x float] into a 64-bit vector of [2 x i32], truncating the result
///    when it is inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTTPS2PI / VTTPS2PI </c>
///   instructions.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 64-bit integer vector containing the converted values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvttps_pi32(__m128 __a)
{
  return (__m64)__builtin_ia32_cvttps2pi((__v4sf)__a);
}

/// Converts two low-order float values in a 128-bit vector of [4 x
///    float] into a 64-bit vector of [2 x i32], truncating the result when it
///    is inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTTPS2PI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 64-bit integer vector containing the converted values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvtt_ps2pi(__m128 __a)
{
  return _mm_cvttps_pi32(__a);
}

/// Converts a 32-bit signed integer value into a floating point value
///    and writes it to the lower 32 bits of the destination. The remaining
///    higher order elements of the destination vector are copied from the
///    corresponding elements in the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSI2SS / CVTSI2SS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 32-bit signed integer operand containing the value to be converted.
/// \returns A 128-bit vector of [4 x float] whose lower 32 bits contain the
///    converted value of the second operand. The upper 96 bits are copied from
///    the upper 96 bits of the first operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvtsi32_ss(__m128 __a, int __b)
{
  __a[0] = __b;
  return __a;
}

/// Converts a 32-bit signed integer value into a floating point value
///    and writes it to the lower 32 bits of the destination. The remaining
///    higher order elements of the destination are copied from the
///    corresponding elements in the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSI2SS / CVTSI2SS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 32-bit signed integer operand containing the value to be converted.
/// \returns A 128-bit vector of [4 x float] whose lower 32 bits contain the
///    converted value of the second operand. The upper 96 bits are copied from
///    the upper 96 bits of the first operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvt_si2ss(__m128 __a, int __b)
{
  return _mm_cvtsi32_ss(__a, __b);
}

#ifdef __x86_64__

/// Converts a 64-bit signed integer value into a floating point value
///    and writes it to the lower 32 bits of the destination. The remaining
///    higher order elements of the destination are copied from the
///    corresponding elements in the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSI2SS / CVTSI2SS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 64-bit signed integer operand containing the value to be converted.
/// \returns A 128-bit vector of [4 x float] whose lower 32 bits contain the
///    converted value of the second operand. The upper 96 bits are copied from
///    the upper 96 bits of the first operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvtsi64_ss(__m128 __a, long long __b)
{
  __a[0] = __b;
  return __a;
}

#endif
# 1544 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/// Converts two elements of a 64-bit vector of [2 x i32] into two
///    floating point values and writes them to the lower 64-bits of the
///    destination. The remaining higher order elements of the destination are
///    copied from the corresponding elements in the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 64-bit vector of [2 x i32]. The elements in this vector are converted
///    and written to the corresponding low-order elements in the destination.
/// \returns A 128-bit vector of [4 x float] whose lower 64 bits contain the
///    converted value of the second operand. The upper 64 bits are copied from
///    the upper 64 bits of the first operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS_MMX
_mm_cvtpi32_ps(__m128 __a, __m64 __b)
{
  return __builtin_ia32_cvtpi2ps((__v4sf)__a, (__v2si)__b);
}

/// Converts two elements of a 64-bit vector of [2 x i32] into two
///    floating point values and writes them to the lower 64-bits of the
///    destination. The remaining higher order elements of the destination are
///    copied from the corresponding elements in the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \param __b
///    A 64-bit vector of [2 x i32]. The elements in this vector are converted
///    and written to the corresponding low-order elements in the destination.
/// \returns A 128-bit vector of [4 x float] whose lower 64 bits contain the
///    converted value from the second operand. The upper 64 bits are copied
///    from the upper 64 bits of the first operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS_MMX
_mm_cvt_pi2ps(__m128 __a, __m64 __b)
{
  return _mm_cvtpi32_ps(__a, __b);
}

/// Extracts a float value contained in the lower 32 bits of a vector of
///    [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower 32 bits of this operand are
///    used in the extraction.
/// \returns A 32-bit float containing the extracted value.
static __inline__ float __DEFAULT_FN_ATTRS
_mm_cvtss_f32(__m128 __a)
{
  return __a[0];
}

/// Loads two packed float values from the address \a __p into the
///     high-order bits of a 128-bit vector of [4 x float]. The low-order bits
///     are copied from the low-order bits of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVHPD / MOVHPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. Bits [63:0] are written to bits [63:0]
///    of the destination.
/// \param __p
///    A pointer to two packed float values. Bits [63:0] are written to bits
///    [127:64] of the destination.
/// \returns A 128-bit vector of [4 x float] containing the moved values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_loadh_pi(__m128 __a, const __m64 *__p)
{
  typedef float __mm_loadh_pi_v2f32 __attribute__((__vector_size__(8)));
  struct __mm_loadh_pi_struct {
    __mm_loadh_pi_v2f32 __u;
  } __attribute__((__packed__, __may_alias__));
  __mm_loadh_pi_v2f32 __b = ((const struct __mm_loadh_pi_struct*)__p)->__u;
  __m128 __bb = __builtin_shufflevector(__b, __b, 0, 1, 0, 1);
  return __builtin_shufflevector(__a, __bb, 0, 1, 4, 5);
}

/// Loads two packed float values from the address \a __p into the
///    low-order bits of a 128-bit vector of [4 x float]. The high-order bits
///    are copied from the high-order bits of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVLPD / MOVLPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. Bits [127:64] are written to bits
///    [127:64] of the destination.
/// \param __p
///    A pointer to two packed float values. Bits [63:0] are written to bits
///    [63:0] of the destination.
/// \returns A 128-bit vector of [4 x float] containing the moved values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_loadl_pi(__m128 __a, const __m64 *__p)
{
  typedef float __mm_loadl_pi_v2f32 __attribute__((__vector_size__(8)));
  struct __mm_loadl_pi_struct {
    __mm_loadl_pi_v2f32 __u;
  } __attribute__((__packed__, __may_alias__));
  __mm_loadl_pi_v2f32 __b = ((const struct __mm_loadl_pi_struct*)__p)->__u;
  __m128 __bb = __builtin_shufflevector(__b, __b, 0, 1, 0, 1);
  return __builtin_shufflevector(__a, __bb, 4, 5, 2, 3);
}

/// Constructs a 128-bit floating-point vector of [4 x float]. The lower
///    32 bits of the vector are initialized with the single-precision
///    floating-point value loaded from a specified memory location. The upper
///    96 bits are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVSS / MOVSS </c> instruction.
///
/// \param __p
///    A pointer to a 32-bit memory location containing a single-precision
///    floating-point value.
/// \returns An initialized 128-bit floating-point vector of [4 x float]. The
///    lower 32 bits contain the value loaded from the memory location. The
///    upper 96 bits are set to zero.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_load_ss(const float *__p)
{
  struct __mm_load_ss_struct {
    float __u;
  } __attribute__((__packed__, __may_alias__));
  float __u = ((const struct __mm_load_ss_struct*)__p)->__u;
  return __extension__ (__m128){ __u, 0, 0, 0 };
}

/// Loads a 32-bit float value and duplicates it to all four vector
///    elements of a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VBROADCASTSS / MOVSS + shuffling </c>
///    instruction.
///
/// \param __p
///    A pointer to a float value to be loaded and duplicated.
/// \returns A 128-bit vector of [4 x float] containing the loaded and
///    duplicated values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_load1_ps(const float *__p)
{
  struct __mm_load1_ps_struct {
    float __u;
  } __attribute__((__packed__, __may_alias__));
  float __u = ((const struct __mm_load1_ps_struct*)__p)->__u;
  return __extension__ (__m128){ __u, __u, __u, __u };
}

#define        _mm_load_ps1(p) _mm_load1_ps(p)

/// Loads a 128-bit floating-point vector of [4 x float] from an aligned
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPS / MOVAPS </c> instruction.
///
/// \param __p
///    A pointer to a 128-bit memory location. The address of the memory
///    location has to be 128-bit aligned.
/// \returns A 128-bit vector of [4 x float] containing the loaded values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_load_ps(const float *__p)
{
  return *(const __m128*)__p;
}

/// Loads a 128-bit floating-point vector of [4 x float] from an
///    unaligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVUPS / MOVUPS </c> instruction.
///
/// \param __p
///    A pointer to a 128-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [4 x float] containing the loaded values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_loadu_ps(const float *__p)
{
  struct __loadu_ps {
    __m128_u __v;
  } __attribute__((__packed__, __may_alias__));
  return ((const struct __loadu_ps*)__p)->__v;
}

/// Loads four packed float values, in reverse order, from an aligned
///    memory location to 32-bit elements in a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPS / MOVAPS + shuffling </c>
///    instruction.
///
/// \param __p
///    A pointer to a 128-bit memory location. The address of the memory
///    location has to be 128-bit aligned.
/// \returns A 128-bit vector of [4 x float] containing the moved values, loaded
///    in reverse order.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_loadr_ps(const float *__p)
{
  __m128 __a = _mm_load_ps(__p);
  return __builtin_shufflevector((__v4sf)__a, (__v4sf)__a, 3, 2, 1, 0);
}

/// Create a 128-bit vector of [4 x float] with undefined values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \returns A 128-bit vector of [4 x float] containing undefined values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_undefined_ps(void)
{
  return (__m128)__builtin_ia32_undef128();
}

/// Constructs a 128-bit floating-point vector of [4 x float]. The lower
///    32 bits of the vector are initialized with the specified single-precision
///    floating-point value. The upper 96 bits are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVSS / MOVSS </c> instruction.
///
/// \param __w
///    A single-precision floating-point value used to initialize the lower 32
///    bits of the result.
/// \returns An initialized 128-bit floating-point vector of [4 x float]. The
///    lower 32 bits contain the value provided in the source operand. The
///    upper 96 bits are set to zero.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_set_ss(float __w)
{
  return __extension__ (__m128){ __w, 0, 0, 0 };
}

/// Constructs a 128-bit floating-point vector of [4 x float], with each
///    of the four single-precision floating-point vector elements set to the
///    specified single-precision floating-point value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPERMILPS / PERMILPS </c> instruction.
///
/// \param __w
///    A single-precision floating-point value used to initialize each vector
///    element of the result.
/// \returns An initialized 128-bit floating-point vector of [4 x float].
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_set1_ps(float __w)
{
  return __extension__ (__m128){ __w, __w, __w, __w };
}

/* Microsoft specific. */
/// Constructs a 128-bit floating-point vector of [4 x float], with each
///    of the four single-precision floating-point vector elements set to the
///    specified single-precision floating-point value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPERMILPS / PERMILPS </c> instruction.
///
/// \param __w
///    A single-precision floating-point value used to initialize each vector
///    element of the result.
/// \returns An initialized 128-bit floating-point vector of [4 x float].
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_set_ps1(float __w)
{
    return _mm_set1_ps(__w);
}

/// Constructs a 128-bit floating-point vector of [4 x float]
///    initialized with the specified single-precision floating-point values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __z
///    A single-precision floating-point value used to initialize bits [127:96]
///    of the result.
/// \param __y
///    A single-precision floating-point value used to initialize bits [95:64]
///    of the result.
/// \param __x
///    A single-precision floating-point value used to initialize bits [63:32]
///    of the result.
/// \param __w
///    A single-precision floating-point value used to initialize bits [31:0]
///    of the result.
/// \returns An initialized 128-bit floating-point vector of [4 x float].
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_set_ps(float __z, float __y, float __x, float __w)
{
  return __extension__ (__m128){ __w, __x, __y, __z };
}

/// Constructs a 128-bit floating-point vector of [4 x float],
///    initialized in reverse order with the specified 32-bit single-precision
///    float-point values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __z
///    A single-precision floating-point value used to initialize bits [31:0]
///    of the result.
/// \param __y
///    A single-precision floating-point value used to initialize bits [63:32]
///    of the result.
/// \param __x
///    A single-precision floating-point value used to initialize bits [95:64]
///    of the result.
/// \param __w
///    A single-precision floating-point value used to initialize bits [127:96]
///    of the result.
/// \returns An initialized 128-bit floating-point vector of [4 x float].
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_setr_ps(float __z, float __y, float __x, float __w)
{
  return __extension__ (__m128){ __z, __y, __x, __w };
}

/// Constructs a 128-bit floating-point vector of [4 x float] initialized
///    to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VXORPS / XORPS </c> instruction.
///
/// \returns An initialized 128-bit floating-point vector of [4 x float] with
///    all elements set to zero.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_setzero_ps(void)
{
  return __extension__ (__m128){ 0, 0, 0, 0 };
}

/// Stores the upper 64 bits of a 128-bit vector of [4 x float] to a
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPEXTRQ / PEXTRQ </c> instruction.
///
/// \param __p
///    A pointer to a 64-bit memory location.
/// \param __a
///    A 128-bit vector of [4 x float] containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeh_pi(__m64 *__p, __m128 __a)
{
  typedef float __mm_storeh_pi_v2f32 __attribute__((__vector_size__(8)));
  struct __mm_storeh_pi_struct {
    __mm_storeh_pi_v2f32 __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_storeh_pi_struct*)__p)->__u = __builtin_shufflevector(__a, __a, 2, 3);
}

/// Stores the lower 64 bits of a 128-bit vector of [4 x float] to a
///     memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVLPS / MOVLPS </c> instruction.
///
/// \param __p
///    A pointer to a memory location that will receive the float values.
/// \param __a
///    A 128-bit vector of [4 x float] containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storel_pi(__m64 *__p, __m128 __a)
{
  typedef float __mm_storeh_pi_v2f32 __attribute__((__vector_size__(8)));
  struct __mm_storeh_pi_struct {
    __mm_storeh_pi_v2f32 __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_storeh_pi_struct*)__p)->__u = __builtin_shufflevector(__a, __a, 0, 1);
}

/// Stores the lower 32 bits of a 128-bit vector of [4 x float] to a
///     memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVSS / MOVSS </c> instruction.
///
/// \param __p
///    A pointer to a 32-bit memory location.
/// \param __a
///    A 128-bit vector of [4 x float] containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_ss(float *__p, __m128 __a)
{
  struct __mm_store_ss_struct {
    float __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_store_ss_struct*)__p)->__u = __a[0];
}

/// Stores a 128-bit vector of [4 x float] to an unaligned memory
///    location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVUPS / MOVUPS </c> instruction.
///
/// \param __p
///    A pointer to a 128-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \param __a
///    A 128-bit vector of [4 x float] containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_ps(float *__p, __m128 __a)
{
  struct __storeu_ps {
    __m128_u __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_ps*)__p)->__v = __a;
}

/// Stores a 128-bit vector of [4 x float] into an aligned memory
///    location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPS / MOVAPS </c> instruction.
///
/// \param __p
///    A pointer to a 128-bit memory location. The address of the memory
///    location has to be 16-byte aligned.
/// \param __a
///    A 128-bit vector of [4 x float] containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_ps(float *__p, __m128 __a)
{
  *(__m128*)__p = __a;
}

/// Stores the lower 32 bits of a 128-bit vector of [4 x float] into
///    four contiguous elements in an aligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to <c> VMOVAPS / MOVAPS + shuffling </c>
///    instruction.
///
/// \param __p
///    A pointer to a 128-bit memory location.
/// \param __a
///    A 128-bit vector of [4 x float] whose lower 32 bits are stored to each
///    of the four contiguous elements pointed by \a __p.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store1_ps(float *__p, __m128 __a)
{
  __a = __builtin_shufflevector((__v4sf)__a, (__v4sf)__a, 0, 0, 0, 0);
  _mm_store_ps(__p, __a);
}

/// Stores the lower 32 bits of a 128-bit vector of [4 x float] into
///    four contiguous elements in an aligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to <c> VMOVAPS / MOVAPS + shuffling </c>
///    instruction.
///
/// \param __p
///    A pointer to a 128-bit memory location.
/// \param __a
///    A 128-bit vector of [4 x float] whose lower 32 bits are stored to each
///    of the four contiguous elements pointed by \a __p.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_ps1(float *__p, __m128 __a)
{
  _mm_store1_ps(__p, __a);
}

/// Stores float values from a 128-bit vector of [4 x float] to an
///    aligned memory location in reverse order.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPS / MOVAPS + shuffling </c>
///    instruction.
///
/// \param __p
///    A pointer to a 128-bit memory location. The address of the memory
///    location has to be 128-bit aligned.
/// \param __a
///    A 128-bit vector of [4 x float] containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storer_ps(float *__p, __m128 __a)
{
  __a = __builtin_shufflevector((__v4sf)__a, (__v4sf)__a, 3, 2, 1, 0);
  _mm_store_ps(__p, __a);
}

#define _MM_HINT_ET0 7
#define _MM_HINT_ET1 6
#define _MM_HINT_T0  3
#define _MM_HINT_T1  2
#define _MM_HINT_T2  1
#define _MM_HINT_NTA 0

#ifndef _MSC_VER
/* FIXME: We have to #define this because "sel" must be a constant integer, and
   Sema doesn't do any form of constant propagation yet. */

/// Loads one cache line of data from the specified address to a location
///    closer to the processor.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// void _mm_prefetch(const void * a, const int sel);
/// \endcode
///
/// This intrinsic corresponds to the <c> PREFETCHNTA </c> instruction.
///
/// \param a
///    A pointer to a memory location containing a cache line of data.
/// \param sel
///    A predefined integer constant specifying the type of prefetch
///    operation: \n
///    _MM_HINT_NTA: Move data using the non-temporal access (NTA) hint. The
///    PREFETCHNTA instruction will be generated. \n
///    _MM_HINT_T0: Move data using the T0 hint. The PREFETCHT0 instruction will
///    be generated. \n
///    _MM_HINT_T1: Move data using the T1 hint. The PREFETCHT1 instruction will
///    be generated. \n
///    _MM_HINT_T2: Move data using the T2 hint. The PREFETCHT2 instruction will
///    be generated.
#define _mm_prefetch(a, sel) (__builtin_prefetch((const void *)(a), \
                                                 ((sel) >> 2) & 1, (sel) & 0x3))
#endif
# 2106 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/// Stores a 64-bit integer in the specified aligned memory location. To
///    minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVNTQ </c> instruction.
///
/// \param __p
///    A pointer to an aligned memory location used to store the register value.
/// \param __a
///    A 64-bit integer containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS_MMX
_mm_stream_pi(__m64 *__p, __m64 __a)
{
  __builtin_ia32_movntq(__p, __a);
}

/// Moves packed float values from a 128-bit vector of [4 x float] to a
///    128-bit aligned memory location. To minimize caching, the data is flagged
///    as non-temporal (unlikely to be used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVNTPS / MOVNTPS </c> instruction.
///
/// \param __p
///    A pointer to a 128-bit aligned memory location that will receive the
///    single-precision floating-point values.
/// \param __a
///    A 128-bit vector of [4 x float] containing the values to be moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_stream_ps(float *__p, __m128 __a)
{
  __builtin_nontemporal_store((__v4sf)__a, (__v4sf*)__p);
}

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2145 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
extern "C" {
#endif
# 2147 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/// Forces strong memory ordering (serialization) between store
///    instructions preceding this instruction and store instructions following
///    this instruction, ensuring the system completes all previous stores
///    before executing subsequent stores.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> SFENCE </c> instruction.
///
void _mm_sfence(void);

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2160 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
} // extern "C"
#endif
# 2162 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/// Extracts 16-bit element from a 64-bit vector of [4 x i16] and
///    returns it, as specified by the immediate integer operand.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// int _mm_extract_pi16(__m64 a, int n);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPEXTRW / PEXTRW </c> instruction.
///
/// \param a
///    A 64-bit vector of [4 x i16].
/// \param n
///    An immediate integer operand that determines which bits are extracted: \n
///    0: Bits [15:0] are copied to the destination. \n
///    1: Bits [31:16] are copied to the destination. \n
///    2: Bits [47:32] are copied to the destination. \n
///    3: Bits [63:48] are copied to the destination.
/// \returns A 16-bit integer containing the extracted 16 bits of packed data.
#define _mm_extract_pi16(a, n) \
  (int)__builtin_ia32_vec_ext_v4hi((__v4hi)a, (int)n)

/// Copies data from the 64-bit vector of [4 x i16] to the destination,
///    and inserts the lower 16-bits of an integer operand at the 16-bit offset
///    specified by the immediate operand \a n.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m64 _mm_insert_pi16(__m64 a, int d, int n);
/// \endcode
///
/// This intrinsic corresponds to the <c> PINSRW </c> instruction.
///
/// \param a
///    A 64-bit vector of [4 x i16].
/// \param d
///    An integer. The lower 16-bit value from this operand is written to the
///    destination at the offset specified by operand \a n.
/// \param n
///    An immediate integer operant that determines which the bits to be used
///    in the destination. \n
///    0: Bits [15:0] are copied to the destination. \n
///    1: Bits [31:16] are copied to the destination. \n
///    2: Bits [47:32] are copied to the destination. \n
///    3: Bits [63:48] are copied to the destination.  \n
///    The remaining bits in the destination are copied from the corresponding
///    bits in operand \a a.
/// \returns A 64-bit integer vector containing the copied packed data from the
///    operands.
#define _mm_insert_pi16(a, d, n) \
  (__m64)__builtin_ia32_vec_set_v4hi((__v4hi)a, (int)d, (int)n)

/// Compares each of the corresponding packed 16-bit integer values of
///    the 64-bit integer vectors, and writes the greater value to the
///    corresponding bits in the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMAXSW </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing one of the source operands.
/// \param __b
///    A 64-bit integer vector containing one of the source operands.
/// \returns A 64-bit integer vector containing the comparison results.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_max_pi16(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_pmaxsw((__v4hi)__a, (__v4hi)__b);
}

/// Compares each of the corresponding packed 8-bit unsigned integer
///    values of the 64-bit integer vectors, and writes the greater value to the
///    corresponding bits in the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMAXUB </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing one of the source operands.
/// \param __b
///    A 64-bit integer vector containing one of the source operands.
/// \returns A 64-bit integer vector containing the comparison results.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_max_pu8(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_pmaxub((__v8qi)__a, (__v8qi)__b);
}

/// Compares each of the corresponding packed 16-bit integer values of
///    the 64-bit integer vectors, and writes the lesser value to the
///    corresponding bits in the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMINSW </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing one of the source operands.
/// \param __b
///    A 64-bit integer vector containing one of the source operands.
/// \returns A 64-bit integer vector containing the comparison results.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_min_pi16(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_pminsw((__v4hi)__a, (__v4hi)__b);
}

/// Compares each of the corresponding packed 8-bit unsigned integer
///    values of the 64-bit integer vectors, and writes the lesser value to the
///    corresponding bits in the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMINUB </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing one of the source operands.
/// \param __b
///    A 64-bit integer vector containing one of the source operands.
/// \returns A 64-bit integer vector containing the comparison results.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_min_pu8(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_pminub((__v8qi)__a, (__v8qi)__b);
}

/// Takes the most significant bit from each 8-bit element in a 64-bit
///    integer vector to create an 8-bit mask value. Zero-extends the value to
///    32-bit integer and writes it to the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMOVMSKB </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing the values with bits to be extracted.
/// \returns The most significant bit from each 8-bit element in \a __a,
///    written to bits [7:0].
static __inline__ int __DEFAULT_FN_ATTRS_MMX
_mm_movemask_pi8(__m64 __a)
{
  return __builtin_ia32_pmovmskb((__v8qi)__a);
}

/// Multiplies packed 16-bit unsigned integer values and writes the
///    high-order 16 bits of each 32-bit product to the corresponding bits in
///    the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMULHUW </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing one of the source operands.
/// \param __b
///    A 64-bit integer vector containing one of the source operands.
/// \returns A 64-bit integer vector containing the products of both operands.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_mulhi_pu16(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_pmulhuw((__v4hi)__a, (__v4hi)__b);
}

/// Shuffles the 4 16-bit integers from a 64-bit integer vector to the
///    destination, as specified by the immediate value operand.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m64 _mm_shuffle_pi16(__m64 a, const int n);
/// \endcode
///
/// This intrinsic corresponds to the <c> PSHUFW </c> instruction.
///
/// \param a
///    A 64-bit integer vector containing the values to be shuffled.
/// \param n
///    An immediate value containing an 8-bit value specifying which elements to
///    copy from \a a. The destinations within the 64-bit destination are
///    assigned values as follows: \n
///    Bits [1:0] are used to assign values to bits [15:0] in the
///    destination. \n
///    Bits [3:2] are used to assign values to bits [31:16] in the
///    destination. \n
///    Bits [5:4] are used to assign values to bits [47:32] in the
///    destination. \n
///    Bits [7:6] are used to assign values to bits [63:48] in the
///    destination. \n
///    Bit value assignments: \n
///    00: assigned from bits [15:0] of \a a. \n
///    01: assigned from bits [31:16] of \a a. \n
///    10: assigned from bits [47:32] of \a a. \n
///    11: assigned from bits [63:48] of \a a.
/// \returns A 64-bit integer vector containing the shuffled values.
#define _mm_shuffle_pi16(a, n) \
  (__m64)__builtin_ia32_pshufw((__v4hi)(__m64)(a), (n))

/// Conditionally copies the values from each 8-bit element in the first
///    64-bit integer vector operand to the specified memory location, as
///    specified by the most significant bit in the corresponding element in the
///    second 64-bit integer vector operand.
///
///    To minimize caching, the data is flagged as non-temporal
///    (unlikely to be used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MASKMOVQ </c> instruction.
///
/// \param __d
///    A 64-bit integer vector containing the values with elements to be copied.
/// \param __n
///    A 64-bit integer vector operand. The most significant bit from each 8-bit
///    element determines whether the corresponding element in operand \a __d
///    is copied. If the most significant bit of a given element is 1, the
///    corresponding element in operand \a __d is copied.
/// \param __p
///    A pointer to a 64-bit memory location that will receive the conditionally
///    copied integer values. The address of the memory location does not have
///    to be aligned.
static __inline__ void __DEFAULT_FN_ATTRS_MMX
_mm_maskmove_si64(__m64 __d, __m64 __n, char *__p)
{
  __builtin_ia32_maskmovq((__v8qi)__d, (__v8qi)__n, __p);
}

/// Computes the rounded averages of the packed unsigned 8-bit integer
///    values and writes the averages to the corresponding bits in the
///    destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PAVGB </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing one of the source operands.
/// \param __b
///    A 64-bit integer vector containing one of the source operands.
/// \returns A 64-bit integer vector containing the averages of both operands.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_avg_pu8(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_pavgb((__v8qi)__a, (__v8qi)__b);
}

/// Computes the rounded averages of the packed unsigned 16-bit integer
///    values and writes the averages to the corresponding bits in the
///    destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PAVGW </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing one of the source operands.
/// \param __b
///    A 64-bit integer vector containing one of the source operands.
/// \returns A 64-bit integer vector containing the averages of both operands.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_avg_pu16(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_pavgw((__v4hi)__a, (__v4hi)__b);
}

/// Subtracts the corresponding 8-bit unsigned integer values of the two
///    64-bit vector operands and computes the absolute value for each of the
///    difference. Then sum of the 8 absolute differences is written to the
///    bits [15:0] of the destination; the remaining bits [63:16] are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSADBW </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing one of the source operands.
/// \param __b
///    A 64-bit integer vector containing one of the source operands.
/// \returns A 64-bit integer vector whose lower 16 bits contain the sums of the
///    sets of absolute differences between both operands. The upper bits are
///    cleared.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_sad_pu8(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_psadbw((__v8qi)__a, (__v8qi)__b);
}

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2454 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
extern "C" {
#endif
# 2456 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/// Returns the contents of the MXCSR register as a 32-bit unsigned
///    integer value.
///
///    There are several groups of macros associated with this
///    intrinsic, including:
///    <ul>
///    <li>
///      For checking exception states: _MM_EXCEPT_INVALID, _MM_EXCEPT_DIV_ZERO,
///      _MM_EXCEPT_DENORM, _MM_EXCEPT_OVERFLOW, _MM_EXCEPT_UNDERFLOW,
///      _MM_EXCEPT_INEXACT. There is a convenience wrapper
///      _MM_GET_EXCEPTION_STATE().
///    </li>
///    <li>
///      For checking exception masks: _MM_MASK_UNDERFLOW, _MM_MASK_OVERFLOW,
///      _MM_MASK_INVALID, _MM_MASK_DENORM, _MM_MASK_DIV_ZERO, _MM_MASK_INEXACT.
///      There is a convenience wrapper _MM_GET_EXCEPTION_MASK().
///    </li>
///    <li>
///      For checking rounding modes: _MM_ROUND_NEAREST, _MM_ROUND_DOWN,
///      _MM_ROUND_UP, _MM_ROUND_TOWARD_ZERO. There is a convenience wrapper
///      _MM_GET_ROUNDING_MODE().
///    </li>
///    <li>
///      For checking flush-to-zero mode: _MM_FLUSH_ZERO_ON, _MM_FLUSH_ZERO_OFF.
///      There is a convenience wrapper _MM_GET_FLUSH_ZERO_MODE().
///    </li>
///    <li>
///      For checking denormals-are-zero mode: _MM_DENORMALS_ZERO_ON,
///      _MM_DENORMALS_ZERO_OFF. There is a convenience wrapper
///      _MM_GET_DENORMALS_ZERO_MODE().
///    </li>
///    </ul>
///
///    For example, the following expression checks if an overflow exception has
///    occurred:
///    \code
///      ( _mm_getcsr() & _MM_EXCEPT_OVERFLOW )
///    \endcode
///
///    The following expression gets the current rounding mode:
///    \code
///      _MM_GET_ROUNDING_MODE()
///    \endcode
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSTMXCSR / STMXCSR </c> instruction.
///
/// \returns A 32-bit unsigned integer containing the contents of the MXCSR
///    register.
unsigned int _mm_getcsr(void);

/// Sets the MXCSR register with the 32-bit unsigned integer value.
///
///    There are several groups of macros associated with this intrinsic,
///    including:
///    <ul>
///    <li>
///      For setting exception states: _MM_EXCEPT_INVALID, _MM_EXCEPT_DIV_ZERO,
///      _MM_EXCEPT_DENORM, _MM_EXCEPT_OVERFLOW, _MM_EXCEPT_UNDERFLOW,
///      _MM_EXCEPT_INEXACT. There is a convenience wrapper
///      _MM_SET_EXCEPTION_STATE(x) where x is one of these macros.
///    </li>
///    <li>
///      For setting exception masks: _MM_MASK_UNDERFLOW, _MM_MASK_OVERFLOW,
///      _MM_MASK_INVALID, _MM_MASK_DENORM, _MM_MASK_DIV_ZERO, _MM_MASK_INEXACT.
///      There is a convenience wrapper _MM_SET_EXCEPTION_MASK(x) where x is one
///      of these macros.
///    </li>
///    <li>
///      For setting rounding modes: _MM_ROUND_NEAREST, _MM_ROUND_DOWN,
///      _MM_ROUND_UP, _MM_ROUND_TOWARD_ZERO. There is a convenience wrapper
///      _MM_SET_ROUNDING_MODE(x) where x is one of these macros.
///    </li>
///    <li>
///      For setting flush-to-zero mode: _MM_FLUSH_ZERO_ON, _MM_FLUSH_ZERO_OFF.
///      There is a convenience wrapper _MM_SET_FLUSH_ZERO_MODE(x) where x is
///      one of these macros.
///    </li>
///    <li>
///      For setting denormals-are-zero mode: _MM_DENORMALS_ZERO_ON,
///      _MM_DENORMALS_ZERO_OFF. There is a convenience wrapper
///      _MM_SET_DENORMALS_ZERO_MODE(x) where x is one of these macros.
///    </li>
///    </ul>
///
///    For example, the following expression causes subsequent floating-point
///    operations to round up:
///      _mm_setcsr(_mm_getcsr() | _MM_ROUND_UP)
///
///    The following example sets the DAZ and FTZ flags:
///    \code
///    void setFlags() {
///      _MM_SET_FLUSH_ZERO_MODE(_MM_FLUSH_ZERO_ON);
///      _MM_SET_DENORMALS_ZERO_MODE(_MM_DENORMALS_ZERO_ON);
///    }
///    \endcode
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VLDMXCSR / LDMXCSR </c> instruction.
///
/// \param __i
///    A 32-bit unsigned integer value to be written to the MXCSR register.
void _mm_setcsr(unsigned int __i);

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 2564 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
} // extern "C"
#endif
# 2566 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

/// Selects 4 float values from the 128-bit operands of [4 x float], as
///    specified by the immediate value operand.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128 _mm_shuffle_ps(__m128 a, __m128 b, const int mask);
/// \endcode
///
/// This intrinsic corresponds to the <c> VSHUFPS / SHUFPS </c> instruction.
///
/// \param a
///    A 128-bit vector of [4 x float].
/// \param b
///    A 128-bit vector of [4 x float].
/// \param mask
///    An immediate value containing an 8-bit value specifying which elements to
///    copy from \a a and \a b. \n
///    Bits [3:0] specify the values copied from operand \a a. \n
///    Bits [7:4] specify the values copied from operand \a b. \n
///    The destinations within the 128-bit destination are assigned values as
///    follows: \n
///    Bits [1:0] are used to assign values to bits [31:0] in the
///    destination. \n
///    Bits [3:2] are used to assign values to bits [63:32] in the
///    destination. \n
///    Bits [5:4] are used to assign values to bits [95:64] in the
///    destination. \n
///    Bits [7:6] are used to assign values to bits [127:96] in the
///    destination. \n
///    Bit value assignments: \n
///    00: Bits [31:0] copied from the specified operand. \n
///    01: Bits [63:32] copied from the specified operand. \n
///    10: Bits [95:64] copied from the specified operand. \n
///    11: Bits [127:96] copied from the specified operand.
/// \returns A 128-bit vector of [4 x float] containing the shuffled values.
#define _mm_shuffle_ps(a, b, mask) \
  (__m128)__builtin_ia32_shufps((__v4sf)(__m128)(a), (__v4sf)(__m128)(b), \
                                (int)(mask))

/// Unpacks the high-order (index 2,3) values from two 128-bit vectors of
///    [4 x float] and interleaves them into a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKHPS / UNPCKHPS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. \n
///    Bits [95:64] are written to bits [31:0] of the destination. \n
///    Bits [127:96] are written to bits [95:64] of the destination.
/// \param __b
///    A 128-bit vector of [4 x float].
///    Bits [95:64] are written to bits [63:32] of the destination. \n
///    Bits [127:96] are written to bits [127:96] of the destination.
/// \returns A 128-bit vector of [4 x float] containing the interleaved values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_unpackhi_ps(__m128 __a, __m128 __b)
{
  return __builtin_shufflevector((__v4sf)__a, (__v4sf)__b, 2, 6, 3, 7);
}

/// Unpacks the low-order (index 0,1) values from two 128-bit vectors of
///    [4 x float] and interleaves them into a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKLPS / UNPCKLPS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. \n
///    Bits [31:0] are written to bits [31:0] of the destination.  \n
///    Bits [63:32] are written to bits [95:64] of the destination.
/// \param __b
///    A 128-bit vector of [4 x float]. \n
///    Bits [31:0] are written to bits [63:32] of the destination. \n
///    Bits [63:32] are written to bits [127:96] of the destination.
/// \returns A 128-bit vector of [4 x float] containing the interleaved values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_unpacklo_ps(__m128 __a, __m128 __b)
{
  return __builtin_shufflevector((__v4sf)__a, (__v4sf)__b, 0, 4, 1, 5);
}

/// Constructs a 128-bit floating-point vector of [4 x float]. The lower
///    32 bits are set to the lower 32 bits of the second parameter. The upper
///    96 bits are set to the upper 96 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VBLENDPS / BLENDPS / MOVSS </c>
///    instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float]. The upper 96 bits are
///    written to the upper 96 bits of the result.
/// \param __b
///    A 128-bit floating-point vector of [4 x float]. The lower 32 bits are
///    written to the lower 32 bits of the result.
/// \returns A 128-bit floating-point vector of [4 x float].
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_move_ss(__m128 __a, __m128 __b)
{
  __a[0] = __b[0];
  return __a;
}

/// Constructs a 128-bit floating-point vector of [4 x float]. The lower
///    64 bits are set to the upper 64 bits of the second parameter. The upper
///    64 bits are set to the upper 64 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKHPD / UNPCKHPD </c> instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float]. The upper 64 bits are
///    written to the upper 64 bits of the result.
/// \param __b
///    A 128-bit floating-point vector of [4 x float]. The upper 64 bits are
///    written to the lower 64 bits of the result.
/// \returns A 128-bit floating-point vector of [4 x float].
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_movehl_ps(__m128 __a, __m128 __b)
{
  return __builtin_shufflevector((__v4sf)__a, (__v4sf)__b, 6, 7, 2, 3);
}

/// Constructs a 128-bit floating-point vector of [4 x float]. The lower
///    64 bits are set to the lower 64 bits of the first parameter. The upper
///    64 bits are set to the lower 64 bits of the second parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKLPD / UNPCKLPD </c> instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float]. The lower 64 bits are
///    written to the lower 64 bits of the result.
/// \param __b
///    A 128-bit floating-point vector of [4 x float]. The lower 64 bits are
///    written to the upper 64 bits of the result.
/// \returns A 128-bit floating-point vector of [4 x float].
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_movelh_ps(__m128 __a, __m128 __b)
{
  return __builtin_shufflevector((__v4sf)__a, (__v4sf)__b, 0, 1, 4, 5);
}

/// Converts a 64-bit vector of [4 x i16] into a 128-bit vector of [4 x
///    float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PS + COMPOSITE </c> instruction.
///
/// \param __a
///    A 64-bit vector of [4 x i16]. The elements of the destination are copied
///    from the corresponding elements in this operand.
/// \returns A 128-bit vector of [4 x float] containing the copied and converted
///    values from the operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS_MMX
_mm_cvtpi16_ps(__m64 __a)
{
  __m64 __b, __c;
  __m128 __r;

  __b = _mm_setzero_si64();
  __b = _mm_cmpgt_pi16(__b, __a);
  __c = _mm_unpackhi_pi16(__a, __b);
  __r = _mm_setzero_ps();
  __r = _mm_cvtpi32_ps(__r, __c);
  __r = _mm_movelh_ps(__r, __r);
  __c = _mm_unpacklo_pi16(__a, __b);
  __r = _mm_cvtpi32_ps(__r, __c);

  return __r;
}

/// Converts a 64-bit vector of 16-bit unsigned integer values into a
///    128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PS + COMPOSITE </c> instruction.
///
/// \param __a
///    A 64-bit vector of 16-bit unsigned integer values. The elements of the
///    destination are copied from the corresponding elements in this operand.
/// \returns A 128-bit vector of [4 x float] containing the copied and converted
///    values from the operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS_MMX
_mm_cvtpu16_ps(__m64 __a)
{
  __m64 __b, __c;
  __m128 __r;

  __b = _mm_setzero_si64();
  __c = _mm_unpackhi_pi16(__a, __b);
  __r = _mm_setzero_ps();
  __r = _mm_cvtpi32_ps(__r, __c);
  __r = _mm_movelh_ps(__r, __r);
  __c = _mm_unpacklo_pi16(__a, __b);
  __r = _mm_cvtpi32_ps(__r, __c);

  return __r;
}

/// Converts the lower four 8-bit values from a 64-bit vector of [8 x i8]
///    into a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PS + COMPOSITE </c> instruction.
///
/// \param __a
///    A 64-bit vector of [8 x i8]. The elements of the destination are copied
///    from the corresponding lower 4 elements in this operand.
/// \returns A 128-bit vector of [4 x float] containing the copied and converted
///    values from the operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS_MMX
_mm_cvtpi8_ps(__m64 __a)
{
  __m64 __b;

  __b = _mm_setzero_si64();
  __b = _mm_cmpgt_pi8(__b, __a);
  __b = _mm_unpacklo_pi8(__a, __b);

  return _mm_cvtpi16_ps(__b);
}

/// Converts the lower four unsigned 8-bit integer values from a 64-bit
///    vector of [8 x u8] into a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PS + COMPOSITE </c> instruction.
///
/// \param __a
///    A 64-bit vector of unsigned 8-bit integer values. The elements of the
///    destination are copied from the corresponding lower 4 elements in this
///    operand.
/// \returns A 128-bit vector of [4 x float] containing the copied and converted
///    values from the source operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS_MMX
_mm_cvtpu8_ps(__m64 __a)
{
  __m64 __b;

  __b = _mm_setzero_si64();
  __b = _mm_unpacklo_pi8(__a, __b);

  return _mm_cvtpi16_ps(__b);
}

/// Converts the two 32-bit signed integer values from each 64-bit vector
///    operand of [2 x i32] into a 128-bit vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PS + COMPOSITE </c> instruction.
///
/// \param __a
///    A 64-bit vector of [2 x i32]. The lower elements of the destination are
///    copied from the elements in this operand.
/// \param __b
///    A 64-bit vector of [2 x i32]. The upper elements of the destination are
///    copied from the elements in this operand.
/// \returns A 128-bit vector of [4 x float] whose lower 64 bits contain the
///    copied and converted values from the first operand. The upper 64 bits
///    contain the copied and converted values from the second operand.
static __inline__ __m128 __DEFAULT_FN_ATTRS_MMX
_mm_cvtpi32x2_ps(__m64 __a, __m64 __b)
{
  __m128 __c;

  __c = _mm_setzero_ps();
  __c = _mm_cvtpi32_ps(__c, __b);
  __c = _mm_movelh_ps(__c, __c);

  return _mm_cvtpi32_ps(__c, __a);
}

/// Converts each single-precision floating-point element of a 128-bit
///    floating-point vector of [4 x float] into a 16-bit signed integer, and
///    packs the results into a 64-bit integer vector of [4 x i16].
///
///    If the floating-point element is NaN or infinity, or if the
///    floating-point element is greater than 0x7FFFFFFF or less than -0x8000,
///    it is converted to 0x8000. Otherwise if the floating-point element is
///    greater than 0x7FFF, it is converted to 0x7FFF.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPS2PI + COMPOSITE </c> instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float].
/// \returns A 64-bit integer vector of [4 x i16] containing the converted
///    values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvtps_pi16(__m128 __a)
{
  __m64 __b, __c;

  __b = _mm_cvtps_pi32(__a);
  __a = _mm_movehl_ps(__a, __a);
  __c = _mm_cvtps_pi32(__a);

  return _mm_packs_pi32(__b, __c);
}

/// Converts each single-precision floating-point element of a 128-bit
///    floating-point vector of [4 x float] into an 8-bit signed integer, and
///    packs the results into the lower 32 bits of a 64-bit integer vector of
///    [8 x i8]. The upper 32 bits of the vector are set to 0.
///
///    If the floating-point element is NaN or infinity, or if the
///    floating-point element is greater than 0x7FFFFFFF or less than -0x80, it
///    is converted to 0x80. Otherwise if the floating-point element is greater
///    than 0x7F, it is converted to 0x7F.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPS2PI + COMPOSITE </c> instruction.
///
/// \param __a
///    128-bit floating-point vector of [4 x float].
/// \returns A 64-bit integer vector of [8 x i8]. The lower 32 bits contain the
///    converted values and the uppper 32 bits are set to zero.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvtps_pi8(__m128 __a)
{
  __m64 __b, __c;

  __b = _mm_cvtps_pi16(__a);
  __c = _mm_setzero_si64();

  return _mm_packs_pi16(__b, __c);
}

/// Extracts the sign bits from each single-precision floating-point
///    element of a 128-bit floating-point vector of [4 x float] and returns the
///    sign bits in bits [0:3] of the result. Bits [31:4] of the result are set
///    to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVMSKPS / MOVMSKPS </c> instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float].
/// \returns A 32-bit integer value. Bits [3:0] contain the sign bits from each
///    single-precision floating-point element of the parameter. Bits [31:4] are
///    set to zero.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_movemask_ps(__m128 __a)
{
  return __builtin_ia32_movmskps((__v4sf)__a);
}


#define _MM_ALIGN16 __attribute__((aligned(16)))

#define _MM_SHUFFLE(z, y, x, w) (((z) << 6) | ((y) << 4) | ((x) << 2) | (w))

#define _MM_EXCEPT_INVALID    (0x0001)
#define _MM_EXCEPT_DENORM     (0x0002)
#define _MM_EXCEPT_DIV_ZERO   (0x0004)
#define _MM_EXCEPT_OVERFLOW   (0x0008)
#define _MM_EXCEPT_UNDERFLOW  (0x0010)
#define _MM_EXCEPT_INEXACT    (0x0020)
#define _MM_EXCEPT_MASK       (0x003f)

#define _MM_MASK_INVALID      (0x0080)
#define _MM_MASK_DENORM       (0x0100)
#define _MM_MASK_DIV_ZERO     (0x0200)
#define _MM_MASK_OVERFLOW     (0x0400)
#define _MM_MASK_UNDERFLOW    (0x0800)
#define _MM_MASK_INEXACT      (0x1000)
#define _MM_MASK_MASK         (0x1f80)

#define _MM_ROUND_NEAREST     (0x0000)
#define _MM_ROUND_DOWN        (0x2000)
#define _MM_ROUND_UP          (0x4000)
#define _MM_ROUND_TOWARD_ZERO (0x6000)
#define _MM_ROUND_MASK        (0x6000)

#define _MM_FLUSH_ZERO_MASK   (0x8000)
#define _MM_FLUSH_ZERO_ON     (0x8000)
#define _MM_FLUSH_ZERO_OFF    (0x0000)

#define _MM_GET_EXCEPTION_MASK() (_mm_getcsr() & _MM_MASK_MASK)
#define _MM_GET_EXCEPTION_STATE() (_mm_getcsr() & _MM_EXCEPT_MASK)
#define _MM_GET_FLUSH_ZERO_MODE() (_mm_getcsr() & _MM_FLUSH_ZERO_MASK)
#define _MM_GET_ROUNDING_MODE() (_mm_getcsr() & _MM_ROUND_MASK)

#define _MM_SET_EXCEPTION_MASK(x) (_mm_setcsr((_mm_getcsr() & ~_MM_MASK_MASK) | (x)))
#define _MM_SET_EXCEPTION_STATE(x) (_mm_setcsr((_mm_getcsr() & ~_MM_EXCEPT_MASK) | (x)))
#define _MM_SET_FLUSH_ZERO_MODE(x) (_mm_setcsr((_mm_getcsr() & ~_MM_FLUSH_ZERO_MASK) | (x)))
#define _MM_SET_ROUNDING_MODE(x) (_mm_setcsr((_mm_getcsr() & ~_MM_ROUND_MASK) | (x)))

#define _MM_TRANSPOSE4_PS(row0, row1, row2, row3) \
do { \
  __m128 tmp3, tmp2, tmp1, tmp0; \
  tmp0 = _mm_unpacklo_ps((row0), (row1)); \
  tmp2 = _mm_unpacklo_ps((row2), (row3)); \
  tmp1 = _mm_unpackhi_ps((row0), (row1)); \
  tmp3 = _mm_unpackhi_ps((row2), (row3)); \
  (row0) = _mm_movelh_ps(tmp0, tmp2); \
  (row1) = _mm_movehl_ps(tmp2, tmp0); \
  (row2) = _mm_movelh_ps(tmp1, tmp3); \
  (row3) = _mm_movehl_ps(tmp3, tmp1); \
} while (0)

/* Aliases for compatibility. */
#define _m_pextrw _mm_extract_pi16
#define _m_pinsrw _mm_insert_pi16
#define _m_pmaxsw _mm_max_pi16
#define _m_pmaxub _mm_max_pu8
#define _m_pminsw _mm_min_pi16
#define _m_pminub _mm_min_pu8
#define _m_pmovmskb _mm_movemask_pi8
#define _m_pmulhuw _mm_mulhi_pu16
#define _m_pshufw _mm_shuffle_pi16
#define _m_maskmovq _mm_maskmove_si64
#define _m_pavgb _mm_avg_pu8
#define _m_pavgw _mm_avg_pu16
#define _m_psadbw _mm_sad_pu8
#define _m_ _mm_
#define _m_ _mm_

#undef __DEFAULT_FN_ATTRS
#undef __DEFAULT_FN_ATTRS_MMX

/* Ugly hack for backwards-compatibility (compatible with gcc) */
#if 0 /* disabled by -frewrite-includes */
#if defined(__SSE2__) && !__building_module(_Builtin_intrinsics)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 3005 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
#if 0 /* expanded by -frewrite-includes */
#include <emmintrin.h>
#endif /* expanded by -frewrite-includes */
# 3005 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
# 1 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 1 3
/*===---- emmintrin.h - SSE2 intrinsics ------------------------------------===
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __EMMINTRIN_H
#define __EMMINTRIN_H

#if 0 /* expanded by -frewrite-includes */
#include <xmmintrin.h>
#endif /* expanded by -frewrite-includes */
# 13 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

typedef double __m128d __attribute__((__vector_size__(16), __aligned__(16)));
typedef long long __m128i __attribute__((__vector_size__(16), __aligned__(16)));

typedef double __m128d_u __attribute__((__vector_size__(16), __aligned__(1)));
typedef long long __m128i_u __attribute__((__vector_size__(16), __aligned__(1)));

/* Type defines.  */
typedef double __v2df __attribute__ ((__vector_size__ (16)));
typedef long long __v2di __attribute__ ((__vector_size__ (16)));
typedef short __v8hi __attribute__((__vector_size__(16)));
typedef char __v16qi __attribute__((__vector_size__(16)));

/* Unsigned types */
typedef unsigned long long __v2du __attribute__ ((__vector_size__ (16)));
typedef unsigned short __v8hu __attribute__((__vector_size__(16)));
typedef unsigned char __v16qu __attribute__((__vector_size__(16)));

/* We need an explicitly signed variant for char. Note that this shouldn't
 * appear in the interface though. */
typedef signed char __v16qs __attribute__((__vector_size__(16)));

/* Define the default attributes for the functions in this file. */
#define __DEFAULT_FN_ATTRS __attribute__((__always_inline__, __nodebug__, __target__("sse2"), __min_vector_width__(128)))
#define __DEFAULT_FN_ATTRS_MMX __attribute__((__always_inline__, __nodebug__, __target__("mmx,sse2"), __min_vector_width__(64)))

/// Adds lower double-precision values in both operands and returns the
///    sum in the lower 64 bits of the result. The upper 64 bits of the result
///    are copied from the upper double-precision value of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VADDSD / ADDSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    sum of the lower 64 bits of both operands. The upper 64 bits are copied
///    from the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_add_sd(__m128d __a, __m128d __b)
{
  __a[0] += __b[0];
  return __a;
}

/// Adds two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VADDPD / ADDPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] containing the sums of both
///    operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_add_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2df)__a + (__v2df)__b);
}

/// Subtracts the lower double-precision value of the second operand
///    from the lower double-precision value of the first operand and returns
///    the difference in the lower 64 bits of the result. The upper 64 bits of
///    the result are copied from the upper double-precision value of the first
///    operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSUBSD / SUBSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the minuend.
/// \param __b
///    A 128-bit vector of [2 x double] containing the subtrahend.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    difference of the lower 64 bits of both operands. The upper 64 bits are
///    copied from the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_sub_sd(__m128d __a, __m128d __b)
{
  __a[0] -= __b[0];
  return __a;
}

/// Subtracts two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSUBPD / SUBPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the minuend.
/// \param __b
///    A 128-bit vector of [2 x double] containing the subtrahend.
/// \returns A 128-bit vector of [2 x double] containing the differences between
///    both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_sub_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2df)__a - (__v2df)__b);
}

/// Multiplies lower double-precision values in both operands and returns
///    the product in the lower 64 bits of the result. The upper 64 bits of the
///    result are copied from the upper double-precision value of the first
///    operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMULSD / MULSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    product of the lower 64 bits of both operands. The upper 64 bits are
///    copied from the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_mul_sd(__m128d __a, __m128d __b)
{
  __a[0] *= __b[0];
  return __a;
}

/// Multiplies two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMULPD / MULPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \returns A 128-bit vector of [2 x double] containing the products of both
///    operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_mul_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2df)__a * (__v2df)__b);
}

/// Divides the lower double-precision value of the first operand by the
///    lower double-precision value of the second operand and returns the
///    quotient in the lower 64 bits of the result. The upper 64 bits of the
///    result are copied from the upper double-precision value of the first
///    operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VDIVSD / DIVSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the dividend.
/// \param __b
///    A 128-bit vector of [2 x double] containing divisor.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    quotient of the lower 64 bits of both operands. The upper 64 bits are
///    copied from the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_div_sd(__m128d __a, __m128d __b)
{
  __a[0] /= __b[0];
  return __a;
}

/// Performs an element-by-element division of two 128-bit vectors of
///    [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VDIVPD / DIVPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the dividend.
/// \param __b
///    A 128-bit vector of [2 x double] containing the divisor.
/// \returns A 128-bit vector of [2 x double] containing the quotients of both
///    operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_div_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2df)__a / (__v2df)__b);
}

/// Calculates the square root of the lower double-precision value of
///    the second operand and returns it in the lower 64 bits of the result.
///    The upper 64 bits of the result are copied from the upper
///    double-precision value of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSQRTSD / SQRTSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    upper 64 bits of this operand are copied to the upper 64 bits of the
///    result.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    square root is calculated using the lower 64 bits of this operand.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    square root of the lower 64 bits of operand \a __b, and whose upper 64
///    bits are copied from the upper 64 bits of operand \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_sqrt_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_sqrtsd((__v2df)__b);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Calculates the square root of the each of two values stored in a
///    128-bit vector of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSQRTPD / SQRTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector of [2 x double] containing the square roots of the
///    values in the operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_sqrt_pd(__m128d __a)
{
  return __builtin_ia32_sqrtpd((__v2df)__a);
}

/// Compares lower 64-bit double-precision values of both operands, and
///    returns the lesser of the pair of values in the lower 64-bits of the
///    result. The upper 64 bits of the result are copied from the upper
///    double-precision value of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMINSD / MINSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    lower 64 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    lower 64 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    minimum value between both operands. The upper 64 bits are copied from
///    the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_min_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_minsd((__v2df)__a, (__v2df)__b);
}

/// Performs element-by-element comparison of the two 128-bit vectors of
///    [2 x double] and returns the vector containing the lesser of each pair of
///    values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMINPD / MINPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \returns A 128-bit vector of [2 x double] containing the minimum values
///    between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_min_pd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_minpd((__v2df)__a, (__v2df)__b);
}

/// Compares lower 64-bit double-precision values of both operands, and
///    returns the greater of the pair of values in the lower 64-bits of the
///    result. The upper 64 bits of the result are copied from the upper
///    double-precision value of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMAXSD / MAXSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    lower 64 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    lower 64 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    maximum value between both operands. The upper 64 bits are copied from
///    the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_max_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_maxsd((__v2df)__a, (__v2df)__b);
}

/// Performs element-by-element comparison of the two 128-bit vectors of
///    [2 x double] and returns the vector containing the greater of each pair
///    of values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMAXPD / MAXPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \returns A 128-bit vector of [2 x double] containing the maximum values
///    between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_max_pd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_maxpd((__v2df)__a, (__v2df)__b);
}

/// Performs a bitwise AND of two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPAND / PAND </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] containing the bitwise AND of the
///    values between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_and_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2du)__a & (__v2du)__b);
}

/// Performs a bitwise AND of two 128-bit vectors of [2 x double], using
///    the one's complement of the values contained in the first source operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPANDN / PANDN </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the left source operand. The
///    one's complement of this value is used in the bitwise AND.
/// \param __b
///    A 128-bit vector of [2 x double] containing the right source operand.
/// \returns A 128-bit vector of [2 x double] containing the bitwise AND of the
///    values in the second operand and the one's complement of the first
///    operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_andnot_pd(__m128d __a, __m128d __b)
{
  return (__m128d)(~(__v2du)__a & (__v2du)__b);
}

/// Performs a bitwise OR of two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPOR / POR </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] containing the bitwise OR of the
///    values between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_or_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2du)__a | (__v2du)__b);
}

/// Performs a bitwise XOR of two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPXOR / PXOR </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] containing the bitwise XOR of the
///    values between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_xor_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2du)__a ^ (__v2du)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] for equality. Each comparison yields 0x0
///    for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPEQPD / CMPEQPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpeq_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpeqpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are less than those in the second operand. Each comparison
///    yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTPD / CMPLTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmplt_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpltpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are less than or equal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLEPD / CMPLEPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmple_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmplepd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are greater than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTPD / CMPLTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpgt_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpltpd((__v2df)__b, (__v2df)__a);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are greater than or equal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLEPD / CMPLEPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpge_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmplepd((__v2df)__b, (__v2df)__a);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are ordered with respect to those in the second operand.
///
///    A pair of double-precision values are "ordered" with respect to each
///    other if neither value is a NaN. Each comparison yields 0x0 for false,
///    0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPORDPD / CMPORDPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpord_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpordpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are unordered with respect to those in the second operand.
///
///    A pair of double-precision values are "unordered" with respect to each
///    other if one or both values are NaN. Each comparison yields 0x0 for
///    false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPUNORDPD / CMPUNORDPD </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpunord_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpunordpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are unequal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNEQPD / CMPNEQPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpneq_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpneqpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are not less than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTPD / CMPNLTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnlt_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnltpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are not less than or equal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLEPD / CMPNLEPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnle_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnlepd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are not greater than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTPD / CMPNLTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpngt_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnltpd((__v2df)__b, (__v2df)__a);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are not greater than or equal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLEPD / CMPNLEPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnge_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnlepd((__v2df)__b, (__v2df)__a);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] for equality.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPEQSD / CMPEQSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpeq_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpeqsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than the corresponding value in
///    the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTSD / CMPLTSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmplt_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpltsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLESD / CMPLESD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmple_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmplesd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than the corresponding value
///    in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTSD / CMPLTSD </c> instruction.
///
/// \param __a
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __b.
/// \param __b
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///     results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpgt_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_cmpltsd((__v2df)__b, (__v2df)__a);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLESD / CMPLESD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpge_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_cmplesd((__v2df)__b, (__v2df)__a);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is "ordered" with respect to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true. A pair
///    of double-precision values are "ordered" with respect to each other if
///    neither value is a NaN.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPORDSD / CMPORDSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpord_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpordsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is "unordered" with respect to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true. A pair
///    of double-precision values are "unordered" with respect to each other if
///    one or both values are NaN.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPUNORDSD / CMPUNORDSD </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpunord_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpunordsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is unequal to the corresponding value in
///    the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNEQSD / CMPNEQSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpneq_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpneqsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is not less than the corresponding
///    value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTSD / CMPNLTSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnlt_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnltsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is not less than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLESD / CMPNLESD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns  A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnle_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnlesd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is not greater than the corresponding
///    value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTSD / CMPNLTSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpngt_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_cmpnltsd((__v2df)__b, (__v2df)__a);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is not greater than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLESD / CMPNLESD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnge_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_cmpnlesd((__v2df)__b, (__v2df)__a);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] for equality.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comieq_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdeq((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than the corresponding value in
///    the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comilt_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdlt((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comile_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdle((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than the corresponding value
///    in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comigt_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdgt((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comige_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdge((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is unequal to the corresponding value in
///    the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 1 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 1 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comineq_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdneq((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] for equality. The
///    comparison yields 0 for false, 1 for true.
///
///    If either of the two lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomieq_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdeq((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than the corresponding value in
///    the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two lower
///    double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomilt_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdlt((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two lower
///    double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomile_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdle((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than the corresponding value
///    in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two lower
///    double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomigt_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdgt((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0 for false, 1 for true.  If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomige_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdge((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is unequal to the corresponding value in
///    the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two lower
///    double-precision values is NaN, 1 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison result. If either of the two
///    lower double-precision values is NaN, 1 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomineq_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdneq((__v2df)__a, (__v2df)__b);
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two single-precision floating-point
///    values, returned in the lower 64 bits of a 128-bit vector of [4 x float].
///    The upper 64 bits of the result vector are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTPD2PS / CVTPD2PS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector of [4 x float] whose lower 64 bits contain the
///    converted values. The upper 64 bits are set to zero.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvtpd_ps(__m128d __a)
{
  return __builtin_ia32_cvtpd2ps((__v2df)__a);
}

/// Converts the lower two single-precision floating-point elements of a
///    128-bit vector of [4 x float] into two double-precision floating-point
///    values, returned in a 128-bit vector of [2 x double]. The upper two
///    elements of the input vector are unused.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTPS2PD / CVTPS2PD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower two single-precision
///    floating-point elements are converted to double-precision values. The
///    upper two elements are unused.
/// \returns A 128-bit vector of [2 x double] containing the converted values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtps_pd(__m128 __a)
{
  return (__m128d) __builtin_convertvector(
      __builtin_shufflevector((__v4sf)__a, (__v4sf)__a, 0, 1), __v2df);
}

/// Converts the lower two integer elements of a 128-bit vector of
///    [4 x i32] into two double-precision floating-point values, returned in a
///    128-bit vector of [2 x double].
///
///    The upper two elements of the input vector are unused.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTDQ2PD / CVTDQ2PD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector of [4 x i32]. The lower two integer elements are
///    converted to double-precision values.
///
///    The upper two elements are unused.
/// \returns A 128-bit vector of [2 x double] containing the converted values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtepi32_pd(__m128i __a)
{
  return (__m128d) __builtin_convertvector(
      __builtin_shufflevector((__v4si)__a, (__v4si)__a, 0, 1), __v2df);
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two signed 32-bit integer values,
///    returned in the lower 64 bits of a 128-bit vector of [4 x i32]. The upper
///    64 bits of the result vector are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTPD2DQ / CVTPD2DQ </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector of [4 x i32] whose lower 64 bits contain the
///    converted values. The upper 64 bits are set to zero.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvtpd_epi32(__m128d __a)
{
  return __builtin_ia32_cvtpd2dq((__v2df)__a);
}

/// Converts the low-order element of a 128-bit vector of [2 x double]
///    into a 32-bit signed integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSD2SI / CVTSD2SI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are used in the
///    conversion.
/// \returns A 32-bit signed integer containing the converted value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvtsd_si32(__m128d __a)
{
  return __builtin_ia32_cvtsd2si((__v2df)__a);
}

/// Converts the lower double-precision floating-point element of a
///    128-bit vector of [2 x double], in the second parameter, into a
///    single-precision floating-point value, returned in the lower 32 bits of a
///    128-bit vector of [4 x float]. The upper 96 bits of the result vector are
///    copied from the upper 96 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSD2SS / CVTSD2SS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The upper 96 bits of this parameter are
///    copied to the upper 96 bits of the result.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision
///    floating-point element is used in the conversion.
/// \returns A 128-bit vector of [4 x float]. The lower 32 bits contain the
///    converted value from the second parameter. The upper 96 bits are copied
///    from the upper 96 bits of the first parameter.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvtsd_ss(__m128 __a, __m128d __b)
{
  return (__m128)__builtin_ia32_cvtsd2ss((__v4sf)__a, (__v2df)__b);
}

/// Converts a 32-bit signed integer value, in the second parameter, into
///    a double-precision floating-point value, returned in the lower 64 bits of
///    a 128-bit vector of [2 x double]. The upper 64 bits of the result vector
///    are copied from the upper 64 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSI2SD / CVTSI2SD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The upper 64 bits of this parameter are
///    copied to the upper 64 bits of the result.
/// \param __b
///    A 32-bit signed integer containing the value to be converted.
/// \returns A 128-bit vector of [2 x double]. The lower 64 bits contain the
///    converted value from the second parameter. The upper 64 bits are copied
///    from the upper 64 bits of the first parameter.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtsi32_sd(__m128d __a, int __b)
{
  __a[0] = __b;
  return __a;
}

/// Converts the lower single-precision floating-point element of a
///    128-bit vector of [4 x float], in the second parameter, into a
///    double-precision floating-point value, returned in the lower 64 bits of
///    a 128-bit vector of [2 x double]. The upper 64 bits of the result vector
///    are copied from the upper 64 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSS2SD / CVTSS2SD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The upper 64 bits of this parameter are
///    copied to the upper 64 bits of the result.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower single-precision
///    floating-point element is used in the conversion.
/// \returns A 128-bit vector of [2 x double]. The lower 64 bits contain the
///    converted value from the second parameter. The upper 64 bits are copied
///    from the upper 64 bits of the first parameter.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtss_sd(__m128d __a, __m128 __b)
{
  __a[0] = __b[0];
  return __a;
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two signed 32-bit integer values,
///    returned in the lower 64 bits of a 128-bit vector of [4 x i32].
///
///    If the result of either conversion is inexact, the result is truncated
///    (rounded towards zero) regardless of the current MXCSR setting. The upper
///    64 bits of the result vector are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTPD2DQ / CVTTPD2DQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector of [4 x i32] whose lower 64 bits contain the
///    converted values. The upper 64 bits are set to zero.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvttpd_epi32(__m128d __a)
{
  return (__m128i)__builtin_ia32_cvttpd2dq((__v2df)__a);
}

/// Converts the low-order element of a [2 x double] vector into a 32-bit
///    signed integer value, truncating the result when it is inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTSD2SI / CVTTSD2SI </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are used in the
///    conversion.
/// \returns A 32-bit signed integer containing the converted value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvttsd_si32(__m128d __a)
{
  return __builtin_ia32_cvttsd2si((__v2df)__a);
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two signed 32-bit integer values,
///    returned in a 64-bit vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPD2PI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 64-bit vector of [2 x i32] containing the converted values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvtpd_pi32(__m128d __a)
{
  return (__m64)__builtin_ia32_cvtpd2pi((__v2df)__a);
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two signed 32-bit integer values,
///    returned in a 64-bit vector of [2 x i32].
///
///    If the result of either conversion is inexact, the result is truncated
///    (rounded towards zero) regardless of the current MXCSR setting.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTTPD2PI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 64-bit vector of [2 x i32] containing the converted values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvttpd_pi32(__m128d __a)
{
  return (__m64)__builtin_ia32_cvttpd2pi((__v2df)__a);
}

/// Converts the two signed 32-bit integer elements of a 64-bit vector of
///    [2 x i32] into two double-precision floating-point values, returned in a
///    128-bit vector of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PD </c> instruction.
///
/// \param __a
///    A 64-bit vector of [2 x i32].
/// \returns A 128-bit vector of [2 x double] containing the converted values.
static __inline__ __m128d __DEFAULT_FN_ATTRS_MMX
_mm_cvtpi32_pd(__m64 __a)
{
  return __builtin_ia32_cvtpi2pd((__v2si)__a);
}

/// Returns the low-order element of a 128-bit vector of [2 x double] as
///    a double-precision floating-point value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are returned.
/// \returns A double-precision floating-point value copied from the lower 64
///    bits of \a __a.
static __inline__ double __DEFAULT_FN_ATTRS
_mm_cvtsd_f64(__m128d __a)
{
  return __a[0];
}

/// Loads a 128-bit floating-point vector of [2 x double] from an aligned
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPD / MOVAPD </c> instruction.
///
/// \param __dp
///    A pointer to a 128-bit memory location. The address of the memory
///    location has to be 16-byte aligned.
/// \returns A 128-bit vector of [2 x double] containing the loaded values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_load_pd(double const *__dp)
{
  return *(const __m128d*)__dp;
}

/// Loads a double-precision floating-point value from a specified memory
///    location and duplicates it to both vector elements of a 128-bit vector of
///    [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDDUP / MOVDDUP </c> instruction.
///
/// \param __dp
///    A pointer to a memory location containing a double-precision value.
/// \returns A 128-bit vector of [2 x double] containing the loaded and
///    duplicated values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_load1_pd(double const *__dp)
{
  struct __mm_load1_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  double __u = ((const struct __mm_load1_pd_struct*)__dp)->__u;
  return __extension__ (__m128d){ __u, __u };
}

#define        _mm_load_pd1(dp)        _mm_load1_pd(dp)

/// Loads two double-precision values, in reverse order, from an aligned
///    memory location into a 128-bit vector of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPD / MOVAPD </c> instruction +
/// needed shuffling instructions. In AVX mode, the shuffling may be combined
/// with the \c VMOVAPD, resulting in only a \c VPERMILPD instruction.
///
/// \param __dp
///    A 16-byte aligned pointer to an array of double-precision values to be
///    loaded in reverse order.
/// \returns A 128-bit vector of [2 x double] containing the reversed loaded
///    values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_loadr_pd(double const *__dp)
{
  __m128d __u = *(const __m128d*)__dp;
  return __builtin_shufflevector((__v2df)__u, (__v2df)__u, 1, 0);
}

/// Loads a 128-bit floating-point vector of [2 x double] from an
///    unaligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVUPD / MOVUPD </c> instruction.
///
/// \param __dp
///    A pointer to a 128-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [2 x double] containing the loaded values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_loadu_pd(double const *__dp)
{
  struct __loadu_pd {
    __m128d_u __v;
  } __attribute__((__packed__, __may_alias__));
  return ((const struct __loadu_pd*)__dp)->__v;
}

/// Loads a 64-bit integer value to the low element of a 128-bit integer
///    vector and clears the upper element.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __a
///    A pointer to a 64-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [2 x i64] containing the loaded value.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadu_si64(void const *__a)
{
  struct __loadu_si64 {
    long long __v;
  } __attribute__((__packed__, __may_alias__));
  long long __u = ((const struct __loadu_si64*)__a)->__v;
  return __extension__ (__m128i)(__v2di){__u, 0LL};
}

/// Loads a 32-bit integer value to the low element of a 128-bit integer
///    vector and clears the upper element.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVD / MOVD </c> instruction.
///
/// \param __a
///    A pointer to a 32-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [4 x i32] containing the loaded value.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadu_si32(void const *__a)
{
  struct __loadu_si32 {
    int __v;
  } __attribute__((__packed__, __may_alias__));
  int __u = ((const struct __loadu_si32*)__a)->__v;
  return __extension__ (__m128i)(__v4si){__u, 0, 0, 0};
}

/// Loads a 16-bit integer value to the low element of a 128-bit integer
///    vector and clears the upper element.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic does not correspond to a specific instruction.
///
/// \param __a
///    A pointer to a 16-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [8 x i16] containing the loaded value.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadu_si16(void const *__a)
{
  struct __loadu_si16 {
    short __v;
  } __attribute__((__packed__, __may_alias__));
  short __u = ((const struct __loadu_si16*)__a)->__v;
  return __extension__ (__m128i)(__v8hi){__u, 0, 0, 0, 0, 0, 0, 0};
}

/// Loads a 64-bit double-precision value to the low element of a
///    128-bit integer vector and clears the upper element.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVSD / MOVSD </c> instruction.
///
/// \param __dp
///    A pointer to a memory location containing a double-precision value.
///    The address of the memory location does not have to be aligned.
/// \returns A 128-bit vector of [2 x double] containing the loaded value.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_load_sd(double const *__dp)
{
  struct __mm_load_sd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  double __u = ((const struct __mm_load_sd_struct*)__dp)->__u;
  return __extension__ (__m128d){ __u, 0 };
}

/// Loads a double-precision value into the high-order bits of a 128-bit
///    vector of [2 x double]. The low-order bits are copied from the low-order
///    bits of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVHPD / MOVHPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. \n
///    Bits [63:0] are written to bits [63:0] of the result.
/// \param __dp
///    A pointer to a 64-bit memory location containing a double-precision
///    floating-point value that is loaded. The loaded value is written to bits
///    [127:64] of the result. The address of the memory location does not have
///    to be aligned.
/// \returns A 128-bit vector of [2 x double] containing the moved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_loadh_pd(__m128d __a, double const *__dp)
{
  struct __mm_loadh_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  double __u = ((const struct __mm_loadh_pd_struct*)__dp)->__u;
  return __extension__ (__m128d){ __a[0], __u };
}

/// Loads a double-precision value into the low-order bits of a 128-bit
///    vector of [2 x double]. The high-order bits are copied from the
///    high-order bits of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVLPD / MOVLPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. \n
///    Bits [127:64] are written to bits [127:64] of the result.
/// \param __dp
///    A pointer to a 64-bit memory location containing a double-precision
///    floating-point value that is loaded. The loaded value is written to bits
///    [63:0] of the result. The address of the memory location does not have to
///    be aligned.
/// \returns A 128-bit vector of [2 x double] containing the moved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_loadl_pd(__m128d __a, double const *__dp)
{
  struct __mm_loadl_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  double __u = ((const struct __mm_loadl_pd_struct*)__dp)->__u;
  return __extension__ (__m128d){ __u, __a[1] };
}

/// Constructs a 128-bit floating-point vector of [2 x double] with
///    unspecified content. This could be used as an argument to another
///    intrinsic function where the argument is required but the value is not
///    actually used.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \returns A 128-bit floating-point vector of [2 x double] with unspecified
///    content.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_undefined_pd(void)
{
  return (__m128d)__builtin_ia32_undef128();
}

/// Constructs a 128-bit floating-point vector of [2 x double]. The lower
///    64 bits of the vector are initialized with the specified double-precision
///    floating-point value. The upper 64 bits are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize the lower 64
///    bits of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double]. The
///    lower 64 bits contain the value of the parameter. The upper 64 bits are
///    set to zero.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_set_sd(double __w)
{
  return __extension__ (__m128d){ __w, 0 };
}

/// Constructs a 128-bit floating-point vector of [2 x double], with each
///    of the two double-precision floating-point vector elements set to the
///    specified double-precision floating-point value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDDUP / MOVLHPS </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize each vector
///    element of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double].
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_set1_pd(double __w)
{
  return __extension__ (__m128d){ __w, __w };
}

/// Constructs a 128-bit floating-point vector of [2 x double], with each
///    of the two double-precision floating-point vector elements set to the
///    specified double-precision floating-point value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDDUP / MOVLHPS </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize each vector
///    element of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double].
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_set_pd1(double __w)
{
  return _mm_set1_pd(__w);
}

/// Constructs a 128-bit floating-point vector of [2 x double]
///    initialized with the specified double-precision floating-point values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKLPD / UNPCKLPD </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize the upper 64
///    bits of the result.
/// \param __x
///    A double-precision floating-point value used to initialize the lower 64
///    bits of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double].
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_set_pd(double __w, double __x)
{
  return __extension__ (__m128d){ __x, __w };
}

/// Constructs a 128-bit floating-point vector of [2 x double],
///    initialized in reverse order with the specified double-precision
///    floating-point values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKLPD / UNPCKLPD </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize the lower 64
///    bits of the result.
/// \param __x
///    A double-precision floating-point value used to initialize the upper 64
///    bits of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double].
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_setr_pd(double __w, double __x)
{
  return __extension__ (__m128d){ __w, __x };
}

/// Constructs a 128-bit floating-point vector of [2 x double]
///    initialized to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VXORPS / XORPS </c> instruction.
///
/// \returns An initialized 128-bit floating-point vector of [2 x double] with
///    all elements set to zero.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_setzero_pd(void)
{
  return __extension__ (__m128d){ 0, 0 };
}

/// Constructs a 128-bit floating-point vector of [2 x double]. The lower
///    64 bits are set to the lower 64 bits of the second parameter. The upper
///    64 bits are set to the upper 64 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VBLENDPD / BLENDPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The upper 64 bits are written to the
///    upper 64 bits of the result.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower 64 bits are written to the
///    lower 64 bits of the result.
/// \returns A 128-bit vector of [2 x double] containing the moved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_move_sd(__m128d __a, __m128d __b)
{
  __a[0] = __b[0];
  return __a;
}

/// Stores the lower 64 bits of a 128-bit vector of [2 x double] to a
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVSD / MOVSD </c> instruction.
///
/// \param __dp
///    A pointer to a 64-bit memory location.
/// \param __a
///    A 128-bit vector of [2 x double] containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_sd(double *__dp, __m128d __a)
{
  struct __mm_store_sd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_store_sd_struct*)__dp)->__u = __a[0];
}

/// Moves packed double-precision values from a 128-bit vector of
///    [2 x double] to a memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c>VMOVAPD / MOVAPS</c> instruction.
///
/// \param __dp
///    A pointer to an aligned memory location that can store two
///    double-precision values.
/// \param __a
///    A packed 128-bit vector of [2 x double] containing the values to be
///    moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_pd(double *__dp, __m128d __a)
{
  *(__m128d*)__dp = __a;
}

/// Moves the lower 64 bits of a 128-bit vector of [2 x double] twice to
///    the upper and lower 64 bits of a memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the
///   <c> VMOVDDUP + VMOVAPD / MOVLHPS + MOVAPS </c> instruction.
///
/// \param __dp
///    A pointer to a memory location that can store two double-precision
///    values.
/// \param __a
///    A 128-bit vector of [2 x double] whose lower 64 bits are copied to each
///    of the values in \a __dp.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store1_pd(double *__dp, __m128d __a)
{
  __a = __builtin_shufflevector((__v2df)__a, (__v2df)__a, 0, 0);
  _mm_store_pd(__dp, __a);
}

/// Moves the lower 64 bits of a 128-bit vector of [2 x double] twice to
///    the upper and lower 64 bits of a memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the
///   <c> VMOVDDUP + VMOVAPD / MOVLHPS + MOVAPS </c> instruction.
///
/// \param __dp
///    A pointer to a memory location that can store two double-precision
///    values.
/// \param __a
///    A 128-bit vector of [2 x double] whose lower 64 bits are copied to each
///    of the values in \a __dp.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_pd1(double *__dp, __m128d __a)
{
  _mm_store1_pd(__dp, __a);
}

/// Stores a 128-bit vector of [2 x double] into an unaligned memory
///    location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVUPD / MOVUPD </c> instruction.
///
/// \param __dp
///    A pointer to a 128-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \param __a
///    A 128-bit vector of [2 x double] containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_pd(double *__dp, __m128d __a)
{
  struct __storeu_pd {
    __m128d_u __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_pd*)__dp)->__v = __a;
}

/// Stores two double-precision values, in reverse order, from a 128-bit
///    vector of [2 x double] to a 16-byte aligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to a shuffling instruction followed by a
/// <c> VMOVAPD / MOVAPD </c> instruction.
///
/// \param __dp
///    A pointer to a 16-byte aligned memory location that can store two
///    double-precision values.
/// \param __a
///    A 128-bit vector of [2 x double] containing the values to be reversed and
///    stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storer_pd(double *__dp, __m128d __a)
{
  __a = __builtin_shufflevector((__v2df)__a, (__v2df)__a, 1, 0);
  *(__m128d *)__dp = __a;
}

/// Stores the upper 64 bits of a 128-bit vector of [2 x double] to a
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVHPD / MOVHPD </c> instruction.
///
/// \param __dp
///    A pointer to a 64-bit memory location.
/// \param __a
///    A 128-bit vector of [2 x double] containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeh_pd(double *__dp, __m128d __a)
{
  struct __mm_storeh_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_storeh_pd_struct*)__dp)->__u = __a[1];
}

/// Stores the lower 64 bits of a 128-bit vector of [2 x double] to a
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVLPD / MOVLPD </c> instruction.
///
/// \param __dp
///    A pointer to a 64-bit memory location.
/// \param __a
///    A 128-bit vector of [2 x double] containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storel_pd(double *__dp, __m128d __a)
{
  struct __mm_storeh_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_storeh_pd_struct*)__dp)->__u = __a[0];
}

/// Adds the corresponding elements of two 128-bit vectors of [16 x i8],
///    saving the lower 8 bits of each sum in the corresponding element of a
///    128-bit result vector of [16 x i8].
///
///    The integer elements of both parameters can be either signed or unsigned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDB / PADDB </c> instruction.
///
/// \param __a
///    A 128-bit vector of [16 x i8].
/// \param __b
///    A 128-bit vector of [16 x i8].
/// \returns A 128-bit vector of [16 x i8] containing the sums of both
///    parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_add_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)((__v16qu)__a + (__v16qu)__b);
}

/// Adds the corresponding elements of two 128-bit vectors of [8 x i16],
///    saving the lower 16 bits of each sum in the corresponding element of a
///    128-bit result vector of [8 x i16].
///
///    The integer elements of both parameters can be either signed or unsigned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDW / PADDW </c> instruction.
///
/// \param __a
///    A 128-bit vector of [8 x i16].
/// \param __b
///    A 128-bit vector of [8 x i16].
/// \returns A 128-bit vector of [8 x i16] containing the sums of both
///    parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_add_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hu)__a + (__v8hu)__b);
}

/// Adds the corresponding elements of two 128-bit vectors of [4 x i32],
///    saving the lower 32 bits of each sum in the corresponding element of a
///    128-bit result vector of [4 x i32].
///
///    The integer elements of both parameters can be either signed or unsigned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDD / PADDD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x i32].
/// \param __b
///    A 128-bit vector of [4 x i32].
/// \returns A 128-bit vector of [4 x i32] containing the sums of both
///    parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_add_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)((__v4su)__a + (__v4su)__b);
}

/// Adds two signed or unsigned 64-bit integer values, returning the
///    lower 64 bits of the sum.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDQ </c> instruction.
///
/// \param __a
///    A 64-bit integer.
/// \param __b
///    A 64-bit integer.
/// \returns A 64-bit integer containing the sum of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_add_si64(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_paddq((__v1di)__a, (__v1di)__b);
}

/// Adds the corresponding elements of two 128-bit vectors of [2 x i64],
///    saving the lower 64 bits of each sum in the corresponding element of a
///    128-bit result vector of [2 x i64].
///
///    The integer elements of both parameters can be either signed or unsigned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDQ / PADDQ </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x i64].
/// \param __b
///    A 128-bit vector of [2 x i64].
/// \returns A 128-bit vector of [2 x i64] containing the sums of both
///    parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_add_epi64(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a + (__v2du)__b);
}

/// Adds, with saturation, the corresponding elements of two 128-bit
///    signed [16 x i8] vectors, saving each sum in the corresponding element of
///    a 128-bit result vector of [16 x i8]. Positive sums greater than 0x7F are
///    saturated to 0x7F. Negative sums less than 0x80 are saturated to 0x80.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDSB / PADDSB </c> instruction.
///
/// \param __a
///    A 128-bit signed [16 x i8] vector.
/// \param __b
///    A 128-bit signed [16 x i8] vector.
/// \returns A 128-bit signed [16 x i8] vector containing the saturated sums of
///    both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_adds_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_paddsb128((__v16qi)__a, (__v16qi)__b);
}

/// Adds, with saturation, the corresponding elements of two 128-bit
///    signed [8 x i16] vectors, saving each sum in the corresponding element of
///    a 128-bit result vector of [8 x i16]. Positive sums greater than 0x7FFF
///    are saturated to 0x7FFF. Negative sums less than 0x8000 are saturated to
///    0x8000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDSW / PADDSW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the saturated sums of
///    both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_adds_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_paddsw128((__v8hi)__a, (__v8hi)__b);
}

/// Adds, with saturation, the corresponding elements of two 128-bit
///    unsigned [16 x i8] vectors, saving each sum in the corresponding element
///    of a 128-bit result vector of [16 x i8]. Positive sums greater than 0xFF
///    are saturated to 0xFF. Negative sums are saturated to 0x00.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDUSB / PADDUSB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [16 x i8] vector.
/// \param __b
///    A 128-bit unsigned [16 x i8] vector.
/// \returns A 128-bit unsigned [16 x i8] vector containing the saturated sums
///    of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_adds_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_paddusb128((__v16qi)__a, (__v16qi)__b);
}

/// Adds, with saturation, the corresponding elements of two 128-bit
///    unsigned [8 x i16] vectors, saving each sum in the corresponding element
///    of a 128-bit result vector of [8 x i16]. Positive sums greater than
///    0xFFFF are saturated to 0xFFFF. Negative sums are saturated to 0x0000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDUSB / PADDUSB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [8 x i16] vector.
/// \param __b
///    A 128-bit unsigned [8 x i16] vector.
/// \returns A 128-bit unsigned [8 x i16] vector containing the saturated sums
///    of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_adds_epu16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_paddusw128((__v8hi)__a, (__v8hi)__b);
}

/// Computes the rounded averages of corresponding elements of two
///    128-bit unsigned [16 x i8] vectors, saving each result in the
///    corresponding element of a 128-bit result vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPAVGB / PAVGB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [16 x i8] vector.
/// \param __b
///    A 128-bit unsigned [16 x i8] vector.
/// \returns A 128-bit unsigned [16 x i8] vector containing the rounded
///    averages of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_avg_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pavgb128((__v16qi)__a, (__v16qi)__b);
}

/// Computes the rounded averages of corresponding elements of two
///    128-bit unsigned [8 x i16] vectors, saving each result in the
///    corresponding element of a 128-bit result vector of [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPAVGW / PAVGW </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [8 x i16] vector.
/// \param __b
///    A 128-bit unsigned [8 x i16] vector.
/// \returns A 128-bit unsigned [8 x i16] vector containing the rounded
///    averages of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_avg_epu16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pavgw128((__v8hi)__a, (__v8hi)__b);
}

/// Multiplies the corresponding elements of two 128-bit signed [8 x i16]
///    vectors, producing eight intermediate 32-bit signed integer products, and
///    adds the consecutive pairs of 32-bit products to form a 128-bit signed
///    [4 x i32] vector.
///
///    For example, bits [15:0] of both parameters are multiplied producing a
///    32-bit product, bits [31:16] of both parameters are multiplied producing
///    a 32-bit product, and the sum of those two products becomes bits [31:0]
///    of the result.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMADDWD / PMADDWD </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [4 x i32] vector containing the sums of products
///    of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_madd_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmaddwd128((__v8hi)__a, (__v8hi)__b);
}

/// Compares corresponding elements of two 128-bit signed [8 x i16]
///    vectors, saving the greater value from each comparison in the
///    corresponding element of a 128-bit result vector of [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMAXSW / PMAXSW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the greater value of
///    each comparison.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_max_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmaxsw128((__v8hi)__a, (__v8hi)__b);
}

/// Compares corresponding elements of two 128-bit unsigned [16 x i8]
///    vectors, saving the greater value from each comparison in the
///    corresponding element of a 128-bit result vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMAXUB / PMAXUB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [16 x i8] vector.
/// \param __b
///    A 128-bit unsigned [16 x i8] vector.
/// \returns A 128-bit unsigned [16 x i8] vector containing the greater value of
///    each comparison.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_max_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmaxub128((__v16qi)__a, (__v16qi)__b);
}

/// Compares corresponding elements of two 128-bit signed [8 x i16]
///    vectors, saving the smaller value from each comparison in the
///    corresponding element of a 128-bit result vector of [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMINSW / PMINSW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the smaller value of
///    each comparison.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_min_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pminsw128((__v8hi)__a, (__v8hi)__b);
}

/// Compares corresponding elements of two 128-bit unsigned [16 x i8]
///    vectors, saving the smaller value from each comparison in the
///    corresponding element of a 128-bit result vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMINUB / PMINUB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [16 x i8] vector.
/// \param __b
///    A 128-bit unsigned [16 x i8] vector.
/// \returns A 128-bit unsigned [16 x i8] vector containing the smaller value of
///    each comparison.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_min_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pminub128((__v16qi)__a, (__v16qi)__b);
}

/// Multiplies the corresponding elements of two signed [8 x i16]
///    vectors, saving the upper 16 bits of each 32-bit product in the
///    corresponding element of a 128-bit signed [8 x i16] result vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMULHW / PMULHW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the upper 16 bits of
///    each of the eight 32-bit products.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_mulhi_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmulhw128((__v8hi)__a, (__v8hi)__b);
}

/// Multiplies the corresponding elements of two unsigned [8 x i16]
///    vectors, saving the upper 16 bits of each 32-bit product in the
///    corresponding element of a 128-bit unsigned [8 x i16] result vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMULHUW / PMULHUW </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [8 x i16] vector.
/// \param __b
///    A 128-bit unsigned [8 x i16] vector.
/// \returns A 128-bit unsigned [8 x i16] vector containing the upper 16 bits
///    of each of the eight 32-bit products.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_mulhi_epu16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmulhuw128((__v8hi)__a, (__v8hi)__b);
}

/// Multiplies the corresponding elements of two signed [8 x i16]
///    vectors, saving the lower 16 bits of each 32-bit product in the
///    corresponding element of a 128-bit signed [8 x i16] result vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMULLW / PMULLW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the lower 16 bits of
///    each of the eight 32-bit products.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_mullo_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hu)__a * (__v8hu)__b);
}

/// Multiplies 32-bit unsigned integer values contained in the lower bits
///    of the two 64-bit integer vectors and returns the 64-bit unsigned
///    product.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMULUDQ </c> instruction.
///
/// \param __a
///    A 64-bit integer containing one of the source operands.
/// \param __b
///    A 64-bit integer containing one of the source operands.
/// \returns A 64-bit integer vector containing the product of both operands.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_mul_su32(__m64 __a, __m64 __b)
{
  return __builtin_ia32_pmuludq((__v2si)__a, (__v2si)__b);
}

/// Multiplies 32-bit unsigned integer values contained in the lower
///    bits of the corresponding elements of two [2 x i64] vectors, and returns
///    the 64-bit products in the corresponding elements of a [2 x i64] vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMULUDQ / PMULUDQ </c> instruction.
///
/// \param __a
///    A [2 x i64] vector containing one of the source operands.
/// \param __b
///    A [2 x i64] vector containing one of the source operands.
/// \returns A [2 x i64] vector containing the product of both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_mul_epu32(__m128i __a, __m128i __b)
{
  return __builtin_ia32_pmuludq128((__v4si)__a, (__v4si)__b);
}

/// Computes the absolute differences of corresponding 8-bit integer
///    values in two 128-bit vectors. Sums the first 8 absolute differences, and
///    separately sums the second 8 absolute differences. Packs these two
///    unsigned 16-bit integer sums into the upper and lower elements of a
///    [2 x i64] vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSADBW / PSADBW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing one of the source operands.
/// \param __b
///    A 128-bit integer vector containing one of the source operands.
/// \returns A [2 x i64] vector containing the sums of the sets of absolute
///    differences between both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sad_epu8(__m128i __a, __m128i __b)
{
  return __builtin_ia32_psadbw128((__v16qi)__a, (__v16qi)__b);
}

/// Subtracts the corresponding 8-bit integer values in the operands.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBB / PSUBB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sub_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)((__v16qu)__a - (__v16qu)__b);
}

/// Subtracts the corresponding 16-bit integer values in the operands.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBW / PSUBW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sub_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hu)__a - (__v8hu)__b);
}

/// Subtracts the corresponding 32-bit integer values in the operands.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBD / PSUBD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sub_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)((__v4su)__a - (__v4su)__b);
}

/// Subtracts signed or unsigned 64-bit integer values and writes the
///    difference to the corresponding bits in the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBQ </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing the minuend.
/// \param __b
///    A 64-bit integer vector containing the subtrahend.
/// \returns A 64-bit integer vector containing the difference of the values in
///    the operands.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_sub_si64(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_psubq((__v1di)__a, (__v1di)__b);
}

/// Subtracts the corresponding elements of two [2 x i64] vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBQ / PSUBQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sub_epi64(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a - (__v2du)__b);
}

/// Subtracts corresponding 8-bit signed integer values in the input and
///    returns the differences in the corresponding bytes in the destination.
///    Differences greater than 0x7F are saturated to 0x7F, and differences less
///    than 0x80 are saturated to 0x80.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBSB / PSUBSB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_subs_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_psubsb128((__v16qi)__a, (__v16qi)__b);
}

/// Subtracts corresponding 16-bit signed integer values in the input and
///    returns the differences in the corresponding bytes in the destination.
///    Differences greater than 0x7FFF are saturated to 0x7FFF, and values less
///    than 0x8000 are saturated to 0x8000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBSW / PSUBSW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_subs_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_psubsw128((__v8hi)__a, (__v8hi)__b);
}

/// Subtracts corresponding 8-bit unsigned integer values in the input
///    and returns the differences in the corresponding bytes in the
///    destination. Differences less than 0x00 are saturated to 0x00.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBUSB / PSUBUSB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the unsigned integer
///    differences of the values in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_subs_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_psubusb128((__v16qi)__a, (__v16qi)__b);
}

/// Subtracts corresponding 16-bit unsigned integer values in the input
///    and returns the differences in the corresponding bytes in the
///    destination. Differences less than 0x0000 are saturated to 0x0000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBUSW / PSUBUSW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the unsigned integer
///    differences of the values in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_subs_epu16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_psubusw128((__v8hi)__a, (__v8hi)__b);
}

/// Performs a bitwise AND of two 128-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPAND / PAND </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing one of the source operands.
/// \param __b
///    A 128-bit integer vector containing one of the source operands.
/// \returns A 128-bit integer vector containing the bitwise AND of the values
///    in both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_and_si128(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a & (__v2du)__b);
}

/// Performs a bitwise AND of two 128-bit integer vectors, using the
///    one's complement of the values contained in the first source operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPANDN / PANDN </c> instruction.
///
/// \param __a
///    A 128-bit vector containing the left source operand. The one's complement
///    of this value is used in the bitwise AND.
/// \param __b
///    A 128-bit vector containing the right source operand.
/// \returns A 128-bit integer vector containing the bitwise AND of the one's
///    complement of the first operand and the values in the second operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_andnot_si128(__m128i __a, __m128i __b)
{
  return (__m128i)(~(__v2du)__a & (__v2du)__b);
}
/// Performs a bitwise OR of two 128-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPOR / POR </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing one of the source operands.
/// \param __b
///    A 128-bit integer vector containing one of the source operands.
/// \returns A 128-bit integer vector containing the bitwise OR of the values
///    in both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_or_si128(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a | (__v2du)__b);
}

/// Performs a bitwise exclusive OR of two 128-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPXOR / PXOR </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing one of the source operands.
/// \param __b
///    A 128-bit integer vector containing one of the source operands.
/// \returns A 128-bit integer vector containing the bitwise exclusive OR of the
///    values in both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_xor_si128(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a ^ (__v2du)__b);
}

/// Left-shifts the 128-bit integer vector operand by the specified
///    number of bytes. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_slli_si128(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSLLDQ / PSLLDQ </c> instruction.
///
/// \param a
///    A 128-bit integer vector containing the source operand.
/// \param imm
///    An immediate value specifying the number of bytes to left-shift operand
///    \a a.
/// \returns A 128-bit integer vector containing the left-shifted value.
#define _mm_slli_si128(a, imm) \
  (__m128i)__builtin_ia32_pslldqi128_byteshift((__v2di)(__m128i)(a), (int)(imm))

#define _mm_bslli_si128(a, imm) \
  (__m128i)__builtin_ia32_pslldqi128_byteshift((__v2di)(__m128i)(a), (int)(imm))

/// Left-shifts each 16-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLW / PSLLW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to left-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_slli_epi16(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psllwi128((__v8hi)__a, __count);
}

/// Left-shifts each 16-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLW / PSLLW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to left-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sll_epi16(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psllw128((__v8hi)__a, (__v8hi)__count);
}

/// Left-shifts each 32-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLD / PSLLD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to left-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_slli_epi32(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_pslldi128((__v4si)__a, __count);
}

/// Left-shifts each 32-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLD / PSLLD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to left-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sll_epi32(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_pslld128((__v4si)__a, (__v4si)__count);
}

/// Left-shifts each 64-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLQ / PSLLQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to left-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_slli_epi64(__m128i __a, int __count)
{
  return __builtin_ia32_psllqi128((__v2di)__a, __count);
}

/// Left-shifts each 64-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLQ / PSLLQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to left-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sll_epi64(__m128i __a, __m128i __count)
{
  return __builtin_ia32_psllq128((__v2di)__a, (__v2di)__count);
}

/// Right-shifts each 16-bit value in the 128-bit integer vector operand
///    by the specified number of bits. High-order bits are filled with the sign
///    bit of the initial value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRAW / PSRAW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srai_epi16(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psrawi128((__v8hi)__a, __count);
}

/// Right-shifts each 16-bit value in the 128-bit integer vector operand
///    by the specified number of bits. High-order bits are filled with the sign
///    bit of the initial value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRAW / PSRAW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sra_epi16(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psraw128((__v8hi)__a, (__v8hi)__count);
}

/// Right-shifts each 32-bit value in the 128-bit integer vector operand
///    by the specified number of bits. High-order bits are filled with the sign
///    bit of the initial value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRAD / PSRAD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srai_epi32(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psradi128((__v4si)__a, __count);
}

/// Right-shifts each 32-bit value in the 128-bit integer vector operand
///    by the specified number of bits. High-order bits are filled with the sign
///    bit of the initial value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRAD / PSRAD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sra_epi32(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psrad128((__v4si)__a, (__v4si)__count);
}

/// Right-shifts the 128-bit integer vector operand by the specified
///    number of bytes. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_srli_si128(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSRLDQ / PSRLDQ </c> instruction.
///
/// \param a
///    A 128-bit integer vector containing the source operand.
/// \param imm
///    An immediate value specifying the number of bytes to right-shift operand
///    \a a.
/// \returns A 128-bit integer vector containing the right-shifted value.
#define _mm_srli_si128(a, imm) \
  (__m128i)__builtin_ia32_psrldqi128_byteshift((__v2di)(__m128i)(a), (int)(imm))

#define _mm_bsrli_si128(a, imm) \
  (__m128i)__builtin_ia32_psrldqi128_byteshift((__v2di)(__m128i)(a), (int)(imm))

/// Right-shifts each of 16-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLW / PSRLW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srli_epi16(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psrlwi128((__v8hi)__a, __count);
}

/// Right-shifts each of 16-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLW / PSRLW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srl_epi16(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psrlw128((__v8hi)__a, (__v8hi)__count);
}

/// Right-shifts each of 32-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLD / PSRLD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srli_epi32(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psrldi128((__v4si)__a, __count);
}

/// Right-shifts each of 32-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLD / PSRLD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srl_epi32(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psrld128((__v4si)__a, (__v4si)__count);
}

/// Right-shifts each of 64-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLQ / PSRLQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srli_epi64(__m128i __a, int __count)
{
  return __builtin_ia32_psrlqi128((__v2di)__a, __count);
}

/// Right-shifts each of 64-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLQ / PSRLQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srl_epi64(__m128i __a, __m128i __count)
{
  return __builtin_ia32_psrlq128((__v2di)__a, (__v2di)__count);
}

/// Compares each of the corresponding 8-bit values of the 128-bit
///    integer vectors for equality. Each comparison yields 0x0 for false, 0xFF
///    for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPEQB / PCMPEQB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpeq_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)((__v16qi)__a == (__v16qi)__b);
}

/// Compares each of the corresponding 16-bit values of the 128-bit
///    integer vectors for equality. Each comparison yields 0x0 for false,
///    0xFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPEQW / PCMPEQW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpeq_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hi)__a == (__v8hi)__b);
}

/// Compares each of the corresponding 32-bit values of the 128-bit
///    integer vectors for equality. Each comparison yields 0x0 for false,
///    0xFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPEQD / PCMPEQD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpeq_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)((__v4si)__a == (__v4si)__b);
}

/// Compares each of the corresponding signed 8-bit values of the 128-bit
///    integer vectors to determine if the values in the first operand are
///    greater than those in the second operand. Each comparison yields 0x0 for
///    false, 0xFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTB / PCMPGTB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpgt_epi8(__m128i __a, __m128i __b)
{
  /* This function always performs a signed comparison, but __v16qi is a char
     which may be signed or unsigned, so use __v16qs. */
  return (__m128i)((__v16qs)__a > (__v16qs)__b);
}

/// Compares each of the corresponding signed 16-bit values of the
///    128-bit integer vectors to determine if the values in the first operand
///    are greater than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTW / PCMPGTW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpgt_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hi)__a > (__v8hi)__b);
}

/// Compares each of the corresponding signed 32-bit values of the
///    128-bit integer vectors to determine if the values in the first operand
///    are greater than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTD / PCMPGTD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpgt_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)((__v4si)__a > (__v4si)__b);
}

/// Compares each of the corresponding signed 8-bit values of the 128-bit
///    integer vectors to determine if the values in the first operand are less
///    than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTB / PCMPGTB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmplt_epi8(__m128i __a, __m128i __b)
{
  return _mm_cmpgt_epi8(__b, __a);
}

/// Compares each of the corresponding signed 16-bit values of the
///    128-bit integer vectors to determine if the values in the first operand
///    are less than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTW / PCMPGTW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmplt_epi16(__m128i __a, __m128i __b)
{
  return _mm_cmpgt_epi16(__b, __a);
}

/// Compares each of the corresponding signed 32-bit values of the
///    128-bit integer vectors to determine if the values in the first operand
///    are less than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTD / PCMPGTD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmplt_epi32(__m128i __a, __m128i __b)
{
  return _mm_cmpgt_epi32(__b, __a);
}

#ifdef __x86_64__
/// Converts a 64-bit signed integer value from the second operand into a
///    double-precision value and returns it in the lower element of a [2 x
///    double] vector; the upper element of the returned vector is copied from
///    the upper element of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSI2SD / CVTSI2SD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The upper 64 bits of this operand are
///    copied to the upper 64 bits of the destination.
/// \param __b
///    A 64-bit signed integer operand containing the value to be converted.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    converted value of the second operand. The upper 64 bits are copied from
///    the upper 64 bits of the first operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtsi64_sd(__m128d __a, long long __b)
{
  __a[0] = __b;
  return __a;
}

/// Converts the first (lower) element of a vector of [2 x double] into a
///    64-bit signed integer value, according to the current rounding mode.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSD2SI / CVTSD2SI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are used in the
///    conversion.
/// \returns A 64-bit signed integer containing the converted value.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvtsd_si64(__m128d __a)
{
  return __builtin_ia32_cvtsd2si64((__v2df)__a);
}

/// Converts the first (lower) element of a vector of [2 x double] into a
///    64-bit signed integer value, truncating the result when it is inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTSD2SI / CVTTSD2SI </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are used in the
///    conversion.
/// \returns A 64-bit signed integer containing the converted value.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvttsd_si64(__m128d __a)
{
  return __builtin_ia32_cvttsd2si64((__v2df)__a);
}
#endif
# 3401 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Converts a vector of [4 x i32] into a vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTDQ2PS / CVTDQ2PS </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \returns A 128-bit vector of [4 x float] containing the converted values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvtepi32_ps(__m128i __a)
{
  return (__m128)__builtin_convertvector((__v4si)__a, __v4sf);
}

/// Converts a vector of [4 x float] into a vector of [4 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTPS2DQ / CVTPS2DQ </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit integer vector of [4 x i32] containing the converted
///    values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvtps_epi32(__m128 __a)
{
  return (__m128i)__builtin_ia32_cvtps2dq((__v4sf)__a);
}

/// Converts a vector of [4 x float] into a vector of [4 x i32],
///    truncating the result when it is inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTPS2DQ / CVTTPS2DQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x i32] containing the converted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvttps_epi32(__m128 __a)
{
  return (__m128i)__builtin_ia32_cvttps2dq((__v4sf)__a);
}

/// Returns a vector of [4 x i32] where the lowest element is the input
///    operand and the remaining elements are zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVD / MOVD </c> instruction.
///
/// \param __a
///    A 32-bit signed integer operand.
/// \returns A 128-bit vector of [4 x i32].
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvtsi32_si128(int __a)
{
  return __extension__ (__m128i)(__v4si){ __a, 0, 0, 0 };
}

#ifdef __x86_64__
/// Returns a vector of [2 x i64] where the lower element is the input
///    operand and the upper element is zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __a
///    A 64-bit signed integer operand containing the value to be converted.
/// \returns A 128-bit vector of [2 x i64] containing the converted value.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvtsi64_si128(long long __a)
{
  return __extension__ (__m128i)(__v2di){ __a, 0 };
}
#endif
# 3483 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Moves the least significant 32 bits of a vector of [4 x i32] to a
///    32-bit signed integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVD / MOVD </c> instruction.
///
/// \param __a
///    A vector of [4 x i32]. The least significant 32 bits are moved to the
///    destination.
/// \returns A 32-bit signed integer containing the moved value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvtsi128_si32(__m128i __a)
{
  __v4si __b = (__v4si)__a;
  return __b[0];
}

#ifdef __x86_64__
/// Moves the least significant 64 bits of a vector of [2 x i64] to a
///    64-bit signed integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __a
///    A vector of [2 x i64]. The least significant 64 bits are moved to the
///    destination.
/// \returns A 64-bit signed integer containing the moved value.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvtsi128_si64(__m128i __a)
{
  return __a[0];
}
#endif
# 3520 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Moves packed integer values from an aligned 128-bit memory location
///    to elements in a 128-bit integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDQA / MOVDQA </c> instruction.
///
/// \param __p
///    An aligned pointer to a memory location containing integer values.
/// \returns A 128-bit integer vector containing the moved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_load_si128(__m128i const *__p)
{
  return *__p;
}

/// Moves packed integer values from an unaligned 128-bit memory location
///    to elements in a 128-bit integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDQU / MOVDQU </c> instruction.
///
/// \param __p
///    A pointer to a memory location containing integer values.
/// \returns A 128-bit integer vector containing the moved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadu_si128(__m128i_u const *__p)
{
  struct __loadu_si128 {
    __m128i_u __v;
  } __attribute__((__packed__, __may_alias__));
  return ((const struct __loadu_si128*)__p)->__v;
}

/// Returns a vector of [2 x i64] where the lower element is taken from
///    the lower element of the operand, and the upper element is zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __p
///    A 128-bit vector of [2 x i64]. Bits [63:0] are written to bits [63:0] of
///    the destination.
/// \returns A 128-bit vector of [2 x i64]. The lower order bits contain the
///    moved value. The higher order bits are cleared.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadl_epi64(__m128i_u const *__p)
{
  struct __mm_loadl_epi64_struct {
    long long __u;
  } __attribute__((__packed__, __may_alias__));
  return __extension__ (__m128i) { ((const struct __mm_loadl_epi64_struct*)__p)->__u, 0};
}

/// Generates a 128-bit vector of [4 x i32] with unspecified content.
///    This could be used as an argument to another intrinsic function where the
///    argument is required but the value is not actually used.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \returns A 128-bit vector of [4 x i32] with unspecified content.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_undefined_si128(void)
{
  return (__m128i)__builtin_ia32_undef128();
}

/// Initializes both 64-bit values in a 128-bit vector of [2 x i64] with
///    the specified 64-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __q1
///    A 64-bit integer value used to initialize the upper 64 bits of the
///    destination vector of [2 x i64].
/// \param __q0
///    A 64-bit integer value used to initialize the lower 64 bits of the
///    destination vector of [2 x i64].
/// \returns An initialized 128-bit vector of [2 x i64] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi64x(long long __q1, long long __q0)
{
  return __extension__ (__m128i)(__v2di){ __q0, __q1 };
}

/// Initializes both 64-bit values in a 128-bit vector of [2 x i64] with
///    the specified 64-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __q1
///    A 64-bit integer value used to initialize the upper 64 bits of the
///    destination vector of [2 x i64].
/// \param __q0
///    A 64-bit integer value used to initialize the lower 64 bits of the
///    destination vector of [2 x i64].
/// \returns An initialized 128-bit vector of [2 x i64] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi64(__m64 __q1, __m64 __q0)
{
  return _mm_set_epi64x((long long)__q1, (long long)__q0);
}

/// Initializes the 32-bit values in a 128-bit vector of [4 x i32] with
///    the specified 32-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i3
///    A 32-bit integer value used to initialize bits [127:96] of the
///    destination vector.
/// \param __i2
///    A 32-bit integer value used to initialize bits [95:64] of the destination
///    vector.
/// \param __i1
///    A 32-bit integer value used to initialize bits [63:32] of the destination
///    vector.
/// \param __i0
///    A 32-bit integer value used to initialize bits [31:0] of the destination
///    vector.
/// \returns An initialized 128-bit vector of [4 x i32] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi32(int __i3, int __i2, int __i1, int __i0)
{
  return __extension__ (__m128i)(__v4si){ __i0, __i1, __i2, __i3};
}

/// Initializes the 16-bit values in a 128-bit vector of [8 x i16] with
///    the specified 16-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __w7
///    A 16-bit integer value used to initialize bits [127:112] of the
///    destination vector.
/// \param __w6
///    A 16-bit integer value used to initialize bits [111:96] of the
///    destination vector.
/// \param __w5
///    A 16-bit integer value used to initialize bits [95:80] of the destination
///    vector.
/// \param __w4
///    A 16-bit integer value used to initialize bits [79:64] of the destination
///    vector.
/// \param __w3
///    A 16-bit integer value used to initialize bits [63:48] of the destination
///    vector.
/// \param __w2
///    A 16-bit integer value used to initialize bits [47:32] of the destination
///    vector.
/// \param __w1
///    A 16-bit integer value used to initialize bits [31:16] of the destination
///    vector.
/// \param __w0
///    A 16-bit integer value used to initialize bits [15:0] of the destination
///    vector.
/// \returns An initialized 128-bit vector of [8 x i16] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi16(short __w7, short __w6, short __w5, short __w4, short __w3, short __w2, short __w1, short __w0)
{
  return __extension__ (__m128i)(__v8hi){ __w0, __w1, __w2, __w3, __w4, __w5, __w6, __w7 };
}

/// Initializes the 8-bit values in a 128-bit vector of [16 x i8] with
///    the specified 8-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b15
///    Initializes bits [127:120] of the destination vector.
/// \param __b14
///    Initializes bits [119:112] of the destination vector.
/// \param __b13
///    Initializes bits [111:104] of the destination vector.
/// \param __b12
///    Initializes bits [103:96] of the destination vector.
/// \param __b11
///    Initializes bits [95:88] of the destination vector.
/// \param __b10
///    Initializes bits [87:80] of the destination vector.
/// \param __b9
///    Initializes bits [79:72] of the destination vector.
/// \param __b8
///    Initializes bits [71:64] of the destination vector.
/// \param __b7
///    Initializes bits [63:56] of the destination vector.
/// \param __b6
///    Initializes bits [55:48] of the destination vector.
/// \param __b5
///    Initializes bits [47:40] of the destination vector.
/// \param __b4
///    Initializes bits [39:32] of the destination vector.
/// \param __b3
///    Initializes bits [31:24] of the destination vector.
/// \param __b2
///    Initializes bits [23:16] of the destination vector.
/// \param __b1
///    Initializes bits [15:8] of the destination vector.
/// \param __b0
///    Initializes bits [7:0] of the destination vector.
/// \returns An initialized 128-bit vector of [16 x i8] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi8(char __b15, char __b14, char __b13, char __b12, char __b11, char __b10, char __b9, char __b8, char __b7, char __b6, char __b5, char __b4, char __b3, char __b2, char __b1, char __b0)
{
  return __extension__ (__m128i)(__v16qi){ __b0, __b1, __b2, __b3, __b4, __b5, __b6, __b7, __b8, __b9, __b10, __b11, __b12, __b13, __b14, __b15 };
}

/// Initializes both values in a 128-bit integer vector with the
///    specified 64-bit integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __q
///    Integer value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit integer vector of [2 x i64] with both
///    elements containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi64x(long long __q)
{
  return _mm_set_epi64x(__q, __q);
}

/// Initializes both values in a 128-bit vector of [2 x i64] with the
///    specified 64-bit value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __q
///    A 64-bit value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit vector of [2 x i64] with all elements
///    containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi64(__m64 __q)
{
  return _mm_set_epi64(__q, __q);
}

/// Initializes all values in a 128-bit vector of [4 x i32] with the
///    specified 32-bit value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i
///    A 32-bit value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit vector of [4 x i32] with all elements
///    containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi32(int __i)
{
  return _mm_set_epi32(__i, __i, __i, __i);
}

/// Initializes all values in a 128-bit vector of [8 x i16] with the
///    specified 16-bit value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __w
///    A 16-bit value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit vector of [8 x i16] with all elements
///    containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi16(short __w)
{
  return _mm_set_epi16(__w, __w, __w, __w, __w, __w, __w, __w);
}

/// Initializes all values in a 128-bit vector of [16 x i8] with the
///    specified 8-bit value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b
///    An 8-bit value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit vector of [16 x i8] with all elements
///    containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi8(char __b)
{
  return _mm_set_epi8(__b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b);
}

/// Constructs a 128-bit integer vector, initialized in reverse order
///     with the specified 64-bit integral values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic does not correspond to a specific instruction.
///
/// \param __q0
///    A 64-bit integral value used to initialize the lower 64 bits of the
///    result.
/// \param __q1
///    A 64-bit integral value used to initialize the upper 64 bits of the
///    result.
/// \returns An initialized 128-bit integer vector.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setr_epi64(__m64 __q0, __m64 __q1)
{
  return _mm_set_epi64(__q1, __q0);
}

/// Constructs a 128-bit integer vector, initialized in reverse order
///     with the specified 32-bit integral values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i0
///    A 32-bit integral value used to initialize bits [31:0] of the result.
/// \param __i1
///    A 32-bit integral value used to initialize bits [63:32] of the result.
/// \param __i2
///    A 32-bit integral value used to initialize bits [95:64] of the result.
/// \param __i3
///    A 32-bit integral value used to initialize bits [127:96] of the result.
/// \returns An initialized 128-bit integer vector.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setr_epi32(int __i0, int __i1, int __i2, int __i3)
{
  return _mm_set_epi32(__i3, __i2, __i1, __i0);
}

/// Constructs a 128-bit integer vector, initialized in reverse order
///     with the specified 16-bit integral values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __w0
///    A 16-bit integral value used to initialize bits [15:0] of the result.
/// \param __w1
///    A 16-bit integral value used to initialize bits [31:16] of the result.
/// \param __w2
///    A 16-bit integral value used to initialize bits [47:32] of the result.
/// \param __w3
///    A 16-bit integral value used to initialize bits [63:48] of the result.
/// \param __w4
///    A 16-bit integral value used to initialize bits [79:64] of the result.
/// \param __w5
///    A 16-bit integral value used to initialize bits [95:80] of the result.
/// \param __w6
///    A 16-bit integral value used to initialize bits [111:96] of the result.
/// \param __w7
///    A 16-bit integral value used to initialize bits [127:112] of the result.
/// \returns An initialized 128-bit integer vector.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setr_epi16(short __w0, short __w1, short __w2, short __w3, short __w4, short __w5, short __w6, short __w7)
{
  return _mm_set_epi16(__w7, __w6, __w5, __w4, __w3, __w2, __w1, __w0);
}

/// Constructs a 128-bit integer vector, initialized in reverse order
///     with the specified 8-bit integral values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b0
///    An 8-bit integral value used to initialize bits [7:0] of the result.
/// \param __b1
///    An 8-bit integral value used to initialize bits [15:8] of the result.
/// \param __b2
///    An 8-bit integral value used to initialize bits [23:16] of the result.
/// \param __b3
///    An 8-bit integral value used to initialize bits [31:24] of the result.
/// \param __b4
///    An 8-bit integral value used to initialize bits [39:32] of the result.
/// \param __b5
///    An 8-bit integral value used to initialize bits [47:40] of the result.
/// \param __b6
///    An 8-bit integral value used to initialize bits [55:48] of the result.
/// \param __b7
///    An 8-bit integral value used to initialize bits [63:56] of the result.
/// \param __b8
///    An 8-bit integral value used to initialize bits [71:64] of the result.
/// \param __b9
///    An 8-bit integral value used to initialize bits [79:72] of the result.
/// \param __b10
///    An 8-bit integral value used to initialize bits [87:80] of the result.
/// \param __b11
///    An 8-bit integral value used to initialize bits [95:88] of the result.
/// \param __b12
///    An 8-bit integral value used to initialize bits [103:96] of the result.
/// \param __b13
///    An 8-bit integral value used to initialize bits [111:104] of the result.
/// \param __b14
///    An 8-bit integral value used to initialize bits [119:112] of the result.
/// \param __b15
///    An 8-bit integral value used to initialize bits [127:120] of the result.
/// \returns An initialized 128-bit integer vector.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setr_epi8(char __b0, char __b1, char __b2, char __b3, char __b4, char __b5, char __b6, char __b7, char __b8, char __b9, char __b10, char __b11, char __b12, char __b13, char __b14, char __b15)
{
  return _mm_set_epi8(__b15, __b14, __b13, __b12, __b11, __b10, __b9, __b8, __b7, __b6, __b5, __b4, __b3, __b2, __b1, __b0);
}

/// Creates a 128-bit integer vector initialized to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VXORPS / XORPS </c> instruction.
///
/// \returns An initialized 128-bit integer vector with all elements set to
///    zero.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setzero_si128(void)
{
  return __extension__ (__m128i)(__v2di){ 0LL, 0LL };
}

/// Stores a 128-bit integer vector to a memory location aligned on a
///    128-bit boundary.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPS / MOVAPS </c> instruction.
///
/// \param __p
///    A pointer to an aligned memory location that will receive the integer
///    values.
/// \param __b
///    A 128-bit integer vector containing the values to be moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_si128(__m128i *__p, __m128i __b)
{
  *__p = __b;
}

/// Stores a 128-bit integer vector to an unaligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVUPS / MOVUPS </c> instruction.
///
/// \param __p
///    A pointer to a memory location that will receive the integer values.
/// \param __b
///    A 128-bit integer vector containing the values to be moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_si128(__m128i_u *__p, __m128i __b)
{
  struct __storeu_si128 {
    __m128i_u __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_si128*)__p)->__v = __b;
}

/// Stores a 64-bit integer value from the low element of a 128-bit integer
///    vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __p
///    A pointer to a 64-bit memory location. The address of the memory
///    location does not have to be algned.
/// \param __b
///    A 128-bit integer vector containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_si64(void *__p, __m128i __b)
{
  struct __storeu_si64 {
    long long __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_si64*)__p)->__v = ((__v2di)__b)[0];
}

/// Stores a 32-bit integer value from the low element of a 128-bit integer
///    vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVD / MOVD </c> instruction.
///
/// \param __p
///    A pointer to a 32-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \param __b
///    A 128-bit integer vector containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_si32(void *__p, __m128i __b)
{
  struct __storeu_si32 {
    int __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_si32*)__p)->__v = ((__v4si)__b)[0];
}

/// Stores a 16-bit integer value from the low element of a 128-bit integer
///    vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic does not correspond to a specific instruction.
///
/// \param __p
///    A pointer to a 16-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \param __b
///    A 128-bit integer vector containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_si16(void *__p, __m128i __b)
{
  struct __storeu_si16 {
    short __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_si16*)__p)->__v = ((__v8hi)__b)[0];
}

/// Moves bytes selected by the mask from the first operand to the
///    specified unaligned memory location. When a mask bit is 1, the
///    corresponding byte is written, otherwise it is not written.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon). Exception and trap behavior for elements not selected
///    for storage to memory are implementation dependent.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMASKMOVDQU / MASKMOVDQU </c>
///   instruction.
///
/// \param __d
///    A 128-bit integer vector containing the values to be moved.
/// \param __n
///    A 128-bit integer vector containing the mask. The most significant bit of
///    each byte represents the mask bits.
/// \param __p
///    A pointer to an unaligned 128-bit memory location where the specified
///    values are moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_maskmoveu_si128(__m128i __d, __m128i __n, char *__p)
{
  __builtin_ia32_maskmovdqu((__v16qi)__d, (__v16qi)__n, __p);
}

/// Stores the lower 64 bits of a 128-bit integer vector of [2 x i64] to
///    a memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVLPS / MOVLPS </c> instruction.
///
/// \param __p
///    A pointer to a 64-bit memory location that will receive the lower 64 bits
///    of the integer vector parameter.
/// \param __a
///    A 128-bit integer vector of [2 x i64]. The lower 64 bits contain the
///    value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storel_epi64(__m128i_u *__p, __m128i __a)
{
  struct __mm_storel_epi64_struct {
    long long __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_storel_epi64_struct*)__p)->__u = __a[0];
}

/// Stores a 128-bit floating point vector of [2 x double] to a 128-bit
///    aligned memory location.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVNTPS / MOVNTPS </c> instruction.
///
/// \param __p
///    A pointer to the 128-bit aligned memory location used to store the value.
/// \param __a
///    A vector of [2 x double] containing the 64-bit values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_stream_pd(double *__p, __m128d __a)
{
  __builtin_nontemporal_store((__v2df)__a, (__v2df*)__p);
}

/// Stores a 128-bit integer vector to a 128-bit aligned memory location.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVNTPS / MOVNTPS </c> instruction.
///
/// \param __p
///    A pointer to the 128-bit aligned memory location used to store the value.
/// \param __a
///    A 128-bit integer vector containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_stream_si128(__m128i *__p, __m128i __a)
{
  __builtin_nontemporal_store((__v2di)__a, (__v2di*)__p);
}

/// Stores a 32-bit integer value in the specified memory location.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVNTI </c> instruction.
///
/// \param __p
///    A pointer to the 32-bit memory location used to store the value.
/// \param __a
///    A 32-bit integer containing the value to be stored.
static __inline__ void __attribute__((__always_inline__, __nodebug__, __target__("sse2")))
_mm_stream_si32(int *__p, int __a)
{
  __builtin_ia32_movnti(__p, __a);
}

#ifdef __x86_64__
/// Stores a 64-bit integer value in the specified memory location.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVNTIQ </c> instruction.
///
/// \param __p
///    A pointer to the 64-bit memory location used to store the value.
/// \param __a
///    A 64-bit integer containing the value to be stored.
static __inline__ void __attribute__((__always_inline__, __nodebug__, __target__("sse2")))
_mm_stream_si64(long long *__p, long long __a)
{
  __builtin_ia32_movnti64(__p, __a);
}
#endif
# 4209 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4211 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
extern "C" {
#endif
# 4213 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// The cache line containing \a __p is flushed and invalidated from all
///    caches in the coherency domain.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CLFLUSH </c> instruction.
///
/// \param __p
///    A pointer to the memory location used to identify the cache line to be
///    flushed.
void _mm_clflush(void const * __p);

/// Forces strong memory ordering (serialization) between load
///    instructions preceding this instruction and load instructions following
///    this instruction, ensuring the system completes all previous loads before
///    executing subsequent loads.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> LFENCE </c> instruction.
///
void _mm_lfence(void);

/// Forces strong memory ordering (serialization) between load and store
///    instructions preceding this instruction and load and store instructions
///    following this instruction, ensuring that the system completes all
///    previous memory accesses before executing subsequent memory accesses.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MFENCE </c> instruction.
///
void _mm_mfence(void);

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4249 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
} // extern "C"
#endif
# 4251 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Converts 16-bit signed integers from both 128-bit integer vector
///    operands into 8-bit signed integers, and packs the results into the
///    destination. Positive values greater than 0x7F are saturated to 0x7F.
///    Negative values less than 0x80 are saturated to 0x80.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPACKSSWB / PACKSSWB </c> instruction.
///
/// \param __a
///   A 128-bit integer vector of [8 x i16]. Each 16-bit element is treated as
///   a signed integer and is converted to a 8-bit signed integer with
///   saturation. Values greater than 0x7F are saturated to 0x7F. Values less
///   than 0x80 are saturated to 0x80. The converted [8 x i8] values are
///   written to the lower 64 bits of the result.
/// \param __b
///   A 128-bit integer vector of [8 x i16]. Each 16-bit element is treated as
///   a signed integer and is converted to a 8-bit signed integer with
///   saturation. Values greater than 0x7F are saturated to 0x7F. Values less
///   than 0x80 are saturated to 0x80. The converted [8 x i8] values are
///   written to the higher 64 bits of the result.
/// \returns A 128-bit vector of [16 x i8] containing the converted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_packs_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_packsswb128((__v8hi)__a, (__v8hi)__b);
}

/// Converts 32-bit signed integers from both 128-bit integer vector
///    operands into 16-bit signed integers, and packs the results into the
///    destination. Positive values greater than 0x7FFF are saturated to 0x7FFF.
///    Negative values less than 0x8000 are saturated to 0x8000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPACKSSDW / PACKSSDW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector of [4 x i32]. Each 32-bit element is treated as
///    a signed integer and is converted to a 16-bit signed integer with
///    saturation. Values greater than 0x7FFF are saturated to 0x7FFF. Values
///    less than 0x8000 are saturated to 0x8000. The converted [4 x i16] values
///    are written to the lower 64 bits of the result.
/// \param __b
///    A 128-bit integer vector of [4 x i32]. Each 32-bit element is treated as
///    a signed integer and is converted to a 16-bit signed integer with
///    saturation. Values greater than 0x7FFF are saturated to 0x7FFF. Values
///    less than 0x8000 are saturated to 0x8000. The converted [4 x i16] values
///    are written to the higher 64 bits of the result.
/// \returns A 128-bit vector of [8 x i16] containing the converted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_packs_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_packssdw128((__v4si)__a, (__v4si)__b);
}

/// Converts 16-bit signed integers from both 128-bit integer vector
///    operands into 8-bit unsigned integers, and packs the results into the
///    destination. Values greater than 0xFF are saturated to 0xFF. Values less
///    than 0x00 are saturated to 0x00.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPACKUSWB / PACKUSWB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector of [8 x i16]. Each 16-bit element is treated as
///    a signed integer and is converted to an 8-bit unsigned integer with
///    saturation. Values greater than 0xFF are saturated to 0xFF. Values less
///    than 0x00 are saturated to 0x00. The converted [8 x i8] values are
///    written to the lower 64 bits of the result.
/// \param __b
///    A 128-bit integer vector of [8 x i16]. Each 16-bit element is treated as
///    a signed integer and is converted to an 8-bit unsigned integer with
///    saturation. Values greater than 0xFF are saturated to 0xFF. Values less
///    than 0x00 are saturated to 0x00. The converted [8 x i8] values are
///    written to the higher 64 bits of the result.
/// \returns A 128-bit vector of [16 x i8] containing the converted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_packus_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_packuswb128((__v8hi)__a, (__v8hi)__b);
}

/// Extracts 16 bits from a 128-bit integer vector of [8 x i16], using
///    the immediate-value parameter as a selector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPEXTRW / PEXTRW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __imm
///    An immediate value. Bits [2:0] selects values from \a __a to be assigned
///    to bits[15:0] of the result. \n
///    000: assign values from bits [15:0] of \a __a. \n
///    001: assign values from bits [31:16] of \a __a. \n
///    010: assign values from bits [47:32] of \a __a. \n
///    011: assign values from bits [63:48] of \a __a. \n
///    100: assign values from bits [79:64] of \a __a. \n
///    101: assign values from bits [95:80] of \a __a. \n
///    110: assign values from bits [111:96] of \a __a. \n
///    111: assign values from bits [127:112] of \a __a.
/// \returns An integer, whose lower 16 bits are selected from the 128-bit
///    integer vector parameter and the remaining bits are assigned zeros.
#define _mm_extract_epi16(a, imm) \
  (int)(unsigned short)__builtin_ia32_vec_ext_v8hi((__v8hi)(__m128i)(a), \
                                                   (int)(imm))

/// Constructs a 128-bit integer vector by first making a copy of the
///    128-bit integer vector parameter, and then inserting the lower 16 bits
///    of an integer parameter into an offset specified by the immediate-value
///    parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPINSRW / PINSRW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector of [8 x i16]. This vector is copied to the
///    result and then one of the eight elements in the result is replaced by
///    the lower 16 bits of \a __b.
/// \param __b
///    An integer. The lower 16 bits of this parameter are written to the
///    result beginning at an offset specified by \a __imm.
/// \param __imm
///    An immediate value specifying the bit offset in the result at which the
///    lower 16 bits of \a __b are written.
/// \returns A 128-bit integer vector containing the constructed values.
#define _mm_insert_epi16(a, b, imm) \
  (__m128i)__builtin_ia32_vec_set_v8hi((__v8hi)(__m128i)(a), (int)(b), \
                                       (int)(imm))

/// Copies the values of the most significant bits from each 8-bit
///    element in a 128-bit integer vector of [16 x i8] to create a 16-bit mask
///    value, zero-extends the value, and writes it to the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMOVMSKB / PMOVMSKB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the values with bits to be extracted.
/// \returns The most significant bits from each 8-bit element in \a __a,
///    written to bits [15:0]. The other bits are assigned zeros.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_movemask_epi8(__m128i __a)
{
  return __builtin_ia32_pmovmskb128((__v16qi)__a);
}

/// Constructs a 128-bit integer vector by shuffling four 32-bit
///    elements of a 128-bit integer vector parameter, using the immediate-value
///    parameter as a specifier.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_shuffle_epi32(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSHUFD / PSHUFD </c> instruction.
///
/// \param a
///    A 128-bit integer vector containing the values to be copied.
/// \param imm
///    An immediate value containing an 8-bit value specifying which elements to
///    copy from a. The destinations within the 128-bit destination are assigned
///    values as follows: \n
///    Bits [1:0] are used to assign values to bits [31:0] of the result. \n
///    Bits [3:2] are used to assign values to bits [63:32] of the result. \n
///    Bits [5:4] are used to assign values to bits [95:64] of the result. \n
///    Bits [7:6] are used to assign values to bits [127:96] of the result. \n
///    Bit value assignments: \n
///    00: assign values from bits [31:0] of \a a. \n
///    01: assign values from bits [63:32] of \a a. \n
///    10: assign values from bits [95:64] of \a a. \n
///    11: assign values from bits [127:96] of \a a.
/// \returns A 128-bit integer vector containing the shuffled values.
#define _mm_shuffle_epi32(a, imm) \
  (__m128i)__builtin_ia32_pshufd((__v4si)(__m128i)(a), (int)(imm))

/// Constructs a 128-bit integer vector by shuffling four lower 16-bit
///    elements of a 128-bit integer vector of [8 x i16], using the immediate
///    value parameter as a specifier.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_shufflelo_epi16(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSHUFLW / PSHUFLW </c> instruction.
///
/// \param a
///    A 128-bit integer vector of [8 x i16]. Bits [127:64] are copied to bits
///    [127:64] of the result.
/// \param imm
///    An 8-bit immediate value specifying which elements to copy from \a a. \n
///    Bits[1:0] are used to assign values to bits [15:0] of the result. \n
///    Bits[3:2] are used to assign values to bits [31:16] of the result. \n
///    Bits[5:4] are used to assign values to bits [47:32] of the result. \n
///    Bits[7:6] are used to assign values to bits [63:48] of the result. \n
///    Bit value assignments: \n
///    00: assign values from bits [15:0] of \a a. \n
///    01: assign values from bits [31:16] of \a a. \n
///    10: assign values from bits [47:32] of \a a. \n
///    11: assign values from bits [63:48] of \a a. \n
/// \returns A 128-bit integer vector containing the shuffled values.
#define _mm_shufflelo_epi16(a, imm) \
  (__m128i)__builtin_ia32_pshuflw((__v8hi)(__m128i)(a), (int)(imm))

/// Constructs a 128-bit integer vector by shuffling four upper 16-bit
///    elements of a 128-bit integer vector of [8 x i16], using the immediate
///    value parameter as a specifier.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_shufflehi_epi16(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSHUFHW / PSHUFHW </c> instruction.
///
/// \param a
///    A 128-bit integer vector of [8 x i16]. Bits [63:0] are copied to bits
///    [63:0] of the result.
/// \param imm
///    An 8-bit immediate value specifying which elements to copy from \a a. \n
///    Bits[1:0] are used to assign values to bits [79:64] of the result. \n
///    Bits[3:2] are used to assign values to bits [95:80] of the result. \n
///    Bits[5:4] are used to assign values to bits [111:96] of the result. \n
///    Bits[7:6] are used to assign values to bits [127:112] of the result. \n
///    Bit value assignments: \n
///    00: assign values from bits [79:64] of \a a. \n
///    01: assign values from bits [95:80] of \a a. \n
///    10: assign values from bits [111:96] of \a a. \n
///    11: assign values from bits [127:112] of \a a. \n
/// \returns A 128-bit integer vector containing the shuffled values.
#define _mm_shufflehi_epi16(a, imm) \
  (__m128i)__builtin_ia32_pshufhw((__v8hi)(__m128i)(a), (int)(imm))

/// Unpacks the high-order (index 8-15) values from two 128-bit vectors
///    of [16 x i8] and interleaves them into a 128-bit vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKHBW / PUNPCKHBW </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [16 x i8].
///    Bits [71:64] are written to bits [7:0] of the result. \n
///    Bits [79:72] are written to bits [23:16] of the result. \n
///    Bits [87:80] are written to bits [39:32] of the result. \n
///    Bits [95:88] are written to bits [55:48] of the result. \n
///    Bits [103:96] are written to bits [71:64] of the result. \n
///    Bits [111:104] are written to bits [87:80] of the result. \n
///    Bits [119:112] are written to bits [103:96] of the result. \n
///    Bits [127:120] are written to bits [119:112] of the result.
/// \param __b
///    A 128-bit vector of [16 x i8]. \n
///    Bits [71:64] are written to bits [15:8] of the result. \n
///    Bits [79:72] are written to bits [31:24] of the result. \n
///    Bits [87:80] are written to bits [47:40] of the result. \n
///    Bits [95:88] are written to bits [63:56] of the result. \n
///    Bits [103:96] are written to bits [79:72] of the result. \n
///    Bits [111:104] are written to bits [95:88] of the result. \n
///    Bits [119:112] are written to bits [111:104] of the result. \n
///    Bits [127:120] are written to bits [127:120] of the result.
/// \returns A 128-bit vector of [16 x i8] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpackhi_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v16qi)__a, (__v16qi)__b, 8, 16+8, 9, 16+9, 10, 16+10, 11, 16+11, 12, 16+12, 13, 16+13, 14, 16+14, 15, 16+15);
}

/// Unpacks the high-order (index 4-7) values from two 128-bit vectors of
///    [8 x i16] and interleaves them into a 128-bit vector of [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKHWD / PUNPCKHWD </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [8 x i16].
///    Bits [79:64] are written to bits [15:0] of the result. \n
///    Bits [95:80] are written to bits [47:32] of the result. \n
///    Bits [111:96] are written to bits [79:64] of the result. \n
///    Bits [127:112] are written to bits [111:96] of the result.
/// \param __b
///    A 128-bit vector of [8 x i16].
///    Bits [79:64] are written to bits [31:16] of the result. \n
///    Bits [95:80] are written to bits [63:48] of the result. \n
///    Bits [111:96] are written to bits [95:80] of the result. \n
///    Bits [127:112] are written to bits [127:112] of the result.
/// \returns A 128-bit vector of [8 x i16] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpackhi_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v8hi)__a, (__v8hi)__b, 4, 8+4, 5, 8+5, 6, 8+6, 7, 8+7);
}

/// Unpacks the high-order (index 2,3) values from two 128-bit vectors of
///    [4 x i32] and interleaves them into a 128-bit vector of [4 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKHDQ / PUNPCKHDQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [4 x i32]. \n
///    Bits [95:64] are written to bits [31:0] of the destination. \n
///    Bits [127:96] are written to bits [95:64] of the destination.
/// \param __b
///    A 128-bit vector of [4 x i32]. \n
///    Bits [95:64] are written to bits [64:32] of the destination. \n
///    Bits [127:96] are written to bits [127:96] of the destination.
/// \returns A 128-bit vector of [4 x i32] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpackhi_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v4si)__a, (__v4si)__b, 2, 4+2, 3, 4+3);
}

/// Unpacks the high-order 64-bit elements from two 128-bit vectors of
///    [2 x i64] and interleaves them into a 128-bit vector of [2 x i64].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKHQDQ / PUNPCKHQDQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x i64]. \n
///    Bits [127:64] are written to bits [63:0] of the destination.
/// \param __b
///    A 128-bit vector of [2 x i64]. \n
///    Bits [127:64] are written to bits [127:64] of the destination.
/// \returns A 128-bit vector of [2 x i64] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpackhi_epi64(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v2di)__a, (__v2di)__b, 1, 2+1);
}

/// Unpacks the low-order (index 0-7) values from two 128-bit vectors of
///    [16 x i8] and interleaves them into a 128-bit vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKLBW / PUNPCKLBW </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [16 x i8]. \n
///    Bits [7:0] are written to bits [7:0] of the result. \n
///    Bits [15:8] are written to bits [23:16] of the result. \n
///    Bits [23:16] are written to bits [39:32] of the result. \n
///    Bits [31:24] are written to bits [55:48] of the result. \n
///    Bits [39:32] are written to bits [71:64] of the result. \n
///    Bits [47:40] are written to bits [87:80] of the result. \n
///    Bits [55:48] are written to bits [103:96] of the result. \n
///    Bits [63:56] are written to bits [119:112] of the result.
/// \param __b
///    A 128-bit vector of [16 x i8].
///    Bits [7:0] are written to bits [15:8] of the result. \n
///    Bits [15:8] are written to bits [31:24] of the result. \n
///    Bits [23:16] are written to bits [47:40] of the result. \n
///    Bits [31:24] are written to bits [63:56] of the result. \n
///    Bits [39:32] are written to bits [79:72] of the result. \n
///    Bits [47:40] are written to bits [95:88] of the result. \n
///    Bits [55:48] are written to bits [111:104] of the result. \n
///    Bits [63:56] are written to bits [127:120] of the result.
/// \returns A 128-bit vector of [16 x i8] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpacklo_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v16qi)__a, (__v16qi)__b, 0, 16+0, 1, 16+1, 2, 16+2, 3, 16+3, 4, 16+4, 5, 16+5, 6, 16+6, 7, 16+7);
}

/// Unpacks the low-order (index 0-3) values from each of the two 128-bit
///    vectors of [8 x i16] and interleaves them into a 128-bit vector of
///    [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKLWD / PUNPCKLWD </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [8 x i16].
///    Bits [15:0] are written to bits [15:0] of the result. \n
///    Bits [31:16] are written to bits [47:32] of the result. \n
///    Bits [47:32] are written to bits [79:64] of the result. \n
///    Bits [63:48] are written to bits [111:96] of the result.
/// \param __b
///    A 128-bit vector of [8 x i16].
///    Bits [15:0] are written to bits [31:16] of the result. \n
///    Bits [31:16] are written to bits [63:48] of the result. \n
///    Bits [47:32] are written to bits [95:80] of the result. \n
///    Bits [63:48] are written to bits [127:112] of the result.
/// \returns A 128-bit vector of [8 x i16] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpacklo_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v8hi)__a, (__v8hi)__b, 0, 8+0, 1, 8+1, 2, 8+2, 3, 8+3);
}

/// Unpacks the low-order (index 0,1) values from two 128-bit vectors of
///    [4 x i32] and interleaves them into a 128-bit vector of [4 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKLDQ / PUNPCKLDQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [4 x i32]. \n
///    Bits [31:0] are written to bits [31:0] of the destination. \n
///    Bits [63:32] are written to bits [95:64] of the destination.
/// \param __b
///    A 128-bit vector of [4 x i32]. \n
///    Bits [31:0] are written to bits [64:32] of the destination. \n
///    Bits [63:32] are written to bits [127:96] of the destination.
/// \returns A 128-bit vector of [4 x i32] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpacklo_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v4si)__a, (__v4si)__b, 0, 4+0, 1, 4+1);
}

/// Unpacks the low-order 64-bit elements from two 128-bit vectors of
///    [2 x i64] and interleaves them into a 128-bit vector of [2 x i64].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKLQDQ / PUNPCKLQDQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x i64]. \n
///    Bits [63:0] are written to bits [63:0] of the destination. \n
/// \param __b
///    A 128-bit vector of [2 x i64]. \n
///    Bits [63:0] are written to bits [127:64] of the destination. \n
/// \returns A 128-bit vector of [2 x i64] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpacklo_epi64(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v2di)__a, (__v2di)__b, 0, 2+0);
}

/// Returns the lower 64 bits of a 128-bit integer vector as a 64-bit
///    integer.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVDQ2Q </c> instruction.
///
/// \param __a
///    A 128-bit integer vector operand. The lower 64 bits are moved to the
///    destination.
/// \returns A 64-bit integer containing the lower 64 bits of the parameter.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_movepi64_pi64(__m128i __a)
{
  return (__m64)__a[0];
}

/// Moves the 64-bit operand to a 128-bit integer vector, zeroing the
///    upper bits.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVD+VMOVQ </c> instruction.
///
/// \param __a
///    A 64-bit value.
/// \returns A 128-bit integer vector. The lower 64 bits contain the value from
///    the operand. The upper 64 bits are assigned zeros.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_movpi64_epi64(__m64 __a)
{
  return __extension__ (__m128i)(__v2di){ (long long)__a, 0 };
}

/// Moves the lower 64 bits of a 128-bit integer vector to a 128-bit
///    integer vector, zeroing the upper bits.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector operand. The lower 64 bits are moved to the
///    destination.
/// \returns A 128-bit integer vector. The lower 64 bits contain the value from
///    the operand. The upper 64 bits are assigned zeros.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_move_epi64(__m128i __a)
{
  return __builtin_shufflevector((__v2di)__a, _mm_setzero_si128(), 0, 2);
}

/// Unpacks the high-order 64-bit elements from two 128-bit vectors of
///    [2 x double] and interleaves them into a 128-bit vector of [2 x
///    double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKHPD / UNPCKHPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. \n
///    Bits [127:64] are written to bits [63:0] of the destination.
/// \param __b
///    A 128-bit vector of [2 x double]. \n
///    Bits [127:64] are written to bits [127:64] of the destination.
/// \returns A 128-bit vector of [2 x double] containing the interleaved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_unpackhi_pd(__m128d __a, __m128d __b)
{
  return __builtin_shufflevector((__v2df)__a, (__v2df)__b, 1, 2+1);
}

/// Unpacks the low-order 64-bit elements from two 128-bit vectors
///    of [2 x double] and interleaves them into a 128-bit vector of [2 x
///    double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKLPD / UNPCKLPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. \n
///    Bits [63:0] are written to bits [63:0] of the destination.
/// \param __b
///    A 128-bit vector of [2 x double]. \n
///    Bits [63:0] are written to bits [127:64] of the destination.
/// \returns A 128-bit vector of [2 x double] containing the interleaved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_unpacklo_pd(__m128d __a, __m128d __b)
{
  return __builtin_shufflevector((__v2df)__a, (__v2df)__b, 0, 2+0);
}

/// Extracts the sign bits of the double-precision values in the 128-bit
///    vector of [2 x double], zero-extends the value, and writes it to the
///    low-order bits of the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVMSKPD / MOVMSKPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the values with sign bits to
///    be extracted.
/// \returns The sign bits from each of the double-precision elements in \a __a,
///    written to bits [1:0]. The remaining bits are assigned values of zero.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_movemask_pd(__m128d __a)
{
  return __builtin_ia32_movmskpd((__v2df)__a);
}


/// Constructs a 128-bit floating-point vector of [2 x double] from two
///    128-bit vector parameters of [2 x double], using the immediate-value
///     parameter as a specifier.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128d _mm_shuffle_pd(__m128d a, __m128d b, const int i);
/// \endcode
///
/// This intrinsic corresponds to the <c> VSHUFPD / SHUFPD </c> instruction.
///
/// \param a
///    A 128-bit vector of [2 x double].
/// \param b
///    A 128-bit vector of [2 x double].
/// \param i
///    An 8-bit immediate value. The least significant two bits specify which
///    elements to copy from \a a and \a b: \n
///    Bit[0] = 0: lower element of \a a copied to lower element of result. \n
///    Bit[0] = 1: upper element of \a a copied to lower element of result. \n
///    Bit[1] = 0: lower element of \a b copied to upper element of result. \n
///    Bit[1] = 1: upper element of \a b copied to upper element of result. \n
/// \returns A 128-bit vector of [2 x double] containing the shuffled values.
#define _mm_shuffle_pd(a, b, i) \
  (__m128d)__builtin_ia32_shufpd((__v2df)(__m128d)(a), (__v2df)(__m128d)(b), \
                                 (int)(i))

/// Casts a 128-bit floating-point vector of [2 x double] into a 128-bit
///    floating-point vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [2 x double].
/// \returns A 128-bit floating-point vector of [4 x float] containing the same
///    bitwise pattern as the parameter.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_castpd_ps(__m128d __a)
{
  return (__m128)__a;
}

/// Casts a 128-bit floating-point vector of [2 x double] into a 128-bit
///    integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [2 x double].
/// \returns A 128-bit integer vector containing the same bitwise pattern as the
///    parameter.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_castpd_si128(__m128d __a)
{
  return (__m128i)__a;
}

/// Casts a 128-bit floating-point vector of [4 x float] into a 128-bit
///    floating-point vector of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float].
/// \returns A 128-bit floating-point vector of [2 x double] containing the same
///    bitwise pattern as the parameter.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_castps_pd(__m128 __a)
{
  return (__m128d)__a;
}

/// Casts a 128-bit floating-point vector of [4 x float] into a 128-bit
///    integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float].
/// \returns A 128-bit integer vector containing the same bitwise pattern as the
///    parameter.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_castps_si128(__m128 __a)
{
  return (__m128i)__a;
}

/// Casts a 128-bit integer vector into a 128-bit floating-point vector
///    of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \returns A 128-bit floating-point vector of [4 x float] containing the same
///    bitwise pattern as the parameter.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_castsi128_ps(__m128i __a)
{
  return (__m128)__a;
}

/// Casts a 128-bit integer vector into a 128-bit floating-point vector
///    of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \returns A 128-bit floating-point vector of [2 x double] containing the same
///    bitwise pattern as the parameter.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_castsi128_pd(__m128i __a)
{
  return (__m128d)__a;
}

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4953 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
extern "C" {
#endif
# 4955 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Indicates that a spin loop is being executed for the purposes of
///    optimizing power consumption during the loop.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PAUSE </c> instruction.
///
void _mm_pause(void);

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 0 /* evaluated by -frewrite-includes */
# 4966 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
} // extern "C"
#endif
# 4968 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
#undef __DEFAULT_FN_ATTRS
#undef __DEFAULT_FN_ATTRS_MMX

#define _MM_SHUFFLE2(x, y) (((x) << 1) | (y))

#define _MM_DENORMALS_ZERO_ON   (0x0040)
#define _MM_DENORMALS_ZERO_OFF  (0x0000)

#define _MM_DENORMALS_ZERO_MASK (0x0040)

#define _MM_GET_DENORMALS_ZERO_MODE() (_mm_getcsr() & _MM_DENORMALS_ZERO_MASK)
#define _MM_SET_DENORMALS_ZERO_MODE(x) (_mm_setcsr((_mm_getcsr() & ~_MM_DENORMALS_ZERO_MASK) | (x)))

#endif /* __EMMINTRIN_H */
# 4982 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
# 3006 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 2 3
#endif
# 3007 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3

#endif /* __XMMINTRIN_H */
# 3009 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/xmmintrin.h" 3
# 14 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 2 3

typedef double __m128d __attribute__((__vector_size__(16), __aligned__(16)));
typedef long long __m128i __attribute__((__vector_size__(16), __aligned__(16)));

typedef double __m128d_u __attribute__((__vector_size__(16), __aligned__(1)));
typedef long long __m128i_u __attribute__((__vector_size__(16), __aligned__(1)));

/* Type defines.  */
typedef double __v2df __attribute__ ((__vector_size__ (16)));
typedef long long __v2di __attribute__ ((__vector_size__ (16)));
typedef short __v8hi __attribute__((__vector_size__(16)));
typedef char __v16qi __attribute__((__vector_size__(16)));

/* Unsigned types */
typedef unsigned long long __v2du __attribute__ ((__vector_size__ (16)));
typedef unsigned short __v8hu __attribute__((__vector_size__(16)));
typedef unsigned char __v16qu __attribute__((__vector_size__(16)));

/* We need an explicitly signed variant for char. Note that this shouldn't
 * appear in the interface though. */
typedef signed char __v16qs __attribute__((__vector_size__(16)));

/* Define the default attributes for the functions in this file. */
#define __DEFAULT_FN_ATTRS __attribute__((__always_inline__, __nodebug__, __target__("sse2"), __min_vector_width__(128)))
#define __DEFAULT_FN_ATTRS_MMX __attribute__((__always_inline__, __nodebug__, __target__("mmx,sse2"), __min_vector_width__(64)))

/// Adds lower double-precision values in both operands and returns the
///    sum in the lower 64 bits of the result. The upper 64 bits of the result
///    are copied from the upper double-precision value of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VADDSD / ADDSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    sum of the lower 64 bits of both operands. The upper 64 bits are copied
///    from the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_add_sd(__m128d __a, __m128d __b)
{
  __a[0] += __b[0];
  return __a;
}

/// Adds two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VADDPD / ADDPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] containing the sums of both
///    operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_add_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2df)__a + (__v2df)__b);
}

/// Subtracts the lower double-precision value of the second operand
///    from the lower double-precision value of the first operand and returns
///    the difference in the lower 64 bits of the result. The upper 64 bits of
///    the result are copied from the upper double-precision value of the first
///    operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSUBSD / SUBSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the minuend.
/// \param __b
///    A 128-bit vector of [2 x double] containing the subtrahend.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    difference of the lower 64 bits of both operands. The upper 64 bits are
///    copied from the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_sub_sd(__m128d __a, __m128d __b)
{
  __a[0] -= __b[0];
  return __a;
}

/// Subtracts two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSUBPD / SUBPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the minuend.
/// \param __b
///    A 128-bit vector of [2 x double] containing the subtrahend.
/// \returns A 128-bit vector of [2 x double] containing the differences between
///    both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_sub_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2df)__a - (__v2df)__b);
}

/// Multiplies lower double-precision values in both operands and returns
///    the product in the lower 64 bits of the result. The upper 64 bits of the
///    result are copied from the upper double-precision value of the first
///    operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMULSD / MULSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    product of the lower 64 bits of both operands. The upper 64 bits are
///    copied from the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_mul_sd(__m128d __a, __m128d __b)
{
  __a[0] *= __b[0];
  return __a;
}

/// Multiplies two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMULPD / MULPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \returns A 128-bit vector of [2 x double] containing the products of both
///    operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_mul_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2df)__a * (__v2df)__b);
}

/// Divides the lower double-precision value of the first operand by the
///    lower double-precision value of the second operand and returns the
///    quotient in the lower 64 bits of the result. The upper 64 bits of the
///    result are copied from the upper double-precision value of the first
///    operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VDIVSD / DIVSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the dividend.
/// \param __b
///    A 128-bit vector of [2 x double] containing divisor.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    quotient of the lower 64 bits of both operands. The upper 64 bits are
///    copied from the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_div_sd(__m128d __a, __m128d __b)
{
  __a[0] /= __b[0];
  return __a;
}

/// Performs an element-by-element division of two 128-bit vectors of
///    [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VDIVPD / DIVPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the dividend.
/// \param __b
///    A 128-bit vector of [2 x double] containing the divisor.
/// \returns A 128-bit vector of [2 x double] containing the quotients of both
///    operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_div_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2df)__a / (__v2df)__b);
}

/// Calculates the square root of the lower double-precision value of
///    the second operand and returns it in the lower 64 bits of the result.
///    The upper 64 bits of the result are copied from the upper
///    double-precision value of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSQRTSD / SQRTSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    upper 64 bits of this operand are copied to the upper 64 bits of the
///    result.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    square root is calculated using the lower 64 bits of this operand.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    square root of the lower 64 bits of operand \a __b, and whose upper 64
///    bits are copied from the upper 64 bits of operand \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_sqrt_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_sqrtsd((__v2df)__b);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Calculates the square root of the each of two values stored in a
///    128-bit vector of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VSQRTPD / SQRTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector of [2 x double] containing the square roots of the
///    values in the operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_sqrt_pd(__m128d __a)
{
  return __builtin_ia32_sqrtpd((__v2df)__a);
}

/// Compares lower 64-bit double-precision values of both operands, and
///    returns the lesser of the pair of values in the lower 64-bits of the
///    result. The upper 64 bits of the result are copied from the upper
///    double-precision value of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMINSD / MINSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    lower 64 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    lower 64 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    minimum value between both operands. The upper 64 bits are copied from
///    the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_min_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_minsd((__v2df)__a, (__v2df)__b);
}

/// Performs element-by-element comparison of the two 128-bit vectors of
///    [2 x double] and returns the vector containing the lesser of each pair of
///    values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMINPD / MINPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \returns A 128-bit vector of [2 x double] containing the minimum values
///    between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_min_pd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_minpd((__v2df)__a, (__v2df)__b);
}

/// Compares lower 64-bit double-precision values of both operands, and
///    returns the greater of the pair of values in the lower 64-bits of the
///    result. The upper 64 bits of the result are copied from the upper
///    double-precision value of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMAXSD / MAXSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    lower 64 bits of this operand are used in the comparison.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands. The
///    lower 64 bits of this operand are used in the comparison.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    maximum value between both operands. The upper 64 bits are copied from
///    the upper 64 bits of the first source operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_max_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_maxsd((__v2df)__a, (__v2df)__b);
}

/// Performs element-by-element comparison of the two 128-bit vectors of
///    [2 x double] and returns the vector containing the greater of each pair
///    of values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMAXPD / MAXPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the operands.
/// \returns A 128-bit vector of [2 x double] containing the maximum values
///    between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_max_pd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_maxpd((__v2df)__a, (__v2df)__b);
}

/// Performs a bitwise AND of two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPAND / PAND </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] containing the bitwise AND of the
///    values between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_and_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2du)__a & (__v2du)__b);
}

/// Performs a bitwise AND of two 128-bit vectors of [2 x double], using
///    the one's complement of the values contained in the first source operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPANDN / PANDN </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the left source operand. The
///    one's complement of this value is used in the bitwise AND.
/// \param __b
///    A 128-bit vector of [2 x double] containing the right source operand.
/// \returns A 128-bit vector of [2 x double] containing the bitwise AND of the
///    values in the second operand and the one's complement of the first
///    operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_andnot_pd(__m128d __a, __m128d __b)
{
  return (__m128d)(~(__v2du)__a & (__v2du)__b);
}

/// Performs a bitwise OR of two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPOR / POR </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] containing the bitwise OR of the
///    values between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_or_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2du)__a | (__v2du)__b);
}

/// Performs a bitwise XOR of two 128-bit vectors of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPXOR / PXOR </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \param __b
///    A 128-bit vector of [2 x double] containing one of the source operands.
/// \returns A 128-bit vector of [2 x double] containing the bitwise XOR of the
///    values between both operands.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_xor_pd(__m128d __a, __m128d __b)
{
  return (__m128d)((__v2du)__a ^ (__v2du)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] for equality. Each comparison yields 0x0
///    for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPEQPD / CMPEQPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpeq_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpeqpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are less than those in the second operand. Each comparison
///    yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTPD / CMPLTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmplt_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpltpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are less than or equal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLEPD / CMPLEPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmple_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmplepd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are greater than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTPD / CMPLTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpgt_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpltpd((__v2df)__b, (__v2df)__a);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are greater than or equal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLEPD / CMPLEPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpge_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmplepd((__v2df)__b, (__v2df)__a);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are ordered with respect to those in the second operand.
///
///    A pair of double-precision values are "ordered" with respect to each
///    other if neither value is a NaN. Each comparison yields 0x0 for false,
///    0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPORDPD / CMPORDPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpord_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpordpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are unordered with respect to those in the second operand.
///
///    A pair of double-precision values are "unordered" with respect to each
///    other if one or both values are NaN. Each comparison yields 0x0 for
///    false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPUNORDPD / CMPUNORDPD </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpunord_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpunordpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are unequal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNEQPD / CMPNEQPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpneq_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpneqpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are not less than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTPD / CMPNLTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnlt_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnltpd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are not less than or equal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLEPD / CMPNLEPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnle_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnlepd((__v2df)__a, (__v2df)__b);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are not greater than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTPD / CMPNLTPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpngt_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnltpd((__v2df)__b, (__v2df)__a);
}

/// Compares each of the corresponding double-precision values of the
///    128-bit vectors of [2 x double] to determine if the values in the first
///    operand are not greater than or equal to those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLEPD / CMPNLEPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \param __b
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector containing the comparison results.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnge_pd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnlepd((__v2df)__b, (__v2df)__a);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] for equality.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPEQSD / CMPEQSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpeq_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpeqsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than the corresponding value in
///    the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTSD / CMPLTSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmplt_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpltsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLESD / CMPLESD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmple_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmplesd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than the corresponding value
///    in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLTSD / CMPLTSD </c> instruction.
///
/// \param __a
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __b.
/// \param __b
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///     results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpgt_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_cmpltsd((__v2df)__b, (__v2df)__a);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPLESD / CMPLESD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpge_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_cmplesd((__v2df)__b, (__v2df)__a);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is "ordered" with respect to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true. A pair
///    of double-precision values are "ordered" with respect to each other if
///    neither value is a NaN.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPORDSD / CMPORDSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpord_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpordsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is "unordered" with respect to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true. A pair
///    of double-precision values are "unordered" with respect to each other if
///    one or both values are NaN.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPUNORDSD / CMPUNORDSD </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpunord_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpunordsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is unequal to the corresponding value in
///    the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNEQSD / CMPNEQSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpneq_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpneqsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is not less than the corresponding
///    value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTSD / CMPNLTSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnlt_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnltsd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is not less than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLESD / CMPNLESD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns  A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnle_sd(__m128d __a, __m128d __b)
{
  return (__m128d)__builtin_ia32_cmpnlesd((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is not greater than the corresponding
///    value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLTSD / CMPNLTSD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpngt_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_cmpnltsd((__v2df)__b, (__v2df)__a);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is not greater than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0x0 for false, 0xFFFFFFFFFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCMPNLESD / CMPNLESD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns A 128-bit vector. The lower 64 bits contains the comparison
///    results. The upper 64 bits are copied from the upper 64 bits of \a __a.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cmpnge_sd(__m128d __a, __m128d __b)
{
  __m128d __c = __builtin_ia32_cmpnlesd((__v2df)__b, (__v2df)__a);
  return __extension__ (__m128d) { __c[0], __a[1] };
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] for equality.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comieq_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdeq((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than the corresponding value in
///    the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comilt_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdlt((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comile_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdle((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than the corresponding value
///    in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comigt_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdgt((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comige_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdge((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is unequal to the corresponding value in
///    the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two
///    lower double-precision values is NaN, 1 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCOMISD / COMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 1 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_comineq_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_comisdneq((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] for equality. The
///    comparison yields 0 for false, 1 for true.
///
///    If either of the two lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomieq_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdeq((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than the corresponding value in
///    the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two lower
///    double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomilt_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdlt((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is less than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two lower
///    double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomile_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdle((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than the corresponding value
///    in the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two lower
///    double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///     A 128-bit vector of [2 x double]. The lower double-precision value is
///     compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///     lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomigt_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdgt((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is greater than or equal to the
///    corresponding value in the second parameter.
///
///    The comparison yields 0 for false, 1 for true.  If either of the two
///    lower double-precision values is NaN, 0 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison results. If either of the two
///    lower double-precision values is NaN, 0 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomige_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdge((__v2df)__a, (__v2df)__b);
}

/// Compares the lower double-precision floating-point values in each of
///    the two 128-bit floating-point vectors of [2 x double] to determine if
///    the value in the first parameter is unequal to the corresponding value in
///    the second parameter.
///
///    The comparison yields 0 for false, 1 for true. If either of the two lower
///    double-precision values is NaN, 1 is returned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUCOMISD / UCOMISD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __b.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision value is
///    compared to the lower double-precision value of \a __a.
/// \returns An integer containing the comparison result. If either of the two
///    lower double-precision values is NaN, 1 is returned.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_ucomineq_sd(__m128d __a, __m128d __b)
{
  return __builtin_ia32_ucomisdneq((__v2df)__a, (__v2df)__b);
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two single-precision floating-point
///    values, returned in the lower 64 bits of a 128-bit vector of [4 x float].
///    The upper 64 bits of the result vector are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTPD2PS / CVTPD2PS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector of [4 x float] whose lower 64 bits contain the
///    converted values. The upper 64 bits are set to zero.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvtpd_ps(__m128d __a)
{
  return __builtin_ia32_cvtpd2ps((__v2df)__a);
}

/// Converts the lower two single-precision floating-point elements of a
///    128-bit vector of [4 x float] into two double-precision floating-point
///    values, returned in a 128-bit vector of [2 x double]. The upper two
///    elements of the input vector are unused.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTPS2PD / CVTPS2PD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The lower two single-precision
///    floating-point elements are converted to double-precision values. The
///    upper two elements are unused.
/// \returns A 128-bit vector of [2 x double] containing the converted values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtps_pd(__m128 __a)
{
  return (__m128d) __builtin_convertvector(
      __builtin_shufflevector((__v4sf)__a, (__v4sf)__a, 0, 1), __v2df);
}

/// Converts the lower two integer elements of a 128-bit vector of
///    [4 x i32] into two double-precision floating-point values, returned in a
///    128-bit vector of [2 x double].
///
///    The upper two elements of the input vector are unused.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTDQ2PD / CVTDQ2PD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector of [4 x i32]. The lower two integer elements are
///    converted to double-precision values.
///
///    The upper two elements are unused.
/// \returns A 128-bit vector of [2 x double] containing the converted values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtepi32_pd(__m128i __a)
{
  return (__m128d) __builtin_convertvector(
      __builtin_shufflevector((__v4si)__a, (__v4si)__a, 0, 1), __v2df);
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two signed 32-bit integer values,
///    returned in the lower 64 bits of a 128-bit vector of [4 x i32]. The upper
///    64 bits of the result vector are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTPD2DQ / CVTPD2DQ </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector of [4 x i32] whose lower 64 bits contain the
///    converted values. The upper 64 bits are set to zero.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvtpd_epi32(__m128d __a)
{
  return __builtin_ia32_cvtpd2dq((__v2df)__a);
}

/// Converts the low-order element of a 128-bit vector of [2 x double]
///    into a 32-bit signed integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSD2SI / CVTSD2SI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are used in the
///    conversion.
/// \returns A 32-bit signed integer containing the converted value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvtsd_si32(__m128d __a)
{
  return __builtin_ia32_cvtsd2si((__v2df)__a);
}

/// Converts the lower double-precision floating-point element of a
///    128-bit vector of [2 x double], in the second parameter, into a
///    single-precision floating-point value, returned in the lower 32 bits of a
///    128-bit vector of [4 x float]. The upper 96 bits of the result vector are
///    copied from the upper 96 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSD2SS / CVTSD2SS </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float]. The upper 96 bits of this parameter are
///    copied to the upper 96 bits of the result.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower double-precision
///    floating-point element is used in the conversion.
/// \returns A 128-bit vector of [4 x float]. The lower 32 bits contain the
///    converted value from the second parameter. The upper 96 bits are copied
///    from the upper 96 bits of the first parameter.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvtsd_ss(__m128 __a, __m128d __b)
{
  return (__m128)__builtin_ia32_cvtsd2ss((__v4sf)__a, (__v2df)__b);
}

/// Converts a 32-bit signed integer value, in the second parameter, into
///    a double-precision floating-point value, returned in the lower 64 bits of
///    a 128-bit vector of [2 x double]. The upper 64 bits of the result vector
///    are copied from the upper 64 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSI2SD / CVTSI2SD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The upper 64 bits of this parameter are
///    copied to the upper 64 bits of the result.
/// \param __b
///    A 32-bit signed integer containing the value to be converted.
/// \returns A 128-bit vector of [2 x double]. The lower 64 bits contain the
///    converted value from the second parameter. The upper 64 bits are copied
///    from the upper 64 bits of the first parameter.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtsi32_sd(__m128d __a, int __b)
{
  __a[0] = __b;
  return __a;
}

/// Converts the lower single-precision floating-point element of a
///    128-bit vector of [4 x float], in the second parameter, into a
///    double-precision floating-point value, returned in the lower 64 bits of
///    a 128-bit vector of [2 x double]. The upper 64 bits of the result vector
///    are copied from the upper 64 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSS2SD / CVTSS2SD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The upper 64 bits of this parameter are
///    copied to the upper 64 bits of the result.
/// \param __b
///    A 128-bit vector of [4 x float]. The lower single-precision
///    floating-point element is used in the conversion.
/// \returns A 128-bit vector of [2 x double]. The lower 64 bits contain the
///    converted value from the second parameter. The upper 64 bits are copied
///    from the upper 64 bits of the first parameter.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtss_sd(__m128d __a, __m128 __b)
{
  __a[0] = __b[0];
  return __a;
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two signed 32-bit integer values,
///    returned in the lower 64 bits of a 128-bit vector of [4 x i32].
///
///    If the result of either conversion is inexact, the result is truncated
///    (rounded towards zero) regardless of the current MXCSR setting. The upper
///    64 bits of the result vector are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTPD2DQ / CVTTPD2DQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 128-bit vector of [4 x i32] whose lower 64 bits contain the
///    converted values. The upper 64 bits are set to zero.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvttpd_epi32(__m128d __a)
{
  return (__m128i)__builtin_ia32_cvttpd2dq((__v2df)__a);
}

/// Converts the low-order element of a [2 x double] vector into a 32-bit
///    signed integer value, truncating the result when it is inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTSD2SI / CVTTSD2SI </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are used in the
///    conversion.
/// \returns A 32-bit signed integer containing the converted value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvttsd_si32(__m128d __a)
{
  return __builtin_ia32_cvttsd2si((__v2df)__a);
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two signed 32-bit integer values,
///    returned in a 64-bit vector of [2 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPD2PI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 64-bit vector of [2 x i32] containing the converted values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvtpd_pi32(__m128d __a)
{
  return (__m64)__builtin_ia32_cvtpd2pi((__v2df)__a);
}

/// Converts the two double-precision floating-point elements of a
///    128-bit vector of [2 x double] into two signed 32-bit integer values,
///    returned in a 64-bit vector of [2 x i32].
///
///    If the result of either conversion is inexact, the result is truncated
///    (rounded towards zero) regardless of the current MXCSR setting.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTTPD2PI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double].
/// \returns A 64-bit vector of [2 x i32] containing the converted values.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_cvttpd_pi32(__m128d __a)
{
  return (__m64)__builtin_ia32_cvttpd2pi((__v2df)__a);
}

/// Converts the two signed 32-bit integer elements of a 64-bit vector of
///    [2 x i32] into two double-precision floating-point values, returned in a
///    128-bit vector of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CVTPI2PD </c> instruction.
///
/// \param __a
///    A 64-bit vector of [2 x i32].
/// \returns A 128-bit vector of [2 x double] containing the converted values.
static __inline__ __m128d __DEFAULT_FN_ATTRS_MMX
_mm_cvtpi32_pd(__m64 __a)
{
  return __builtin_ia32_cvtpi2pd((__v2si)__a);
}

/// Returns the low-order element of a 128-bit vector of [2 x double] as
///    a double-precision floating-point value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are returned.
/// \returns A double-precision floating-point value copied from the lower 64
///    bits of \a __a.
static __inline__ double __DEFAULT_FN_ATTRS
_mm_cvtsd_f64(__m128d __a)
{
  return __a[0];
}

/// Loads a 128-bit floating-point vector of [2 x double] from an aligned
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPD / MOVAPD </c> instruction.
///
/// \param __dp
///    A pointer to a 128-bit memory location. The address of the memory
///    location has to be 16-byte aligned.
/// \returns A 128-bit vector of [2 x double] containing the loaded values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_load_pd(double const *__dp)
{
  return *(const __m128d*)__dp;
}

/// Loads a double-precision floating-point value from a specified memory
///    location and duplicates it to both vector elements of a 128-bit vector of
///    [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDDUP / MOVDDUP </c> instruction.
///
/// \param __dp
///    A pointer to a memory location containing a double-precision value.
/// \returns A 128-bit vector of [2 x double] containing the loaded and
///    duplicated values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_load1_pd(double const *__dp)
{
  struct __mm_load1_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  double __u = ((const struct __mm_load1_pd_struct*)__dp)->__u;
  return __extension__ (__m128d){ __u, __u };
}

#define        _mm_load_pd1(dp)        _mm_load1_pd(dp)

/// Loads two double-precision values, in reverse order, from an aligned
///    memory location into a 128-bit vector of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPD / MOVAPD </c> instruction +
/// needed shuffling instructions. In AVX mode, the shuffling may be combined
/// with the \c VMOVAPD, resulting in only a \c VPERMILPD instruction.
///
/// \param __dp
///    A 16-byte aligned pointer to an array of double-precision values to be
///    loaded in reverse order.
/// \returns A 128-bit vector of [2 x double] containing the reversed loaded
///    values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_loadr_pd(double const *__dp)
{
  __m128d __u = *(const __m128d*)__dp;
  return __builtin_shufflevector((__v2df)__u, (__v2df)__u, 1, 0);
}

/// Loads a 128-bit floating-point vector of [2 x double] from an
///    unaligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVUPD / MOVUPD </c> instruction.
///
/// \param __dp
///    A pointer to a 128-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [2 x double] containing the loaded values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_loadu_pd(double const *__dp)
{
  struct __loadu_pd {
    __m128d_u __v;
  } __attribute__((__packed__, __may_alias__));
  return ((const struct __loadu_pd*)__dp)->__v;
}

/// Loads a 64-bit integer value to the low element of a 128-bit integer
///    vector and clears the upper element.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __a
///    A pointer to a 64-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [2 x i64] containing the loaded value.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadu_si64(void const *__a)
{
  struct __loadu_si64 {
    long long __v;
  } __attribute__((__packed__, __may_alias__));
  long long __u = ((const struct __loadu_si64*)__a)->__v;
  return __extension__ (__m128i)(__v2di){__u, 0LL};
}

/// Loads a 32-bit integer value to the low element of a 128-bit integer
///    vector and clears the upper element.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVD / MOVD </c> instruction.
///
/// \param __a
///    A pointer to a 32-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [4 x i32] containing the loaded value.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadu_si32(void const *__a)
{
  struct __loadu_si32 {
    int __v;
  } __attribute__((__packed__, __may_alias__));
  int __u = ((const struct __loadu_si32*)__a)->__v;
  return __extension__ (__m128i)(__v4si){__u, 0, 0, 0};
}

/// Loads a 16-bit integer value to the low element of a 128-bit integer
///    vector and clears the upper element.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic does not correspond to a specific instruction.
///
/// \param __a
///    A pointer to a 16-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \returns A 128-bit vector of [8 x i16] containing the loaded value.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadu_si16(void const *__a)
{
  struct __loadu_si16 {
    short __v;
  } __attribute__((__packed__, __may_alias__));
  short __u = ((const struct __loadu_si16*)__a)->__v;
  return __extension__ (__m128i)(__v8hi){__u, 0, 0, 0, 0, 0, 0, 0};
}

/// Loads a 64-bit double-precision value to the low element of a
///    128-bit integer vector and clears the upper element.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVSD / MOVSD </c> instruction.
///
/// \param __dp
///    A pointer to a memory location containing a double-precision value.
///    The address of the memory location does not have to be aligned.
/// \returns A 128-bit vector of [2 x double] containing the loaded value.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_load_sd(double const *__dp)
{
  struct __mm_load_sd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  double __u = ((const struct __mm_load_sd_struct*)__dp)->__u;
  return __extension__ (__m128d){ __u, 0 };
}

/// Loads a double-precision value into the high-order bits of a 128-bit
///    vector of [2 x double]. The low-order bits are copied from the low-order
///    bits of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVHPD / MOVHPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. \n
///    Bits [63:0] are written to bits [63:0] of the result.
/// \param __dp
///    A pointer to a 64-bit memory location containing a double-precision
///    floating-point value that is loaded. The loaded value is written to bits
///    [127:64] of the result. The address of the memory location does not have
///    to be aligned.
/// \returns A 128-bit vector of [2 x double] containing the moved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_loadh_pd(__m128d __a, double const *__dp)
{
  struct __mm_loadh_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  double __u = ((const struct __mm_loadh_pd_struct*)__dp)->__u;
  return __extension__ (__m128d){ __a[0], __u };
}

/// Loads a double-precision value into the low-order bits of a 128-bit
///    vector of [2 x double]. The high-order bits are copied from the
///    high-order bits of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVLPD / MOVLPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. \n
///    Bits [127:64] are written to bits [127:64] of the result.
/// \param __dp
///    A pointer to a 64-bit memory location containing a double-precision
///    floating-point value that is loaded. The loaded value is written to bits
///    [63:0] of the result. The address of the memory location does not have to
///    be aligned.
/// \returns A 128-bit vector of [2 x double] containing the moved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_loadl_pd(__m128d __a, double const *__dp)
{
  struct __mm_loadl_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  double __u = ((const struct __mm_loadl_pd_struct*)__dp)->__u;
  return __extension__ (__m128d){ __u, __a[1] };
}

/// Constructs a 128-bit floating-point vector of [2 x double] with
///    unspecified content. This could be used as an argument to another
///    intrinsic function where the argument is required but the value is not
///    actually used.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \returns A 128-bit floating-point vector of [2 x double] with unspecified
///    content.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_undefined_pd(void)
{
  return (__m128d)__builtin_ia32_undef128();
}

/// Constructs a 128-bit floating-point vector of [2 x double]. The lower
///    64 bits of the vector are initialized with the specified double-precision
///    floating-point value. The upper 64 bits are set to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize the lower 64
///    bits of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double]. The
///    lower 64 bits contain the value of the parameter. The upper 64 bits are
///    set to zero.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_set_sd(double __w)
{
  return __extension__ (__m128d){ __w, 0 };
}

/// Constructs a 128-bit floating-point vector of [2 x double], with each
///    of the two double-precision floating-point vector elements set to the
///    specified double-precision floating-point value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDDUP / MOVLHPS </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize each vector
///    element of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double].
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_set1_pd(double __w)
{
  return __extension__ (__m128d){ __w, __w };
}

/// Constructs a 128-bit floating-point vector of [2 x double], with each
///    of the two double-precision floating-point vector elements set to the
///    specified double-precision floating-point value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDDUP / MOVLHPS </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize each vector
///    element of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double].
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_set_pd1(double __w)
{
  return _mm_set1_pd(__w);
}

/// Constructs a 128-bit floating-point vector of [2 x double]
///    initialized with the specified double-precision floating-point values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKLPD / UNPCKLPD </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize the upper 64
///    bits of the result.
/// \param __x
///    A double-precision floating-point value used to initialize the lower 64
///    bits of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double].
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_set_pd(double __w, double __x)
{
  return __extension__ (__m128d){ __x, __w };
}

/// Constructs a 128-bit floating-point vector of [2 x double],
///    initialized in reverse order with the specified double-precision
///    floating-point values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKLPD / UNPCKLPD </c> instruction.
///
/// \param __w
///    A double-precision floating-point value used to initialize the lower 64
///    bits of the result.
/// \param __x
///    A double-precision floating-point value used to initialize the upper 64
///    bits of the result.
/// \returns An initialized 128-bit floating-point vector of [2 x double].
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_setr_pd(double __w, double __x)
{
  return __extension__ (__m128d){ __w, __x };
}

/// Constructs a 128-bit floating-point vector of [2 x double]
///    initialized to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VXORPS / XORPS </c> instruction.
///
/// \returns An initialized 128-bit floating-point vector of [2 x double] with
///    all elements set to zero.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_setzero_pd(void)
{
  return __extension__ (__m128d){ 0, 0 };
}

/// Constructs a 128-bit floating-point vector of [2 x double]. The lower
///    64 bits are set to the lower 64 bits of the second parameter. The upper
///    64 bits are set to the upper 64 bits of the first parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VBLENDPD / BLENDPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The upper 64 bits are written to the
///    upper 64 bits of the result.
/// \param __b
///    A 128-bit vector of [2 x double]. The lower 64 bits are written to the
///    lower 64 bits of the result.
/// \returns A 128-bit vector of [2 x double] containing the moved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_move_sd(__m128d __a, __m128d __b)
{
  __a[0] = __b[0];
  return __a;
}

/// Stores the lower 64 bits of a 128-bit vector of [2 x double] to a
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVSD / MOVSD </c> instruction.
///
/// \param __dp
///    A pointer to a 64-bit memory location.
/// \param __a
///    A 128-bit vector of [2 x double] containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_sd(double *__dp, __m128d __a)
{
  struct __mm_store_sd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_store_sd_struct*)__dp)->__u = __a[0];
}

/// Moves packed double-precision values from a 128-bit vector of
///    [2 x double] to a memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c>VMOVAPD / MOVAPS</c> instruction.
///
/// \param __dp
///    A pointer to an aligned memory location that can store two
///    double-precision values.
/// \param __a
///    A packed 128-bit vector of [2 x double] containing the values to be
///    moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_pd(double *__dp, __m128d __a)
{
  *(__m128d*)__dp = __a;
}

/// Moves the lower 64 bits of a 128-bit vector of [2 x double] twice to
///    the upper and lower 64 bits of a memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the
///   <c> VMOVDDUP + VMOVAPD / MOVLHPS + MOVAPS </c> instruction.
///
/// \param __dp
///    A pointer to a memory location that can store two double-precision
///    values.
/// \param __a
///    A 128-bit vector of [2 x double] whose lower 64 bits are copied to each
///    of the values in \a __dp.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store1_pd(double *__dp, __m128d __a)
{
  __a = __builtin_shufflevector((__v2df)__a, (__v2df)__a, 0, 0);
  _mm_store_pd(__dp, __a);
}

/// Moves the lower 64 bits of a 128-bit vector of [2 x double] twice to
///    the upper and lower 64 bits of a memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the
///   <c> VMOVDDUP + VMOVAPD / MOVLHPS + MOVAPS </c> instruction.
///
/// \param __dp
///    A pointer to a memory location that can store two double-precision
///    values.
/// \param __a
///    A 128-bit vector of [2 x double] whose lower 64 bits are copied to each
///    of the values in \a __dp.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_pd1(double *__dp, __m128d __a)
{
  _mm_store1_pd(__dp, __a);
}

/// Stores a 128-bit vector of [2 x double] into an unaligned memory
///    location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVUPD / MOVUPD </c> instruction.
///
/// \param __dp
///    A pointer to a 128-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \param __a
///    A 128-bit vector of [2 x double] containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_pd(double *__dp, __m128d __a)
{
  struct __storeu_pd {
    __m128d_u __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_pd*)__dp)->__v = __a;
}

/// Stores two double-precision values, in reverse order, from a 128-bit
///    vector of [2 x double] to a 16-byte aligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to a shuffling instruction followed by a
/// <c> VMOVAPD / MOVAPD </c> instruction.
///
/// \param __dp
///    A pointer to a 16-byte aligned memory location that can store two
///    double-precision values.
/// \param __a
///    A 128-bit vector of [2 x double] containing the values to be reversed and
///    stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storer_pd(double *__dp, __m128d __a)
{
  __a = __builtin_shufflevector((__v2df)__a, (__v2df)__a, 1, 0);
  *(__m128d *)__dp = __a;
}

/// Stores the upper 64 bits of a 128-bit vector of [2 x double] to a
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVHPD / MOVHPD </c> instruction.
///
/// \param __dp
///    A pointer to a 64-bit memory location.
/// \param __a
///    A 128-bit vector of [2 x double] containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeh_pd(double *__dp, __m128d __a)
{
  struct __mm_storeh_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_storeh_pd_struct*)__dp)->__u = __a[1];
}

/// Stores the lower 64 bits of a 128-bit vector of [2 x double] to a
///    memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVLPD / MOVLPD </c> instruction.
///
/// \param __dp
///    A pointer to a 64-bit memory location.
/// \param __a
///    A 128-bit vector of [2 x double] containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storel_pd(double *__dp, __m128d __a)
{
  struct __mm_storeh_pd_struct {
    double __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_storeh_pd_struct*)__dp)->__u = __a[0];
}

/// Adds the corresponding elements of two 128-bit vectors of [16 x i8],
///    saving the lower 8 bits of each sum in the corresponding element of a
///    128-bit result vector of [16 x i8].
///
///    The integer elements of both parameters can be either signed or unsigned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDB / PADDB </c> instruction.
///
/// \param __a
///    A 128-bit vector of [16 x i8].
/// \param __b
///    A 128-bit vector of [16 x i8].
/// \returns A 128-bit vector of [16 x i8] containing the sums of both
///    parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_add_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)((__v16qu)__a + (__v16qu)__b);
}

/// Adds the corresponding elements of two 128-bit vectors of [8 x i16],
///    saving the lower 16 bits of each sum in the corresponding element of a
///    128-bit result vector of [8 x i16].
///
///    The integer elements of both parameters can be either signed or unsigned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDW / PADDW </c> instruction.
///
/// \param __a
///    A 128-bit vector of [8 x i16].
/// \param __b
///    A 128-bit vector of [8 x i16].
/// \returns A 128-bit vector of [8 x i16] containing the sums of both
///    parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_add_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hu)__a + (__v8hu)__b);
}

/// Adds the corresponding elements of two 128-bit vectors of [4 x i32],
///    saving the lower 32 bits of each sum in the corresponding element of a
///    128-bit result vector of [4 x i32].
///
///    The integer elements of both parameters can be either signed or unsigned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDD / PADDD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x i32].
/// \param __b
///    A 128-bit vector of [4 x i32].
/// \returns A 128-bit vector of [4 x i32] containing the sums of both
///    parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_add_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)((__v4su)__a + (__v4su)__b);
}

/// Adds two signed or unsigned 64-bit integer values, returning the
///    lower 64 bits of the sum.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PADDQ </c> instruction.
///
/// \param __a
///    A 64-bit integer.
/// \param __b
///    A 64-bit integer.
/// \returns A 64-bit integer containing the sum of both parameters.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_add_si64(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_paddq((__v1di)__a, (__v1di)__b);
}

/// Adds the corresponding elements of two 128-bit vectors of [2 x i64],
///    saving the lower 64 bits of each sum in the corresponding element of a
///    128-bit result vector of [2 x i64].
///
///    The integer elements of both parameters can be either signed or unsigned.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDQ / PADDQ </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x i64].
/// \param __b
///    A 128-bit vector of [2 x i64].
/// \returns A 128-bit vector of [2 x i64] containing the sums of both
///    parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_add_epi64(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a + (__v2du)__b);
}

/// Adds, with saturation, the corresponding elements of two 128-bit
///    signed [16 x i8] vectors, saving each sum in the corresponding element of
///    a 128-bit result vector of [16 x i8]. Positive sums greater than 0x7F are
///    saturated to 0x7F. Negative sums less than 0x80 are saturated to 0x80.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDSB / PADDSB </c> instruction.
///
/// \param __a
///    A 128-bit signed [16 x i8] vector.
/// \param __b
///    A 128-bit signed [16 x i8] vector.
/// \returns A 128-bit signed [16 x i8] vector containing the saturated sums of
///    both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_adds_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_paddsb128((__v16qi)__a, (__v16qi)__b);
}

/// Adds, with saturation, the corresponding elements of two 128-bit
///    signed [8 x i16] vectors, saving each sum in the corresponding element of
///    a 128-bit result vector of [8 x i16]. Positive sums greater than 0x7FFF
///    are saturated to 0x7FFF. Negative sums less than 0x8000 are saturated to
///    0x8000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDSW / PADDSW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the saturated sums of
///    both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_adds_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_paddsw128((__v8hi)__a, (__v8hi)__b);
}

/// Adds, with saturation, the corresponding elements of two 128-bit
///    unsigned [16 x i8] vectors, saving each sum in the corresponding element
///    of a 128-bit result vector of [16 x i8]. Positive sums greater than 0xFF
///    are saturated to 0xFF. Negative sums are saturated to 0x00.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDUSB / PADDUSB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [16 x i8] vector.
/// \param __b
///    A 128-bit unsigned [16 x i8] vector.
/// \returns A 128-bit unsigned [16 x i8] vector containing the saturated sums
///    of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_adds_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_paddusb128((__v16qi)__a, (__v16qi)__b);
}

/// Adds, with saturation, the corresponding elements of two 128-bit
///    unsigned [8 x i16] vectors, saving each sum in the corresponding element
///    of a 128-bit result vector of [8 x i16]. Positive sums greater than
///    0xFFFF are saturated to 0xFFFF. Negative sums are saturated to 0x0000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPADDUSB / PADDUSB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [8 x i16] vector.
/// \param __b
///    A 128-bit unsigned [8 x i16] vector.
/// \returns A 128-bit unsigned [8 x i16] vector containing the saturated sums
///    of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_adds_epu16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_paddusw128((__v8hi)__a, (__v8hi)__b);
}

/// Computes the rounded averages of corresponding elements of two
///    128-bit unsigned [16 x i8] vectors, saving each result in the
///    corresponding element of a 128-bit result vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPAVGB / PAVGB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [16 x i8] vector.
/// \param __b
///    A 128-bit unsigned [16 x i8] vector.
/// \returns A 128-bit unsigned [16 x i8] vector containing the rounded
///    averages of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_avg_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pavgb128((__v16qi)__a, (__v16qi)__b);
}

/// Computes the rounded averages of corresponding elements of two
///    128-bit unsigned [8 x i16] vectors, saving each result in the
///    corresponding element of a 128-bit result vector of [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPAVGW / PAVGW </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [8 x i16] vector.
/// \param __b
///    A 128-bit unsigned [8 x i16] vector.
/// \returns A 128-bit unsigned [8 x i16] vector containing the rounded
///    averages of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_avg_epu16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pavgw128((__v8hi)__a, (__v8hi)__b);
}

/// Multiplies the corresponding elements of two 128-bit signed [8 x i16]
///    vectors, producing eight intermediate 32-bit signed integer products, and
///    adds the consecutive pairs of 32-bit products to form a 128-bit signed
///    [4 x i32] vector.
///
///    For example, bits [15:0] of both parameters are multiplied producing a
///    32-bit product, bits [31:16] of both parameters are multiplied producing
///    a 32-bit product, and the sum of those two products becomes bits [31:0]
///    of the result.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMADDWD / PMADDWD </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [4 x i32] vector containing the sums of products
///    of both parameters.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_madd_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmaddwd128((__v8hi)__a, (__v8hi)__b);
}

/// Compares corresponding elements of two 128-bit signed [8 x i16]
///    vectors, saving the greater value from each comparison in the
///    corresponding element of a 128-bit result vector of [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMAXSW / PMAXSW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the greater value of
///    each comparison.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_max_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmaxsw128((__v8hi)__a, (__v8hi)__b);
}

/// Compares corresponding elements of two 128-bit unsigned [16 x i8]
///    vectors, saving the greater value from each comparison in the
///    corresponding element of a 128-bit result vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMAXUB / PMAXUB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [16 x i8] vector.
/// \param __b
///    A 128-bit unsigned [16 x i8] vector.
/// \returns A 128-bit unsigned [16 x i8] vector containing the greater value of
///    each comparison.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_max_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmaxub128((__v16qi)__a, (__v16qi)__b);
}

/// Compares corresponding elements of two 128-bit signed [8 x i16]
///    vectors, saving the smaller value from each comparison in the
///    corresponding element of a 128-bit result vector of [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMINSW / PMINSW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the smaller value of
///    each comparison.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_min_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pminsw128((__v8hi)__a, (__v8hi)__b);
}

/// Compares corresponding elements of two 128-bit unsigned [16 x i8]
///    vectors, saving the smaller value from each comparison in the
///    corresponding element of a 128-bit result vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMINUB / PMINUB </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [16 x i8] vector.
/// \param __b
///    A 128-bit unsigned [16 x i8] vector.
/// \returns A 128-bit unsigned [16 x i8] vector containing the smaller value of
///    each comparison.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_min_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pminub128((__v16qi)__a, (__v16qi)__b);
}

/// Multiplies the corresponding elements of two signed [8 x i16]
///    vectors, saving the upper 16 bits of each 32-bit product in the
///    corresponding element of a 128-bit signed [8 x i16] result vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMULHW / PMULHW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the upper 16 bits of
///    each of the eight 32-bit products.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_mulhi_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmulhw128((__v8hi)__a, (__v8hi)__b);
}

/// Multiplies the corresponding elements of two unsigned [8 x i16]
///    vectors, saving the upper 16 bits of each 32-bit product in the
///    corresponding element of a 128-bit unsigned [8 x i16] result vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMULHUW / PMULHUW </c> instruction.
///
/// \param __a
///    A 128-bit unsigned [8 x i16] vector.
/// \param __b
///    A 128-bit unsigned [8 x i16] vector.
/// \returns A 128-bit unsigned [8 x i16] vector containing the upper 16 bits
///    of each of the eight 32-bit products.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_mulhi_epu16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_pmulhuw128((__v8hi)__a, (__v8hi)__b);
}

/// Multiplies the corresponding elements of two signed [8 x i16]
///    vectors, saving the lower 16 bits of each 32-bit product in the
///    corresponding element of a 128-bit signed [8 x i16] result vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMULLW / PMULLW </c> instruction.
///
/// \param __a
///    A 128-bit signed [8 x i16] vector.
/// \param __b
///    A 128-bit signed [8 x i16] vector.
/// \returns A 128-bit signed [8 x i16] vector containing the lower 16 bits of
///    each of the eight 32-bit products.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_mullo_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hu)__a * (__v8hu)__b);
}

/// Multiplies 32-bit unsigned integer values contained in the lower bits
///    of the two 64-bit integer vectors and returns the 64-bit unsigned
///    product.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PMULUDQ </c> instruction.
///
/// \param __a
///    A 64-bit integer containing one of the source operands.
/// \param __b
///    A 64-bit integer containing one of the source operands.
/// \returns A 64-bit integer vector containing the product of both operands.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_mul_su32(__m64 __a, __m64 __b)
{
  return __builtin_ia32_pmuludq((__v2si)__a, (__v2si)__b);
}

/// Multiplies 32-bit unsigned integer values contained in the lower
///    bits of the corresponding elements of two [2 x i64] vectors, and returns
///    the 64-bit products in the corresponding elements of a [2 x i64] vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMULUDQ / PMULUDQ </c> instruction.
///
/// \param __a
///    A [2 x i64] vector containing one of the source operands.
/// \param __b
///    A [2 x i64] vector containing one of the source operands.
/// \returns A [2 x i64] vector containing the product of both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_mul_epu32(__m128i __a, __m128i __b)
{
  return __builtin_ia32_pmuludq128((__v4si)__a, (__v4si)__b);
}

/// Computes the absolute differences of corresponding 8-bit integer
///    values in two 128-bit vectors. Sums the first 8 absolute differences, and
///    separately sums the second 8 absolute differences. Packs these two
///    unsigned 16-bit integer sums into the upper and lower elements of a
///    [2 x i64] vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSADBW / PSADBW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing one of the source operands.
/// \param __b
///    A 128-bit integer vector containing one of the source operands.
/// \returns A [2 x i64] vector containing the sums of the sets of absolute
///    differences between both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sad_epu8(__m128i __a, __m128i __b)
{
  return __builtin_ia32_psadbw128((__v16qi)__a, (__v16qi)__b);
}

/// Subtracts the corresponding 8-bit integer values in the operands.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBB / PSUBB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sub_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)((__v16qu)__a - (__v16qu)__b);
}

/// Subtracts the corresponding 16-bit integer values in the operands.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBW / PSUBW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sub_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hu)__a - (__v8hu)__b);
}

/// Subtracts the corresponding 32-bit integer values in the operands.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBD / PSUBD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sub_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)((__v4su)__a - (__v4su)__b);
}

/// Subtracts signed or unsigned 64-bit integer values and writes the
///    difference to the corresponding bits in the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PSUBQ </c> instruction.
///
/// \param __a
///    A 64-bit integer vector containing the minuend.
/// \param __b
///    A 64-bit integer vector containing the subtrahend.
/// \returns A 64-bit integer vector containing the difference of the values in
///    the operands.
static __inline__ __m64 __DEFAULT_FN_ATTRS_MMX
_mm_sub_si64(__m64 __a, __m64 __b)
{
  return (__m64)__builtin_ia32_psubq((__v1di)__a, (__v1di)__b);
}

/// Subtracts the corresponding elements of two [2 x i64] vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBQ / PSUBQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sub_epi64(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a - (__v2du)__b);
}

/// Subtracts corresponding 8-bit signed integer values in the input and
///    returns the differences in the corresponding bytes in the destination.
///    Differences greater than 0x7F are saturated to 0x7F, and differences less
///    than 0x80 are saturated to 0x80.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBSB / PSUBSB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_subs_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_psubsb128((__v16qi)__a, (__v16qi)__b);
}

/// Subtracts corresponding 16-bit signed integer values in the input and
///    returns the differences in the corresponding bytes in the destination.
///    Differences greater than 0x7FFF are saturated to 0x7FFF, and values less
///    than 0x8000 are saturated to 0x8000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBSW / PSUBSW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the differences of the values
///    in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_subs_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_psubsw128((__v8hi)__a, (__v8hi)__b);
}

/// Subtracts corresponding 8-bit unsigned integer values in the input
///    and returns the differences in the corresponding bytes in the
///    destination. Differences less than 0x00 are saturated to 0x00.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBUSB / PSUBUSB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the unsigned integer
///    differences of the values in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_subs_epu8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_psubusb128((__v16qi)__a, (__v16qi)__b);
}

/// Subtracts corresponding 16-bit unsigned integer values in the input
///    and returns the differences in the corresponding bytes in the
///    destination. Differences less than 0x0000 are saturated to 0x0000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSUBUSW / PSUBUSW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the minuends.
/// \param __b
///    A 128-bit integer vector containing the subtrahends.
/// \returns A 128-bit integer vector containing the unsigned integer
///    differences of the values in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_subs_epu16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_psubusw128((__v8hi)__a, (__v8hi)__b);
}

/// Performs a bitwise AND of two 128-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPAND / PAND </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing one of the source operands.
/// \param __b
///    A 128-bit integer vector containing one of the source operands.
/// \returns A 128-bit integer vector containing the bitwise AND of the values
///    in both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_and_si128(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a & (__v2du)__b);
}

/// Performs a bitwise AND of two 128-bit integer vectors, using the
///    one's complement of the values contained in the first source operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPANDN / PANDN </c> instruction.
///
/// \param __a
///    A 128-bit vector containing the left source operand. The one's complement
///    of this value is used in the bitwise AND.
/// \param __b
///    A 128-bit vector containing the right source operand.
/// \returns A 128-bit integer vector containing the bitwise AND of the one's
///    complement of the first operand and the values in the second operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_andnot_si128(__m128i __a, __m128i __b)
{
  return (__m128i)(~(__v2du)__a & (__v2du)__b);
}
/// Performs a bitwise OR of two 128-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPOR / POR </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing one of the source operands.
/// \param __b
///    A 128-bit integer vector containing one of the source operands.
/// \returns A 128-bit integer vector containing the bitwise OR of the values
///    in both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_or_si128(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a | (__v2du)__b);
}

/// Performs a bitwise exclusive OR of two 128-bit integer vectors.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPXOR / PXOR </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing one of the source operands.
/// \param __b
///    A 128-bit integer vector containing one of the source operands.
/// \returns A 128-bit integer vector containing the bitwise exclusive OR of the
///    values in both operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_xor_si128(__m128i __a, __m128i __b)
{
  return (__m128i)((__v2du)__a ^ (__v2du)__b);
}

/// Left-shifts the 128-bit integer vector operand by the specified
///    number of bytes. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_slli_si128(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSLLDQ / PSLLDQ </c> instruction.
///
/// \param a
///    A 128-bit integer vector containing the source operand.
/// \param imm
///    An immediate value specifying the number of bytes to left-shift operand
///    \a a.
/// \returns A 128-bit integer vector containing the left-shifted value.
#define _mm_slli_si128(a, imm) \
  (__m128i)__builtin_ia32_pslldqi128_byteshift((__v2di)(__m128i)(a), (int)(imm))

#define _mm_bslli_si128(a, imm) \
  (__m128i)__builtin_ia32_pslldqi128_byteshift((__v2di)(__m128i)(a), (int)(imm))

/// Left-shifts each 16-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLW / PSLLW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to left-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_slli_epi16(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psllwi128((__v8hi)__a, __count);
}

/// Left-shifts each 16-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLW / PSLLW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to left-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sll_epi16(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psllw128((__v8hi)__a, (__v8hi)__count);
}

/// Left-shifts each 32-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLD / PSLLD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to left-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_slli_epi32(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_pslldi128((__v4si)__a, __count);
}

/// Left-shifts each 32-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLD / PSLLD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to left-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sll_epi32(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_pslld128((__v4si)__a, (__v4si)__count);
}

/// Left-shifts each 64-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLQ / PSLLQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to left-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_slli_epi64(__m128i __a, int __count)
{
  return __builtin_ia32_psllqi128((__v2di)__a, __count);
}

/// Left-shifts each 64-bit value in the 128-bit integer vector operand
///    by the specified number of bits. Low-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSLLQ / PSLLQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to left-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the left-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sll_epi64(__m128i __a, __m128i __count)
{
  return __builtin_ia32_psllq128((__v2di)__a, (__v2di)__count);
}

/// Right-shifts each 16-bit value in the 128-bit integer vector operand
///    by the specified number of bits. High-order bits are filled with the sign
///    bit of the initial value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRAW / PSRAW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srai_epi16(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psrawi128((__v8hi)__a, __count);
}

/// Right-shifts each 16-bit value in the 128-bit integer vector operand
///    by the specified number of bits. High-order bits are filled with the sign
///    bit of the initial value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRAW / PSRAW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sra_epi16(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psraw128((__v8hi)__a, (__v8hi)__count);
}

/// Right-shifts each 32-bit value in the 128-bit integer vector operand
///    by the specified number of bits. High-order bits are filled with the sign
///    bit of the initial value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRAD / PSRAD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srai_epi32(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psradi128((__v4si)__a, __count);
}

/// Right-shifts each 32-bit value in the 128-bit integer vector operand
///    by the specified number of bits. High-order bits are filled with the sign
///    bit of the initial value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRAD / PSRAD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_sra_epi32(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psrad128((__v4si)__a, (__v4si)__count);
}

/// Right-shifts the 128-bit integer vector operand by the specified
///    number of bytes. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_srli_si128(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSRLDQ / PSRLDQ </c> instruction.
///
/// \param a
///    A 128-bit integer vector containing the source operand.
/// \param imm
///    An immediate value specifying the number of bytes to right-shift operand
///    \a a.
/// \returns A 128-bit integer vector containing the right-shifted value.
#define _mm_srli_si128(a, imm) \
  (__m128i)__builtin_ia32_psrldqi128_byteshift((__v2di)(__m128i)(a), (int)(imm))

#define _mm_bsrli_si128(a, imm) \
  (__m128i)__builtin_ia32_psrldqi128_byteshift((__v2di)(__m128i)(a), (int)(imm))

/// Right-shifts each of 16-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLW / PSRLW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srli_epi16(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psrlwi128((__v8hi)__a, __count);
}

/// Right-shifts each of 16-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLW / PSRLW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srl_epi16(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psrlw128((__v8hi)__a, (__v8hi)__count);
}

/// Right-shifts each of 32-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLD / PSRLD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srli_epi32(__m128i __a, int __count)
{
  return (__m128i)__builtin_ia32_psrldi128((__v4si)__a, __count);
}

/// Right-shifts each of 32-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLD / PSRLD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srl_epi32(__m128i __a, __m128i __count)
{
  return (__m128i)__builtin_ia32_psrld128((__v4si)__a, (__v4si)__count);
}

/// Right-shifts each of 64-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLQ / PSRLQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    An integer value specifying the number of bits to right-shift each value
///    in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srli_epi64(__m128i __a, int __count)
{
  return __builtin_ia32_psrlqi128((__v2di)__a, __count);
}

/// Right-shifts each of 64-bit values in the 128-bit integer vector
///    operand by the specified number of bits. High-order bits are cleared.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPSRLQ / PSRLQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the source operand.
/// \param __count
///    A 128-bit integer vector in which bits [63:0] specify the number of bits
///    to right-shift each value in operand \a __a.
/// \returns A 128-bit integer vector containing the right-shifted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_srl_epi64(__m128i __a, __m128i __count)
{
  return __builtin_ia32_psrlq128((__v2di)__a, (__v2di)__count);
}

/// Compares each of the corresponding 8-bit values of the 128-bit
///    integer vectors for equality. Each comparison yields 0x0 for false, 0xFF
///    for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPEQB / PCMPEQB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpeq_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)((__v16qi)__a == (__v16qi)__b);
}

/// Compares each of the corresponding 16-bit values of the 128-bit
///    integer vectors for equality. Each comparison yields 0x0 for false,
///    0xFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPEQW / PCMPEQW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpeq_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hi)__a == (__v8hi)__b);
}

/// Compares each of the corresponding 32-bit values of the 128-bit
///    integer vectors for equality. Each comparison yields 0x0 for false,
///    0xFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPEQD / PCMPEQD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpeq_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)((__v4si)__a == (__v4si)__b);
}

/// Compares each of the corresponding signed 8-bit values of the 128-bit
///    integer vectors to determine if the values in the first operand are
///    greater than those in the second operand. Each comparison yields 0x0 for
///    false, 0xFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTB / PCMPGTB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpgt_epi8(__m128i __a, __m128i __b)
{
  /* This function always performs a signed comparison, but __v16qi is a char
     which may be signed or unsigned, so use __v16qs. */
  return (__m128i)((__v16qs)__a > (__v16qs)__b);
}

/// Compares each of the corresponding signed 16-bit values of the
///    128-bit integer vectors to determine if the values in the first operand
///    are greater than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTW / PCMPGTW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpgt_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)((__v8hi)__a > (__v8hi)__b);
}

/// Compares each of the corresponding signed 32-bit values of the
///    128-bit integer vectors to determine if the values in the first operand
///    are greater than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTD / PCMPGTD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmpgt_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)((__v4si)__a > (__v4si)__b);
}

/// Compares each of the corresponding signed 8-bit values of the 128-bit
///    integer vectors to determine if the values in the first operand are less
///    than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTB / PCMPGTB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmplt_epi8(__m128i __a, __m128i __b)
{
  return _mm_cmpgt_epi8(__b, __a);
}

/// Compares each of the corresponding signed 16-bit values of the
///    128-bit integer vectors to determine if the values in the first operand
///    are less than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTW / PCMPGTW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmplt_epi16(__m128i __a, __m128i __b)
{
  return _mm_cmpgt_epi16(__b, __a);
}

/// Compares each of the corresponding signed 32-bit values of the
///    128-bit integer vectors to determine if the values in the first operand
///    are less than those in the second operand.
///
///    Each comparison yields 0x0 for false, 0xFFFFFFFF for true.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPCMPGTD / PCMPGTD </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __b
///    A 128-bit integer vector.
/// \returns A 128-bit integer vector containing the comparison results.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cmplt_epi32(__m128i __a, __m128i __b)
{
  return _mm_cmpgt_epi32(__b, __a);
}

#ifdef __x86_64__
/// Converts a 64-bit signed integer value from the second operand into a
///    double-precision value and returns it in the lower element of a [2 x
///    double] vector; the upper element of the returned vector is copied from
///    the upper element of the first operand.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSI2SD / CVTSI2SD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The upper 64 bits of this operand are
///    copied to the upper 64 bits of the destination.
/// \param __b
///    A 64-bit signed integer operand containing the value to be converted.
/// \returns A 128-bit vector of [2 x double] whose lower 64 bits contain the
///    converted value of the second operand. The upper 64 bits are copied from
///    the upper 64 bits of the first operand.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_cvtsi64_sd(__m128d __a, long long __b)
{
  __a[0] = __b;
  return __a;
}

/// Converts the first (lower) element of a vector of [2 x double] into a
///    64-bit signed integer value, according to the current rounding mode.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTSD2SI / CVTSD2SI </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are used in the
///    conversion.
/// \returns A 64-bit signed integer containing the converted value.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvtsd_si64(__m128d __a)
{
  return __builtin_ia32_cvtsd2si64((__v2df)__a);
}

/// Converts the first (lower) element of a vector of [2 x double] into a
///    64-bit signed integer value, truncating the result when it is inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTSD2SI / CVTTSD2SI </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. The lower 64 bits are used in the
///    conversion.
/// \returns A 64-bit signed integer containing the converted value.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvttsd_si64(__m128d __a)
{
  return __builtin_ia32_cvttsd2si64((__v2df)__a);
}
#endif
# 3401 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Converts a vector of [4 x i32] into a vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTDQ2PS / CVTDQ2PS </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \returns A 128-bit vector of [4 x float] containing the converted values.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_cvtepi32_ps(__m128i __a)
{
  return (__m128)__builtin_convertvector((__v4si)__a, __v4sf);
}

/// Converts a vector of [4 x float] into a vector of [4 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTPS2DQ / CVTPS2DQ </c> instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit integer vector of [4 x i32] containing the converted
///    values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvtps_epi32(__m128 __a)
{
  return (__m128i)__builtin_ia32_cvtps2dq((__v4sf)__a);
}

/// Converts a vector of [4 x float] into a vector of [4 x i32],
///    truncating the result when it is inexact.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VCVTTPS2DQ / CVTTPS2DQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [4 x float].
/// \returns A 128-bit vector of [4 x i32] containing the converted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvttps_epi32(__m128 __a)
{
  return (__m128i)__builtin_ia32_cvttps2dq((__v4sf)__a);
}

/// Returns a vector of [4 x i32] where the lowest element is the input
///    operand and the remaining elements are zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVD / MOVD </c> instruction.
///
/// \param __a
///    A 32-bit signed integer operand.
/// \returns A 128-bit vector of [4 x i32].
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvtsi32_si128(int __a)
{
  return __extension__ (__m128i)(__v4si){ __a, 0, 0, 0 };
}

#ifdef __x86_64__
/// Returns a vector of [2 x i64] where the lower element is the input
///    operand and the upper element is zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __a
///    A 64-bit signed integer operand containing the value to be converted.
/// \returns A 128-bit vector of [2 x i64] containing the converted value.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_cvtsi64_si128(long long __a)
{
  return __extension__ (__m128i)(__v2di){ __a, 0 };
}
#endif
# 3483 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Moves the least significant 32 bits of a vector of [4 x i32] to a
///    32-bit signed integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVD / MOVD </c> instruction.
///
/// \param __a
///    A vector of [4 x i32]. The least significant 32 bits are moved to the
///    destination.
/// \returns A 32-bit signed integer containing the moved value.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_cvtsi128_si32(__m128i __a)
{
  __v4si __b = (__v4si)__a;
  return __b[0];
}

#ifdef __x86_64__
/// Moves the least significant 64 bits of a vector of [2 x i64] to a
///    64-bit signed integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __a
///    A vector of [2 x i64]. The least significant 64 bits are moved to the
///    destination.
/// \returns A 64-bit signed integer containing the moved value.
static __inline__ long long __DEFAULT_FN_ATTRS
_mm_cvtsi128_si64(__m128i __a)
{
  return __a[0];
}
#endif
# 3520 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Moves packed integer values from an aligned 128-bit memory location
///    to elements in a 128-bit integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDQA / MOVDQA </c> instruction.
///
/// \param __p
///    An aligned pointer to a memory location containing integer values.
/// \returns A 128-bit integer vector containing the moved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_load_si128(__m128i const *__p)
{
  return *__p;
}

/// Moves packed integer values from an unaligned 128-bit memory location
///    to elements in a 128-bit integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVDQU / MOVDQU </c> instruction.
///
/// \param __p
///    A pointer to a memory location containing integer values.
/// \returns A 128-bit integer vector containing the moved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadu_si128(__m128i_u const *__p)
{
  struct __loadu_si128 {
    __m128i_u __v;
  } __attribute__((__packed__, __may_alias__));
  return ((const struct __loadu_si128*)__p)->__v;
}

/// Returns a vector of [2 x i64] where the lower element is taken from
///    the lower element of the operand, and the upper element is zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __p
///    A 128-bit vector of [2 x i64]. Bits [63:0] are written to bits [63:0] of
///    the destination.
/// \returns A 128-bit vector of [2 x i64]. The lower order bits contain the
///    moved value. The higher order bits are cleared.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_loadl_epi64(__m128i_u const *__p)
{
  struct __mm_loadl_epi64_struct {
    long long __u;
  } __attribute__((__packed__, __may_alias__));
  return __extension__ (__m128i) { ((const struct __mm_loadl_epi64_struct*)__p)->__u, 0};
}

/// Generates a 128-bit vector of [4 x i32] with unspecified content.
///    This could be used as an argument to another intrinsic function where the
///    argument is required but the value is not actually used.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \returns A 128-bit vector of [4 x i32] with unspecified content.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_undefined_si128(void)
{
  return (__m128i)__builtin_ia32_undef128();
}

/// Initializes both 64-bit values in a 128-bit vector of [2 x i64] with
///    the specified 64-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __q1
///    A 64-bit integer value used to initialize the upper 64 bits of the
///    destination vector of [2 x i64].
/// \param __q0
///    A 64-bit integer value used to initialize the lower 64 bits of the
///    destination vector of [2 x i64].
/// \returns An initialized 128-bit vector of [2 x i64] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi64x(long long __q1, long long __q0)
{
  return __extension__ (__m128i)(__v2di){ __q0, __q1 };
}

/// Initializes both 64-bit values in a 128-bit vector of [2 x i64] with
///    the specified 64-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __q1
///    A 64-bit integer value used to initialize the upper 64 bits of the
///    destination vector of [2 x i64].
/// \param __q0
///    A 64-bit integer value used to initialize the lower 64 bits of the
///    destination vector of [2 x i64].
/// \returns An initialized 128-bit vector of [2 x i64] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi64(__m64 __q1, __m64 __q0)
{
  return _mm_set_epi64x((long long)__q1, (long long)__q0);
}

/// Initializes the 32-bit values in a 128-bit vector of [4 x i32] with
///    the specified 32-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i3
///    A 32-bit integer value used to initialize bits [127:96] of the
///    destination vector.
/// \param __i2
///    A 32-bit integer value used to initialize bits [95:64] of the destination
///    vector.
/// \param __i1
///    A 32-bit integer value used to initialize bits [63:32] of the destination
///    vector.
/// \param __i0
///    A 32-bit integer value used to initialize bits [31:0] of the destination
///    vector.
/// \returns An initialized 128-bit vector of [4 x i32] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi32(int __i3, int __i2, int __i1, int __i0)
{
  return __extension__ (__m128i)(__v4si){ __i0, __i1, __i2, __i3};
}

/// Initializes the 16-bit values in a 128-bit vector of [8 x i16] with
///    the specified 16-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __w7
///    A 16-bit integer value used to initialize bits [127:112] of the
///    destination vector.
/// \param __w6
///    A 16-bit integer value used to initialize bits [111:96] of the
///    destination vector.
/// \param __w5
///    A 16-bit integer value used to initialize bits [95:80] of the destination
///    vector.
/// \param __w4
///    A 16-bit integer value used to initialize bits [79:64] of the destination
///    vector.
/// \param __w3
///    A 16-bit integer value used to initialize bits [63:48] of the destination
///    vector.
/// \param __w2
///    A 16-bit integer value used to initialize bits [47:32] of the destination
///    vector.
/// \param __w1
///    A 16-bit integer value used to initialize bits [31:16] of the destination
///    vector.
/// \param __w0
///    A 16-bit integer value used to initialize bits [15:0] of the destination
///    vector.
/// \returns An initialized 128-bit vector of [8 x i16] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi16(short __w7, short __w6, short __w5, short __w4, short __w3, short __w2, short __w1, short __w0)
{
  return __extension__ (__m128i)(__v8hi){ __w0, __w1, __w2, __w3, __w4, __w5, __w6, __w7 };
}

/// Initializes the 8-bit values in a 128-bit vector of [16 x i8] with
///    the specified 8-bit integer values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b15
///    Initializes bits [127:120] of the destination vector.
/// \param __b14
///    Initializes bits [119:112] of the destination vector.
/// \param __b13
///    Initializes bits [111:104] of the destination vector.
/// \param __b12
///    Initializes bits [103:96] of the destination vector.
/// \param __b11
///    Initializes bits [95:88] of the destination vector.
/// \param __b10
///    Initializes bits [87:80] of the destination vector.
/// \param __b9
///    Initializes bits [79:72] of the destination vector.
/// \param __b8
///    Initializes bits [71:64] of the destination vector.
/// \param __b7
///    Initializes bits [63:56] of the destination vector.
/// \param __b6
///    Initializes bits [55:48] of the destination vector.
/// \param __b5
///    Initializes bits [47:40] of the destination vector.
/// \param __b4
///    Initializes bits [39:32] of the destination vector.
/// \param __b3
///    Initializes bits [31:24] of the destination vector.
/// \param __b2
///    Initializes bits [23:16] of the destination vector.
/// \param __b1
///    Initializes bits [15:8] of the destination vector.
/// \param __b0
///    Initializes bits [7:0] of the destination vector.
/// \returns An initialized 128-bit vector of [16 x i8] containing the values
///    provided in the operands.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set_epi8(char __b15, char __b14, char __b13, char __b12, char __b11, char __b10, char __b9, char __b8, char __b7, char __b6, char __b5, char __b4, char __b3, char __b2, char __b1, char __b0)
{
  return __extension__ (__m128i)(__v16qi){ __b0, __b1, __b2, __b3, __b4, __b5, __b6, __b7, __b8, __b9, __b10, __b11, __b12, __b13, __b14, __b15 };
}

/// Initializes both values in a 128-bit integer vector with the
///    specified 64-bit integer value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __q
///    Integer value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit integer vector of [2 x i64] with both
///    elements containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi64x(long long __q)
{
  return _mm_set_epi64x(__q, __q);
}

/// Initializes both values in a 128-bit vector of [2 x i64] with the
///    specified 64-bit value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __q
///    A 64-bit value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit vector of [2 x i64] with all elements
///    containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi64(__m64 __q)
{
  return _mm_set_epi64(__q, __q);
}

/// Initializes all values in a 128-bit vector of [4 x i32] with the
///    specified 32-bit value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i
///    A 32-bit value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit vector of [4 x i32] with all elements
///    containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi32(int __i)
{
  return _mm_set_epi32(__i, __i, __i, __i);
}

/// Initializes all values in a 128-bit vector of [8 x i16] with the
///    specified 16-bit value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __w
///    A 16-bit value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit vector of [8 x i16] with all elements
///    containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi16(short __w)
{
  return _mm_set_epi16(__w, __w, __w, __w, __w, __w, __w, __w);
}

/// Initializes all values in a 128-bit vector of [16 x i8] with the
///    specified 8-bit value.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b
///    An 8-bit value used to initialize the elements of the destination integer
///    vector.
/// \returns An initialized 128-bit vector of [16 x i8] with all elements
///    containing the value provided in the operand.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_set1_epi8(char __b)
{
  return _mm_set_epi8(__b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b, __b);
}

/// Constructs a 128-bit integer vector, initialized in reverse order
///     with the specified 64-bit integral values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic does not correspond to a specific instruction.
///
/// \param __q0
///    A 64-bit integral value used to initialize the lower 64 bits of the
///    result.
/// \param __q1
///    A 64-bit integral value used to initialize the upper 64 bits of the
///    result.
/// \returns An initialized 128-bit integer vector.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setr_epi64(__m64 __q0, __m64 __q1)
{
  return _mm_set_epi64(__q1, __q0);
}

/// Constructs a 128-bit integer vector, initialized in reverse order
///     with the specified 32-bit integral values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __i0
///    A 32-bit integral value used to initialize bits [31:0] of the result.
/// \param __i1
///    A 32-bit integral value used to initialize bits [63:32] of the result.
/// \param __i2
///    A 32-bit integral value used to initialize bits [95:64] of the result.
/// \param __i3
///    A 32-bit integral value used to initialize bits [127:96] of the result.
/// \returns An initialized 128-bit integer vector.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setr_epi32(int __i0, int __i1, int __i2, int __i3)
{
  return _mm_set_epi32(__i3, __i2, __i1, __i0);
}

/// Constructs a 128-bit integer vector, initialized in reverse order
///     with the specified 16-bit integral values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __w0
///    A 16-bit integral value used to initialize bits [15:0] of the result.
/// \param __w1
///    A 16-bit integral value used to initialize bits [31:16] of the result.
/// \param __w2
///    A 16-bit integral value used to initialize bits [47:32] of the result.
/// \param __w3
///    A 16-bit integral value used to initialize bits [63:48] of the result.
/// \param __w4
///    A 16-bit integral value used to initialize bits [79:64] of the result.
/// \param __w5
///    A 16-bit integral value used to initialize bits [95:80] of the result.
/// \param __w6
///    A 16-bit integral value used to initialize bits [111:96] of the result.
/// \param __w7
///    A 16-bit integral value used to initialize bits [127:112] of the result.
/// \returns An initialized 128-bit integer vector.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setr_epi16(short __w0, short __w1, short __w2, short __w3, short __w4, short __w5, short __w6, short __w7)
{
  return _mm_set_epi16(__w7, __w6, __w5, __w4, __w3, __w2, __w1, __w0);
}

/// Constructs a 128-bit integer vector, initialized in reverse order
///     with the specified 8-bit integral values.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic is a utility function and does not correspond to a specific
///    instruction.
///
/// \param __b0
///    An 8-bit integral value used to initialize bits [7:0] of the result.
/// \param __b1
///    An 8-bit integral value used to initialize bits [15:8] of the result.
/// \param __b2
///    An 8-bit integral value used to initialize bits [23:16] of the result.
/// \param __b3
///    An 8-bit integral value used to initialize bits [31:24] of the result.
/// \param __b4
///    An 8-bit integral value used to initialize bits [39:32] of the result.
/// \param __b5
///    An 8-bit integral value used to initialize bits [47:40] of the result.
/// \param __b6
///    An 8-bit integral value used to initialize bits [55:48] of the result.
/// \param __b7
///    An 8-bit integral value used to initialize bits [63:56] of the result.
/// \param __b8
///    An 8-bit integral value used to initialize bits [71:64] of the result.
/// \param __b9
///    An 8-bit integral value used to initialize bits [79:72] of the result.
/// \param __b10
///    An 8-bit integral value used to initialize bits [87:80] of the result.
/// \param __b11
///    An 8-bit integral value used to initialize bits [95:88] of the result.
/// \param __b12
///    An 8-bit integral value used to initialize bits [103:96] of the result.
/// \param __b13
///    An 8-bit integral value used to initialize bits [111:104] of the result.
/// \param __b14
///    An 8-bit integral value used to initialize bits [119:112] of the result.
/// \param __b15
///    An 8-bit integral value used to initialize bits [127:120] of the result.
/// \returns An initialized 128-bit integer vector.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setr_epi8(char __b0, char __b1, char __b2, char __b3, char __b4, char __b5, char __b6, char __b7, char __b8, char __b9, char __b10, char __b11, char __b12, char __b13, char __b14, char __b15)
{
  return _mm_set_epi8(__b15, __b14, __b13, __b12, __b11, __b10, __b9, __b8, __b7, __b6, __b5, __b4, __b3, __b2, __b1, __b0);
}

/// Creates a 128-bit integer vector initialized to zero.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VXORPS / XORPS </c> instruction.
///
/// \returns An initialized 128-bit integer vector with all elements set to
///    zero.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_setzero_si128(void)
{
  return __extension__ (__m128i)(__v2di){ 0LL, 0LL };
}

/// Stores a 128-bit integer vector to a memory location aligned on a
///    128-bit boundary.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVAPS / MOVAPS </c> instruction.
///
/// \param __p
///    A pointer to an aligned memory location that will receive the integer
///    values.
/// \param __b
///    A 128-bit integer vector containing the values to be moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_store_si128(__m128i *__p, __m128i __b)
{
  *__p = __b;
}

/// Stores a 128-bit integer vector to an unaligned memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVUPS / MOVUPS </c> instruction.
///
/// \param __p
///    A pointer to a memory location that will receive the integer values.
/// \param __b
///    A 128-bit integer vector containing the values to be moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_si128(__m128i_u *__p, __m128i __b)
{
  struct __storeu_si128 {
    __m128i_u __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_si128*)__p)->__v = __b;
}

/// Stores a 64-bit integer value from the low element of a 128-bit integer
///    vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __p
///    A pointer to a 64-bit memory location. The address of the memory
///    location does not have to be algned.
/// \param __b
///    A 128-bit integer vector containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_si64(void *__p, __m128i __b)
{
  struct __storeu_si64 {
    long long __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_si64*)__p)->__v = ((__v2di)__b)[0];
}

/// Stores a 32-bit integer value from the low element of a 128-bit integer
///    vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVD / MOVD </c> instruction.
///
/// \param __p
///    A pointer to a 32-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \param __b
///    A 128-bit integer vector containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_si32(void *__p, __m128i __b)
{
  struct __storeu_si32 {
    int __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_si32*)__p)->__v = ((__v4si)__b)[0];
}

/// Stores a 16-bit integer value from the low element of a 128-bit integer
///    vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic does not correspond to a specific instruction.
///
/// \param __p
///    A pointer to a 16-bit memory location. The address of the memory
///    location does not have to be aligned.
/// \param __b
///    A 128-bit integer vector containing the value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storeu_si16(void *__p, __m128i __b)
{
  struct __storeu_si16 {
    short __v;
  } __attribute__((__packed__, __may_alias__));
  ((struct __storeu_si16*)__p)->__v = ((__v8hi)__b)[0];
}

/// Moves bytes selected by the mask from the first operand to the
///    specified unaligned memory location. When a mask bit is 1, the
///    corresponding byte is written, otherwise it is not written.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon). Exception and trap behavior for elements not selected
///    for storage to memory are implementation dependent.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMASKMOVDQU / MASKMOVDQU </c>
///   instruction.
///
/// \param __d
///    A 128-bit integer vector containing the values to be moved.
/// \param __n
///    A 128-bit integer vector containing the mask. The most significant bit of
///    each byte represents the mask bits.
/// \param __p
///    A pointer to an unaligned 128-bit memory location where the specified
///    values are moved.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_maskmoveu_si128(__m128i __d, __m128i __n, char *__p)
{
  __builtin_ia32_maskmovdqu((__v16qi)__d, (__v16qi)__n, __p);
}

/// Stores the lower 64 bits of a 128-bit integer vector of [2 x i64] to
///    a memory location.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVLPS / MOVLPS </c> instruction.
///
/// \param __p
///    A pointer to a 64-bit memory location that will receive the lower 64 bits
///    of the integer vector parameter.
/// \param __a
///    A 128-bit integer vector of [2 x i64]. The lower 64 bits contain the
///    value to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_storel_epi64(__m128i_u *__p, __m128i __a)
{
  struct __mm_storel_epi64_struct {
    long long __u;
  } __attribute__((__packed__, __may_alias__));
  ((struct __mm_storel_epi64_struct*)__p)->__u = __a[0];
}

/// Stores a 128-bit floating point vector of [2 x double] to a 128-bit
///    aligned memory location.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVNTPS / MOVNTPS </c> instruction.
///
/// \param __p
///    A pointer to the 128-bit aligned memory location used to store the value.
/// \param __a
///    A vector of [2 x double] containing the 64-bit values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_stream_pd(double *__p, __m128d __a)
{
  __builtin_nontemporal_store((__v2df)__a, (__v2df*)__p);
}

/// Stores a 128-bit integer vector to a 128-bit aligned memory location.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVNTPS / MOVNTPS </c> instruction.
///
/// \param __p
///    A pointer to the 128-bit aligned memory location used to store the value.
/// \param __a
///    A 128-bit integer vector containing the values to be stored.
static __inline__ void __DEFAULT_FN_ATTRS
_mm_stream_si128(__m128i *__p, __m128i __a)
{
  __builtin_nontemporal_store((__v2di)__a, (__v2di*)__p);
}

/// Stores a 32-bit integer value in the specified memory location.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVNTI </c> instruction.
///
/// \param __p
///    A pointer to the 32-bit memory location used to store the value.
/// \param __a
///    A 32-bit integer containing the value to be stored.
static __inline__ void __attribute__((__always_inline__, __nodebug__, __target__("sse2")))
_mm_stream_si32(int *__p, int __a)
{
  __builtin_ia32_movnti(__p, __a);
}

#ifdef __x86_64__
/// Stores a 64-bit integer value in the specified memory location.
///
///    To minimize caching, the data is flagged as non-temporal (unlikely to be
///    used again soon).
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVNTIQ </c> instruction.
///
/// \param __p
///    A pointer to the 64-bit memory location used to store the value.
/// \param __a
///    A 64-bit integer containing the value to be stored.
static __inline__ void __attribute__((__always_inline__, __nodebug__, __target__("sse2")))
_mm_stream_si64(long long *__p, long long __a)
{
  __builtin_ia32_movnti64(__p, __a);
}
#endif
# 4209 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4211 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
extern "C" {
#endif
# 4213 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// The cache line containing \a __p is flushed and invalidated from all
///    caches in the coherency domain.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> CLFLUSH </c> instruction.
///
/// \param __p
///    A pointer to the memory location used to identify the cache line to be
///    flushed.
void _mm_clflush(void const * __p);

/// Forces strong memory ordering (serialization) between load
///    instructions preceding this instruction and load instructions following
///    this instruction, ensuring the system completes all previous loads before
///    executing subsequent loads.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> LFENCE </c> instruction.
///
void _mm_lfence(void);

/// Forces strong memory ordering (serialization) between load and store
///    instructions preceding this instruction and load and store instructions
///    following this instruction, ensuring that the system completes all
///    previous memory accesses before executing subsequent memory accesses.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MFENCE </c> instruction.
///
void _mm_mfence(void);

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4249 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
} // extern "C"
#endif
# 4251 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Converts 16-bit signed integers from both 128-bit integer vector
///    operands into 8-bit signed integers, and packs the results into the
///    destination. Positive values greater than 0x7F are saturated to 0x7F.
///    Negative values less than 0x80 are saturated to 0x80.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPACKSSWB / PACKSSWB </c> instruction.
///
/// \param __a
///   A 128-bit integer vector of [8 x i16]. Each 16-bit element is treated as
///   a signed integer and is converted to a 8-bit signed integer with
///   saturation. Values greater than 0x7F are saturated to 0x7F. Values less
///   than 0x80 are saturated to 0x80. The converted [8 x i8] values are
///   written to the lower 64 bits of the result.
/// \param __b
///   A 128-bit integer vector of [8 x i16]. Each 16-bit element is treated as
///   a signed integer and is converted to a 8-bit signed integer with
///   saturation. Values greater than 0x7F are saturated to 0x7F. Values less
///   than 0x80 are saturated to 0x80. The converted [8 x i8] values are
///   written to the higher 64 bits of the result.
/// \returns A 128-bit vector of [16 x i8] containing the converted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_packs_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_packsswb128((__v8hi)__a, (__v8hi)__b);
}

/// Converts 32-bit signed integers from both 128-bit integer vector
///    operands into 16-bit signed integers, and packs the results into the
///    destination. Positive values greater than 0x7FFF are saturated to 0x7FFF.
///    Negative values less than 0x8000 are saturated to 0x8000.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPACKSSDW / PACKSSDW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector of [4 x i32]. Each 32-bit element is treated as
///    a signed integer and is converted to a 16-bit signed integer with
///    saturation. Values greater than 0x7FFF are saturated to 0x7FFF. Values
///    less than 0x8000 are saturated to 0x8000. The converted [4 x i16] values
///    are written to the lower 64 bits of the result.
/// \param __b
///    A 128-bit integer vector of [4 x i32]. Each 32-bit element is treated as
///    a signed integer and is converted to a 16-bit signed integer with
///    saturation. Values greater than 0x7FFF are saturated to 0x7FFF. Values
///    less than 0x8000 are saturated to 0x8000. The converted [4 x i16] values
///    are written to the higher 64 bits of the result.
/// \returns A 128-bit vector of [8 x i16] containing the converted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_packs_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_packssdw128((__v4si)__a, (__v4si)__b);
}

/// Converts 16-bit signed integers from both 128-bit integer vector
///    operands into 8-bit unsigned integers, and packs the results into the
///    destination. Values greater than 0xFF are saturated to 0xFF. Values less
///    than 0x00 are saturated to 0x00.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPACKUSWB / PACKUSWB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector of [8 x i16]. Each 16-bit element is treated as
///    a signed integer and is converted to an 8-bit unsigned integer with
///    saturation. Values greater than 0xFF are saturated to 0xFF. Values less
///    than 0x00 are saturated to 0x00. The converted [8 x i8] values are
///    written to the lower 64 bits of the result.
/// \param __b
///    A 128-bit integer vector of [8 x i16]. Each 16-bit element is treated as
///    a signed integer and is converted to an 8-bit unsigned integer with
///    saturation. Values greater than 0xFF are saturated to 0xFF. Values less
///    than 0x00 are saturated to 0x00. The converted [8 x i8] values are
///    written to the higher 64 bits of the result.
/// \returns A 128-bit vector of [16 x i8] containing the converted values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_packus_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_ia32_packuswb128((__v8hi)__a, (__v8hi)__b);
}

/// Extracts 16 bits from a 128-bit integer vector of [8 x i16], using
///    the immediate-value parameter as a selector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPEXTRW / PEXTRW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \param __imm
///    An immediate value. Bits [2:0] selects values from \a __a to be assigned
///    to bits[15:0] of the result. \n
///    000: assign values from bits [15:0] of \a __a. \n
///    001: assign values from bits [31:16] of \a __a. \n
///    010: assign values from bits [47:32] of \a __a. \n
///    011: assign values from bits [63:48] of \a __a. \n
///    100: assign values from bits [79:64] of \a __a. \n
///    101: assign values from bits [95:80] of \a __a. \n
///    110: assign values from bits [111:96] of \a __a. \n
///    111: assign values from bits [127:112] of \a __a.
/// \returns An integer, whose lower 16 bits are selected from the 128-bit
///    integer vector parameter and the remaining bits are assigned zeros.
#define _mm_extract_epi16(a, imm) \
  (int)(unsigned short)__builtin_ia32_vec_ext_v8hi((__v8hi)(__m128i)(a), \
                                                   (int)(imm))

/// Constructs a 128-bit integer vector by first making a copy of the
///    128-bit integer vector parameter, and then inserting the lower 16 bits
///    of an integer parameter into an offset specified by the immediate-value
///    parameter.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPINSRW / PINSRW </c> instruction.
///
/// \param __a
///    A 128-bit integer vector of [8 x i16]. This vector is copied to the
///    result and then one of the eight elements in the result is replaced by
///    the lower 16 bits of \a __b.
/// \param __b
///    An integer. The lower 16 bits of this parameter are written to the
///    result beginning at an offset specified by \a __imm.
/// \param __imm
///    An immediate value specifying the bit offset in the result at which the
///    lower 16 bits of \a __b are written.
/// \returns A 128-bit integer vector containing the constructed values.
#define _mm_insert_epi16(a, b, imm) \
  (__m128i)__builtin_ia32_vec_set_v8hi((__v8hi)(__m128i)(a), (int)(b), \
                                       (int)(imm))

/// Copies the values of the most significant bits from each 8-bit
///    element in a 128-bit integer vector of [16 x i8] to create a 16-bit mask
///    value, zero-extends the value, and writes it to the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPMOVMSKB / PMOVMSKB </c> instruction.
///
/// \param __a
///    A 128-bit integer vector containing the values with bits to be extracted.
/// \returns The most significant bits from each 8-bit element in \a __a,
///    written to bits [15:0]. The other bits are assigned zeros.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_movemask_epi8(__m128i __a)
{
  return __builtin_ia32_pmovmskb128((__v16qi)__a);
}

/// Constructs a 128-bit integer vector by shuffling four 32-bit
///    elements of a 128-bit integer vector parameter, using the immediate-value
///    parameter as a specifier.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_shuffle_epi32(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSHUFD / PSHUFD </c> instruction.
///
/// \param a
///    A 128-bit integer vector containing the values to be copied.
/// \param imm
///    An immediate value containing an 8-bit value specifying which elements to
///    copy from a. The destinations within the 128-bit destination are assigned
///    values as follows: \n
///    Bits [1:0] are used to assign values to bits [31:0] of the result. \n
///    Bits [3:2] are used to assign values to bits [63:32] of the result. \n
///    Bits [5:4] are used to assign values to bits [95:64] of the result. \n
///    Bits [7:6] are used to assign values to bits [127:96] of the result. \n
///    Bit value assignments: \n
///    00: assign values from bits [31:0] of \a a. \n
///    01: assign values from bits [63:32] of \a a. \n
///    10: assign values from bits [95:64] of \a a. \n
///    11: assign values from bits [127:96] of \a a.
/// \returns A 128-bit integer vector containing the shuffled values.
#define _mm_shuffle_epi32(a, imm) \
  (__m128i)__builtin_ia32_pshufd((__v4si)(__m128i)(a), (int)(imm))

/// Constructs a 128-bit integer vector by shuffling four lower 16-bit
///    elements of a 128-bit integer vector of [8 x i16], using the immediate
///    value parameter as a specifier.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_shufflelo_epi16(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSHUFLW / PSHUFLW </c> instruction.
///
/// \param a
///    A 128-bit integer vector of [8 x i16]. Bits [127:64] are copied to bits
///    [127:64] of the result.
/// \param imm
///    An 8-bit immediate value specifying which elements to copy from \a a. \n
///    Bits[1:0] are used to assign values to bits [15:0] of the result. \n
///    Bits[3:2] are used to assign values to bits [31:16] of the result. \n
///    Bits[5:4] are used to assign values to bits [47:32] of the result. \n
///    Bits[7:6] are used to assign values to bits [63:48] of the result. \n
///    Bit value assignments: \n
///    00: assign values from bits [15:0] of \a a. \n
///    01: assign values from bits [31:16] of \a a. \n
///    10: assign values from bits [47:32] of \a a. \n
///    11: assign values from bits [63:48] of \a a. \n
/// \returns A 128-bit integer vector containing the shuffled values.
#define _mm_shufflelo_epi16(a, imm) \
  (__m128i)__builtin_ia32_pshuflw((__v8hi)(__m128i)(a), (int)(imm))

/// Constructs a 128-bit integer vector by shuffling four upper 16-bit
///    elements of a 128-bit integer vector of [8 x i16], using the immediate
///    value parameter as a specifier.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128i _mm_shufflehi_epi16(__m128i a, const int imm);
/// \endcode
///
/// This intrinsic corresponds to the <c> VPSHUFHW / PSHUFHW </c> instruction.
///
/// \param a
///    A 128-bit integer vector of [8 x i16]. Bits [63:0] are copied to bits
///    [63:0] of the result.
/// \param imm
///    An 8-bit immediate value specifying which elements to copy from \a a. \n
///    Bits[1:0] are used to assign values to bits [79:64] of the result. \n
///    Bits[3:2] are used to assign values to bits [95:80] of the result. \n
///    Bits[5:4] are used to assign values to bits [111:96] of the result. \n
///    Bits[7:6] are used to assign values to bits [127:112] of the result. \n
///    Bit value assignments: \n
///    00: assign values from bits [79:64] of \a a. \n
///    01: assign values from bits [95:80] of \a a. \n
///    10: assign values from bits [111:96] of \a a. \n
///    11: assign values from bits [127:112] of \a a. \n
/// \returns A 128-bit integer vector containing the shuffled values.
#define _mm_shufflehi_epi16(a, imm) \
  (__m128i)__builtin_ia32_pshufhw((__v8hi)(__m128i)(a), (int)(imm))

/// Unpacks the high-order (index 8-15) values from two 128-bit vectors
///    of [16 x i8] and interleaves them into a 128-bit vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKHBW / PUNPCKHBW </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [16 x i8].
///    Bits [71:64] are written to bits [7:0] of the result. \n
///    Bits [79:72] are written to bits [23:16] of the result. \n
///    Bits [87:80] are written to bits [39:32] of the result. \n
///    Bits [95:88] are written to bits [55:48] of the result. \n
///    Bits [103:96] are written to bits [71:64] of the result. \n
///    Bits [111:104] are written to bits [87:80] of the result. \n
///    Bits [119:112] are written to bits [103:96] of the result. \n
///    Bits [127:120] are written to bits [119:112] of the result.
/// \param __b
///    A 128-bit vector of [16 x i8]. \n
///    Bits [71:64] are written to bits [15:8] of the result. \n
///    Bits [79:72] are written to bits [31:24] of the result. \n
///    Bits [87:80] are written to bits [47:40] of the result. \n
///    Bits [95:88] are written to bits [63:56] of the result. \n
///    Bits [103:96] are written to bits [79:72] of the result. \n
///    Bits [111:104] are written to bits [95:88] of the result. \n
///    Bits [119:112] are written to bits [111:104] of the result. \n
///    Bits [127:120] are written to bits [127:120] of the result.
/// \returns A 128-bit vector of [16 x i8] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpackhi_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v16qi)__a, (__v16qi)__b, 8, 16+8, 9, 16+9, 10, 16+10, 11, 16+11, 12, 16+12, 13, 16+13, 14, 16+14, 15, 16+15);
}

/// Unpacks the high-order (index 4-7) values from two 128-bit vectors of
///    [8 x i16] and interleaves them into a 128-bit vector of [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKHWD / PUNPCKHWD </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [8 x i16].
///    Bits [79:64] are written to bits [15:0] of the result. \n
///    Bits [95:80] are written to bits [47:32] of the result. \n
///    Bits [111:96] are written to bits [79:64] of the result. \n
///    Bits [127:112] are written to bits [111:96] of the result.
/// \param __b
///    A 128-bit vector of [8 x i16].
///    Bits [79:64] are written to bits [31:16] of the result. \n
///    Bits [95:80] are written to bits [63:48] of the result. \n
///    Bits [111:96] are written to bits [95:80] of the result. \n
///    Bits [127:112] are written to bits [127:112] of the result.
/// \returns A 128-bit vector of [8 x i16] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpackhi_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v8hi)__a, (__v8hi)__b, 4, 8+4, 5, 8+5, 6, 8+6, 7, 8+7);
}

/// Unpacks the high-order (index 2,3) values from two 128-bit vectors of
///    [4 x i32] and interleaves them into a 128-bit vector of [4 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKHDQ / PUNPCKHDQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [4 x i32]. \n
///    Bits [95:64] are written to bits [31:0] of the destination. \n
///    Bits [127:96] are written to bits [95:64] of the destination.
/// \param __b
///    A 128-bit vector of [4 x i32]. \n
///    Bits [95:64] are written to bits [64:32] of the destination. \n
///    Bits [127:96] are written to bits [127:96] of the destination.
/// \returns A 128-bit vector of [4 x i32] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpackhi_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v4si)__a, (__v4si)__b, 2, 4+2, 3, 4+3);
}

/// Unpacks the high-order 64-bit elements from two 128-bit vectors of
///    [2 x i64] and interleaves them into a 128-bit vector of [2 x i64].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKHQDQ / PUNPCKHQDQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x i64]. \n
///    Bits [127:64] are written to bits [63:0] of the destination.
/// \param __b
///    A 128-bit vector of [2 x i64]. \n
///    Bits [127:64] are written to bits [127:64] of the destination.
/// \returns A 128-bit vector of [2 x i64] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpackhi_epi64(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v2di)__a, (__v2di)__b, 1, 2+1);
}

/// Unpacks the low-order (index 0-7) values from two 128-bit vectors of
///    [16 x i8] and interleaves them into a 128-bit vector of [16 x i8].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKLBW / PUNPCKLBW </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [16 x i8]. \n
///    Bits [7:0] are written to bits [7:0] of the result. \n
///    Bits [15:8] are written to bits [23:16] of the result. \n
///    Bits [23:16] are written to bits [39:32] of the result. \n
///    Bits [31:24] are written to bits [55:48] of the result. \n
///    Bits [39:32] are written to bits [71:64] of the result. \n
///    Bits [47:40] are written to bits [87:80] of the result. \n
///    Bits [55:48] are written to bits [103:96] of the result. \n
///    Bits [63:56] are written to bits [119:112] of the result.
/// \param __b
///    A 128-bit vector of [16 x i8].
///    Bits [7:0] are written to bits [15:8] of the result. \n
///    Bits [15:8] are written to bits [31:24] of the result. \n
///    Bits [23:16] are written to bits [47:40] of the result. \n
///    Bits [31:24] are written to bits [63:56] of the result. \n
///    Bits [39:32] are written to bits [79:72] of the result. \n
///    Bits [47:40] are written to bits [95:88] of the result. \n
///    Bits [55:48] are written to bits [111:104] of the result. \n
///    Bits [63:56] are written to bits [127:120] of the result.
/// \returns A 128-bit vector of [16 x i8] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpacklo_epi8(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v16qi)__a, (__v16qi)__b, 0, 16+0, 1, 16+1, 2, 16+2, 3, 16+3, 4, 16+4, 5, 16+5, 6, 16+6, 7, 16+7);
}

/// Unpacks the low-order (index 0-3) values from each of the two 128-bit
///    vectors of [8 x i16] and interleaves them into a 128-bit vector of
///    [8 x i16].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKLWD / PUNPCKLWD </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [8 x i16].
///    Bits [15:0] are written to bits [15:0] of the result. \n
///    Bits [31:16] are written to bits [47:32] of the result. \n
///    Bits [47:32] are written to bits [79:64] of the result. \n
///    Bits [63:48] are written to bits [111:96] of the result.
/// \param __b
///    A 128-bit vector of [8 x i16].
///    Bits [15:0] are written to bits [31:16] of the result. \n
///    Bits [31:16] are written to bits [63:48] of the result. \n
///    Bits [47:32] are written to bits [95:80] of the result. \n
///    Bits [63:48] are written to bits [127:112] of the result.
/// \returns A 128-bit vector of [8 x i16] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpacklo_epi16(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v8hi)__a, (__v8hi)__b, 0, 8+0, 1, 8+1, 2, 8+2, 3, 8+3);
}

/// Unpacks the low-order (index 0,1) values from two 128-bit vectors of
///    [4 x i32] and interleaves them into a 128-bit vector of [4 x i32].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKLDQ / PUNPCKLDQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [4 x i32]. \n
///    Bits [31:0] are written to bits [31:0] of the destination. \n
///    Bits [63:32] are written to bits [95:64] of the destination.
/// \param __b
///    A 128-bit vector of [4 x i32]. \n
///    Bits [31:0] are written to bits [64:32] of the destination. \n
///    Bits [63:32] are written to bits [127:96] of the destination.
/// \returns A 128-bit vector of [4 x i32] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpacklo_epi32(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v4si)__a, (__v4si)__b, 0, 4+0, 1, 4+1);
}

/// Unpacks the low-order 64-bit elements from two 128-bit vectors of
///    [2 x i64] and interleaves them into a 128-bit vector of [2 x i64].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VPUNPCKLQDQ / PUNPCKLQDQ </c>
///   instruction.
///
/// \param __a
///    A 128-bit vector of [2 x i64]. \n
///    Bits [63:0] are written to bits [63:0] of the destination. \n
/// \param __b
///    A 128-bit vector of [2 x i64]. \n
///    Bits [63:0] are written to bits [127:64] of the destination. \n
/// \returns A 128-bit vector of [2 x i64] containing the interleaved values.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_unpacklo_epi64(__m128i __a, __m128i __b)
{
  return (__m128i)__builtin_shufflevector((__v2di)__a, (__v2di)__b, 0, 2+0);
}

/// Returns the lower 64 bits of a 128-bit integer vector as a 64-bit
///    integer.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVDQ2Q </c> instruction.
///
/// \param __a
///    A 128-bit integer vector operand. The lower 64 bits are moved to the
///    destination.
/// \returns A 64-bit integer containing the lower 64 bits of the parameter.
static __inline__ __m64 __DEFAULT_FN_ATTRS
_mm_movepi64_pi64(__m128i __a)
{
  return (__m64)__a[0];
}

/// Moves the 64-bit operand to a 128-bit integer vector, zeroing the
///    upper bits.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> MOVD+VMOVQ </c> instruction.
///
/// \param __a
///    A 64-bit value.
/// \returns A 128-bit integer vector. The lower 64 bits contain the value from
///    the operand. The upper 64 bits are assigned zeros.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_movpi64_epi64(__m64 __a)
{
  return __extension__ (__m128i)(__v2di){ (long long)__a, 0 };
}

/// Moves the lower 64 bits of a 128-bit integer vector to a 128-bit
///    integer vector, zeroing the upper bits.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVQ / MOVQ </c> instruction.
///
/// \param __a
///    A 128-bit integer vector operand. The lower 64 bits are moved to the
///    destination.
/// \returns A 128-bit integer vector. The lower 64 bits contain the value from
///    the operand. The upper 64 bits are assigned zeros.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_move_epi64(__m128i __a)
{
  return __builtin_shufflevector((__v2di)__a, _mm_setzero_si128(), 0, 2);
}

/// Unpacks the high-order 64-bit elements from two 128-bit vectors of
///    [2 x double] and interleaves them into a 128-bit vector of [2 x
///    double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKHPD / UNPCKHPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. \n
///    Bits [127:64] are written to bits [63:0] of the destination.
/// \param __b
///    A 128-bit vector of [2 x double]. \n
///    Bits [127:64] are written to bits [127:64] of the destination.
/// \returns A 128-bit vector of [2 x double] containing the interleaved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_unpackhi_pd(__m128d __a, __m128d __b)
{
  return __builtin_shufflevector((__v2df)__a, (__v2df)__b, 1, 2+1);
}

/// Unpacks the low-order 64-bit elements from two 128-bit vectors
///    of [2 x double] and interleaves them into a 128-bit vector of [2 x
///    double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VUNPCKLPD / UNPCKLPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double]. \n
///    Bits [63:0] are written to bits [63:0] of the destination.
/// \param __b
///    A 128-bit vector of [2 x double]. \n
///    Bits [63:0] are written to bits [127:64] of the destination.
/// \returns A 128-bit vector of [2 x double] containing the interleaved values.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_unpacklo_pd(__m128d __a, __m128d __b)
{
  return __builtin_shufflevector((__v2df)__a, (__v2df)__b, 0, 2+0);
}

/// Extracts the sign bits of the double-precision values in the 128-bit
///    vector of [2 x double], zero-extends the value, and writes it to the
///    low-order bits of the destination.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> VMOVMSKPD / MOVMSKPD </c> instruction.
///
/// \param __a
///    A 128-bit vector of [2 x double] containing the values with sign bits to
///    be extracted.
/// \returns The sign bits from each of the double-precision elements in \a __a,
///    written to bits [1:0]. The remaining bits are assigned values of zero.
static __inline__ int __DEFAULT_FN_ATTRS
_mm_movemask_pd(__m128d __a)
{
  return __builtin_ia32_movmskpd((__v2df)__a);
}


/// Constructs a 128-bit floating-point vector of [2 x double] from two
///    128-bit vector parameters of [2 x double], using the immediate-value
///     parameter as a specifier.
///
/// \headerfile <x86intrin.h>
///
/// \code
/// __m128d _mm_shuffle_pd(__m128d a, __m128d b, const int i);
/// \endcode
///
/// This intrinsic corresponds to the <c> VSHUFPD / SHUFPD </c> instruction.
///
/// \param a
///    A 128-bit vector of [2 x double].
/// \param b
///    A 128-bit vector of [2 x double].
/// \param i
///    An 8-bit immediate value. The least significant two bits specify which
///    elements to copy from \a a and \a b: \n
///    Bit[0] = 0: lower element of \a a copied to lower element of result. \n
///    Bit[0] = 1: upper element of \a a copied to lower element of result. \n
///    Bit[1] = 0: lower element of \a b copied to upper element of result. \n
///    Bit[1] = 1: upper element of \a b copied to upper element of result. \n
/// \returns A 128-bit vector of [2 x double] containing the shuffled values.
#define _mm_shuffle_pd(a, b, i) \
  (__m128d)__builtin_ia32_shufpd((__v2df)(__m128d)(a), (__v2df)(__m128d)(b), \
                                 (int)(i))

/// Casts a 128-bit floating-point vector of [2 x double] into a 128-bit
///    floating-point vector of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [2 x double].
/// \returns A 128-bit floating-point vector of [4 x float] containing the same
///    bitwise pattern as the parameter.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_castpd_ps(__m128d __a)
{
  return (__m128)__a;
}

/// Casts a 128-bit floating-point vector of [2 x double] into a 128-bit
///    integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [2 x double].
/// \returns A 128-bit integer vector containing the same bitwise pattern as the
///    parameter.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_castpd_si128(__m128d __a)
{
  return (__m128i)__a;
}

/// Casts a 128-bit floating-point vector of [4 x float] into a 128-bit
///    floating-point vector of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float].
/// \returns A 128-bit floating-point vector of [2 x double] containing the same
///    bitwise pattern as the parameter.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_castps_pd(__m128 __a)
{
  return (__m128d)__a;
}

/// Casts a 128-bit floating-point vector of [4 x float] into a 128-bit
///    integer vector.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit floating-point vector of [4 x float].
/// \returns A 128-bit integer vector containing the same bitwise pattern as the
///    parameter.
static __inline__ __m128i __DEFAULT_FN_ATTRS
_mm_castps_si128(__m128 __a)
{
  return (__m128i)__a;
}

/// Casts a 128-bit integer vector into a 128-bit floating-point vector
///    of [4 x float].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \returns A 128-bit floating-point vector of [4 x float] containing the same
///    bitwise pattern as the parameter.
static __inline__ __m128 __DEFAULT_FN_ATTRS
_mm_castsi128_ps(__m128i __a)
{
  return (__m128)__a;
}

/// Casts a 128-bit integer vector into a 128-bit floating-point vector
///    of [2 x double].
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic has no corresponding instruction.
///
/// \param __a
///    A 128-bit integer vector.
/// \returns A 128-bit floating-point vector of [2 x double] containing the same
///    bitwise pattern as the parameter.
static __inline__ __m128d __DEFAULT_FN_ATTRS
_mm_castsi128_pd(__m128i __a)
{
  return (__m128d)__a;
}

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4953 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
extern "C" {
#endif
# 4955 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3

/// Indicates that a spin loop is being executed for the purposes of
///    optimizing power consumption during the loop.
///
/// \headerfile <x86intrin.h>
///
/// This intrinsic corresponds to the <c> PAUSE </c> instruction.
///
void _mm_pause(void);

#if 0 /* disabled by -frewrite-includes */
#if defined(__cplusplus)
#endif
#endif /* disabled by -frewrite-includes */
#if 1 /* evaluated by -frewrite-includes */
# 4966 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
} // extern "C"
#endif
# 4968 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
#undef __DEFAULT_FN_ATTRS
#undef __DEFAULT_FN_ATTRS_MMX

#define _MM_SHUFFLE2(x, y) (((x) << 1) | (y))

#define _MM_DENORMALS_ZERO_ON   (0x0040)
#define _MM_DENORMALS_ZERO_OFF  (0x0000)

#define _MM_DENORMALS_ZERO_MASK (0x0040)

#define _MM_GET_DENORMALS_ZERO_MODE() (_mm_getcsr() & _MM_DENORMALS_ZERO_MASK)
#define _MM_SET_DENORMALS_ZERO_MODE(x) (_mm_setcsr((_mm_getcsr() & ~_MM_DENORMALS_ZERO_MASK) | (x)))

#endif /* __EMMINTRIN_H */
# 4982 "/Users/vsk/src/builds/llvm-project-master-RA/lib/clang/11.0.0/include/emmintrin.h" 3
# 1231 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp" 2
#endif
# 1232 "/Users/vsk/src/llvm-project-master/clang/lib/Basic/SourceManager.cpp"

static LLVM_ATTRIBUTE_NOINLINE void
ComputeLineNumbers(DiagnosticsEngine &Diag, ContentCache *FI,
                   llvm::BumpPtrAllocator &Alloc,
                   const SourceManager &SM, bool &Invalid);
static void ComputeLineNumbers(DiagnosticsEngine &Diag, ContentCache *FI,
                               llvm::BumpPtrAllocator &Alloc,
                               const SourceManager &SM, bool &Invalid) {
  // Note that calling 'getBuffer()' may lazily page in the file.
  const MemoryBuffer *Buffer =
      FI->getBuffer(Diag, SM.getFileManager(), SourceLocation(), &Invalid);
  if (Invalid)
    return;

  // Find the file offsets of all of the *physical* source lines.  This does
  // not look at trigraphs, escaped newlines, or anything else tricky.
  SmallVector<unsigned, 256> LineOffsets;

  // Line #1 starts at char 0.
  LineOffsets.push_back(0);

  const unsigned char *Buf = (const unsigned char *)Buffer->getBufferStart();
  const unsigned char *End = (const unsigned char *)Buffer->getBufferEnd();
  const std::size_t BufLen = End - Buf;
  unsigned I = 0;
  while (I < BufLen) {
    if (Buf[I] == '\n') {
      LineOffsets.push_back(I + 1);
    } else if (Buf[I] == '\r') {
      // If this is \r\n, skip both characters.
      if (I + 1 < BufLen && Buf[I + 1] == '\n')
        ++I;
      LineOffsets.push_back(I + 1);
    }
    ++I;
  }

  // Copy the offsets into the FileInfo structure.
  FI->NumLines = LineOffsets.size();
  FI->SourceLineCache = Alloc.Allocate<unsigned>(LineOffsets.size());
  std::copy(LineOffsets.begin(), LineOffsets.end(), FI->SourceLineCache);
}

/// getLineNumber - Given a SourceLocation, return the spelling line number
/// for the position indicated.  This requires building and caching a table of
/// line offsets for the MemoryBuffer, so this is not cheap: use only when
/// about to emit a diagnostic.
unsigned SourceManager::getLineNumber(FileID FID, unsigned FilePos,
                                      bool *Invalid) const {
  if (FID.isInvalid()) {
    if (Invalid)
      *Invalid = true;
    return 1;
  }

  ContentCache *Content;
  if (LastLineNoFileIDQuery == FID)
    Content = LastLineNoContentCache;
  else {
    bool MyInvalid = false;
    const SLocEntry &Entry = getSLocEntry(FID, &MyInvalid);
    if (MyInvalid || !Entry.isFile()) {
      if (Invalid)
        *Invalid = true;
      return 1;
    }

    Content = const_cast<ContentCache*>(Entry.getFile().getContentCache());
  }

  // If this is the first use of line information for this buffer, compute the
  /// SourceLineCache for it on demand.
  if (!Content->SourceLineCache) {
    bool MyInvalid = false;
    ComputeLineNumbers(Diag, Content, ContentCacheAlloc, *this, MyInvalid);
    if (Invalid)
      *Invalid = MyInvalid;
    if (MyInvalid)
      return 1;
  } else if (Invalid)
    *Invalid = false;

  // Okay, we know we have a line number table.  Do a binary search to find the
  // line number that this character position lands on.
  unsigned *SourceLineCache = Content->SourceLineCache;
  unsigned *SourceLineCacheStart = SourceLineCache;
  unsigned *SourceLineCacheEnd = SourceLineCache + Content->NumLines;

  unsigned QueriedFilePos = FilePos+1;

  // FIXME: I would like to be convinced that this code is worth being as
  // complicated as it is, binary search isn't that slow.
  //
  // If it is worth being optimized, then in my opinion it could be more
  // performant, simpler, and more obviously correct by just "galloping" outward
  // from the queried file position. In fact, this could be incorporated into a
  // generic algorithm such as lower_bound_with_hint.
  //
  // If someone gives me a test case where this matters, and I will do it! - DWD

  // If the previous query was to the same file, we know both the file pos from
  // that query and the line number returned.  This allows us to narrow the
  // search space from the entire file to something near the match.
  if (LastLineNoFileIDQuery == FID) {
    if (QueriedFilePos >= LastLineNoFilePos) {
      // FIXME: Potential overflow?
      SourceLineCache = SourceLineCache+LastLineNoResult-1;

      // The query is likely to be nearby the previous one.  Here we check to
      // see if it is within 5, 10 or 20 lines.  It can be far away in cases
      // where big comment blocks and vertical whitespace eat up lines but
      // contribute no tokens.
      if (SourceLineCache+5 < SourceLineCacheEnd) {
        if (SourceLineCache[5] > QueriedFilePos)
          SourceLineCacheEnd = SourceLineCache+5;
        else if (SourceLineCache+10 < SourceLineCacheEnd) {
          if (SourceLineCache[10] > QueriedFilePos)
            SourceLineCacheEnd = SourceLineCache+10;
          else if (SourceLineCache+20 < SourceLineCacheEnd) {
            if (SourceLineCache[20] > QueriedFilePos)
              SourceLineCacheEnd = SourceLineCache+20;
          }
        }
      }
    } else {
      if (LastLineNoResult < Content->NumLines)
        SourceLineCacheEnd = SourceLineCache+LastLineNoResult+1;
    }
  }

  unsigned *Pos
    = std::lower_bound(SourceLineCache, SourceLineCacheEnd, QueriedFilePos);
  unsigned LineNo = Pos-SourceLineCacheStart;

  LastLineNoFileIDQuery = FID;
  LastLineNoContentCache = Content;
  LastLineNoFilePos = QueriedFilePos;
  LastLineNoResult = LineNo;
  return LineNo;
}

unsigned SourceManager::getSpellingLineNumber(SourceLocation Loc,
                                              bool *Invalid) const {
  if (isInvalid(Loc, Invalid)) return 0;
  std::pair<FileID, unsigned> LocInfo = getDecomposedSpellingLoc(Loc);
  return getLineNumber(LocInfo.first, LocInfo.second);
}
unsigned SourceManager::getExpansionLineNumber(SourceLocation Loc,
                                               bool *Invalid) const {
  if (isInvalid(Loc, Invalid)) return 0;
  std::pair<FileID, unsigned> LocInfo = getDecomposedExpansionLoc(Loc);
  return getLineNumber(LocInfo.first, LocInfo.second);
}
unsigned SourceManager::getPresumedLineNumber(SourceLocation Loc,
                                              bool *Invalid) const {
  PresumedLoc PLoc = getPresumedLoc(Loc);
  if (isInvalid(PLoc, Invalid)) return 0;
  return PLoc.getLine();
}

/// getFileCharacteristic - return the file characteristic of the specified
/// source location, indicating whether this is a normal file, a system
/// header, or an "implicit extern C" system header.
///
/// This state can be modified with flags on GNU linemarker directives like:
///   # 4 "foo.h" 3
/// which changes all source locations in the current file after that to be
/// considered to be from a system header.
SrcMgr::CharacteristicKind
SourceManager::getFileCharacteristic(SourceLocation Loc) const {
  assert(Loc.isValid() && "Can't get file characteristic of invalid loc!");
  std::pair<FileID, unsigned> LocInfo = getDecomposedExpansionLoc(Loc);
  bool Invalid = false;
  const SLocEntry &SEntry = getSLocEntry(LocInfo.first, &Invalid);
  if (Invalid || !SEntry.isFile())
    return C_User;

  const SrcMgr::FileInfo &FI = SEntry.getFile();

  // If there are no #line directives in this file, just return the whole-file
  // state.
  if (!FI.hasLineDirectives())
    return FI.getFileCharacteristic();

  assert(LineTable && "Can't have linetable entries without a LineTable!");
  // See if there is a #line directive before the location.
  const LineEntry *Entry =
    LineTable->FindNearestLineEntry(LocInfo.first, LocInfo.second);

  // If this is before the first line marker, use the file characteristic.
  if (!Entry)
    return FI.getFileCharacteristic();

  return Entry->FileKind;
}

/// Return the filename or buffer identifier of the buffer the location is in.
/// Note that this name does not respect \#line directives.  Use getPresumedLoc
/// for normal clients.
StringRef SourceManager::getBufferName(SourceLocation Loc,
                                       bool *Invalid) const {
  if (isInvalid(Loc, Invalid)) return "<invalid loc>";

  return getBuffer(getFileID(Loc), Invalid)->getBufferIdentifier();
}

/// getPresumedLoc - This method returns the "presumed" location of a
/// SourceLocation specifies.  A "presumed location" can be modified by \#line
/// or GNU line marker directives.  This provides a view on the data that a
/// user should see in diagnostics, for example.
///
/// Note that a presumed location is always given as the expansion point of an
/// expansion location, not at the spelling location.
PresumedLoc SourceManager::getPresumedLoc(SourceLocation Loc,
                                          bool UseLineDirectives) const {
  if (Loc.isInvalid()) return PresumedLoc();

  // Presumed locations are always for expansion points.
  std::pair<FileID, unsigned> LocInfo = getDecomposedExpansionLoc(Loc);

  bool Invalid = false;
  const SLocEntry &Entry = getSLocEntry(LocInfo.first, &Invalid);
  if (Invalid || !Entry.isFile())
    return PresumedLoc();

  const SrcMgr::FileInfo &FI = Entry.getFile();
  const SrcMgr::ContentCache *C = FI.getContentCache();

  // To get the source name, first consult the FileEntry (if one exists)
  // before the MemBuffer as this will avoid unnecessarily paging in the
  // MemBuffer.
  FileID FID = LocInfo.first;
  StringRef Filename;
  if (C->OrigEntry)
    Filename = C->OrigEntry->getName();
  else
    Filename = C->getBuffer(Diag, getFileManager())->getBufferIdentifier();

  unsigned LineNo = getLineNumber(LocInfo.first, LocInfo.second, &Invalid);
  if (Invalid)
    return PresumedLoc();
  unsigned ColNo  = getColumnNumber(LocInfo.first, LocInfo.second, &Invalid);
  if (Invalid)
    return PresumedLoc();

  SourceLocation IncludeLoc = FI.getIncludeLoc();

  // If we have #line directives in this file, update and overwrite the physical
  // location info if appropriate.
  if (UseLineDirectives && FI.hasLineDirectives()) {
    assert(LineTable && "Can't have linetable entries without a LineTable!");
    // See if there is a #line directive before this.  If so, get it.
    if (const LineEntry *Entry =
          LineTable->FindNearestLineEntry(LocInfo.first, LocInfo.second)) {
      // If the LineEntry indicates a filename, use it.
      if (Entry->FilenameID != -1) {
        Filename = LineTable->getFilename(Entry->FilenameID);
        // The contents of files referenced by #line are not in the
        // SourceManager
        FID = FileID::get(0);
      }

      // Use the line number specified by the LineEntry.  This line number may
      // be multiple lines down from the line entry.  Add the difference in
      // physical line numbers from the query point and the line marker to the
      // total.
      unsigned MarkerLineNo = getLineNumber(LocInfo.first, Entry->FileOffset);
      LineNo = Entry->LineNo + (LineNo-MarkerLineNo-1);

      // Note that column numbers are not molested by line markers.

      // Handle virtual #include manipulation.
      if (Entry->IncludeOffset) {
        IncludeLoc = getLocForStartOfFile(LocInfo.first);
        IncludeLoc = IncludeLoc.getLocWithOffset(Entry->IncludeOffset);
      }
    }
  }

  return PresumedLoc(Filename.data(), FID, LineNo, ColNo, IncludeLoc);
}

/// Returns whether the PresumedLoc for a given SourceLocation is
/// in the main file.
///
/// This computes the "presumed" location for a SourceLocation, then checks
/// whether it came from a file other than the main file. This is different
/// from isWrittenInMainFile() because it takes line marker directives into
/// account.
bool SourceManager::isInMainFile(SourceLocation Loc) const {
  if (Loc.isInvalid()) return false;

  // Presumed locations are always for expansion points.
  std::pair<FileID, unsigned> LocInfo = getDecomposedExpansionLoc(Loc);

  bool Invalid = false;
  const SLocEntry &Entry = getSLocEntry(LocInfo.first, &Invalid);
  if (Invalid || !Entry.isFile())
    return false;

  const SrcMgr::FileInfo &FI = Entry.getFile();

  // Check if there is a line directive for this location.
  if (FI.hasLineDirectives())
    if (const LineEntry *Entry =
            LineTable->FindNearestLineEntry(LocInfo.first, LocInfo.second))
      if (Entry->IncludeOffset)
        return false;

  return FI.getIncludeLoc().isInvalid();
}

/// The size of the SLocEntry that \p FID represents.
unsigned SourceManager::getFileIDSize(FileID FID) const {
  bool Invalid = false;
  const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
  if (Invalid)
    return 0;

  int ID = FID.ID;
  unsigned NextOffset;
  if ((ID > 0 && unsigned(ID+1) == local_sloc_entry_size()))
    NextOffset = getNextLocalOffset();
  else if (ID+1 == -1)
    NextOffset = MaxLoadedOffset;
  else
    NextOffset = getSLocEntry(FileID::get(ID+1)).getOffset();

  return NextOffset - Entry.getOffset() - 1;
}

//===----------------------------------------------------------------------===//
// Other miscellaneous methods.
//===----------------------------------------------------------------------===//

/// Get the source location for the given file:line:col triplet.
///
/// If the source file is included multiple times, the source location will
/// be based upon an arbitrary inclusion.
SourceLocation SourceManager::translateFileLineCol(const FileEntry *SourceFile,
                                                  unsigned Line,
                                                  unsigned Col) const {
  assert(SourceFile && "Null source file!");
  assert(Line && Col && "Line and column should start from 1!");

  FileID FirstFID = translateFile(SourceFile);
  return translateLineCol(FirstFID, Line, Col);
}

/// Get the FileID for the given file.
///
/// If the source file is included multiple times, the FileID will be the
/// first inclusion.
FileID SourceManager::translateFile(const FileEntry *SourceFile) const {
  assert(SourceFile && "Null source file!");

  // First, check the main file ID, since it is common to look for a
  // location in the main file.
  if (MainFileID.isValid()) {
    bool Invalid = false;
    const SLocEntry &MainSLoc = getSLocEntry(MainFileID, &Invalid);
    if (Invalid)
      return FileID();

    if (MainSLoc.isFile()) {
      const ContentCache *MainContentCache =
          MainSLoc.getFile().getContentCache();
      if (MainContentCache && MainContentCache->OrigEntry == SourceFile)
        return MainFileID;
    }
  }

  // The location we're looking for isn't in the main file; look
  // through all of the local source locations.
  for (unsigned I = 0, N = local_sloc_entry_size(); I != N; ++I) {
    bool Invalid = false;
    const SLocEntry &SLoc = getLocalSLocEntry(I, &Invalid);
    if (Invalid)
      return FileID();

    if (SLoc.isFile() && SLoc.getFile().getContentCache() &&
        SLoc.getFile().getContentCache()->OrigEntry == SourceFile)
      return FileID::get(I);
  }

  // If that still didn't help, try the modules.
  for (unsigned I = 0, N = loaded_sloc_entry_size(); I != N; ++I) {
    const SLocEntry &SLoc = getLoadedSLocEntry(I);
    if (SLoc.isFile() && SLoc.getFile().getContentCache() &&
        SLoc.getFile().getContentCache()->OrigEntry == SourceFile)
      return FileID::get(-int(I) - 2);
  }

  return FileID();
}

/// Get the source location in \arg FID for the given line:col.
/// Returns null location if \arg FID is not a file SLocEntry.
SourceLocation SourceManager::translateLineCol(FileID FID,
                                               unsigned Line,
                                               unsigned Col) const {
  // Lines are used as a one-based index into a zero-based array. This assert
  // checks for possible buffer underruns.
  assert(Line && Col && "Line and column should start from 1!");

  if (FID.isInvalid())
    return SourceLocation();

  bool Invalid = false;
  const SLocEntry &Entry = getSLocEntry(FID, &Invalid);
  if (Invalid)
    return SourceLocation();

  if (!Entry.isFile())
    return SourceLocation();

  SourceLocation FileLoc = SourceLocation::getFileLoc(Entry.getOffset());

  if (Line == 1 && Col == 1)
    return FileLoc;

  ContentCache *Content
    = const_cast<ContentCache *>(Entry.getFile().getContentCache());
  if (!Content)
    return SourceLocation();

  // If this is the first use of line information for this buffer, compute the
  // SourceLineCache for it on demand.
  if (!Content->SourceLineCache) {
    bool MyInvalid = false;
    ComputeLineNumbers(Diag, Content, ContentCacheAlloc, *this, MyInvalid);
    if (MyInvalid)
      return SourceLocation();
  }

  if (Line > Content->NumLines) {
    unsigned Size = Content->getBuffer(Diag, getFileManager())->getBufferSize();
    if (Size > 0)
      --Size;
    return FileLoc.getLocWithOffset(Size);
  }

  const llvm::MemoryBuffer *Buffer = Content->getBuffer(Diag, getFileManager());
  unsigned FilePos = Content->SourceLineCache[Line - 1];
  const char *Buf = Buffer->getBufferStart() + FilePos;
  unsigned BufLength = Buffer->getBufferSize() - FilePos;
  if (BufLength == 0)
    return FileLoc.getLocWithOffset(FilePos);

  unsigned i = 0;

  // Check that the given column is valid.
  while (i < BufLength-1 && i < Col-1 && Buf[i] != '\n' && Buf[i] != '\r')
    ++i;
  return FileLoc.getLocWithOffset(FilePos + i);
}

/// Compute a map of macro argument chunks to their expanded source
/// location. Chunks that are not part of a macro argument will map to an
/// invalid source location. e.g. if a file contains one macro argument at
/// offset 100 with length 10, this is how the map will be formed:
///     0   -> SourceLocation()
///     100 -> Expanded macro arg location
///     110 -> SourceLocation()
void SourceManager::computeMacroArgsCache(MacroArgsMap &MacroArgsCache,
                                          FileID FID) const {
  assert(FID.isValid());

  // Initially no macro argument chunk is present.
  MacroArgsCache.insert(std::make_pair(0, SourceLocation()));

  int ID = FID.ID;
  while (true) {
    ++ID;
    // Stop if there are no more FileIDs to check.
    if (ID > 0) {
      if (unsigned(ID) >= local_sloc_entry_size())
        return;
    } else if (ID == -1) {
      return;
    }

    bool Invalid = false;
    const SrcMgr::SLocEntry &Entry = getSLocEntryByID(ID, &Invalid);
    if (Invalid)
      return;
    if (Entry.isFile()) {
      SourceLocation IncludeLoc = Entry.getFile().getIncludeLoc();
      if (IncludeLoc.isInvalid())
        continue;
      if (!isInFileID(IncludeLoc, FID))
        return; // No more files/macros that may be "contained" in this file.

      // Skip the files/macros of the #include'd file, we only care about macros
      // that lexed macro arguments from our file.
      if (Entry.getFile().NumCreatedFIDs)
        ID += Entry.getFile().NumCreatedFIDs - 1/*because of next ++ID*/;
      continue;
    }

    const ExpansionInfo &ExpInfo = Entry.getExpansion();

    if (ExpInfo.getExpansionLocStart().isFileID()) {
      if (!isInFileID(ExpInfo.getExpansionLocStart(), FID))
        return; // No more files/macros that may be "contained" in this file.
    }

    if (!ExpInfo.isMacroArgExpansion())
      continue;

    associateFileChunkWithMacroArgExp(MacroArgsCache, FID,
                                 ExpInfo.getSpellingLoc(),
                                 SourceLocation::getMacroLoc(Entry.getOffset()),
                                 getFileIDSize(FileID::get(ID)));
  }
}

void SourceManager::associateFileChunkWithMacroArgExp(
                                         MacroArgsMap &MacroArgsCache,
                                         FileID FID,
                                         SourceLocation SpellLoc,
                                         SourceLocation ExpansionLoc,
                                         unsigned ExpansionLength) const {
  if (!SpellLoc.isFileID()) {
    unsigned SpellBeginOffs = SpellLoc.getOffset();
    unsigned SpellEndOffs = SpellBeginOffs + ExpansionLength;

    // The spelling range for this macro argument expansion can span multiple
    // consecutive FileID entries. Go through each entry contained in the
    // spelling range and if one is itself a macro argument expansion, recurse
    // and associate the file chunk that it represents.

    FileID SpellFID; // Current FileID in the spelling range.
    unsigned SpellRelativeOffs;
    std::tie(SpellFID, SpellRelativeOffs) = getDecomposedLoc(SpellLoc);
    while (true) {
      const SLocEntry &Entry = getSLocEntry(SpellFID);
      unsigned SpellFIDBeginOffs = Entry.getOffset();
      unsigned SpellFIDSize = getFileIDSize(SpellFID);
      unsigned SpellFIDEndOffs = SpellFIDBeginOffs + SpellFIDSize;
      const ExpansionInfo &Info = Entry.getExpansion();
      if (Info.isMacroArgExpansion()) {
        unsigned CurrSpellLength;
        if (SpellFIDEndOffs < SpellEndOffs)
          CurrSpellLength = SpellFIDSize - SpellRelativeOffs;
        else
          CurrSpellLength = ExpansionLength;
        associateFileChunkWithMacroArgExp(MacroArgsCache, FID,
                      Info.getSpellingLoc().getLocWithOffset(SpellRelativeOffs),
                      ExpansionLoc, CurrSpellLength);
      }

      if (SpellFIDEndOffs >= SpellEndOffs)
        return; // we covered all FileID entries in the spelling range.

      // Move to the next FileID entry in the spelling range.
      unsigned advance = SpellFIDSize - SpellRelativeOffs + 1;
      ExpansionLoc = ExpansionLoc.getLocWithOffset(advance);
      ExpansionLength -= advance;
      ++SpellFID.ID;
      SpellRelativeOffs = 0;
    }
  }

  assert(SpellLoc.isFileID());

  unsigned BeginOffs;
  if (!isInFileID(SpellLoc, FID, &BeginOffs))
    return;

  unsigned EndOffs = BeginOffs + ExpansionLength;

  // Add a new chunk for this macro argument. A previous macro argument chunk
  // may have been lexed again, so e.g. if the map is
  //     0   -> SourceLocation()
  //     100 -> Expanded loc #1
  //     110 -> SourceLocation()
  // and we found a new macro FileID that lexed from offset 105 with length 3,
  // the new map will be:
  //     0   -> SourceLocation()
  //     100 -> Expanded loc #1
  //     105 -> Expanded loc #2
  //     108 -> Expanded loc #1
  //     110 -> SourceLocation()
  //
  // Since re-lexed macro chunks will always be the same size or less of
  // previous chunks, we only need to find where the ending of the new macro
  // chunk is mapped to and update the map with new begin/end mappings.

  MacroArgsMap::iterator I = MacroArgsCache.upper_bound(EndOffs);
  --I;
  SourceLocation EndOffsMappedLoc = I->second;
  MacroArgsCache[BeginOffs] = ExpansionLoc;
  MacroArgsCache[EndOffs] = EndOffsMappedLoc;
}

/// If \arg Loc points inside a function macro argument, the returned
/// location will be the macro location in which the argument was expanded.
/// If a macro argument is used multiple times, the expanded location will
/// be at the first expansion of the argument.
/// e.g.
///   MY_MACRO(foo);
///             ^
/// Passing a file location pointing at 'foo', will yield a macro location
/// where 'foo' was expanded into.
SourceLocation
SourceManager::getMacroArgExpandedLocation(SourceLocation Loc) const {
  if (Loc.isInvalid() || !Loc.isFileID())
    return Loc;

  FileID FID;
  unsigned Offset;
  std::tie(FID, Offset) = getDecomposedLoc(Loc);
  if (FID.isInvalid())
    return Loc;

  std::unique_ptr<MacroArgsMap> &MacroArgsCache = MacroArgsCacheMap[FID];
  if (!MacroArgsCache) {
    MacroArgsCache = std::make_unique<MacroArgsMap>();
    computeMacroArgsCache(*MacroArgsCache, FID);
  }

  assert(!MacroArgsCache->empty());
  MacroArgsMap::iterator I = MacroArgsCache->upper_bound(Offset);
  --I;

  unsigned MacroArgBeginOffs = I->first;
  SourceLocation MacroArgExpandedLoc = I->second;
  if (MacroArgExpandedLoc.isValid())
    return MacroArgExpandedLoc.getLocWithOffset(Offset - MacroArgBeginOffs);

  return Loc;
}

std::pair<FileID, unsigned>
SourceManager::getDecomposedIncludedLoc(FileID FID) const {
  if (FID.isInvalid())
    return std::make_pair(FileID(), 0);

  // Uses IncludedLocMap to retrieve/cache the decomposed loc.

  using DecompTy = std::pair<FileID, unsigned>;
  auto InsertOp = IncludedLocMap.try_emplace(FID);
  DecompTy &DecompLoc = InsertOp.first->second;
  if (!InsertOp.second)
    return DecompLoc; // already in map.

  SourceLocation UpperLoc;
  bool Invalid = false;
  const SrcMgr::SLocEntry &Entry = getSLocEntry(FID, &Invalid);
  if (!Invalid) {
    if (Entry.isExpansion())
      UpperLoc = Entry.getExpansion().getExpansionLocStart();
    else
      UpperLoc = Entry.getFile().getIncludeLoc();
  }

  if (UpperLoc.isValid())
    DecompLoc = getDecomposedLoc(UpperLoc);

  return DecompLoc;
}

/// Given a decomposed source location, move it up the include/expansion stack
/// to the parent source location.  If this is possible, return the decomposed
/// version of the parent in Loc and return false.  If Loc is the top-level
/// entry, return true and don't modify it.
static bool MoveUpIncludeHierarchy(std::pair<FileID, unsigned> &Loc,
                                   const SourceManager &SM) {
  std::pair<FileID, unsigned> UpperLoc = SM.getDecomposedIncludedLoc(Loc.first);
  if (UpperLoc.first.isInvalid())
    return true; // We reached the top.

  Loc = UpperLoc;
  return false;
}

/// Return the cache entry for comparing the given file IDs
/// for isBeforeInTranslationUnit.
InBeforeInTUCacheEntry &SourceManager::getInBeforeInTUCache(FileID LFID,
                                                            FileID RFID) const {
  // This is a magic number for limiting the cache size.  It was experimentally
  // derived from a small Objective-C project (where the cache filled
  // out to ~250 items).  We can make it larger if necessary.
  enum { MagicCacheSize = 300 };
  IsBeforeInTUCacheKey Key(LFID, RFID);

  // If the cache size isn't too large, do a lookup and if necessary default
  // construct an entry.  We can then return it to the caller for direct
  // use.  When they update the value, the cache will get automatically
  // updated as well.
  if (IBTUCache.size() < MagicCacheSize)
    return IBTUCache[Key];

  // Otherwise, do a lookup that will not construct a new value.
  InBeforeInTUCache::iterator I = IBTUCache.find(Key);
  if (I != IBTUCache.end())
    return I->second;

  // Fall back to the overflow value.
  return IBTUCacheOverflow;
}

/// Determines the order of 2 source locations in the translation unit.
///
/// \returns true if LHS source location comes before RHS, false otherwise.
bool SourceManager::isBeforeInTranslationUnit(SourceLocation LHS,
                                              SourceLocation RHS) const {
  assert(LHS.isValid() && RHS.isValid() && "Passed invalid source location!");
  if (LHS == RHS)
    return false;

  std::pair<FileID, unsigned> LOffs = getDecomposedLoc(LHS);
  std::pair<FileID, unsigned> ROffs = getDecomposedLoc(RHS);

  // getDecomposedLoc may have failed to return a valid FileID because, e.g. it
  // is a serialized one referring to a file that was removed after we loaded
  // the PCH.
  if (LOffs.first.isInvalid() || ROffs.first.isInvalid())
    return LOffs.first.isInvalid() && !ROffs.first.isInvalid();

  std::pair<bool, bool> InSameTU = isInTheSameTranslationUnit(LOffs, ROffs);
  if (InSameTU.first)
    return InSameTU.second;

  // If we arrived here, the location is either in a built-ins buffer or
  // associated with global inline asm. PR5662 and PR22576 are examples.

  StringRef LB = getBuffer(LOffs.first)->getBufferIdentifier();
  StringRef RB = getBuffer(ROffs.first)->getBufferIdentifier();
  bool LIsBuiltins = LB == "<built-in>";
  bool RIsBuiltins = RB == "<built-in>";
  // Sort built-in before non-built-in.
  if (LIsBuiltins || RIsBuiltins) {
    if (LIsBuiltins != RIsBuiltins)
      return LIsBuiltins;
    // Both are in built-in buffers, but from different files. We just claim that
    // lower IDs come first.
    return LOffs.first < ROffs.first;
  }
  bool LIsAsm = LB == "<inline asm>";
  bool RIsAsm = RB == "<inline asm>";
  // Sort assembler after built-ins, but before the rest.
  if (LIsAsm || RIsAsm) {
    if (LIsAsm != RIsAsm)
      return RIsAsm;
    assert(LOffs.first == ROffs.first);
    return false;
  }
  bool LIsScratch = LB == "<scratch space>";
  bool RIsScratch = RB == "<scratch space>";
  // Sort scratch after inline asm, but before the rest.
  if (LIsScratch || RIsScratch) {
    if (LIsScratch != RIsScratch)
      return LIsScratch;
    return LOffs.second < ROffs.second;
  }
  llvm_unreachable("Unsortable locations found");
}

std::pair<bool, bool> SourceManager::isInTheSameTranslationUnit(
    std::pair<FileID, unsigned> &LOffs,
    std::pair<FileID, unsigned> &ROffs) const {
  // If the source locations are in the same file, just compare offsets.
  if (LOffs.first == ROffs.first)
    return std::make_pair(true, LOffs.second < ROffs.second);

  // If we are comparing a source location with multiple locations in the same
  // file, we get a big win by caching the result.
  InBeforeInTUCacheEntry &IsBeforeInTUCache =
    getInBeforeInTUCache(LOffs.first, ROffs.first);

  // If we are comparing a source location with multiple locations in the same
  // file, we get a big win by caching the result.
  if (IsBeforeInTUCache.isCacheValid(LOffs.first, ROffs.first))
    return std::make_pair(
        true, IsBeforeInTUCache.getCachedResult(LOffs.second, ROffs.second));

  // Okay, we missed in the cache, start updating the cache for this query.
  IsBeforeInTUCache.setQueryFIDs(LOffs.first, ROffs.first,
                          /*isLFIDBeforeRFID=*/LOffs.first.ID < ROffs.first.ID);

  // We need to find the common ancestor. The only way of doing this is to
  // build the complete include chain for one and then walking up the chain
  // of the other looking for a match.
  // We use a map from FileID to Offset to store the chain. Easier than writing
  // a custom set hash info that only depends on the first part of a pair.
  using LocSet = llvm::SmallDenseMap<FileID, unsigned, 16>;
  LocSet LChain;
  do {
    LChain.insert(LOffs);
    // We catch the case where LOffs is in a file included by ROffs and
    // quit early. The other way round unfortunately remains suboptimal.
  } while (LOffs.first != ROffs.first && !MoveUpIncludeHierarchy(LOffs, *this));
  LocSet::iterator I;
  while((I = LChain.find(ROffs.first)) == LChain.end()) {
    if (MoveUpIncludeHierarchy(ROffs, *this))
      break; // Met at topmost file.
  }
  if (I != LChain.end())
    LOffs = *I;

  // If we exited because we found a nearest common ancestor, compare the
  // locations within the common file and cache them.
  if (LOffs.first == ROffs.first) {
    IsBeforeInTUCache.setCommonLoc(LOffs.first, LOffs.second, ROffs.second);
    return std::make_pair(
        true, IsBeforeInTUCache.getCachedResult(LOffs.second, ROffs.second));
  }
  // Clear the lookup cache, it depends on a common location.
  IsBeforeInTUCache.clear();
  return std::make_pair(false, false);
}

void SourceManager::PrintStats() const {
  llvm::errs() << "\n*** Source Manager Stats:\n";
  llvm::errs() << FileInfos.size() << " files mapped, " << MemBufferInfos.size()
               << " mem buffers mapped.\n";
  llvm::errs() << LocalSLocEntryTable.size() << " local SLocEntry's allocated ("
               << llvm::capacity_in_bytes(LocalSLocEntryTable)
               << " bytes of capacity), "
               << NextLocalOffset << "B of Sloc address space used.\n";
  llvm::errs() << LoadedSLocEntryTable.size()
               << " loaded SLocEntries allocated, "
               << MaxLoadedOffset - CurrentLoadedOffset
               << "B of Sloc address space used.\n";

  unsigned NumLineNumsComputed = 0;
  unsigned NumFileBytesMapped = 0;
  for (fileinfo_iterator I = fileinfo_begin(), E = fileinfo_end(); I != E; ++I){
    NumLineNumsComputed += I->second->SourceLineCache != nullptr;
    NumFileBytesMapped  += I->second->getSizeBytesMapped();
  }
  unsigned NumMacroArgsComputed = MacroArgsCacheMap.size();

  llvm::errs() << NumFileBytesMapped << " bytes of files mapped, "
               << NumLineNumsComputed << " files with line #'s computed, "
               << NumMacroArgsComputed << " files with macro args computed.\n";
  llvm::errs() << "FileID scans: " << NumLinearScans << " linear, "
               << NumBinaryProbes << " binary.\n";
}

LLVM_DUMP_METHOD void SourceManager::dump() const {
  llvm::raw_ostream &out = llvm::errs();

  auto DumpSLocEntry = [&](int ID, const SrcMgr::SLocEntry &Entry,
                           llvm::Optional<unsigned> NextStart) {
    out << "SLocEntry <FileID " << ID << "> " << (Entry.isFile() ? "file" : "expansion")
        << " <SourceLocation " << Entry.getOffset() << ":";
    if (NextStart)
      out << *NextStart << ">\n";
    else
      out << "???\?>\n";
    if (Entry.isFile()) {
      auto &FI = Entry.getFile();
      if (FI.NumCreatedFIDs)
        out << "  covers <FileID " << ID << ":" << int(ID + FI.NumCreatedFIDs)
            << ">\n";
      if (FI.getIncludeLoc().isValid())
        out << "  included from " << FI.getIncludeLoc().getOffset() << "\n";
      if (auto *CC = FI.getContentCache()) {
        out << "  for " << (CC->OrigEntry ? CC->OrigEntry->getName() : "<none>")
            << "\n";
        if (CC->BufferOverridden)
          out << "  contents overridden\n";
        if (CC->ContentsEntry != CC->OrigEntry) {
          out << "  contents from "
              << (CC->ContentsEntry ? CC->ContentsEntry->getName() : "<none>")
              << "\n";
        }
      }
    } else {
      auto &EI = Entry.getExpansion();
      out << "  spelling from " << EI.getSpellingLoc().getOffset() << "\n";
      out << "  macro " << (EI.isMacroArgExpansion() ? "arg" : "body")
          << " range <" << EI.getExpansionLocStart().getOffset() << ":"
          << EI.getExpansionLocEnd().getOffset() << ">\n";
    }
  };

  // Dump local SLocEntries.
  for (unsigned ID = 0, NumIDs = LocalSLocEntryTable.size(); ID != NumIDs; ++ID) {
    DumpSLocEntry(ID, LocalSLocEntryTable[ID],
                  ID == NumIDs - 1 ? NextLocalOffset
                                   : LocalSLocEntryTable[ID + 1].getOffset());
  }
  // Dump loaded SLocEntries.
  llvm::Optional<unsigned> NextStart;
  for (unsigned Index = 0; Index != LoadedSLocEntryTable.size(); ++Index) {
    int ID = -(int)Index - 2;
    if (SLocEntryLoaded[Index]) {
      DumpSLocEntry(ID, LoadedSLocEntryTable[Index], NextStart);
      NextStart = LoadedSLocEntryTable[Index].getOffset();
    } else {
      NextStart = None;
    }
  }
}

ExternalSLocEntrySource::~ExternalSLocEntrySource() = default;

/// Return the amount of memory used by memory buffers, breaking down
/// by heap-backed versus mmap'ed memory.
SourceManager::MemoryBufferSizes SourceManager::getMemoryBufferSizes() const {
  size_t malloc_bytes = 0;
  size_t mmap_bytes = 0;

  for (unsigned i = 0, e = MemBufferInfos.size(); i != e; ++i)
    if (size_t sized_mapped = MemBufferInfos[i]->getSizeBytesMapped())
      switch (MemBufferInfos[i]->getMemoryBufferKind()) {
        case llvm::MemoryBuffer::MemoryBuffer_MMap:
          mmap_bytes += sized_mapped;
          break;
        case llvm::MemoryBuffer::MemoryBuffer_Malloc:
          malloc_bytes += sized_mapped;
          break;
      }

  return MemoryBufferSizes(malloc_bytes, mmap_bytes);
}

size_t SourceManager::getDataStructureSizes() const {
  size_t size = llvm::capacity_in_bytes(MemBufferInfos)
    + llvm::capacity_in_bytes(LocalSLocEntryTable)
    + llvm::capacity_in_bytes(LoadedSLocEntryTable)
    + llvm::capacity_in_bytes(SLocEntryLoaded)
    + llvm::capacity_in_bytes(FileInfos);

  if (OverriddenFilesInfo)
    size += llvm::capacity_in_bytes(OverriddenFilesInfo->OverriddenFiles);

  return size;
}

SourceManagerForFile::SourceManagerForFile(StringRef FileName,
                                           StringRef Content) {
  // This is referenced by `FileMgr` and will be released by `FileMgr` when it
  // is deleted.
  IntrusiveRefCntPtr<llvm::vfs::InMemoryFileSystem> InMemoryFileSystem(
      new llvm::vfs::InMemoryFileSystem);
  InMemoryFileSystem->addFile(
      FileName, 0,
      llvm::MemoryBuffer::getMemBuffer(Content, FileName,
                                       /*RequiresNullTerminator=*/false));
  // This is passed to `SM` as reference, so the pointer has to be referenced
  // in `Environment` so that `FileMgr` can out-live this function scope.
  FileMgr =
      std::make_unique<FileManager>(FileSystemOptions(), InMemoryFileSystem);
  // This is passed to `SM` as reference, so the pointer has to be referenced
  // by `Environment` due to the same reason above.
  Diagnostics = std::make_unique<DiagnosticsEngine>(
      IntrusiveRefCntPtr<DiagnosticIDs>(new DiagnosticIDs),
      new DiagnosticOptions);
  SourceMgr = std::make_unique<SourceManager>(*Diagnostics, *FileMgr);
  FileID ID = SourceMgr->createFileID(*FileMgr->getFile(FileName),
                                      SourceLocation(), clang::SrcMgr::C_User);
  assert(ID.isValid());
  SourceMgr->setMainFileID(ID);
}
